/*
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 *  Copyright (C) 2000 - 2005 Liam Girdwood <lgirdwood@gmail.com>
 *
 *  The functions in this file use the Lunar Solution ELP 2000-82B by
 *  Michelle Chapront-Touze and Jean Chapront.
 */

#include <math.h>
#include <libnova/lunar.h>
#include <libnova/vsop87.h>
#include <libnova/solar.h>
#include <libnova/earth.h>
#include <libnova/transform.h>
#include <libnova/rise_set.h>
#include <libnova/utility.h>

#ifdef HAVE_LIBsunmath
#include <sunmath.h>
#endif

/* AU in KM */
#define AU			149597870

/* sequence sizes */
#define ELP1_SIZE	1023  	  	/* Main problem. Longitude periodic terms (sine) */
#define ELP2_SIZE	918    		/* Main problem. Latitude (sine) */
#define ELP3_SIZE	704    		/* Main problem. Distance (cosine) */
#define ELP4_SIZE	347    		/* Earth figure perturbations. Longitude */
#define ELP5_SIZE	316   		/* Earth figure perturbations. Latitude */
#define ELP6_SIZE	237    		/* Earth figure perturbations. Distance */
#define ELP7_SIZE	14    		/* Earth figure perturbations. Longitude/t */
#define ELP8_SIZE	11    		/* Earth figure perturbations. Latitude/t */
#define ELP9_SIZE	8    		/* Earth figure perturbations. Distance/t */
#define ELP10_SIZE	14328    	/* Planetary perturbations. Table 1 Longitude */
#define ELP11_SIZE	5233    	/* Planetary perturbations. Table 1 Latitude */
#define ELP12_SIZE	6631    	/* Planetary perturbations. Table 1 Distance */
#define ELP13_SIZE	4384    	/* Planetary perturbations. Table 1 Longitude/t */
#define ELP14_SIZE	833    		/* Planetary perturbations. Table 1 Latitude/t */
#define ELP15_SIZE	1715    	/* Planetary perturbations. Table 1 Distance/t */
#define ELP16_SIZE	170    		/* Planetary perturbations. Table 2 Longitude */
#define ELP17_SIZE	150    		/* Planetary perturbations. Table 2 Latitude */
#define ELP18_SIZE	114    		/* Planetary perturbations. Table 2 Distance */
#define ELP19_SIZE	226    		/* Planetary perturbations. Table 2 Longitude/t */
#define ELP20_SIZE	188    		/* Planetary perturbations. Table 2 Latitude/t */
#define ELP21_SIZE	169    		/* Planetary perturbations. Table 2 Distance/t */
#define ELP22_SIZE	3    		/* Tidal effects. Longitude */
#define ELP23_SIZE	2    		/* Tidal effects. Latitude */
#define ELP24_SIZE	2    		/* Tidal effects. Distance */
#define ELP25_SIZE	6    		/* Tidal effects. Longitude/t */
#define ELP26_SIZE	4    		/* Tidal effects. Latitude/t */
#define ELP27_SIZE	5    		/* Tidal effects. Distance/t */
#define ELP28_SIZE	20    		/* Moon figure perturbations. Longitude */
#define ELP29_SIZE	12    		/* Moon figure perturbations. Latitude */
#define ELP30_SIZE	14    		/* Moon figure perturbations. Distance */
#define ELP31_SIZE	11    		/* Relativistic perturbations. Longitude */
#define ELP32_SIZE	4    		/* Relativistic perturbations. Latitude */
#define ELP33_SIZE	10    		/* Relativistic perturbations. Distance */
#define ELP34_SIZE	28    		/* Planetary perturbations - solar eccentricity. Longitude/t2 */
#define ELP35_SIZE	13    		/* Planetary perturbations - solar eccentricity. Latitude/t2 */
#define ELP36_SIZE	19    		/* Planetary perturbations - solar eccentricity. Distance/t2 */


/* Chapront theory lunar constants */
#define 	RAD		(648000.0 / M_PI)
#define		DEG		(M_PI / 180.0)
#define		M_PI2 	(2.0 * M_PI)
#define		PIS2	(M_PI / 2.0)
#define 	ATH		384747.9806743165
#define 	A0		384747.9806448954
#define		AM	 	0.074801329518
#define		ALPHA 	0.002571881335
#define		DTASM	(2.0 * ALPHA / (3.0 * AM))
#define		W12		(1732559343.73604 / RAD)
#define		PRECES	(5029.0966 / RAD)
#define		C1		60.0
#define		C2		3600.0

/* Corrections of the constants for DE200/LE200 */
#define		DELNU	((0.55604 / RAD) / W12)
#define		DELE	(0.01789 / RAD)
#define		DELG	(-0.08066 / RAD)
#define		DELNP	((-0.06424 / RAD) / W12)
#define 	DELEP	(-0.12879 / RAD)

/*     Precession matrix */
#define		P1		0.10180391e-4
#define		P2		0.47020439e-6
#define		P3		-0.5417367e-9
#define		P4		-0.2507948e-11
#define		P5		0.463486e-14
#define		Q1		-0.113469002e-3
#define		Q2		0.12372674e-6
#define		Q3		0.1265417e-8
#define		Q4		-0.1371808e-11
#define		Q5		-0.320334e-14

/* used for elp1 - 3 */
struct main_problem
{
	int ilu[4];
	double A;
	double B[5];
};

/* used for elp 4 - 9 */
struct earth_pert
{
	int iz;
	int ilu[4];
	double O;
	double A;
	double P;
}; 

/* used for elp 10 - 21 */
struct planet_pert
{
	int ipla[11];
	double theta;
	double O;
	double P;
};

typedef struct earth_pert tidal_effects;
typedef struct earth_pert moon_pert;
typedef struct earth_pert rel_pert;
typedef struct earth_pert plan_sol_pert;
 
/* initialise lunar constants */
void init_lunar_constants ();

/* cache values */
static double c_JD = 0;
static double c_X = 0;
static double c_Y = 0;
static double c_Z = 0;
static double c_precision = 1.0;

/* constants with corrections for DE200 / LE200 */
static const double W1[5] = 
{
	((218.0 + (18.0 / 60.0) + (59.95571 / 3600.0))) * DEG,
	1732559343.73604 / RAD,
	-5.8883 / RAD,
	0.006604 / RAD,
	-0.00003169 / RAD
}; 

static const double W2[5] = 
{
	((83.0 + (21.0 / 60.0) + (11.67475 / 3600.0))) * DEG,
	14643420.2632 / RAD,
	-38.2776 /  RAD,
	-0.045047 / RAD,
	0.00021301 / RAD
};

static const double W3[5] = 
{
	(125.0 + (2.0 / 60.0) + (40.39816 / 3600.0)) * DEG,
	-6967919.3622 / RAD,
	6.3622 / RAD,
	0.007625 / RAD,
	-0.00003586 / RAD
};

static const double earth[5] = 
{
	(100.0 + (27.0 / 60.0) + (59.22059 / 3600.0)) * DEG,
	129597742.2758 / RAD,
	-0.0202 / RAD,
	0.000009 / RAD,
	0.00000015 / RAD	
};

static const double peri[5] =
{
	(102.0 + (56.0 / 60.0) + (14.42753 / 3600.0)) * DEG,
	1161.2283 / RAD,
	0.5327 / RAD,
	-0.000138 / RAD,
	0
};

/* Delaunay's arguments.*/
static const double del[4][5] = {
	{ 5.198466741027443, 7771.377146811758394, -0.000028449351621, 0.000000031973462, -0.000000000154365 },
	{ -0.043125180208125, 628.301955168488007, -0.000002680534843, 0.000000000712676, 0.000000000000727 },
	{ 2.355555898265799, 8328.691426955554562, 0.000157027757616, 0.000000250411114, -0.000000001186339 },
	{ 1.627905233371468, 8433.466158130539043, -0.000059392100004, -0.000000004949948, 0.000000000020217 }
};


static const double zeta[2] = 
{
	(218.0 + (18.0 / 60.0) + (59.95571 / 3600.0)) * DEG, 
	((1732559343.73604 / RAD) + PRECES)
};


/* Planetary arguments */
static const double p[8][2] = 
{
	{(252 + 15 / C1 + 3.25986 / C2 ) * DEG, 538101628.68898 / RAD },
	{(181 + 58 / C1 + 47.28305 / C2) * DEG, 210664136.43355 / RAD },
	{(100.0 + (27.0 / 60.0) + (59.22059 / 3600.0)) * DEG, 129597742.2758 / RAD},
	{(355 + 25 / C1 + 59.78866 / C2) * DEG, 68905077.59284 / RAD },
	{(34 + 21 / C1 + 5.34212 / C2) * DEG, 10925660.42861 / RAD },
	{(50 + 4 / C1 + 38.89694 / C2) * DEG, 4399609.65932 / RAD },
	{(314 + 3 / C1 + 18.01841 / C2) * DEG, 1542481.19393 / RAD },
	{(304 + 20 / C1 + 55.19575 / C2) * DEG, 786550.32074 / RAD }
};

/* precision */
static double pre[3];

/* ELP 2000-82B Arguments */
static const struct main_problem main_elp1[ELP1_SIZE] = 
{
	{{0, 0, 0, 2}, -411.602870, {168.480000, -18433.810000, -121.620000, 0.400000, -0.180000}},
	{{0, 0, 0, 4}, 0.420340, {-0.390000, 37.650000, 0.570000, 0.000000, 0.000000}},
	{{0, 0, 0, 6}, -0.000590, {0.000000, -0.080000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 1, -6}, 0.000160, {0.000000, 0.020000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 1, -4}, -0.080190, {0.770000, -7.220000, -1.460000, 0.000000, 0.000000}},
	{{0, 0, 1, -2}, 39.533930, {-395.240000, 1788.330000, 720.910000, -2.600000, 0.900000}},
	{{0, 0, 1, 0}, 22639.550000, {0.000000, 0.000000, 412529.610000, 0.000000, 0.000000}},
	{{0, 0, 1, 2}, -45.100320, {17.410000, -2019.780000, -830.200000, 0.090000, -0.020000}},
	{{0, 0, 1, 4}, 0.090920, {-0.070000, 8.140000, 1.730000, 0.000000, 0.000000}},
	{{0, 0, 1, 6}, -0.000190, {0.000000, -0.020000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 2, -4}, 0.000680, {0.070000, 0.060000, 0.030000, 0.000000, 0.000000}},
	{{0, 0, 2, -2}, -1.372590, {-7.580000, -62.490000, -50.120000, -0.070000, 0.000000}},
	{{0, 0, 2, 0}, 769.023260, {-257.510000, -47.390000, 28008.990000, -6.830000, -0.560000}},
	{{0, 0, 2, 2}, -3.997670, {2.400000, -178.940000, -146.180000, 0.050000, 0.000000}},
	{{0, 0, 2, 4}, 0.012970, {-0.010000, 1.160000, 0.480000, 0.000000, 0.000000}},
	{{0, 0, 2, 6}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 3, -4}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 3, -2}, -0.056840, {0.380000, -2.650000, -3.130000, 0.000000, 0.000000}},
	{{0, 0, 3, 0}, 36.123640, {-28.420000, -5.100000, 1972.740000, -0.930000, -0.080000}},
	{{0, 0, 3, 2}, -0.328660, {0.320000, -14.700000, -17.990000, 0.000000, 0.000000}},
	{{0, 0, 3, 4}, 0.001530, {0.000000, 0.140000, 0.080000, 0.000000, 0.000000}},
	{{0, 0, 4, -2}, -0.003540, {0.040000, -0.170000, -0.260000, 0.000000, 0.000000}},
	{{0, 0, 4, 0}, 1.933670, {-2.650000, -0.440000, 140.750000, -0.100000, 0.000000}},
	{{0, 0, 4, 2}, -0.026020, {0.040000, -1.160000, -1.900000, 0.000000, 0.000000}},
	{{0, 0, 4, 4}, 0.000160, {0.000000, 0.010000, 0.010000, 0.000000, 0.000000}},
	{{0, 0, 5, -2}, -0.000230, {0.000000, -0.010000, -0.020000, 0.000000, 0.000000}},
	{{0, 0, 5, 0}, 0.111000, {-0.230000, -0.040000, 10.100000, 0.000000, 0.000000}},
	{{0, 0, 5, 2}, -0.002010, {0.000000, -0.090000, -0.180000, 0.000000, 0.000000}},
	{{0, 0, 5, 4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 6, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 6, 0}, 0.006650, {-0.020000, 0.000000, 0.730000, 0.000000, 0.000000}},
	{{0, 0, 6, 2}, -0.000150, {0.000000, 0.000000, -0.020000, 0.000000, 0.000000}},
	{{0, 0, 7, 0}, 0.000410, {0.000000, 0.000000, 0.050000, 0.000000, 0.000000}},
	{{0, 0, 7, 2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 8, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -7, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -6, 0}, -0.000240, {0.000000, 0.000000, -0.030000, -0.010000, 0.000000}},
	{{0, 1, -5, -2}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -5, 0}, -0.003320, {-0.070000, 0.000000, -0.300000, -0.200000, 0.000000}},
	{{0, 1, -4, -2}, 0.000640, {0.010000, 0.030000, 0.050000, 0.040000, 0.000000}},
	{{0, 1, -4, 0}, -0.047020, {-1.040000, 0.030000, -3.420000, -2.820000, 0.000000}},
	{{0, 1, -4, 2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -3, -4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -3, -2}, 0.006230, {0.140000, 0.280000, 0.340000, 0.370000, 0.000000}},
	{{0, 1, -3, 0}, -0.669400, {-15.550000, 0.380000, -36.530000, -40.100000, -0.020000}},
	{{0, 1, -3, 2}, 0.001060, {0.020000, 0.050000, 0.060000, 0.070000, 0.000000}},
	{{0, 1, -2, -4}, -0.000170, {0.000000, -0.020000, 0.000000, -0.010000, 0.000000}},
	{{0, 1, -2, -2}, 0.051650, {1.170000, 2.290000, 1.890000, 3.090000, 0.000000}},
	{{0, 1, -2, 0}, -9.679380, {-235.290000, 4.900000, -352.520000, -579.940000, -0.150000}},
	{{0, 1, -2, 2}, 0.024290, {0.740000, 1.090000, 0.890000, 1.460000, 0.000000}},
	{{0, 1, -2, 4}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -1, -4}, -0.000630, {-0.010000, -0.060000, -0.010000, -0.040000, 0.000000}},
	{{0, 1, -1, -2}, 0.301570, {6.600000, 13.340000, 5.610000, 18.070000, 0.000000}},
	{{0, 1, -1, 0}, -147.326540, {-3778.620000, 68.680000, -2688.530000, -8829.170000, -0.760000}},
	{{0, 1, -1, 2}, -0.080490, {0.250000, -3.630000, -1.390000, -4.820000, -0.010000}},
	{{0, 1, -1, 4}, 0.000130, {0.000000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 0, -4}, -0.000230, {0.010000, -0.020000, 0.000000, -0.010000, 0.000000}},
	{{0, 1, 0, -2}, 0.075010, {-6.720000, 3.040000, 0.850000, 4.460000, 0.000000}},
	{{0, 1, 0, 0}, -666.441860, {-5206.840000, 258.790000, -555.980000, -39887.790000, 1.730000}},
	{{0, 1, 0, 2}, 0.413420, {1.500000, 18.150000, 1.190000, 24.720000, 0.010000}},
	{{0, 1, 0, 4}, -0.000830, {0.000000, -0.070000, 0.000000, -0.050000, 0.000000}},
	{{0, 1, 1, -4}, 0.000110, {0.000000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 1, -2}, -0.082820, {1.730000, -3.730000, -1.500000, -4.950000, 0.000000}},
	{{0, 1, 1, 0}, -109.384190, {-2193.780000, 51.640000, -2018.130000, -6556.100000, 0.540000}},
	{{0, 1, 1, 2}, 0.263380, {4.530000, 11.650000, 5.030000, 15.780000, 0.000000}},
	{{0, 1, 1, 4}, -0.000620, {0.000000, -0.060000, -0.010000, -0.040000, 0.000000}},
	{{0, 1, 2, -4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 2, -2}, 0.026770, {1.100000, 1.200000, 0.970000, 1.600000, 0.000000}},
	{{0, 1, 2, 0}, -7.630410, {-156.070000, 4.090000, -279.890000, -457.410000, 0.120000}},
	{{0, 1, 2, 2}, 0.043380, {0.810000, 1.920000, 1.610000, 2.600000, 0.000000}},
	{{0, 1, 2, 4}, -0.000150, {0.000000, -0.010000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 3, -2}, 0.001660, {0.060000, 0.080000, 0.090000, 0.100000, 0.000000}},
	{{0, 1, 3, 0}, -0.545940, {-11.180000, 0.340000, -29.970000, -32.730000, 0.010000}},
	{{0, 1, 3, 2}, 0.005260, {0.100000, 0.230000, 0.290000, 0.320000, 0.000000}},
	{{0, 1, 3, 4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 4, -2}, 0.000140, {0.000000, 0.000000, 0.010000, 0.000000, 0.000000}},
	{{0, 1, 4, 0}, -0.039470, {-0.800000, 0.030000, -2.890000, -2.370000, 0.000000}},
	{{0, 1, 4, 2}, 0.000550, {0.010000, 0.020000, 0.040000, 0.030000, 0.000000}},
	{{0, 1, 5, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 5, 0}, -0.002870, {-0.060000, 0.000000, -0.260000, -0.170000, 0.000000}},
	{{0, 1, 5, 2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 6, 0}, -0.000210, {0.000000, 0.000000, -0.020000, -0.010000, 0.000000}},
	{{0, 1, 7, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -5, 0}, -0.000090, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{0, 2, -4, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -4, 0}, -0.001190, {-0.040000, 0.000000, -0.090000, -0.140000, 0.000000}},
	{{0, 2, -3, -2}, 0.000140, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{0, 2, -3, 0}, -0.015140, {-0.500000, 0.010000, -0.830000, -1.810000, 0.000000}},
	{{0, 2, -3, 2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -2, -2}, 0.001000, {0.030000, 0.040000, 0.040000, 0.120000, 0.000000}},
	{{0, 2, -2, 0}, -0.193110, {-6.230000, 0.130000, -7.040000, -23.130000, 0.000000}},
	{{0, 2, -2, 2}, 0.000600, {0.020000, 0.030000, 0.020000, 0.070000, 0.000000}},
	{{0, 2, -1, -2}, 0.004730, {0.120000, 0.210000, 0.090000, 0.570000, 0.000000}},
	{{0, 2, -1, 0}, -2.568130, {-81.060000, 1.440000, -46.940000, -307.620000, 0.000000}},
	{{0, 2, -1, 2}, 0.000130, {0.050000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{0, 2, 0, -2}, -0.003550, {-0.260000, -0.160000, 0.020000, -0.420000, 0.000000}},
	{{0, 2, 0, 0}, -7.448040, {-12.640000, 2.980000, -9.320000, -891.270000, 0.030000}},
	{{0, 2, 0, 2}, 0.005190, {-0.030000, 0.230000, 0.020000, 0.620000, 0.000000}},
	{{0, 2, 0, 4}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 1, -2}, -0.000400, {0.080000, -0.020000, 0.000000, -0.050000, 0.000000}},
	{{0, 2, 1, 0}, -1.161770, {-19.750000, 0.430000, -21.520000, -139.130000, 0.000000}},
	{{0, 2, 1, 2}, 0.002700, {0.030000, 0.120000, 0.050000, 0.320000, 0.000000}},
	{{0, 2, 2, -2}, 0.000400, {0.020000, 0.020000, 0.020000, 0.050000, 0.000000}},
	{{0, 2, 2, 0}, -0.065130, {-0.790000, 0.020000, -2.390000, -7.800000, 0.000000}},
	{{0, 2, 2, 2}, 0.000350, {0.000000, 0.020000, 0.010000, 0.040000, 0.000000}},
	{{0, 2, 3, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 3, 0}, -0.003410, {0.000000, 0.000000, -0.190000, -0.410000, 0.000000}},
	{{0, 2, 3, 2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 4, 0}, -0.000150, {0.000000, 0.000000, -0.010000, -0.020000, 0.000000}},
	{{0, 3, -4, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -3, 0}, -0.000350, {-0.010000, 0.000000, -0.020000, -0.060000, 0.000000}},
	{{0, 3, -2, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -2, 0}, -0.004160, {-0.150000, 0.000000, -0.150000, -0.750000, 0.000000}},
	{{0, 3, -2, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -1, -2}, 0.000080, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{0, 3, -1, 0}, -0.051420, {-1.820000, 0.030000, -0.940000, -9.240000, 0.000000}},
	{{0, 3, -1, 2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, 0, -2}, -0.000160, {0.000000, 0.000000, 0.000000, -0.030000, 0.000000}},
	{{0, 3, 0, 0}, -0.101360, {1.160000, 0.040000, -0.200000, -18.190000, 0.000000}},
	{{0, 3, 0, 2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{0, 3, 1, 0}, -0.017960, {-0.300000, 0.000000, -0.330000, -3.230000, 0.000000}},
	{{0, 3, 1, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, 2, 0}, -0.000950, {-0.010000, 0.000000, -0.030000, -0.170000, 0.000000}},
	{{0, 3, 3, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 4, -2, 0}, -0.000090, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{0, 4, -1, 0}, -0.001080, {-0.040000, 0.000000, -0.020000, -0.260000, 0.000000}},
	{{0, 4, 0, 0}, -0.001280, {0.060000, 0.000000, 0.000000, -0.300000, 0.000000}},
	{{0, 4, 1, 0}, -0.000320, {0.000000, 0.000000, 0.000000, -0.080000, 0.000000}},
	{{0, 4, 2, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 5, -1, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -4, 0, 0}, 0.000110, {0.000000, 0.000000, 0.000000, 0.030000, 0.040000}},
	{{1, -3, -2, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -3, -1, 0}, 0.000200, {0.000000, 0.000000, 0.000000, 0.040000, 0.080000}},
	{{1, -3, 0, 0}, 0.002540, {0.030000, 0.000000, 0.000000, 0.450000, 0.990000}},
	{{1, -3, 1, 0}, 0.000070, {0.000000, 0.000000, 0.000000, 0.010000, 0.030000}},
	{{1, -3, 2, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -2, -3, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, -2, -2, 0}, 0.000250, {0.000000, 0.000000, 0.010000, 0.030000, 0.100000}},
	{{1, -2, -1, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{1, -2, -1, 0}, 0.002290, {0.060000, 0.000000, 0.050000, 0.270000, 0.890000}},
	{{1, -2, 0, -2}, -0.000320, {0.000000, -0.010000, 0.000000, -0.040000, -0.120000}},
	{{1, -2, 0, 0}, 0.043040, {-0.010000, 0.000000, 0.060000, 5.140000, 16.740000}},
	{{1, -2, 0, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{1, -2, 1, -2}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{1, -2, 1, 0}, -0.000330, {-0.160000, 0.000000, -0.010000, -0.040000, -0.130000}},
	{{1, -2, 2, 0}, -0.000370, {-0.030000, 0.000000, -0.020000, -0.040000, -0.140000}},
	{{1, -2, 3, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{1, -1, -5, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, -4, 0}, 0.000140, {0.000000, 0.000000, 0.010000, 0.000000, 0.050000}},
	{{1, -1, -3, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, -3, 0}, 0.000690, {0.020000, 0.000000, 0.040000, 0.040000, 0.270000}},
	{{1, -1, -3, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, -2, -2}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{1, -1, -2, 0}, -0.006940, {-0.250000, 0.000000, -0.230000, -0.420000, -2.700000}},
	{{1, -1, -2, 2}, 0.000130, {0.000000, 0.000000, 0.000000, 0.000000, 0.050000}},
	{{1, -1, -1, -2}, -0.001000, {0.000000, -0.040000, -0.020000, -0.060000, -0.390000}},
	{{1, -1, -1, 0}, -0.136360, {-3.240000, 0.190000, -2.410000, -8.170000, -53.020000}},
	{{1, -1, -1, 2}, 0.000130, {0.000000, 0.000000, 0.000000, 0.000000, 0.050000}},
	{{1, -1, 0, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, 0, -2}, -0.012810, {-0.130000, -0.570000, 0.000000, -0.770000, -4.980000}},
	{{1, -1, 0, 0}, -0.556940, {-40.230000, 1.700000, -0.010000, -33.620000, -216.550000}},
	{{1, -1, 0, 2}, 0.001550, {0.090000, 0.070000, 0.000000, 0.090000, 0.600000}},
	{{1, -1, 1, -2}, -0.002120, {-0.020000, -0.090000, -0.040000, -0.130000, -0.830000}},
	{{1, -1, 1, 0}, -0.120730, {-6.320000, 0.250000, -2.380000, -7.230000, -46.940000}},
	{{1, -1, 1, 2}, 0.000600, {0.030000, 0.030000, 0.010000, 0.040000, 0.230000}},
	{{1, -1, 2, -2}, 0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.050000}},
	{{1, -1, 2, 0}, -0.014830, {-0.720000, 0.030000, -0.560000, -0.890000, -5.770000}},
	{{1, -1, 2, 2}, 0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.050000}},
	{{1, -1, 3, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, 3, 0}, -0.001490, {-0.070000, 0.000000, -0.080000, -0.090000, -0.580000}},
	{{1, -1, 3, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, 4, 0}, -0.000140, {0.000000, 0.000000, -0.010000, 0.000000, -0.050000}},
	{{1, -1, 5, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, -6, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{1, 0, -5, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, -5, 0}, -0.000720, {-0.020000, 0.000000, -0.060000, 0.000000, -0.280000}},
	{{1, 0, -4, -2}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{1, 0, -4, 0}, -0.009550, {-0.280000, 0.010000, -0.700000, 0.000000, -3.710000}},
	{{1, 0, -4, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, -3, -2}, 0.000690, {0.020000, 0.030000, 0.040000, 0.000000, 0.270000}},
	{{1, 0, -3, 0}, -0.128120, {-3.660000, 0.130000, -7.030000, -0.050000, -49.820000}},
	{{1, 0, -3, 2}, 0.000380, {0.060000, 0.020000, 0.030000, 0.000000, 0.140000}},
	{{1, 0, -2, -4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, -2, -2}, 0.002890, {0.140000, 0.120000, 0.110000, 0.000000, 1.120000}},
	{{1, 0, -2, 0}, -1.752960, {-48.870000, 1.670000, -64.280000, -0.510000, -681.600000}},
	{{1, 0, -2, 2}, -0.001420, {0.050000, -0.070000, -0.050000, 0.000000, -0.550000}},
	{{1, 0, -1, -4}, 0.000190, {0.000000, 0.020000, 0.000000, 0.000000, 0.070000}},
	{{1, 0, -1, -2}, -0.023790, {0.120000, -1.090000, -0.420000, 0.000000, -9.250000}},
	{{1, 0, -1, 0}, -18.584670, {-437.660000, 18.910000, -346.510000, -1.000000, -7226.220000}},
	{{1, 0, -1, 2}, 0.015980, {0.320000, 0.690000, 0.300000, 0.000000, 6.210000}},
	{{1, 0, -1, 4}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{1, 0, 0, -4}, 0.001230, {0.010000, 0.110000, 0.000000, 0.000000, 0.480000}},
	{{1, 0, 0, -2}, -0.583320, {-5.890000, -25.980000, -0.120000, 0.000000, -226.810000}},
	{{1, 0, 0, 0}, -124.988060, {-2831.880000, 136.180000, -86.600000, -2.680000, -48598.150000}},
	{{1, 0, 0, 2}, 0.254290, {5.730000, 11.110000, 0.260000, 0.000000, 98.870000}},
	{{1, 0, 0, 4}, -0.000540, {-0.010000, -0.050000, 0.000000, 0.000000, -0.210000}},
	{{1, 0, 1, -4}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{1, 0, 1, -2}, -0.040120, {-0.220000, -1.800000, -0.720000, 0.000000, -15.600000}},
	{{1, 0, 1, 0}, -8.453080, {-187.780000, 10.100000, -158.620000, 0.770000, -3286.750000}},
	{{1, 0, 1, 2}, 0.044500, {0.980000, 1.940000, 0.840000, 0.000000, 17.300000}},
	{{1, 0, 1, 4}, -0.000150, {0.000000, -0.010000, 0.000000, 0.000000, -0.060000}},
	{{1, 0, 2, -2}, -0.000770, {0.030000, -0.030000, -0.030000, 0.000000, -0.300000}},
	{{1, 0, 2, 0}, -0.583990, {-12.360000, 0.750000, -21.520000, 0.130000, -227.070000}},
	{{1, 0, 2, 2}, 0.005400, {0.120000, 0.240000, 0.200000, 0.000000, 2.100000}},
	{{1, 0, 2, 4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, 0, 3, -2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{1, 0, 3, 0}, -0.040740, {-0.810000, 0.060000, -2.240000, 0.020000, -15.840000}},
	{{1, 0, 3, 2}, 0.000560, {0.010000, 0.020000, 0.030000, 0.000000, 0.220000}},
	{{1, 0, 4, 0}, -0.002850, {-0.050000, 0.000000, -0.210000, 0.000000, -1.110000}},
	{{1, 0, 4, 2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, 0, 5, 0}, -0.000200, {0.000000, 0.000000, -0.020000, 0.000000, -0.080000}},
	{{1, 0, 6, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, -5, 0}, 0.000110, {0.000000, 0.000000, 0.010000, 0.000000, 0.040000}},
	{{1, 1, -4, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, -4, 0}, 0.001550, {0.020000, 0.000000, 0.110000, 0.090000, 0.600000}},
	{{1, 1, -3, -2}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{1, 1, -3, 0}, 0.022960, {0.300000, 0.000000, 1.260000, 1.380000, 8.930000}},
	{{1, 1, -3, 2}, -0.000060, {0.020000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{1, 1, -2, -2}, -0.000710, {0.000000, -0.030000, -0.030000, -0.040000, -0.270000}},
	{{1, 1, -2, 0}, 0.349660, {5.360000, -0.110000, 12.830000, 20.950000, 135.950000}},
	{{1, 1, -2, 2}, 0.000630, {0.000000, 0.030000, 0.020000, 0.040000, 0.250000}},
	{{1, 1, -1, -2}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{1, 1, -1, 0}, 1.077730, {9.380000, -1.150000, 21.490000, 64.240000, 418.880000}},
	{{1, 1, -1, 2}, 0.000000, {0.030000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, 0, -2}, 0.000170, {0.030000, 0.000000, 0.070000, 0.000000, 0.070000}},
	{{1, 1, 0, 0}, 17.955120, {6.590000, -11.640000, 21.840000, 1074.240000, 6981.340000}},
	{{1, 1, 0, 2}, -0.035870, {0.000000, -1.580000, -0.050000, -2.150000, -13.950000}},
	{{1, 1, 0, 4}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 1, 1, -2}, -0.001570, {0.360000, -0.040000, -0.040000, -0.070000, -0.560000}},
	{{1, 1, 1, 0}, 1.261860, {1.830000, -0.900000, 24.500000, 75.500000, 490.640000}},
	{{1, 1, 1, 2}, -0.006590, {0.000000, -0.290000, -0.130000, -0.390000, -2.560000}},
	{{1, 1, 1, 4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, 2, -2}, 0.000280, {0.030000, 0.010000, 0.000000, 0.020000, 0.110000}},
	{{1, 1, 2, 0}, 0.092050, {0.220000, -0.070000, 3.460000, 5.510000, 35.790000}},
	{{1, 1, 2, 2}, -0.000840, {0.000000, -0.040000, -0.030000, -0.050000, -0.330000}},
	{{1, 1, 3, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, 3, 0}, 0.006790, {0.020000, 0.000000, 0.380000, 0.410000, 2.640000}},
	{{1, 1, 3, 2}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{1, 1, 4, 0}, 0.000500, {0.000000, 0.000000, 0.040000, 0.030000, 0.200000}},
	{{1, 1, 5, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{1, 2, -4, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{1, 2, -3, 0}, 0.000380, {0.020000, 0.000000, 0.020000, 0.050000, 0.150000}},
	{{1, 2, -2, 0}, 0.003610, {0.160000, 0.000000, 0.130000, 0.430000, 1.400000}},
	{{1, 2, -1, 0}, -0.003000, {-0.180000, 0.000000, -0.050000, -0.360000, -1.160000}},
	{{1, 2, -1, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 2, 0, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.010000, 0.010000}},
	{{1, 2, 0, 0}, -0.039680, {-0.610000, 0.040000, -0.070000, -4.750000, -15.430000}},
	{{1, 2, 0, 2}, 0.000110, {0.000000, 0.000000, 0.000000, 0.010000, 0.040000}},
	{{1, 2, 1, -2}, 0.000020, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 2, 1, 0}, -0.008490, {-0.160000, 0.000000, -0.170000, -1.020000, -3.300000}},
	{{1, 2, 1, 2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, 2, 2, 0}, -0.001020, {-0.020000, 0.000000, -0.040000, -0.120000, -0.400000}},
	{{1, 2, 2, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 2, 3, 0}, -0.000110, {0.000000, 0.000000, 0.000000, -0.010000, -0.040000}},
	{{1, 2, 4, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 3, -2, 0}, 0.000070, {0.000000, 0.000000, 0.000000, 0.010000, 0.030000}},
	{{1, 3, -1, 0}, -0.000110, {0.000000, 0.000000, 0.000000, -0.020000, -0.040000}},
	{{1, 3, 0, -2}, 0.000000, {0.020000, -0.010000, 0.010000, 0.020000, 0.000000}},
	{{1, 3, 0, 0}, -0.000560, {-0.010000, 0.000000, 0.000000, -0.100000, -0.220000}},
	{{1, 3, 1, 0}, -0.000090, {0.000000, 0.000000, 0.000000, -0.020000, -0.030000}},
	{{1, 4, 0, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -6, 0, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -5, -2, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -5, -1, 0}, 0.000270, {0.000000, 0.000000, 0.000000, 0.080000, 0.000000}},
	{{2, -5, 0, 0}, 0.000500, {0.020000, 0.000000, 0.000000, 0.150000, 0.000000}},
	{{2, -5, 1, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{2, -4, -3, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, -2, 0}, 0.000320, {0.010000, 0.000000, 0.010000, 0.080000, 0.000000}},
	{{2, -4, -1, 0}, 0.008120, {0.240000, 0.000000, 0.150000, 1.940000, 0.000000}},
	{{2, -4, -1, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, 0, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, 0, 0}, 0.013310, {0.580000, 0.000000, 0.020000, 3.180000, 0.000000}},
	{{2, -4, 0, 2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, 1, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, 1, 0}, 0.001330, {0.060000, 0.000000, 0.030000, 0.320000, 0.000000}},
	{{2, -4, 2, 0}, 0.000120, {0.000000, 0.000000, 0.000000, 0.030000, 0.000000}},
	{{2, -4, 3, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -4, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -3, 0}, 0.000490, {0.010000, 0.000000, 0.030000, 0.090000, 0.000000}},
	{{2, -3, -2, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -2, 0}, 0.009650, {0.260000, 0.000000, 0.350000, 1.730000, 0.000000}},
	{{2, -3, -2, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -1, -2}, -0.000210, {0.000000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{2, -3, -1, 0}, 0.246970, {6.330000, -0.030000, 4.520000, 44.320000, 0.000000}},
	{{2, -3, -1, 2}, -0.000520, {-0.010000, -0.020000, 0.000000, -0.090000, 0.000000}},
	{{2, -3, 0, -2}, 0.001630, {0.000000, 0.070000, 0.000000, 0.290000, 0.000000}},
	{{2, -3, 0, 0}, 0.339830, {13.410000, -0.120000, 0.740000, 60.980000, 0.000000}},
	{{2, -3, 0, 2}, -0.000750, {-0.030000, -0.030000, 0.000000, -0.130000, 0.000000}},
	{{2, -3, 1, -2}, -0.000650, {-0.020000, -0.030000, -0.010000, -0.120000, 0.000000}},
	{{2, -3, 1, 0}, 0.033000, {1.420000, -0.020000, 0.670000, 5.920000, 0.000000}},
	{{2, -3, 1, 2}, -0.000160, {0.000000, 0.000000, 0.000000, -0.030000, 0.000000}},
	{{2, -3, 2, -2}, -0.000050, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{2, -3, 2, 0}, 0.002950, {0.140000, 0.000000, 0.110000, 0.530000, 0.000000}},
	{{2, -3, 2, 2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, 3, 0}, 0.000260, {0.010000, 0.000000, 0.010000, 0.050000, 0.000000}},
	{{2, -3, 4, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, -5, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, -4, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, -4, 0}, 0.000880, {0.010000, 0.000000, 0.060000, 0.100000, 0.000000}},
	{{2, -2, -3, -2}, -0.000130, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{2, -2, -3, 0}, 0.015440, {0.290000, 0.000000, 0.840000, 1.850000, 0.000000}},
	{{2, -2, -2, -2}, -0.001110, {-0.030000, -0.050000, -0.040000, -0.130000, 0.000000}},
	{{2, -2, -2, 0}, 0.294220, {6.880000, -0.030000, 10.730000, 35.210000, 0.000000}},
	{{2, -2, -2, 2}, -0.000720, {0.000000, -0.030000, -0.030000, -0.090000, 0.000000}},
	{{2, -2, -1, -2}, -0.004340, {-0.200000, -0.190000, -0.080000, -0.520000, 0.000000}},
	{{2, -2, -1, 0}, 7.371730, {165.380000, -1.060000, 134.790000, 881.890000, -0.040000}},
	{{2, -2, -1, 2}, -0.015410, {-0.330000, -0.690000, -0.290000, -1.840000, 0.000000}},
	{{2, -2, -1, 4}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 0, -4}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 0, -2}, 0.063140, {0.430000, 2.820000, -0.040000, 7.550000, 0.000000}},
	{{2, -2, 0, 0}, 8.050760, {289.140000, -3.140000, 21.090000, 962.910000, -0.060000}},
	{{2, -2, 0, 2}, -0.018160, {-0.620000, -0.810000, -0.120000, -2.170000, 0.000000}},
	{{2, -2, 0, 4}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 1, -4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 1, -2}, -0.016440, {-0.380000, -0.740000, -0.300000, -1.970000, 0.000000}},
	{{2, -2, 1, 0}, 0.751730, {29.040000, -0.430000, 15.470000, 89.900000, 0.000000}},
	{{2, -2, 1, 2}, -0.003780, {-0.140000, -0.170000, -0.090000, -0.450000, 0.000000}},
	{{2, -2, 1, 4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 2, -2}, -0.001330, {-0.030000, -0.060000, -0.050000, -0.160000, 0.000000}},
	{{2, -2, 2, 0}, 0.064390, {2.630000, -0.050000, 2.500000, 7.700000, 0.000000}},
	{{2, -2, 2, 2}, -0.000550, {-0.020000, -0.020000, -0.020000, -0.070000, 0.000000}},
	{{2, -2, 3, -2}, -0.000110, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{2, -2, 3, 0}, 0.005380, {0.230000, 0.000000, 0.310000, 0.640000, 0.000000}},
	{{2, -2, 3, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 4, 0}, 0.000440, {0.020000, 0.000000, 0.030000, 0.050000, 0.000000}},
	{{2, -2, 5, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -6, 0}, 0.000100, {0.000000, 0.000000, 0.010000, 0.000000, 0.000000}},
	{{2, -1, -5, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -5, 0}, 0.001780, {0.010000, 0.000000, 0.160000, 0.110000, 0.000000}},
	{{2, -1, -4, -2}, -0.000360, {0.000000, -0.020000, -0.030000, -0.020000, 0.000000}},
	{{2, -1, -4, 0}, 0.029490, {0.410000, 0.000000, 2.150000, 1.770000, 0.000000}},
	{{2, -1, -4, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -3, -4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -3, -2}, -0.003650, {-0.080000, -0.160000, -0.200000, -0.220000, 0.000000}},
	{{2, -1, -3, 0}, 0.478420, {8.720000, -0.050000, 26.150000, 28.630000, 0.000000}},
	{{2, -1, -3, 2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -2, -4}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -2, -2}, -0.028040, {-0.740000, -1.250000, -1.030000, -1.680000, 0.000000}},
	{{2, -1, -2, 0}, 8.605820, {187.040000, -1.140000, 313.850000, 515.030000, 0.020000}},
	{{2, -1, -2, 2}, -0.021570, {-0.210000, -0.970000, -0.790000, -1.290000, 0.000000}},
	{{2, -1, -2, 4}, 0.000120, {0.000000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -1, -4}, -0.000150, {0.000000, -0.010000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -1, -2}, -0.061030, {-3.570000, -2.720000, -1.220000, -3.650000, 0.000000}},
	{{2, -1, -1, 0}, 205.443150, {4157.780000, -32.990000, 3751.430000, 12284.720000, -0.130000}},
	{{2, -1, -1, 2}, -0.426240, {-8.300000, -19.010000, -7.930000, -25.480000, 0.000000}},
	{{2, -1, -1, 4}, 0.000930, {0.020000, 0.080000, 0.020000, 0.060000, 0.000000}},
	{{2, -1, 0, -4}, -0.002860, {-0.020000, -0.260000, 0.000000, -0.170000, 0.000000}},
	{{2, -1, 0, -2}, 2.146190, {18.770000, 95.810000, -0.840000, 128.220000, 0.050000}},
	{{2, -1, 0, 0}, 164.734580, {5378.280000, -77.430000, 545.710000, 9844.150000, -0.180000}},
	{{2, -1, 0, 2}, -0.382150, {-11.750000, -16.940000, -3.100000, -22.840000, 0.000000}},
	{{2, -1, 0, 4}, 0.000890, {0.030000, 0.080000, 0.010000, 0.050000, 0.000000}},
	{{2, -1, 1, -4}, 0.000180, {0.000000, 0.020000, 0.000000, 0.010000, 0.000000}},
	{{2, -1, 1, -2}, -0.374530, {-6.500000, -16.890000, -6.910000, -22.360000, 0.000000}},
	{{2, -1, 1, 0}, 14.530780, {497.460000, -9.380000, 307.250000, 867.990000, 0.000000}},
	{{2, -1, 1, 2}, -0.073730, {-2.450000, -3.260000, -1.770000, -4.400000, 0.000000}},
	{{2, -1, 1, 4}, 0.000250, {0.000000, 0.020000, 0.000000, 0.020000, 0.000000}},
	{{2, -1, 2, -4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 2, -2}, -0.028870, {-0.540000, -1.300000, -1.060000, -1.720000, 0.000000}},
	{{2, -1, 2, 0}, 1.177040, {41.720000, -0.960000, 46.230000, 70.280000, 0.000000}},
	{{2, -1, 2, 2}, -0.010070, {-0.350000, -0.440000, -0.420000, -0.600000, 0.000000}},
	{{2, -1, 2, 4}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 3, -2}, -0.002320, {-0.050000, -0.100000, -0.130000, -0.140000, 0.000000}},
	{{2, -1, 3, 0}, 0.093200, {3.390000, -0.090000, 5.360000, 5.560000, 0.000000}},
	{{2, -1, 3, 2}, -0.001170, {-0.040000, -0.050000, -0.070000, -0.070000, 0.000000}},
	{{2, -1, 4, -2}, -0.000190, {0.000000, 0.000000, -0.010000, -0.010000, 0.000000}},
	{{2, -1, 4, 0}, 0.007300, {0.270000, 0.000000, 0.550000, 0.440000, 0.000000}},
	{{2, -1, 4, 2}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 5, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 5, 0}, 0.000570, {0.020000, 0.000000, 0.050000, 0.030000, 0.000000}},
	{{2, -1, 5, 2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 6, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -8, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -7, 0}, 0.000360, {0.000000, 0.000000, 0.050000, 0.000000, 0.000000}},
	{{2, 0, -6, -2}, -0.000110, {0.000000, 0.000000, -0.010000, 0.000000, 0.000000}},
	{{2, 0, -6, 0}, 0.004970, {0.100000, 0.000000, 0.540000, 0.000000, 0.000000}},
	{{2, 0, -5, -2}, -0.001110, {-0.020000, -0.050000, -0.100000, 0.000000, 0.000000}},
	{{2, 0, -5, 0}, 0.068500, {1.400000, -0.030000, 6.240000, 0.000000, 0.000000}},
	{{2, 0, -5, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -4, -4}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -4, -2}, -0.010770, {-0.240000, -0.480000, -0.790000, 0.000000, 0.000000}},
	{{2, 0, -4, 0}, 0.948270, {19.710000, -0.300000, 69.110000, 0.060000, 0.000000}},
	{{2, 0, -4, 2}, -0.000540, {0.000000, -0.030000, -0.040000, 0.000000, 0.000000}},
	{{2, 0, -3, -4}, 0.000240, {0.000000, 0.020000, 0.010000, 0.000000, 0.000000}},
	{{2, 0, -3, -2}, -0.091540, {-2.110000, -4.080000, -5.030000, 0.000000, 0.000000}},
	{{2, 0, -3, 0}, 13.194000, {279.870000, -3.190000, 721.290000, 0.650000, 0.140000}},
	{{2, 0, -3, 2}, 0.004670, {0.380000, 0.200000, 0.240000, 0.000000, 0.000000}},
	{{2, 0, -3, 4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -2, -4}, 0.000370, {0.030000, 0.030000, 0.020000, 0.000000, 0.000000}},
	{{2, 0, -2, -2}, -0.560650, {-14.540000, -24.990000, -20.690000, -0.010000, 0.000000}},
	{{2, 0, -2, 0}, 211.654870, {4685.540000, -42.060000, 7715.640000, 7.860000, 2.120000}},
	{{2, 0, -2, 2}, -0.535720, {-4.500000, -24.120000, -19.500000, 0.040000, -0.010000}},
	{{2, 0, -2, 4}, 0.002820, {0.020000, 0.250000, 0.100000, 0.000000, 0.000000}},
	{{2, 0, -1, -6}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -1, -4}, -0.008500, {0.000000, -0.760000, -0.140000, 0.000000, 0.000000}},
	{{2, 0, -1, -2}, 0.179030, {-34.060000, 7.980000, 1.010000, 0.030000, 0.180000}},
	{{2, 0, -1, 0}, 4586.430610, {87132.460000, -842.120000, 83586.180000, -191.170000, 20.310000}},
	{{2, 0, -1, 2}, -9.366010, {-173.580000, -417.660000, -173.700000, 0.480000, -0.060000}},
	{{2, 0, -1, 4}, 0.019930, {0.360000, 1.780000, 0.390000, 0.000000, 0.000000}},
	{{2, 0, -1, 6}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 0, -6}, 0.000150, {0.000000, 0.020000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 0, -4}, -0.075180, {-0.700000, -6.720000, 0.060000, 0.000000, 0.000000}},
	{{2, 0, 0, -2}, 55.178010, {530.970000, 2463.550000, -15.350000, -6.960000, 1.200000}},
	{{2, 0, 0, 0}, 2369.912270, {69551.140000, -1472.500000, 10817.070000, -255.360000, 22.070000}},
	{{2, 0, 0, 2}, -5.741700, {-155.850000, -254.000000, -59.770000, 0.640000, -0.100000}},
	{{2, 0, 0, 4}, 0.013720, {0.350000, 1.220000, 0.210000, 0.000000, 0.000000}},
	{{2, 0, 0, 6}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 1, -6}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 1, -4}, 0.000560, {0.100000, 0.050000, 0.010000, 0.000000, 0.000000}},
	{{2, 0, 1, -2}, -6.383250, {-72.700000, -288.510000, -117.470000, 1.160000, 0.000000}},
	{{2, 0, 1, 0}, 191.955750, {5619.270000, -153.090000, 4250.550000, -30.100000, 2.780000}},
	{{2, 0, 1, 2}, -0.990230, {-27.730000, -43.700000, -25.330000, 0.160000, -0.020000}},
	{{2, 0, 1, 4}, 0.003440, {0.090000, 0.310000, 0.100000, 0.000000, 0.000000}},
	{{2, 0, 1, 6}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 2, -4}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 2, -2}, -0.453800, {-4.940000, -20.520000, -16.630000, 0.100000, 0.000000}},
	{{2, 0, 2, 0}, 14.379640, {417.800000, -13.710000, 577.470000, -3.080000, 0.280000}},
	{{2, 0, 2, 2}, -0.123860, {-3.490000, -5.450000, -5.280000, 0.030000, 0.000000}},
	{{2, 0, 2, 4}, 0.000590, {0.020000, 0.050000, 0.030000, 0.000000, 0.000000}},
	{{2, 0, 3, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 3, -2}, -0.033360, {-0.350000, -1.510000, -1.830000, 0.000000, 0.000000}},
	{{2, 0, 3, 0}, 1.059490, {30.460000, -1.160000, 61.740000, -0.300000, 0.030000}},
	{{2, 0, 3, 2}, -0.013320, {-0.370000, -0.590000, -0.800000, 0.000000, 0.000000}},
	{{2, 0, 3, 4}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 4, -2}, -0.002470, {-0.030000, -0.110000, -0.180000, 0.000000, 0.000000}},
	{{2, 0, 4, 0}, 0.077650, {2.200000, -0.100000, 5.930000, -0.030000, 0.000000}},
	{{2, 0, 4, 2}, -0.001310, {-0.040000, -0.060000, -0.100000, 0.000000, 0.000000}},
	{{2, 0, 4, 4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 5, -2}, -0.000180, {0.000000, 0.000000, -0.020000, 0.000000, 0.000000}},
	{{2, 0, 5, 0}, 0.005680, {0.160000, 0.000000, 0.540000, 0.000000, 0.000000}},
	{{2, 0, 5, 2}, -0.000120, {0.000000, 0.000000, -0.010000, 0.000000, 0.000000}},
	{{2, 0, 6, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 6, 0}, 0.000410, {0.010000, 0.000000, 0.050000, 0.000000, 0.000000}},
	{{2, 0, 6, 2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 7, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -7, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -6, 0}, 0.000150, {0.010000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{2, 1, -5, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -5, 0}, 0.001730, {0.120000, 0.000000, 0.160000, 0.100000, 0.000000}},
	{{2, 1, -4, -2}, -0.000200, {-0.020000, 0.000000, -0.010000, -0.010000, 0.000000}},
	{{2, 1, -4, 0}, 0.018190, {1.370000, -0.020000, 1.320000, 1.100000, 0.000000}},
	{{2, 1, -4, 2}, -0.000030, {0.040000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{2, 1, -3, -2}, -0.001160, {-0.100000, -0.050000, -0.060000, -0.070000, 0.000000}},
	{{2, 1, -3, 0}, 0.176240, {15.800000, -0.230000, 9.590000, 10.630000, 0.050000}},
	{{2, 1, -3, 2}, -0.000240, {0.000000, -0.010000, -0.020000, -0.020000, 0.000000}},
	{{2, 1, -2, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -2, -2}, -0.003460, {-0.430000, -0.150000, -0.130000, -0.210000, 0.000000}},
	{{2, 1, -2, 0}, 2.488970, {257.300000, -3.720000, 89.710000, 150.190000, 0.260000}},
	{{2, 1, -2, 2}, -0.000010, {-0.340000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -1, -4}, 0.000170, {0.000000, 0.020000, 0.000000, 0.010000, 0.000000}},
	{{2, 1, -1, -2}, -0.002280, {0.760000, -0.110000, -0.050000, -0.130000, 0.000000}},
	{{2, 1, -1, 0}, -28.398100, {915.460000, -16.700000, -528.730000, -1693.300000, -0.380000}},
	{{2, 1, -1, 2}, 0.067420, {-1.630000, 3.040000, 1.290000, 4.020000, 0.000000}},
	{{2, 1, -1, 4}, -0.000160, {0.000000, -0.010000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 0, -4}, 0.001980, {0.030000, 0.180000, 0.000000, 0.120000, 0.000000}},
	{{2, 1, 0, -2}, -1.437240, {-23.320000, -64.110000, -0.160000, -86.030000, -0.040000}},
	{{2, 1, 0, 0}, -24.359100, {-661.000000, 29.130000, -128.060000, -1457.610000, -5.210000}},
	{{2, 1, 0, 2}, 0.065410, {1.460000, 2.860000, 0.750000, 3.910000, 0.030000}},
	{{2, 1, 0, 4}, -0.000170, {0.000000, -0.020000, 0.000000, -0.010000, 0.000000}},
	{{2, 1, 1, -4}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 1, -2}, 0.084720, {-0.380000, 3.850000, 1.590000, 5.050000, 0.000000}},
	{{2, 1, 1, 0}, -2.914640, {-100.960000, 4.260000, -66.130000, -174.490000, -0.750000}},
	{{2, 1, 1, 2}, 0.016050, {0.510000, 0.700000, 0.420000, 0.960000, 0.000000}},
	{{2, 1, 1, 4}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 2, -2}, 0.008890, {0.070000, 0.400000, 0.330000, 0.530000, 0.000000}},
	{{2, 1, 2, 0}, -0.290230, {-11.130000, 0.470000, -11.800000, -17.380000, -0.080000}},
	{{2, 1, 2, 2}, 0.002620, {0.100000, 0.110000, 0.110000, 0.160000, 0.000000}},
	{{2, 1, 2, 4}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 3, -2}, 0.000850, {0.010000, 0.040000, 0.050000, 0.050000, 0.000000}},
	{{2, 1, 3, 0}, -0.026760, {-1.080000, 0.050000, -1.570000, -1.600000, 0.000000}},
	{{2, 1, 3, 2}, 0.000350, {0.010000, 0.020000, 0.020000, 0.020000, 0.000000}},
	{{2, 1, 4, -2}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 4, 0}, -0.002360, {-0.100000, 0.000000, -0.180000, -0.140000, 0.000000}},
	{{2, 1, 4, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 5, 0}, -0.000200, {0.000000, 0.000000, -0.020000, -0.010000, 0.000000}},
	{{2, 1, 6, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -5, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -4, 0}, -0.000490, {0.000000, 0.000000, -0.040000, -0.060000, 0.000000}},
	{{2, 2, -3, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -3, 0}, -0.009440, {-0.260000, 0.000000, -0.530000, -1.140000, 0.000000}},
	{{2, 2, -3, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -2, -2}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -2, 0}, -0.249900, {-10.760000, 0.110000, -9.200000, -29.880000, -0.020000}},
	{{2, 2, -2, 2}, 0.000600, {0.020000, 0.030000, 0.020000, 0.070000, 0.000000}},
	{{2, 2, -1, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -1, -2}, -0.006540, {-0.240000, -0.290000, -0.090000, -0.780000, 0.000000}},
	{{2, 2, -1, 0}, -2.521380, {-84.660000, 0.740000, -46.070000, -302.130000, 0.070000}},
	{{2, 2, -1, 2}, 0.005150, {0.170000, 0.230000, 0.100000, 0.620000, 0.000000}},
	{{2, 2, -1, 4}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, 0, -4}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, 0, -2}, -0.023490, {-0.290000, -0.900000, 0.490000, -2.750000, 0.040000}},
	{{2, 2, 0, 0}, -0.185760, {-6.480000, 0.330000, -6.560000, -22.260000, 0.390000}},
	{{2, 2, 0, 2}, 0.000960, {0.030000, 0.040000, 0.030000, 0.110000, 0.000000}},
	{{2, 2, 1, -2}, -0.002000, {-0.120000, -0.070000, 0.000000, -0.230000, 0.000000}},
	{{2, 2, 1, 0}, -0.013430, {-0.460000, 0.030000, -0.710000, -1.610000, 0.060000}},
	{{2, 2, 1, 2}, 0.000120, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{2, 2, 2, -2}, -0.000140, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{2, 2, 2, 0}, -0.000660, {-0.010000, 0.000000, -0.060000, -0.080000, 0.000000}},
	{{2, 2, 3, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, -3, 0}, -0.000090, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{2, 3, -2, 0}, -0.000930, {-0.060000, 0.000000, -0.030000, -0.170000, 0.000000}},
	{{2, 3, -1, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, -1, 0}, -0.001880, {-0.120000, 0.000000, -0.030000, -0.340000, 0.000000}},
	{{2, 3, 0, -2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{2, 3, 0, 0}, 0.000380, {0.030000, 0.000000, 0.020000, 0.070000, 0.000000}},
	{{2, 3, 1, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, 1, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 4, -2, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 4, -1, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -4, -1, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -4, 0, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -3, -2, 0}, -0.000170, {0.000000, 0.000000, 0.000000, -0.030000, -0.070000}},
	{{3, -3, -1, 0}, -0.000530, {-0.020000, 0.000000, 0.000000, -0.090000, -0.210000}},
	{{3, -3, 0, -2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -3, 0, 0}, 0.000300, {0.000000, 0.000000, 0.000000, 0.050000, 0.120000}},
	{{3, -3, 1, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{3, -2, -3, 0}, -0.000140, {0.000000, 0.000000, 0.000000, -0.020000, -0.060000}},
	{{3, -2, -2, 0}, -0.003990, {-0.100000, 0.000000, -0.150000, -0.480000, -1.550000}},
	{{3, -2, -1, -2}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{3, -2, -1, 0}, -0.011820, {-0.500000, 0.000000, -0.230000, -1.410000, -4.600000}},
	{{3, -2, -1, 2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{3, -2, 0, -2}, -0.001020, {-0.020000, -0.050000, 0.000000, -0.120000, -0.400000}},
	{{3, -2, 0, 0}, 0.005180, {0.050000, 0.000000, -0.050000, 0.620000, 2.010000}},
	{{3, -2, 1, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -2, 1, 0}, 0.000370, {0.000000, 0.000000, 0.000000, 0.040000, 0.150000}},
	{{3, -1, -4, 0}, -0.000130, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{3, -1, -3, 0}, -0.002970, {-0.060000, 0.000000, -0.160000, -0.180000, -1.160000}},
	{{3, -1, -2, 0}, -0.083110, {-1.910000, 0.020000, -3.040000, -4.980000, -32.320000}},
	{{3, -1, -2, 2}, 0.000200, {0.000000, 0.000000, 0.000000, 0.010000, 0.080000}},
	{{3, -1, -1, -2}, -0.001890, {-0.020000, -0.080000, -0.030000, -0.110000, -0.730000}},
	{{3, -1, -1, 0}, -0.231410, {-9.240000, 0.190000, -4.480000, -13.780000, -89.980000}},
	{{3, -1, -1, 2}, 0.000750, {0.030000, 0.030000, 0.020000, 0.050000, 0.290000}},
	{{3, -1, 0, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, 0, -2}, -0.019480, {-0.340000, -0.870000, 0.000000, -1.160000, -7.570000}},
	{{3, -1, 0, 0}, 0.065070, {-0.180000, 0.160000, -1.040000, 3.930000, 25.300000}},
	{{3, -1, 0, 2}, 0.000200, {0.020000, 0.000000, 0.000000, 0.010000, 0.080000}},
	{{3, -1, 1, -2}, -0.000840, {0.000000, -0.040000, -0.010000, -0.050000, -0.330000}},
	{{3, -1, 1, 0}, 0.003300, {-0.250000, 0.030000, -0.050000, 0.210000, 1.280000}},
	{{3, -1, 1, 2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, -1, 2, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -1, 2, 0}, -0.000110, {-0.050000, 0.000000, -0.010000, 0.000000, -0.040000}},
	{{3, -1, 2, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, 3, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 0, -5, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 0, -4, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, -4, 0}, -0.001740, {0.000000, 0.000000, -0.130000, 0.000000, -0.680000}},
	{{3, 0, -3, -2}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{3, 0, -3, 0}, -0.044420, {-0.910000, 0.000000, -2.430000, -0.030000, -17.270000}},
	{{3, 0, -3, 2}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{3, 0, -2, -2}, -0.000280, {0.020000, -0.010000, 0.000000, 0.000000, -0.110000}},
	{{3, 0, -2, 0}, -1.224120, {-28.100000, 0.420000, -44.730000, -0.150000, -475.970000}},
	{{3, 0, -2, 2}, 0.002980, {0.070000, 0.130000, 0.110000, 0.000000, 1.160000}},
	{{3, 0, -2, 4}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, -1, -4}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, 0, -1, -2}, -0.029790, {-0.390000, -1.330000, -0.540000, 0.000000, -11.590000}},
	{{3, 0, -1, 0}, -3.209680, {-121.620000, 3.090000, -62.390000, 1.610000, -1248.010000}},
	{{3, 0, -1, 2}, 0.012150, {0.480000, 0.530000, 0.250000, 0.000000, 4.720000}},
	{{3, 0, -1, 4}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{3, 0, 0, -4}, 0.000250, {0.000000, 0.020000, 0.000000, 0.000000, 0.100000}},
	{{3, 0, 0, -2}, -0.253040, {-3.600000, -11.270000, 0.100000, 0.080000, -98.390000}},
	{{3, 0, 0, 0}, 0.404230, {-12.920000, 2.280000, -14.170000, 1.050000, 157.170000}},
	{{3, 0, 0, 2}, 0.003750, {0.240000, 0.160000, 0.110000, 0.000000, 1.460000}},
	{{3, 0, 0, 4}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, 1, -4}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, 0, 1, -2}, -0.010620, {-0.050000, -0.470000, -0.180000, 0.000000, -4.130000}},
	{{3, 0, 1, 0}, 0.000370, {-3.590000, 0.360000, -1.360000, 0.180000, 0.140000}},
	{{3, 0, 1, 2}, 0.000830, {0.060000, 0.030000, 0.030000, 0.000000, 0.320000}},
	{{3, 0, 2, -2}, -0.000510, {0.000000, -0.020000, -0.020000, 0.000000, -0.200000}},
	{{3, 0, 2, 0}, -0.003890, {-0.500000, 0.040000, -0.260000, 0.020000, -1.510000}},
	{{3, 0, 2, 2}, 0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.050000}},
	{{3, 0, 3, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, 3, 0}, -0.000620, {-0.050000, 0.000000, -0.040000, 0.000000, -0.240000}},
	{{3, 0, 3, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, 4, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{3, 1, -5, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 1, -4, 0}, -0.000590, {-0.020000, 0.000000, -0.040000, -0.040000, -0.230000}},
	{{3, 1, -3, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -3, 0}, -0.006230, {-0.300000, 0.000000, -0.340000, -0.370000, -2.420000}},
	{{3, 1, -3, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -2, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -2, 0}, -0.041890, {-2.510000, 0.020000, -1.500000, -2.520000, -16.290000}},
	{{3, 1, -2, 2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{3, 1, -1, -2}, 0.001160, {0.020000, 0.050000, 0.020000, 0.070000, 0.450000}},
	{{3, 1, -1, 0}, 0.273770, {5.060000, -0.240000, 5.220000, 16.360000, 106.450000}},
	{{3, 1, -1, 2}, -0.001380, {-0.020000, -0.060000, -0.030000, -0.080000, -0.530000}},
	{{3, 1, 0, -2}, 0.008910, {0.140000, 0.400000, -0.010000, 0.530000, 3.460000}},
	{{3, 1, 0, 0}, 0.149900, {4.450000, -0.270000, 1.610000, 8.950000, 58.290000}},
	{{3, 1, 0, 2}, -0.000960, {-0.030000, -0.040000, -0.010000, -0.060000, -0.370000}},
	{{3, 1, 1, -2}, 0.000200, {0.000000, 0.000000, 0.000000, 0.010000, 0.080000}},
	{{3, 1, 1, 0}, 0.022440, {0.700000, -0.040000, 0.590000, 1.340000, 8.730000}},
	{{3, 1, 1, 2}, -0.000220, {0.000000, 0.000000, 0.000000, -0.010000, -0.090000}},
	{{3, 1, 2, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, 2, 0}, 0.002560, {0.080000, 0.000000, 0.110000, 0.150000, 1.000000}},
	{{3, 1, 2, 2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{3, 1, 3, 0}, 0.000260, {0.000000, 0.000000, 0.020000, 0.020000, 0.100000}},
	{{3, 1, 4, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 2, -4, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 2, -3, 0}, -0.000200, {0.000000, 0.000000, -0.010000, -0.020000, -0.080000}},
	{{3, 2, -2, 0}, -0.000360, {-0.060000, 0.000000, -0.010000, -0.040000, -0.140000}},
	{{3, 2, -1, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 2, -1, 0}, -0.001270, {0.070000, 0.000000, -0.030000, -0.150000, -0.490000}},
	{{3, 2, 0, -2}, -0.000090, {0.000000, 0.000000, 0.000000, -0.020000, -0.040000}},
	{{3, 2, 0, 0}, -0.001910, {-0.050000, 0.000000, -0.020000, -0.230000, -0.740000}},
	{{3, 2, 0, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 2, 1, 0}, -0.000390, {-0.010000, 0.000000, 0.000000, -0.050000, -0.150000}},
	{{3, 2, 2, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 3, -3, 0}, 0.000000, {0.000000, 0.000000, 0.000000, -0.020000, -0.030000}},
	{{3, 3, -2, -2}, 0.000000, {-0.030000, 0.010000, -0.030000, 0.000000, -0.080000}},
	{{3, 3, -2, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{3, 3, -1, 0}, -0.000140, {0.000000, 0.000000, 0.000000, -0.020000, -0.050000}},
	{{3, 3, 0, -2}, -0.000020, {-0.090000, 0.070000, -0.080000, -0.080000, 0.050000}},
	{{3, 3, 0, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -5, -2, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -5, -1, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{4, -5, 0, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -4, -3, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -4, -2, 0}, 0.000330, {0.020000, 0.000000, 0.010000, 0.080000, 0.000000}},
	{{4, -4, -1, 0}, 0.000860, {0.050000, 0.000000, 0.020000, 0.210000, 0.000000}},
	{{4, -4, 0, 0}, 0.000540, {0.040000, 0.000000, 0.000000, 0.130000, 0.000000}},
	{{4, -4, 1, 0}, 0.000090, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, -4, 2, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, -3, 0}, 0.000270, {0.010000, 0.000000, 0.010000, 0.050000, 0.000000}},
	{{4, -3, -2, 0}, 0.007550, {0.330000, 0.000000, 0.280000, 1.350000, 0.000000}},
	{{4, -3, -2, 2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, -1, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, -1, 0}, 0.017410, {0.970000, -0.010000, 0.360000, 3.120000, 0.000000}},
	{{4, -3, -1, 2}, -0.000090, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{4, -3, 0, -2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{4, -3, 0, 0}, 0.009710, {0.650000, 0.000000, 0.110000, 1.740000, 0.000000}},
	{{4, -3, 0, 2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, 1, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, 1, 0}, 0.001600, {0.110000, 0.000000, 0.040000, 0.290000, 0.000000}},
	{{4, -3, 1, 2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, 2, 0}, 0.000200, {0.010000, 0.000000, 0.000000, 0.040000, 0.000000}},
	{{4, -3, 3, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -5, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -4, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -3, 0}, 0.005600, {0.270000, 0.000000, 0.310000, 0.670000, 0.000000}},
	{{4, -2, -3, 2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -2, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -2, 0}, 0.157810, {6.460000, -0.060000, 5.770000, 18.870000, 0.000000}},
	{{4, -2, -2, 2}, -0.000900, {-0.040000, -0.040000, -0.030000, -0.110000, 0.000000}},
	{{4, -2, -1, -2}, 0.001080, {0.000000, 0.050000, 0.020000, 0.130000, 0.000000}},
	{{4, -2, -1, 0}, 0.308740, {16.370000, -0.230000, 6.490000, 36.900000, 0.000000}},
	{{4, -2, -1, 2}, -0.001600, {-0.080000, -0.070000, -0.040000, -0.190000, 0.000000}},
	{{4, -2, 0, -2}, 0.000910, {0.070000, 0.040000, -0.020000, 0.110000, 0.000000}},
	{{4, -2, 0, 0}, 0.152270, {9.620000, -0.170000, 1.880000, 18.190000, 0.010000}},
	{{4, -2, 0, 2}, -0.000890, {-0.050000, -0.040000, -0.020000, -0.110000, 0.000000}},
	{{4, -2, 1, -2}, -0.000520, {-0.020000, -0.020000, -0.010000, -0.060000, 0.000000}},
	{{4, -2, 1, 0}, 0.024110, {1.580000, -0.030000, 0.660000, 2.880000, 0.000000}},
	{{4, -2, 1, 2}, -0.000210, {-0.010000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{4, -2, 2, -2}, -0.000090, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{4, -2, 2, 0}, 0.002900, {0.200000, 0.000000, 0.130000, 0.350000, 0.000000}},
	{{4, -2, 2, 2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 3, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 3, 0}, 0.000310, {0.020000, 0.000000, 0.020000, 0.040000, 0.000000}},
	{{4, -2, 4, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -6, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -5, 0}, -0.000340, {-0.010000, 0.000000, -0.030000, -0.020000, 0.000000}},
	{{4, -1, -4, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -4, 0}, -0.000200, {0.000000, 0.000000, -0.010000, -0.010000, 0.000000}},
	{{4, -1, -3, -2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -3, 0}, 0.099820, {4.580000, -0.040000, 5.460000, 5.980000, 0.020000}},
	{{4, -1, -3, 2}, -0.000780, {-0.030000, -0.040000, -0.040000, -0.050000, 0.000000}},
	{{4, -1, -2, -4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -2, -2}, 0.000430, {0.000000, 0.020000, 0.020000, 0.030000, 0.000000}},
	{{4, -1, -2, 0}, 2.731980, {106.730000, -1.040000, 99.830000, 163.200000, 0.110000}},
	{{4, -1, -2, 2}, -0.015330, {-0.590000, -0.680000, -0.570000, -0.920000, 0.000000}},
	{{4, -1, -2, 4}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -1, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -1, -2}, 0.022890, {0.270000, 1.020000, 0.410000, 1.360000, 0.020000}},
	{{4, -1, -1, 0}, 4.374160, {221.000000, -3.710000, 93.870000, 260.990000, -0.050000}},
	{{4, -1, -1, 2}, -0.022730, {-1.120000, -1.000000, -0.560000, -1.360000, 0.000000}},
	{{4, -1, -1, 4}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 0, -4}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 0, -2}, 0.006660, {0.750000, 0.260000, -0.270000, 0.390000, 0.020000}},
	{{4, -1, 0, 0}, 1.870830, {111.800000, -2.350000, 25.650000, 111.490000, 0.160000}},
	{{4, -1, 0, 2}, -0.011140, {-0.640000, -0.490000, -0.230000, -0.660000, 0.000000}},
	{{4, -1, 0, 4}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 1, -4}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 1, -2}, -0.007320, {-0.280000, -0.330000, -0.180000, -0.440000, 0.000000}},
	{{4, -1, 1, 0}, 0.282510, {17.390000, -0.420000, 8.050000, 16.820000, 0.020000}},
	{{4, -1, 1, 2}, -0.002510, {-0.150000, -0.110000, -0.080000, -0.150000, 0.000000}},
	{{4, -1, 1, 4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 2, -2}, -0.001210, {-0.050000, -0.050000, -0.050000, -0.070000, 0.000000}},
	{{4, -1, 2, 0}, 0.032740, {2.050000, -0.060000, 1.490000, 1.950000, 0.000000}},
	{{4, -1, 2, 2}, -0.000410, {-0.030000, -0.020000, -0.020000, -0.020000, 0.000000}},
	{{4, -1, 3, -2}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 3, 0}, 0.003360, {0.210000, 0.000000, 0.210000, 0.200000, 0.000000}},
	{{4, -1, 3, 2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 4, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 4, 0}, 0.000320, {0.020000, 0.000000, 0.030000, 0.020000, 0.000000}},
	{{4, -1, 5, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -7, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -6, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -6, 0}, -0.000620, {-0.030000, 0.000000, -0.070000, 0.000000, 0.000000}},
	{{4, 0, -5, -2}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -5, 0}, -0.004310, {-0.180000, 0.000000, -0.390000, 0.000000, 0.000000}},
	{{4, 0, -4, -2}, 0.000420, {0.020000, 0.020000, 0.030000, 0.000000, 0.000000}},
	{{4, 0, -4, 0}, -0.000700, {0.030000, 0.000000, -0.050000, 0.000000, 0.000000}},
	{{4, 0, -4, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -3, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -3, -2}, 0.000230, {0.020000, 0.010000, 0.010000, 0.000000, 0.000000}},
	{{4, 0, -3, 0}, 1.186820, {52.890000, -0.500000, 64.880000, 0.220000, 0.250000}},
	{{4, 0, -3, 2}, -0.009340, {-0.290000, -0.420000, -0.510000, 0.000000, 0.000000}},
	{{4, 0, -3, 4}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -2, -4}, 0.000130, {0.000000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -2, -2}, 0.006620, {0.090000, 0.290000, 0.240000, 0.000000, 0.000000}},
	{{4, 0, -2, 0}, 30.772470, {1164.740000, -12.420000, 1123.350000, -4.250000, 1.180000}},
	{{4, 0, -2, 2}, -0.169770, {-6.360000, -7.540000, -6.260000, 0.030000, 0.000000}},
	{{4, 0, -2, 4}, 0.000610, {0.020000, 0.050000, 0.020000, 0.000000, 0.000000}},
	{{4, 0, -1, -4}, 0.000170, {0.010000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -1, -2}, 0.300860, {5.060000, 13.370000, 5.390000, -0.190000, 0.150000}},
	{{4, 0, -1, 0}, 38.429740, {1853.280000, -37.860000, 849.770000, -9.840000, 0.080000}},
	{{4, 0, -1, 2}, -0.201340, {-9.450000, -8.850000, -5.160000, 0.050000, 0.000000}},
	{{4, 0, -1, 4}, 0.000720, {0.030000, 0.060000, 0.020000, 0.000000, 0.000000}},
	{{4, 0, 0, -4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 0, -2}, -0.023910, {4.230000, -1.470000, -2.510000, -0.040000, 0.160000}},
	{{4, 0, 0, 0}, 13.899030, {782.370000, -19.880000, 215.740000, -5.220000, 1.370000}},
	{{4, 0, 0, 2}, -0.085000, {-4.560000, -3.710000, -1.970000, 0.030000, 0.000000}},
	{{4, 0, 0, 4}, 0.000350, {0.020000, 0.030000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 1, -4}, -0.000610, {0.000000, -0.050000, -0.010000, 0.000000, 0.000000}},
	{{4, 0, 1, -2}, -0.066010, {-2.120000, -2.980000, -1.620000, 0.030000, 0.020000}},
	{{4, 0, 1, 0}, 1.977720, {113.340000, -3.310000, 59.210000, -0.940000, 0.180000}},
	{{4, 0, 1, 2}, -0.017810, {-0.990000, -0.770000, -0.630000, 0.000000, 0.000000}},
	{{4, 0, 1, 4}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 2, -4}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 2, -2}, -0.009800, {-0.350000, -0.440000, -0.410000, 0.000000, 0.000000}},
	{{4, 0, 2, 0}, 0.218530, {12.570000, -0.410000, 10.190000, -0.130000, 0.020000}},
	{{4, 0, 2, 2}, -0.002740, {-0.150000, -0.120000, -0.140000, 0.000000, 0.000000}},
	{{4, 0, 2, 4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 3, -2}, -0.001090, {-0.040000, -0.050000, -0.070000, 0.000000, 0.000000}},
	{{4, 0, 3, 0}, 0.021490, {1.240000, -0.040000, 1.380000, -0.020000, 0.000000}},
	{{4, 0, 3, 2}, -0.000360, {-0.020000, -0.020000, -0.020000, 0.000000, 0.000000}},
	{{4, 0, 4, -2}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 4, 0}, 0.001980, {0.110000, 0.000000, 0.160000, 0.000000, 0.000000}},
	{{4, 0, 4, 2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 5, 0}, 0.000170, {0.010000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{4, 0, 6, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -6, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -5, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -4, 0}, 0.000640, {0.060000, 0.000000, 0.050000, 0.040000, 0.000000}},
	{{4, 1, -3, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -3, 0}, 0.026820, {3.500000, -0.050000, 1.450000, 1.600000, 0.020000}},
	{{4, 1, -3, 2}, -0.000030, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -2, -2}, -0.000390, {-0.020000, -0.020000, -0.010000, -0.020000, 0.000000}},
	{{4, 1, -2, 0}, -0.357590, {7.750000, -0.180000, -13.130000, -21.490000, -0.040000}},
	{{4, 1, -2, 2}, 0.002200, {-0.030000, 0.100000, 0.080000, 0.130000, 0.000000}},
	{{4, 1, -1, -2}, -0.018750, {-0.680000, -0.830000, -0.350000, -1.120000, 0.000000}},
	{{4, 1, -1, 0}, -0.635230, {-17.620000, 0.740000, -14.320000, -38.110000, -0.210000}},
	{{4, 1, -1, 2}, 0.003530, {0.090000, 0.150000, 0.090000, 0.210000, 0.000000}},
	{{4, 1, -1, 4}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 0, -2}, 0.000510, {-0.280000, 0.040000, 0.020000, 0.030000, -0.010000}},
	{{4, 1, 0, 0}, -0.289110, {-15.100000, 0.590000, -4.730000, -17.300000, -0.060000}},
	{{4, 1, 0, 2}, 0.001860, {0.090000, 0.080000, 0.050000, 0.110000, 0.000000}},
	{{4, 1, 1, -4}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 1, -2}, 0.001830, {0.030000, 0.080000, 0.040000, 0.110000, 0.000000}},
	{{4, 1, 1, 0}, -0.050700, {-2.990000, 0.120000, -1.550000, -3.030000, -0.010000}},
	{{4, 1, 1, 2}, 0.000480, {0.030000, 0.020000, 0.020000, 0.030000, 0.000000}},
	{{4, 1, 2, -2}, 0.000320, {0.010000, 0.010000, 0.010000, 0.020000, 0.000000}},
	{{4, 1, 2, 0}, -0.006680, {-0.420000, 0.020000, -0.320000, -0.400000, 0.000000}},
	{{4, 1, 2, 2}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 3, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 3, 0}, -0.000770, {-0.050000, 0.000000, -0.050000, -0.050000, 0.000000}},
	{{4, 1, 3, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 4, 0}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -4, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -3, 0}, -0.003690, {-0.240000, 0.000000, -0.200000, -0.440000, 0.000000}},
	{{4, 2, -3, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -2, -2}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -2, 0}, -0.035140, {-2.040000, 0.020000, -1.290000, -4.210000, 0.000000}},
	{{4, 2, -2, 2}, 0.000190, {0.010000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, 2, -1, -2}, 0.000900, {0.060000, 0.040000, 0.020000, 0.110000, 0.000000}},
	{{4, 2, -1, 0}, -0.021710, {-1.510000, 0.030000, -0.570000, -2.600000, 0.010000}},
	{{4, 2, -1, 2}, 0.000120, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{4, 2, 0, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, 0, 0}, -0.002080, {-0.160000, 0.000000, -0.120000, -0.250000, 0.000000}},
	{{4, 2, 0, 2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, 1, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, 1, 0}, -0.000080, {0.000000, 0.000000, -0.010000, -0.010000, 0.000000}},
	{{4, 2, 2, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 3, -2, 0}, 0.000200, {0.000000, 0.000000, 0.000000, 0.040000, 0.000000}},
	{{4, 3, -1, 0}, 0.000230, {0.010000, 0.000000, 0.000000, 0.040000, 0.000000}},
	{{4, 3, 0, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 4, -2, -2}, 0.000000, {-0.020000, 0.000000, 0.000000, 0.040000, -0.060000}},
	{{5, -3, -2, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{5, -3, 0, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -2, -3, 0}, -0.000130, {0.000000, 0.000000, 0.000000, -0.020000, -0.050000}},
	{{5, -2, -2, 0}, -0.000520, {-0.030000, 0.000000, -0.020000, -0.060000, -0.200000}},
	{{5, -2, -1, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{5, -2, -1, 0}, -0.000110, {-0.020000, 0.000000, 0.000000, -0.010000, -0.040000}},
	{{5, -2, 0, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -2, 0, 0}, 0.000120, {0.000000, 0.000000, 0.000000, 0.010000, 0.050000}},
	{{5, -2, 1, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, -4, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, -1, -3, 0}, -0.001890, {-0.080000, 0.000000, -0.100000, -0.110000, -0.730000}},
	{{5, -1, -3, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, -2, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{5, -1, -2, 0}, -0.006930, {-0.400000, 0.000000, -0.260000, -0.410000, -2.700000}},
	{{5, -1, -2, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{5, -1, -1, -2}, -0.000400, {-0.020000, -0.020000, 0.000000, -0.020000, -0.160000}},
	{{5, -1, -1, 0}, -0.001540, {-0.210000, 0.010000, -0.080000, -0.090000, -0.600000}},
	{{5, -1, -1, 2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{5, -1, 0, -2}, -0.000210, {0.000000, 0.000000, 0.000000, -0.010000, -0.080000}},
	{{5, -1, 0, 0}, 0.001020, {0.010000, 0.000000, -0.020000, 0.060000, 0.400000}},
	{{5, -1, 1, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{5, -1, 1, 0}, 0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.050000}},
	{{5, 0, -4, 0}, -0.000590, {-0.030000, 0.000000, -0.040000, 0.000000, -0.230000}},
	{{5, 0, -3, 0}, -0.016860, {-0.720000, 0.000000, -0.920000, 0.000000, -6.560000}},
	{{5, 0, -3, 2}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{5, 0, -2, -2}, -0.000310, {0.000000, -0.010000, -0.010000, 0.000000, -0.120000}},
	{{5, 0, -2, 0}, -0.057250, {-3.180000, 0.070000, -2.180000, 0.050000, -22.260000}},
	{{5, 0, -2, 2}, 0.000390, {0.020000, 0.020000, 0.020000, 0.000000, 0.150000}},
	{{5, 0, -1, -2}, -0.003350, {-0.110000, -0.150000, -0.060000, 0.000000, -1.300000}},
	{{5, 0, -1, 0}, -0.013500, {-1.570000, 0.090000, -0.640000, 0.060000, -5.250000}},
	{{5, 0, -1, 2}, 0.000240, {0.020000, 0.010000, 0.000000, 0.000000, 0.090000}},
	{{5, 0, 0, -4}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, 0, -2}, -0.001370, {-0.060000, -0.060000, 0.000000, 0.000000, -0.530000}},
	{{5, 0, 0, 0}, 0.004390, {-0.050000, 0.030000, -0.180000, 0.030000, 1.710000}},
	{{5, 0, 0, 2}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{5, 0, 1, -2}, -0.000190, {0.000000, 0.000000, 0.000000, 0.000000, -0.070000}},
	{{5, 0, 1, 0}, 0.000500, {-0.030000, 0.000000, -0.020000, 0.000000, 0.200000}},
	{{5, 0, 1, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, 2, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, 2, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 1, -4, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 1, -3, 0}, -0.000460, {-0.050000, 0.000000, -0.020000, -0.030000, -0.180000}},
	{{5, 1, -2, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 1, -2, 0}, 0.003920, {0.120000, 0.000000, 0.150000, 0.230000, 1.520000}},
	{{5, 1, -2, 2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{5, 1, -1, -2}, 0.000160, {0.000000, 0.000000, 0.000000, 0.000000, 0.060000}},
	{{5, 1, -1, 0}, 0.004750, {0.240000, -0.010000, 0.120000, 0.280000, 1.850000}},
	{{5, 1, -1, 2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 1, 0, -2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{5, 1, 0, 0}, 0.001810, {0.110000, 0.000000, 0.050000, 0.110000, 0.700000}},
	{{5, 1, 0, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 1, 1, 0}, 0.000350, {0.020000, 0.000000, 0.010000, 0.020000, 0.140000}},
	{{5, 1, 2, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{5, 2, -3, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 2, -2, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 2, -1, 0}, -0.000080, {0.000000, 0.000000, 0.000000, -0.010000, -0.030000}},
	{{5, 2, 0, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 2, 1, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 3, -2, -2}, 0.000000, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{6, -4, -3, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -4, -2, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -4, -1, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -4, 0, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -3, -3, 0}, 0.000200, {0.010000, 0.000000, 0.010000, 0.030000, 0.000000}},
	{{6, -3, -2, 0}, 0.000590, {0.040000, 0.000000, 0.020000, 0.110000, 0.000000}},
	{{6, -3, -1, 0}, 0.000590, {0.050000, 0.000000, 0.020000, 0.110000, 0.000000}},
	{{6, -3, 0, 0}, 0.000240, {0.020000, 0.000000, 0.000000, 0.040000, 0.000000}},
	{{6, -3, 1, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -4, 0}, 0.000140, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{6, -2, -3, 0}, 0.003120, {0.190000, 0.000000, 0.170000, 0.370000, 0.000000}},
	{{6, -2, -3, 2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -2, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -2, 0}, 0.008360, {0.590000, 0.000000, 0.330000, 1.000000, 0.000000}},
	{{6, -2, -2, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -1, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -1, 0}, 0.007440, {0.610000, -0.010000, 0.210000, 0.890000, 0.000000}},
	{{6, -2, -1, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 0, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 0, 0}, 0.002850, {0.260000, 0.000000, 0.070000, 0.340000, 0.000000}},
	{{6, -2, 0, 2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 1, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 1, 0}, 0.000560, {0.050000, 0.000000, 0.020000, 0.070000, 0.000000}},
	{{6, -2, 2, 0}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 3, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -5, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -4, 0}, 0.001760, {0.110000, 0.000000, 0.130000, 0.110000, 0.000000}},
	{{6, -1, -4, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -3, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -3, 0}, 0.039000, {2.280000, -0.020000, 2.140000, 2.330000, 0.000000}},
	{{6, -1, -3, 2}, -0.000390, {-0.020000, -0.020000, -0.020000, -0.020000, 0.000000}},
	{{6, -1, -2, -2}, 0.000440, {0.010000, 0.020000, 0.020000, 0.030000, 0.000000}},
	{{6, -1, -2, 0}, 0.090330, {6.230000, -0.110000, 3.590000, 5.380000, 0.000000}},
	{{6, -1, -2, 2}, -0.000800, {-0.050000, -0.040000, -0.030000, -0.050000, 0.000000}},
	{{6, -1, -1, -2}, 0.000180, {0.020000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{6, -1, -1, 0}, 0.071420, {5.640000, -0.120000, 2.050000, 4.250000, 0.000000}},
	{{6, -1, -1, 2}, -0.000640, {-0.050000, -0.030000, -0.020000, -0.040000, 0.000000}},
	{{6, -1, 0, -2}, -0.000250, {0.000000, -0.010000, -0.010000, -0.010000, 0.000000}},
	{{6, -1, 0, 0}, 0.025100, {2.160000, -0.050000, 0.660000, 1.490000, 0.000000}},
	{{6, -1, 0, 2}, -0.000260, {-0.020000, -0.010000, 0.000000, -0.020000, 0.000000}},
	{{6, -1, 1, -2}, -0.000160, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 1, 0}, 0.004770, {0.420000, -0.010000, 0.180000, 0.280000, 0.000000}},
	{{6, -1, 1, 2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 2, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 2, 0}, 0.000690, {0.060000, 0.000000, 0.040000, 0.040000, 0.000000}},
	{{6, -1, 2, 2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 3, 0}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -5, 0}, 0.000200, {0.010000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{6, 0, -4, 0}, 0.013760, {0.880000, 0.000000, 1.000000, 0.000000, 0.000000}},
	{{6, 0, -4, 2}, -0.000170, {0.000000, 0.000000, -0.010000, 0.000000, 0.000000}},
	{{6, 0, -3, -2}, 0.000180, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -3, 0}, 0.292550, {16.720000, -0.190000, 16.040000, -0.080000, 0.030000}},
	{{6, 0, -3, 2}, -0.002870, {-0.160000, -0.130000, -0.160000, 0.000000, 0.000000}},
	{{6, 0, -3, 4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -2, -2}, 0.003640, {0.130000, 0.160000, 0.130000, 0.000000, 0.000000}},
	{{6, 0, -2, 0}, 0.571560, {38.340000, -0.750000, 22.970000, -0.260000, 0.020000}},
	{{6, 0, -2, 2}, -0.005090, {-0.340000, -0.220000, -0.220000, 0.000000, 0.000000}},
	{{6, 0, -2, 4}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -1, -2}, 0.000070, {0.080000, 0.000000, -0.030000, 0.000000, 0.000000}},
	{{6, 0, -1, 0}, 0.394510, {30.100000, -0.740000, 11.790000, -0.250000, 0.030000}},
	{{6, 0, -1, 2}, -0.003590, {-0.270000, -0.160000, -0.130000, 0.000000, 0.000000}},
	{{6, 0, -1, 4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 0, -4}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 0, -2}, -0.002140, {-0.070000, -0.100000, -0.070000, 0.000000, 0.000000}},
	{{6, 0, 0, 0}, 0.126160, {10.430000, -0.290000, 3.570000, -0.100000, 0.020000}},
	{{6, 0, 0, 2}, -0.001320, {-0.110000, -0.060000, -0.050000, 0.000000, 0.000000}},
	{{6, 0, 1, -4}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 1, -2}, -0.000940, {-0.050000, -0.040000, -0.030000, 0.000000, 0.000000}},
	{{6, 0, 1, 0}, 0.022850, {1.930000, -0.060000, 0.910000, -0.020000, 0.000000}},
	{{6, 0, 1, 2}, -0.000310, {-0.020000, -0.010000, -0.010000, 0.000000, 0.000000}},
	{{6, 0, 2, -2}, -0.000180, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 2, 0}, 0.003180, {0.270000, 0.000000, 0.180000, 0.000000, 0.000000}},
	{{6, 0, 2, 2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 3, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 3, 0}, 0.000380, {0.030000, 0.000000, 0.030000, 0.000000, 0.000000}},
	{{6, 0, 4, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -5, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -4, 0}, 0.000280, {0.050000, 0.000000, 0.020000, 0.020000, 0.000000}},
	{{6, 1, -3, 0}, -0.004780, {0.050000, 0.000000, -0.260000, -0.290000, 0.000000}},
	{{6, 1, -3, 2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -2, -2}, -0.000260, {-0.010000, -0.010000, 0.000000, -0.020000, 0.000000}},
	{{6, 1, -2, 0}, -0.012820, {-0.470000, 0.020000, -0.520000, -0.770000, 0.000000}},
	{{6, 1, -2, 2}, 0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -1, -2}, -0.000070, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -1, 0}, -0.010640, {-0.660000, 0.020000, -0.320000, -0.640000, 0.000000}},
	{{6, 1, -1, 2}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 0, -2}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 0, 0}, -0.003960, {-0.310000, 0.010000, -0.120000, -0.240000, 0.000000}},
	{{6, 1, 0, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 1, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 1, 0}, -0.000830, {-0.070000, 0.000000, -0.030000, -0.050000, 0.000000}},
	{{6, 1, 1, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 2, 0}, -0.000130, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 3, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -4, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -3, 0}, -0.000510, {-0.040000, 0.000000, -0.030000, -0.060000, 0.000000}},
	{{6, 2, -2, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -2, 0}, -0.000610, {-0.060000, 0.000000, -0.030000, -0.070000, 0.000000}},
	{{6, 2, -1, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -1, 0}, -0.000210, {-0.020000, 0.000000, 0.000000, -0.030000, 0.000000}},
	{{6, 2, 0, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 3, -2, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -2, -3, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -2, -2, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -1, -4, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{7, -1, -3, 0}, -0.000160, {-0.010000, 0.000000, 0.000000, -0.010000, -0.060000}},
	{{7, -1, -2, 0}, -0.000120, {-0.010000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{7, -1, 0, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -5, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -4, 0}, -0.000250, {-0.020000, 0.000000, -0.020000, 0.000000, -0.100000}},
	{{7, 0, -3, 0}, -0.000980, {-0.070000, 0.000000, -0.060000, 0.000000, -0.380000}},
	{{7, 0, -3, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -2, -2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{7, 0, -2, 0}, -0.000680, {-0.070000, 0.000000, -0.030000, 0.000000, -0.260000}},
	{{7, 0, -2, 2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -1, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{7, 0, -1, 0}, -0.000050, {-0.020000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{7, 0, 0, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, 0, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{7, 1, -3, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{7, 1, -2, 0}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{7, 1, -1, 0}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{7, 1, 0, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{8, -3, -3, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -3, -2, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -3, -1, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -4, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -3, 0}, 0.000190, {0.020000, 0.000000, 0.010000, 0.020000, 0.000000}},
	{{8, -2, -2, 0}, 0.000250, {0.030000, 0.000000, 0.010000, 0.030000, 0.000000}},
	{{8, -2, -1, 0}, 0.000150, {0.020000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{8, -2, 0, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, 1, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -5, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -4, 0}, 0.000580, {0.040000, 0.000000, 0.040000, 0.030000, 0.000000}},
	{{8, -1, -3, 0}, 0.001700, {0.150000, 0.000000, 0.100000, 0.100000, 0.000000}},
	{{8, -1, -3, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -2, 0}, 0.001960, {0.190000, 0.000000, 0.090000, 0.120000, 0.000000}},
	{{8, -1, -2, 2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -1, 0}, 0.001120, {0.120000, 0.000000, 0.040000, 0.070000, 0.000000}},
	{{8, -1, -1, 2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, 0, 0}, 0.000370, {0.040000, 0.000000, 0.020000, 0.020000, 0.000000}},
	{{8, -1, 1, 0}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, 2, 0}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -5, 0}, 0.000180, {0.010000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{8, 0, -4, 0}, 0.003240, {0.250000, 0.000000, 0.240000, 0.000000, 0.000000}},
	{{8, 0, -4, 2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -3, -2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -3, 0}, 0.008400, {0.720000, -0.010000, 0.490000, 0.000000, 0.000000}},
	{{8, 0, -3, 2}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -2, -2}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -2, 0}, 0.008660, {0.830000, -0.020000, 0.400000, 0.000000, 0.000000}},
	{{8, 0, -2, 2}, -0.000110, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -1, -2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -1, 0}, 0.004550, {0.470000, -0.010000, 0.180000, 0.000000, 0.000000}},
	{{8, 0, -1, 2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 0, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 0, 0}, 0.001390, {0.150000, 0.000000, 0.060000, 0.000000, 0.000000}},
	{{8, 0, 0, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 1, -2}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 1, 0}, 0.000290, {0.030000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{8, 0, 2, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -4, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -3, 0}, -0.000240, {-0.010000, 0.000000, -0.010000, -0.010000, 0.000000}},
	{{8, 1, -2, 0}, -0.000290, {-0.020000, 0.000000, -0.010000, -0.020000, 0.000000}},
	{{8, 1, -1, 0}, -0.000170, {-0.020000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{8, 1, 0, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, 1, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 2, -3, 0}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{9, 0, -4, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{9, 0, -3, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, -1, -4, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, -1, -3, 0}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, -1, -2, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, -1, -1, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -5, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -4, 0}, 0.000120, {0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -3, 0}, 0.000170, {0.020000, 0.000000, 0.010000, 0.000000, 0.000000}},
	{{10, 0, -2, 0}, 0.000130, {0.020000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -1, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, 0, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}}
};

static const struct main_problem main_elp2[ELP2_SIZE] =
{
	{{0, 0, 0, 1}, 18461.400000, {0.000000, 412529.610000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 0, 3}, -6.296640, {7.680000, -422.650000, -13.210000, 0.020000, -0.020000}},
	{{0, 0, 0, 5}, 0.005920, {0.000000, 0.660000, 0.020000, 0.000000, 0.000000}},
	{{0, 0, 1, -5}, -0.002360, {0.020000, -0.260000, -0.050000, 0.000000, 0.000000}},
	{{0, 0, 1, -3}, 2.798710, {-17.130000, 188.680000, 50.780000, -0.110000, 0.040000}},
	{{0, 0, 1, -1}, 999.700790, {-563.820000, 22508.540000, 18298.820000, -0.920000, -0.210000}},
	{{0, 0, 1, 1}, 1010.174300, {-93.160000, 22571.830000, 18386.360000, -0.760000, -0.170000}},
	{{0, 0, 1, 3}, -1.019410, {0.950000, -68.420000, -19.880000, 0.000000, 0.000000}},
	{{0, 0, 1, 5}, 0.001560, {0.000000, 0.170000, 0.030000, 0.000000, 0.000000}},
	{{0, 0, 2, -5}, -0.000440, {0.000000, -0.050000, -0.020000, 0.000000, 0.000000}},
	{{0, 0, 2, -3}, -0.130350, {-0.400000, -8.780000, -4.770000, 0.000000, 0.000000}},
	{{0, 0, 2, -1}, 31.759850, {-167.640000, 723.950000, 1159.970000, -1.090000, 0.220000}},
	{{0, 0, 2, 1}, 61.912290, {-23.730000, 1382.400000, 2253.180000, -0.620000, -0.060000}},
	{{0, 0, 2, 3}, -0.117870, {0.110000, -7.910000, -4.410000, 0.000000, 0.000000}},
	{{0, 0, 2, 5}, 0.000260, {0.000000, 0.030000, 0.010000, 0.000000, 0.000000}},
	{{0, 0, 3, -5}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 3, -3}, -0.001460, {0.040000, -0.100000, -0.080000, 0.000000, 0.000000}},
	{{0, 0, 3, -1}, 1.581310, {-10.250000, 36.060000, 86.530000, -0.080000, 0.000000}},
	{{0, 0, 3, 1}, 3.984070, {-3.300000, 88.860000, 217.430000, -0.110000, -0.010000}},
	{{0, 0, 3, 3}, -0.011810, {0.010000, -0.790000, -0.650000, 0.000000, 0.000000}},
	{{0, 0, 3, 5}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 4, -3}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 4, -1}, 0.091570, {-0.700000, 2.090000, 6.680000, 0.000000, 0.000000}},
	{{0, 0, 4, 1}, 0.263250, {-0.370000, 5.860000, 19.150000, -0.010000, 0.000000}},
	{{0, 0, 4, 3}, -0.001090, {0.000000, -0.070000, -0.080000, 0.000000, 0.000000}},
	{{0, 0, 5, -1}, 0.005660, {-0.050000, 0.130000, 0.510000, 0.000000, 0.000000}},
	{{0, 0, 5, 1}, 0.017680, {-0.040000, 0.390000, 1.610000, 0.000000, 0.000000}},
	{{0, 0, 5, 3}, -0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 6, -1}, 0.000360, {0.000000, 0.000000, 0.040000, 0.000000, 0.000000}},
	{{0, 0, 6, 1}, 0.001200, {0.000000, 0.030000, 0.130000, 0.000000, 0.000000}},
	{{0, 0, 7, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 7, 1}, 0.000080, {0.000000, 0.000000, 0.010000, 0.000000, 0.000000}},
	{{0, 1, -6, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -6, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -5, -1}, -0.000530, {-0.010000, -0.010000, -0.050000, -0.030000, 0.000000}},
	{{0, 1, -5, 1}, -0.000140, {0.000000, 0.000000, -0.010000, 0.000000, 0.000000}},
	{{0, 1, -4, -3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -4, -1}, -0.006460, {-0.140000, -0.140000, -0.470000, -0.390000, 0.000000}},
	{{0, 1, -4, 1}, -0.001860, {-0.020000, -0.040000, -0.140000, -0.110000, 0.000000}},
	{{0, 1, -3, -3}, 0.000230, {0.000000, 0.010000, 0.010000, 0.010000, 0.000000}},
	{{0, 1, -3, -1}, -0.074790, {-1.690000, -1.630000, -4.080000, -4.480000, 0.000000}},
	{{0, 1, -3, 1}, -0.023650, {-0.350000, -0.530000, -1.290000, -1.420000, 0.000000}},
	{{0, 1, -3, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -2, -3}, 0.001540, {0.030000, 0.100000, 0.060000, 0.090000, 0.000000}},
	{{0, 1, -2, -1}, -0.793220, {-18.590000, -17.320000, -28.860000, -47.520000, -0.010000}},
	{{0, 1, -2, 1}, -0.301290, {-4.790000, -6.710000, -11.010000, -18.040000, -0.010000}},
	{{0, 1, -2, 3}, 0.001910, {0.060000, 0.130000, 0.070000, 0.120000, 0.000000}},
	{{0, 1, -1, -5}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -1, -3}, 0.006790, {0.140000, 0.450000, 0.140000, 0.410000, 0.000000}},
	{{0, 1, -1, -1}, -6.731730, {-159.360000, -146.940000, -122.890000, -403.360000, -0.030000}},
	{{0, 1, -1, 1}, -5.632600, {-148.810000, -123.960000, -102.800000, -337.620000, -0.040000}},
	{{0, 1, -1, 3}, -0.009110, {-0.200000, -0.610000, -0.150000, -0.550000, 0.000000}},
	{{0, 1, 0, -3}, 0.000100, {-0.170000, 0.000000, 0.060000, 0.000000, 0.000000}},
	{{0, 1, 0, -1}, -4.839830, {70.860000, -100.970000, -8.740000, -289.050000, 0.020000}},
	{{0, 1, 0, 1}, -6.460360, {28.140000, -136.250000, -20.210000, -386.090000, 0.290000}},
	{{0, 1, 0, 3}, 0.011570, {0.060000, 0.770000, 0.040000, 0.690000, 0.000000}},
	{{0, 1, 0, 5}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 1, -3}, -0.007030, {-0.040000, -0.470000, -0.130000, -0.420000, 0.000000}},
	{{0, 1, 1, -1}, -5.076140, {-113.160000, -112.230000, -93.120000, -304.280000, 0.000000}},
	{{0, 1, 1, 1}, -5.311510, {-99.030000, -115.960000, -99.190000, -318.300000, 0.060000}},
	{{0, 1, 1, 3}, 0.006680, {0.100000, 0.450000, 0.130000, 0.400000, 0.000000}},
	{{0, 1, 1, 5}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 2, -3}, 0.001410, {0.040000, 0.090000, 0.050000, 0.080000, 0.000000}},
	{{0, 1, 2, -1}, -0.312920, {-4.920000, -6.960000, -11.470000, -18.750000, 0.000000}},
	{{0, 1, 2, 1}, -0.638840, {-12.560000, -13.950000, -23.510000, -38.290000, 0.010000}},
	{{0, 1, 2, 3}, 0.001350, {0.020000, 0.090000, 0.050000, 0.080000, 0.000000}},
	{{0, 1, 3, -3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 3, -1}, -0.024190, {-0.360000, -0.540000, -1.330000, -1.450000, 0.000000}},
	{{0, 1, 3, 1}, -0.061760, {-1.230000, -1.350000, -3.400000, -3.700000, 0.000000}},
	{{0, 1, 3, 3}, 0.000200, {0.000000, 0.010000, 0.010000, 0.010000, 0.000000}},
	{{0, 1, 4, -1}, -0.001910, {-0.030000, -0.040000, -0.140000, -0.110000, 0.000000}},
	{{0, 1, 4, 1}, -0.005480, {-0.110000, -0.120000, -0.400000, -0.330000, 0.000000}},
	{{0, 1, 4, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 5, -1}, -0.000150, {0.000000, 0.000000, -0.010000, 0.000000, 0.000000}},
	{{0, 1, 5, 1}, -0.000460, {0.000000, -0.010000, -0.040000, -0.030000, 0.000000}},
	{{0, 1, 6, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 6, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -5, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -4, -1}, -0.000160, {0.000000, 0.000000, -0.010000, -0.020000, 0.000000}},
	{{0, 2, -4, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -3, -1}, -0.001690, {-0.050000, -0.040000, -0.090000, -0.200000, 0.000000}},
	{{0, 2, -3, 1}, -0.000490, {-0.010000, -0.010000, -0.030000, -0.060000, 0.000000}},
	{{0, 2, -2, -3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -2, -1}, -0.015710, {-0.490000, -0.340000, -0.570000, -1.880000, 0.000000}},
	{{0, 2, -2, 1}, -0.005360, {-0.120000, -0.120000, -0.200000, -0.640000, 0.000000}},
	{{0, 2, -2, 3}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -1, -3}, 0.000100, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{0, 2, -1, -1}, -0.113350, {-3.250000, -2.460000, -2.070000, -13.580000, 0.000000}},
	{{0, 2, -1, 1}, -0.095110, {-3.170000, -2.080000, -1.730000, -11.390000, 0.000000}},
	{{0, 2, -1, 3}, -0.000090, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{0, 2, 0, -3}, -0.000140, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{0, 2, 0, -1}, -0.018010, {3.130000, -0.330000, -0.140000, -2.140000, 0.000000}},
	{{0, 2, 0, 1}, -0.057290, {2.090000, -1.190000, -0.390000, -6.840000, 0.000000}},
	{{0, 2, 0, 3}, 0.000160, {0.000000, 0.010000, 0.000000, 0.020000, 0.000000}},
	{{0, 2, 1, -3}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 1, -1}, -0.061870, {-1.290000, -1.370000, -1.130000, -7.410000, 0.000000}},
	{{0, 2, 1, 1}, -0.055040, {-0.810000, -1.210000, -1.040000, -6.590000, 0.000000}},
	{{0, 2, 1, 3}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 2, -3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 2, -1}, -0.002840, {-0.020000, -0.060000, -0.100000, -0.340000, 0.000000}},
	{{0, 2, 2, 1}, -0.005280, {-0.060000, -0.120000, -0.190000, -0.630000, 0.000000}},
	{{0, 2, 2, 3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 3, -1}, -0.000160, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{0, 2, 3, 1}, -0.000370, {0.000000, 0.000000, -0.020000, -0.040000, 0.000000}},
	{{0, 2, 4, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -3, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -3, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -2, -1}, -0.000330, {-0.010000, 0.000000, -0.010000, -0.060000, 0.000000}},
	{{0, 3, -2, 1}, -0.000110, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{0, 3, -1, -1}, -0.002160, {-0.070000, -0.050000, -0.040000, -0.390000, 0.000000}},
	{{0, 3, -1, 1}, -0.001900, {-0.070000, -0.040000, -0.030000, -0.340000, 0.000000}},
	{{0, 3, 0, -1}, 0.000660, {0.110000, 0.020000, 0.000000, 0.120000, 0.000000}},
	{{0, 3, 0, 1}, -0.000310, {0.080000, 0.000000, 0.000000, -0.060000, 0.000000}},
	{{0, 3, 1, -1}, -0.001090, {-0.020000, -0.020000, -0.020000, -0.190000, 0.000000}},
	{{0, 3, 1, 1}, -0.000830, {-0.010000, -0.020000, -0.020000, -0.150000, 0.000000}},
	{{0, 3, 2, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, 2, 1}, -0.000080, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{0, 4, -1, -1}, -0.000040, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{0, 4, -1, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 4, 0, -1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 4, 0, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 4, 1, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 4, 1, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -3, -1, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{1, -3, 0, -1}, 0.000110, {0.000000, 0.000000, 0.000000, 0.020000, 0.040000}},
	{{1, -3, 0, 1}, 0.000120, {0.000000, 0.000000, 0.000000, 0.020000, 0.050000}},
	{{1, -3, 1, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -2, -2, -1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, -2, -2, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, -2, -1, -1}, 0.000640, {0.000000, 0.010000, 0.010000, 0.080000, 0.250000}},
	{{1, -2, -1, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -2, 0, -1}, 0.002040, {0.020000, 0.050000, 0.000000, 0.240000, 0.790000}},
	{{1, -2, 0, 1}, 0.002140, {0.000000, 0.050000, 0.000000, 0.260000, 0.830000}},
	{{1, -2, 1, -1}, -0.000600, {-0.010000, -0.010000, -0.010000, -0.070000, -0.230000}},
	{{1, -2, 1, 1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, -2, 2, -1}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{1, -2, 2, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, -1, -4, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{1, -1, -3, -1}, 0.000180, {0.000000, 0.000000, 0.010000, 0.010000, 0.070000}},
	{{1, -1, -3, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, -1, -2, -1}, 0.000960, {0.000000, 0.020000, 0.040000, 0.060000, 0.370000}},
	{{1, -1, -2, 1}, -0.001370, {-0.030000, -0.030000, -0.050000, -0.080000, -0.530000}},
	{{1, -1, -1, -3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, -1, -1, -1}, 0.010310, {0.070000, 0.230000, 0.200000, 0.620000, 4.010000}},
	{{1, -1, -1, 1}, 0.000800, {0.040000, 0.030000, 0.000000, 0.050000, 0.310000}},
	{{1, -1, 0, -3}, -0.000520, {0.000000, -0.030000, 0.000000, -0.030000, -0.200000}},
	{{1, -1, 0, -1}, -0.013460, {-1.070000, -0.270000, 0.000000, -0.820000, -5.230000}},
	{{1, -1, 0, 1}, -0.018290, {-1.520000, -0.330000, 0.000000, -1.110000, -7.110000}},
	{{1, -1, 0, 3}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, -1, 1, -3}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{1, -1, 1, -1}, -0.020120, {-0.420000, -0.450000, -0.380000, -1.200000, -7.830000}},
	{{1, -1, 1, 1}, -0.008450, {-0.450000, -0.170000, -0.170000, -0.510000, -3.290000}},
	{{1, -1, 1, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, 2, -1}, -0.001750, {-0.040000, -0.040000, -0.060000, -0.100000, -0.680000}},
	{{1, -1, 2, 1}, -0.001460, {-0.070000, -0.030000, -0.060000, -0.090000, -0.570000}},
	{{1, -1, 3, -1}, -0.000150, {0.000000, 0.000000, 0.000000, 0.000000, -0.060000}},
	{{1, -1, 3, 1}, -0.000180, {0.000000, 0.000000, -0.010000, -0.010000, -0.070000}},
	{{1, -1, 4, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, 4, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, -5, -1}, -0.000110, {0.000000, 0.000000, -0.010000, 0.000000, -0.040000}},
	{{1, 0, -5, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, 0, -4, -1}, -0.001220, {-0.040000, -0.030000, -0.090000, 0.000000, -0.470000}},
	{{1, 0, -4, 1}, -0.000430, {0.000000, 0.000000, -0.030000, 0.000000, -0.170000}},
	{{1, 0, -3, -1}, -0.012550, {-0.370000, -0.270000, -0.690000, 0.000000, -4.880000}},
	{{1, 0, -3, 1}, -0.005370, {-0.120000, -0.120000, -0.290000, 0.000000, -2.090000}},
	{{1, 0, -3, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, -2, -3}, -0.000250, {0.000000, -0.020000, 0.000000, 0.000000, -0.100000}},
	{{1, 0, -2, -1}, -0.109640, {-3.190000, -2.330000, -4.030000, -0.020000, -42.630000}},
	{{1, 0, -2, 1}, -0.078460, {-2.000000, -1.720000, -2.870000, -0.030000, -30.510000}},
	{{1, 0, -2, 3}, -0.000200, {0.000000, -0.010000, 0.000000, 0.000000, -0.080000}},
	{{1, 0, -1, -3}, -0.003690, {-0.040000, -0.250000, -0.070000, 0.000000, -1.440000}},
	{{1, 0, -1, -1}, -0.429890, {-13.130000, -8.830000, -8.150000, -0.010000, -167.150000}},
	{{1, 0, -1, 1}, 0.139280, {1.860000, 3.370000, 2.460000, 0.040000, 54.160000}},
	{{1, 0, -1, 3}, 0.002340, {0.050000, 0.160000, 0.040000, 0.000000, 0.910000}},
	{{1, 0, 0, -5}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{1, 0, 0, -3}, -0.032260, {-0.410000, -2.150000, 0.000000, 0.000000, -12.540000}},
	{{1, 0, 0, -1}, -4.805780, {-102.500000, -103.390000, -3.120000, -0.090000, -1868.590000}},
	{{1, 0, 0, 1}, -5.368440, {-119.820000, -113.860000, -3.160000, -0.080000, -2087.370000}},
	{{1, 0, 0, 3}, 0.006450, {0.150000, 0.430000, 0.020000, 0.000000, 2.510000}},
	{{1, 0, 0, 5}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, 1, -5}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, 1, -3}, -0.000190, {0.010000, -0.010000, 0.000000, 0.000000, -0.070000}},
	{{1, 0, 1, -1}, -0.588930, {-7.870000, -13.100000, -10.900000, 0.030000, -228.990000}},
	{{1, 0, 1, 1}, -0.667410, {-14.680000, -14.150000, -12.470000, 0.070000, -259.500000}},
	{{1, 0, 1, 3}, 0.001420, {0.030000, 0.090000, 0.030000, 0.000000, 0.550000}},
	{{1, 0, 2, -1}, -0.036360, {-0.400000, -0.810000, -1.340000, 0.000000, -14.140000}},
	{{1, 0, 2, 1}, -0.063830, {-1.350000, -1.350000, -2.350000, 0.020000, -24.820000}},
	{{1, 0, 2, 3}, 0.000210, {0.000000, 0.010000, 0.000000, 0.000000, 0.080000}},
	{{1, 0, 3, -1}, -0.002470, {-0.020000, -0.050000, -0.140000, 0.000000, -0.960000}},
	{{1, 0, 3, 1}, -0.005530, {-0.110000, -0.120000, -0.300000, 0.000000, -2.150000}},
	{{1, 0, 3, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, 4, -1}, -0.000170, {0.000000, 0.000000, -0.010000, 0.000000, -0.070000}},
	{{1, 0, 4, 1}, -0.000450, {0.000000, 0.000000, -0.030000, 0.000000, -0.180000}},
	{{1, 0, 5, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, 5, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, 1, -5, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, -4, -1}, 0.000170, {0.000000, 0.000000, 0.010000, 0.010000, 0.070000}},
	{{1, 1, -4, 1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 1, -3, -1}, 0.001860, {0.020000, 0.040000, 0.100000, 0.110000, 0.720000}},
	{{1, 1, -3, 1}, 0.000930, {0.000000, 0.020000, 0.050000, 0.060000, 0.360000}},
	{{1, 1, -2, -3}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, -2, -1}, 0.015970, {0.200000, 0.350000, 0.590000, 0.960000, 6.210000}},
	{{1, 1, -2, 1}, 0.016800, {0.230000, 0.380000, 0.610000, 1.010000, 6.530000}},
	{{1, 1, -2, 3}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 1, -1, -3}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 1, -1, -1}, 0.006350, {-0.380000, 0.070000, 0.200000, 0.360000, 2.460000}},
	{{1, 1, -1, 1}, -0.055900, {-0.180000, -1.290000, -0.970000, -3.360000, -21.740000}},
	{{1, 1, -1, 3}, -0.000210, {0.000000, -0.010000, 0.000000, -0.010000, -0.080000}},
	{{1, 1, 0, -3}, 0.000800, {0.000000, 0.050000, 0.000000, 0.050000, 0.310000}},
	{{1, 1, 0, -1}, 0.804260, {0.220000, 17.530000, 1.110000, 48.120000, 312.710000}},
	{{1, 1, 0, 1}, 0.802630, {0.340000, 17.410000, 0.850000, 48.020000, 312.080000}},
	{{1, 1, 0, 3}, -0.000830, {0.000000, -0.060000, 0.000000, -0.050000, -0.320000}},
	{{1, 1, 1, -3}, -0.000210, {0.010000, -0.010000, 0.000000, -0.010000, -0.080000}},
	{{1, 1, 1, -1}, 0.034650, {0.090000, 0.750000, 0.710000, 2.070000, 13.480000}},
	{{1, 1, 1, 1}, 0.101760, {0.150000, 2.200000, 1.970000, 6.090000, 39.570000}},
	{{1, 1, 1, 3}, -0.000200, {0.000000, -0.010000, 0.000000, -0.010000, -0.080000}},
	{{1, 1, 2, -3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, 2, -1}, 0.003170, {0.000000, 0.070000, 0.120000, 0.190000, 1.230000}},
	{{1, 1, 2, 1}, 0.010160, {0.030000, 0.220000, 0.380000, 0.610000, 3.950000}},
	{{1, 1, 2, 3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, 1, 3, -1}, 0.000270, {0.000000, 0.000000, 0.020000, 0.020000, 0.110000}},
	{{1, 1, 3, 1}, 0.000930, {0.000000, 0.020000, 0.050000, 0.060000, 0.360000}},
	{{1, 1, 4, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, 4, 1}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 2, -3, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{1, 2, -3, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 2, -2, -1}, 0.000170, {0.000000, 0.000000, 0.000000, 0.020000, 0.060000}},
	{{1, 2, -2, 1}, 0.000160, {0.000000, 0.000000, 0.000000, 0.020000, 0.060000}},
	{{1, 2, -1, -1}, -0.000080, {0.000000, 0.000000, 0.000000, -0.010000, -0.030000}},
	{{1, 2, -1, 1}, -0.000390, {-0.020000, 0.000000, 0.000000, -0.050000, -0.150000}},
	{{1, 2, 0, -1}, -0.001700, {-0.030000, -0.040000, 0.000000, -0.200000, -0.660000}},
	{{1, 2, 0, 1}, -0.002040, {-0.030000, -0.040000, 0.000000, -0.240000, -0.790000}},
	{{1, 2, 1, -1}, -0.000220, {0.000000, 0.000000, 0.000000, -0.030000, -0.090000}},
	{{1, 2, 1, 1}, -0.000720, {-0.010000, -0.020000, -0.010000, -0.090000, -0.280000}},
	{{1, 2, 2, -1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, 2, 2, 1}, -0.000120, {0.000000, 0.000000, 0.000000, -0.010000, -0.050000}},
	{{1, 2, 3, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 3, 0, -1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{1, 3, 0, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{2, -5, -1, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -5, -1, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -5, 0, -1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{2, -5, 0, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, -2, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, -1, -1}, 0.000310, {0.000000, 0.000000, 0.000000, 0.070000, 0.000000}},
	{{2, -4, -1, 1}, 0.000340, {0.000000, 0.000000, 0.000000, 0.080000, 0.000000}},
	{{2, -4, 0, -1}, 0.001180, {0.030000, 0.030000, 0.000000, 0.280000, 0.000000}},
	{{2, -4, 0, 1}, 0.000620, {0.030000, 0.010000, 0.000000, 0.150000, 0.000000}},
	{{2, -4, 1, -1}, 0.000080, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{2, -4, 1, 1}, 0.000100, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{2, -4, 2, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -3, -1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{2, -3, -2, -1}, 0.000770, {0.020000, 0.020000, 0.030000, 0.140000, 0.000000}},
	{{2, -3, -2, 1}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -1, -1}, 0.009140, {0.250000, 0.200000, 0.170000, 1.640000, 0.000000}},
	{{2, -3, -1, 1}, 0.010420, {0.250000, 0.230000, 0.190000, 1.870000, 0.000000}},
	{{2, -3, -1, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, 0, -3}, 0.000080, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{2, -3, 0, -1}, 0.036470, {0.910000, 0.810000, 0.020000, 6.540000, 0.000000}},
	{{2, -3, 0, 1}, 0.016030, {0.620000, 0.350000, 0.060000, 2.880000, 0.000000}},
	{{2, -3, 0, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, 1, -3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, 1, -1}, 0.002400, {0.070000, 0.050000, 0.050000, 0.430000, 0.000000}},
	{{2, -3, 1, 1}, 0.002560, {0.110000, 0.060000, 0.050000, 0.460000, 0.000000}},
	{{2, -3, 2, -1}, 0.000210, {0.000000, 0.000000, 0.000000, 0.040000, 0.000000}},
	{{2, -3, 2, 1}, 0.000310, {0.010000, 0.000000, 0.010000, 0.060000, 0.000000}},
	{{2, -3, 3, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, 3, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, -4, -1}, 0.000120, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{2, -2, -4, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, -3, -1}, 0.001780, {0.030000, 0.040000, 0.100000, 0.210000, 0.000000}},
	{{2, -2, -3, 1}, 0.000300, {0.000000, 0.000000, 0.020000, 0.040000, 0.000000}},
	{{2, -2, -2, -1}, 0.022850, {0.530000, 0.510000, 0.830000, 2.730000, 0.000000}},
	{{2, -2, -2, 1}, -0.001920, {0.000000, -0.040000, -0.070000, -0.230000, 0.000000}},
	{{2, -2, -2, 3}, -0.000090, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{2, -2, -1, -3}, 0.000240, {0.000000, 0.020000, 0.000000, 0.030000, 0.000000}},
	{{2, -2, -1, -1}, 0.268650, {6.320000, 5.970000, 4.910000, 32.140000, 0.000000}},
	{{2, -2, -1, 1}, 0.314740, {6.780000, 6.970000, 5.750000, 37.650000, 0.000000}},
	{{2, -2, -1, 3}, -0.000450, {0.000000, -0.030000, 0.000000, -0.050000, 0.000000}},
	{{2, -2, 0, -3}, 0.002730, {0.030000, 0.180000, 0.000000, 0.330000, 0.000000}},
	{{2, -2, 0, -1}, 1.085870, {23.510000, 24.250000, 0.470000, 129.870000, 0.000000}},
	{{2, -2, 0, 1}, 0.383530, {13.480000, 8.450000, 1.720000, 45.870000, 0.000000}},
	{{2, -2, 0, 3}, -0.000440, {-0.010000, -0.030000, 0.000000, -0.050000, 0.000000}},
	{{2, -2, 1, -3}, -0.000720, {-0.020000, -0.050000, -0.010000, -0.090000, 0.000000}},
	{{2, -2, 1, -1}, 0.069150, {1.690000, 1.510000, 1.310000, 8.270000, 0.000000}},
	{{2, -2, 1, 1}, 0.058480, {2.240000, 1.280000, 1.260000, 6.990000, 0.000000}},
	{{2, -2, 1, 3}, -0.000110, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{2, -2, 2, -3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 2, -1}, 0.005550, {0.160000, 0.120000, 0.210000, 0.660000, 0.000000}},
	{{2, -2, 2, 1}, 0.006770, {0.270000, 0.150000, 0.270000, 0.810000, 0.000000}},
	{{2, -2, 2, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 3, -1}, 0.000460, {0.010000, 0.000000, 0.030000, 0.060000, 0.000000}},
	{{2, -2, 3, 1}, 0.000700, {0.030000, 0.020000, 0.040000, 0.080000, 0.000000}},
	{{2, -2, 4, -1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 4, 1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -6, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -5, -1}, 0.000290, {0.000000, 0.000000, 0.030000, 0.020000, 0.000000}},
	{{2, -1, -5, 1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -4, -1}, 0.004160, {0.060000, 0.090000, 0.300000, 0.250000, 0.000000}},
	{{2, -1, -4, 1}, 0.000800, {0.000000, 0.020000, 0.060000, 0.050000, 0.000000}},
	{{2, -1, -3, -3}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -3, -1}, 0.055020, {0.990000, 1.230000, 3.010000, 3.290000, 0.000000}},
	{{2, -1, -3, 1}, 0.009350, {0.120000, 0.210000, 0.510000, 0.560000, 0.000000}},
	{{2, -1, -3, 3}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -2, -3}, 0.000330, {-0.010000, 0.020000, 0.010000, 0.020000, 0.000000}},
	{{2, -1, -2, -1}, 0.650250, {13.750000, 14.460000, 23.700000, 38.910000, 0.000000}},
	{{2, -1, -2, 1}, -0.062080, {-0.480000, -1.400000, -2.270000, -3.710000, 0.000000}},
	{{2, -1, -2, 3}, -0.002670, {-0.030000, -0.180000, -0.100000, -0.160000, 0.000000}},
	{{2, -1, -1, -5}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -1, -3}, 0.010340, {0.060000, 0.690000, 0.170000, 0.620000, 0.000000}},
	{{2, -1, -1, -1}, 7.434880, {154.990000, 165.140000, 135.900000, 444.610000, -0.020000}},
	{{2, -1, -1, 1}, 8.868530, {174.250000, 196.330000, 161.680000, 530.290000, -0.010000}},
	{{2, -1, -1, 3}, -0.011770, {-0.230000, -0.790000, -0.240000, -0.700000, 0.000000}},
	{{2, -1, -1, 5}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 0, -5}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 0, -3}, 0.088150, {0.980000, 5.900000, -0.130000, 5.270000, 0.000000}},
	{{2, -1, 0, -1}, 29.577940, {553.390000, 661.640000, 12.430000, 1767.420000, 0.160000}},
	{{2, -1, 0, 1}, 7.958910, {253.110000, 175.210000, 44.350000, 475.600000, 0.000000}},
	{{2, -1, 0, 3}, -0.009440, {-0.280000, -0.630000, -0.110000, -0.560000, 0.000000}},
	{{2, -1, 0, 5}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 1, -5}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 1, -3}, -0.016690, {-0.300000, -1.120000, -0.310000, -1.000000, 0.000000}},
	{{2, -1, 1, -1}, 1.766060, {35.980000, 38.730000, 33.430000, 105.500000, 0.020000}},
	{{2, -1, 1, 1}, 1.134660, {38.360000, 24.880000, 25.430000, 67.780000, 0.000000}},
	{{2, -1, 1, 3}, -0.002240, {-0.070000, -0.150000, -0.060000, -0.130000, 0.000000}},
	{{2, -1, 2, -3}, -0.000610, {-0.010000, -0.040000, -0.020000, -0.040000, 0.000000}},
	{{2, -1, 2, -1}, 0.128970, {2.890000, 2.780000, 4.820000, 7.700000, 0.000000}},
	{{2, -1, 2, 1}, 0.123870, {4.350000, 2.710000, 4.970000, 7.400000, 0.000000}},
	{{2, -1, 2, 3}, -0.000360, {-0.010000, -0.020000, -0.020000, -0.020000, 0.000000}},
	{{2, -1, 3, -3}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 3, -1}, 0.009850, {0.240000, 0.210000, 0.550000, 0.590000, 0.000000}},
	{{2, -1, 3, 1}, 0.012110, {0.440000, 0.260000, 0.700000, 0.720000, 0.000000}},
	{{2, -1, 3, 3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 4, -1}, 0.000760, {0.020000, 0.020000, 0.060000, 0.050000, 0.000000}},
	{{2, -1, 4, 1}, 0.001110, {0.040000, 0.020000, 0.080000, 0.070000, 0.000000}},
	{{2, -1, 5, -1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 5, 1}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -7, -1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -7, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -6, -1}, 0.000920, {0.020000, 0.020000, 0.100000, 0.000000, 0.000000}},
	{{2, 0, -6, 1}, 0.000200, {0.000000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{2, 0, -5, -3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -5, -1}, 0.011270, {0.230000, 0.250000, 1.030000, 0.000000, 0.000000}},
	{{2, 0, -5, 1}, 0.002300, {0.030000, 0.050000, 0.210000, 0.000000, 0.000000}},
	{{2, 0, -4, -3}, -0.000140, {0.000000, 0.000000, -0.010000, 0.000000, 0.000000}},
	{{2, 0, -4, -1}, 0.133810, {2.770000, 2.960000, 9.750000, 0.000000, 0.000000}},
	{{2, 0, -4, 1}, 0.024960, {0.390000, 0.560000, 1.820000, 0.000000, 0.000000}},
	{{2, 0, -4, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -3, -3}, 0.000230, {-0.020000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -3, -1}, 1.515640, {31.760000, 33.590000, 82.840000, 0.070000, 0.000000}},
	{{2, 0, -3, 1}, 0.254080, {3.880000, 5.750000, 13.920000, 0.000000, 0.010000}},
	{{2, 0, -3, 3}, 0.002320, {0.050000, 0.160000, 0.130000, 0.000000, 0.000000}},
	{{2, 0, -3, 5}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -2, -5}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -2, -3}, 0.020450, {0.100000, 1.370000, 0.700000, 0.000000, 0.000000}},
	{{2, 0, -2, -1}, 15.566350, {330.350000, 344.990000, 567.470000, 0.230000, 0.030000}},
	{{2, 0, -2, 1}, -1.624430, {-20.880000, -36.380000, -59.200000, 0.180000, -0.020000}},
	{{2, 0, -2, 3}, -0.065610, {-0.770000, -4.410000, -2.380000, 0.000000, 0.000000}},
	{{2, 0, -2, 5}, 0.000120, {0.000000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -1, -5}, -0.000460, {0.000000, -0.050000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -1, -3}, 0.329070, {3.620000, 22.030000, 5.640000, -0.020000, 0.010000}},
	{{2, 0, -1, -1}, 166.575280, {3219.290000, 3695.900000, 3042.800000, -5.990000, 0.390000}},
	{{2, 0, -1, 1}, 199.485150, {3726.280000, 4413.250000, 3627.390000, -8.680000, 0.730000}},
	{{2, 0, -1, 3}, -0.244840, {-4.550000, -16.390000, -4.940000, 0.020000, 0.000000}},
	{{2, 0, -1, 5}, 0.000380, {0.000000, 0.040000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 0, -5}, -0.002210, {-0.020000, -0.250000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 0, -3}, 2.186370, {23.850000, 146.450000, -2.380000, -0.270000, 0.030000}},
	{{2, 0, 0, -1}, 623.657830, {9963.620000, 13978.190000, 245.160000, -70.260000, 5.000000}},
	{{2, 0, 0, 1}, 117.261610, {3313.250000, 2575.660000, 874.520000, -12.650000, 1.790000}},
	{{2, 0, 0, 3}, -0.144530, {-3.710000, -9.640000, -2.050000, 0.020000, 0.000000}},
	{{2, 0, 0, 5}, 0.000260, {0.000000, 0.030000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 1, -5}, -0.000750, {0.000000, -0.080000, -0.010000, 0.000000, 0.000000}},
	{{2, 0, 1, -3}, -0.291160, {-3.490000, -19.630000, -5.360000, 0.050000, 0.000000}},
	{{2, 0, 1, -1}, 33.357430, {512.770000, 735.760000, 630.310000, -5.210000, 0.430000}},
	{{2, 0, 1, 1}, 15.121650, {433.440000, 331.250000, 359.200000, -2.400000, 0.310000}},
	{{2, 0, 1, 3}, -0.030380, {-0.820000, -2.020000, -0.850000, 0.000000, 0.000000}},
	{{2, 0, 1, 5}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 2, -5}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 2, -3}, -0.009950, {-0.120000, -0.680000, -0.360000, 0.000000, 0.000000}},
	{{2, 0, 2, -1}, 2.146180, {33.220000, 46.620000, 80.120000, -0.450000, 0.040000}},
	{{2, 0, 2, 1}, 1.519760, {43.480000, 33.210000, 62.710000, -0.330000, 0.040000}},
	{{2, 0, 2, 3}, -0.004510, {-0.120000, -0.300000, -0.200000, 0.000000, 0.000000}},
	{{2, 0, 2, 5}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 3, -3}, -0.000930, {0.000000, -0.060000, -0.050000, 0.000000, 0.000000}},
	{{2, 0, 3, -1}, 0.146420, {2.280000, 3.130000, 8.160000, -0.040000, 0.000000}},
	{{2, 0, 3, 1}, 0.137950, {3.920000, 3.010000, 8.150000, -0.040000, 0.000000}},
	{{2, 0, 3, 3}, -0.000560, {-0.020000, -0.040000, -0.030000, 0.000000, 0.000000}},
	{{2, 0, 4, -3}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 4, -1}, 0.010270, {0.160000, 0.220000, 0.760000, 0.000000, 0.000000}},
	{{2, 0, 4, 1}, 0.011860, {0.330000, 0.260000, 0.910000, 0.000000, 0.000000}},
	{{2, 0, 4, 3}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 5, -1}, 0.000730, {0.010000, 0.020000, 0.070000, 0.000000, 0.000000}},
	{{2, 0, 5, 1}, 0.000990, {0.030000, 0.020000, 0.090000, 0.000000, 0.000000}},
	{{2, 0, 6, -1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 6, 1}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -6, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -5, -1}, 0.000280, {0.020000, 0.000000, 0.030000, 0.020000, 0.000000}},
	{{2, 1, -5, 1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -4, -1}, 0.002470, {0.190000, 0.050000, 0.180000, 0.150000, 0.000000}},
	{{2, 1, -4, 1}, 0.000340, {0.030000, 0.000000, 0.030000, 0.020000, 0.000000}},
	{{2, 1, -3, -3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -3, -1}, 0.018180, {1.670000, 0.380000, 0.990000, 1.100000, 0.000000}},
	{{2, 1, -3, 1}, 0.001620, {0.170000, 0.030000, 0.090000, 0.100000, 0.000000}},
	{{2, 1, -2, -3}, -0.000150, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -2, -1}, 0.079130, {12.080000, 1.570000, 2.840000, 4.800000, 0.000000}},
	{{2, 1, -2, 1}, 0.054290, {3.180000, 1.160000, 1.970000, 3.260000, 0.000000}},
	{{2, 1, -2, 3}, 0.000170, {-0.030000, 0.010000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -1, -3}, -0.003420, {0.050000, -0.230000, -0.060000, -0.200000, 0.000000}},
	{{2, 1, -1, -1}, -0.791050, {41.530000, -18.400000, -14.910000, -47.090000, -0.010000}},
	{{2, 1, -1, 1}, -1.317880, {39.710000, -29.980000, -24.580000, -78.590000, 0.000000}},
	{{2, 1, -1, 3}, 0.001920, {-0.030000, 0.130000, 0.040000, 0.110000, 0.000000}},
	{{2, 1, 0, -5}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 0, -3}, -0.054570, {-0.950000, -3.650000, 0.010000, -3.270000, 0.000000}},
	{{2, 1, 0, -1}, -12.094700, {-205.760000, -271.060000, -3.140000, -723.840000, -0.310000}},
	{{2, 1, 0, 1}, -1.264330, {-30.650000, -27.380000, -10.590000, -75.650000, -0.410000}},
	{{2, 1, 0, 3}, 0.001770, {0.040000, 0.120000, 0.030000, 0.110000, 0.000000}},
	{{2, 1, 1, -5}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 1, -3}, 0.004650, {0.020000, 0.310000, 0.090000, 0.280000, 0.000000}},
	{{2, 1, 1, -1}, -0.822750, {-17.020000, -18.200000, -15.410000, -49.250000, -0.040000}},
	{{2, 1, 1, 1}, -0.237020, {-7.850000, -5.100000, -5.790000, -14.190000, -0.080000}},
	{{2, 1, 1, 3}, 0.000520, {0.020000, 0.030000, 0.020000, 0.030000, 0.000000}},
	{{2, 1, 2, -3}, 0.000210, {0.000000, 0.010000, 0.000000, 0.010000, 0.000000}},
	{{2, 1, 2, -1}, -0.062830, {-1.470000, -1.370000, -2.340000, -3.760000, 0.000000}},
	{{2, 1, 2, 1}, -0.031420, {-1.170000, -0.670000, -1.310000, -1.880000, -0.010000}},
	{{2, 1, 2, 3}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 3, -3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 3, -1}, -0.004960, {-0.130000, -0.110000, -0.280000, -0.300000, 0.000000}},
	{{2, 1, 3, 1}, -0.003550, {-0.140000, -0.080000, -0.210000, -0.210000, 0.000000}},
	{{2, 1, 3, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 4, -1}, -0.000400, {-0.010000, 0.000000, -0.030000, -0.020000, 0.000000}},
	{{2, 1, 4, 1}, -0.000370, {-0.020000, 0.000000, -0.030000, -0.020000, 0.000000}},
	{{2, 1, 5, -1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 5, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -4, -1}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -4, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -3, -1}, -0.001020, {-0.030000, -0.020000, -0.060000, -0.120000, 0.000000}},
	{{2, 2, -3, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -2, -3}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -2, -1}, -0.012620, {-0.470000, -0.280000, -0.460000, -1.510000, 0.000000}},
	{{2, 2, -2, 1}, -0.005040, {-0.270000, -0.110000, -0.190000, -0.600000, 0.000000}},
	{{2, 2, -2, 3}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -1, -3}, -0.000460, {-0.020000, -0.030000, 0.000000, -0.060000, 0.000000}},
	{{2, 2, -1, -1}, -0.105350, {-3.660000, -2.340000, -1.910000, -12.620000, 0.000000}},
	{{2, 2, -1, 1}, -0.113300, {-3.820000, -2.500000, -2.080000, -13.580000, 0.000000}},
	{{2, 2, -1, 3}, 0.000120, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{2, 2, 0, -3}, -0.001030, {-0.020000, -0.060000, 0.020000, -0.120000, 0.000000}},
	{{2, 2, 0, -1}, -0.134150, {-2.410000, -3.040000, -0.260000, -16.070000, 0.000000}},
	{{2, 2, 0, 1}, -0.014820, {-0.520000, -0.320000, -0.530000, -1.780000, 0.030000}},
	{{2, 2, 0, 3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, 1, -3}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, 1, -1}, -0.006170, {-0.080000, -0.140000, -0.130000, -0.740000, 0.000000}},
	{{2, 2, 1, 1}, -0.001450, {-0.050000, -0.030000, -0.080000, -0.170000, 0.000000}},
	{{2, 2, 2, -1}, -0.000250, {0.000000, 0.000000, -0.010000, -0.030000, 0.000000}},
	{{2, 2, 2, 1}, -0.000090, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{2, 3, -2, -1}, -0.000060, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{2, 3, -2, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, -1, -1}, -0.000090, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{2, 3, -1, 1}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, 0, -1}, 0.000370, {0.010000, 0.000000, 0.000000, 0.070000, 0.000000}},
	{{2, 3, 0, 1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, 1, -1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{3, -3, -1, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -3, -1, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{3, -3, 0, -1}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -2, -3, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -2, -2, -1}, -0.000140, {0.000000, 0.000000, 0.000000, -0.020000, -0.060000}},
	{{3, -2, -2, 1}, -0.000160, {0.000000, 0.000000, 0.000000, -0.020000, -0.060000}},
	{{3, -2, -1, -1}, -0.001010, {-0.030000, -0.020000, -0.020000, -0.120000, -0.390000}},
	{{3, -2, -1, 1}, -0.000630, {-0.030000, -0.010000, -0.010000, -0.080000, -0.250000}},
	{{3, -2, 0, -3}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -2, 0, -1}, -0.001310, {-0.050000, -0.030000, 0.000000, -0.160000, -0.510000}},
	{{3, -2, 0, 1}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{3, -2, 1, -1}, -0.000140, {0.000000, 0.000000, 0.000000, -0.020000, -0.060000}},
	{{3, -2, 2, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, -4, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, -3, -1}, -0.000220, {0.000000, 0.000000, -0.010000, -0.010000, -0.080000}},
	{{3, -1, -2, -1}, -0.002820, {-0.070000, -0.060000, -0.100000, -0.170000, -1.100000}},
	{{3, -1, -2, 1}, -0.003290, {-0.070000, -0.070000, -0.120000, -0.200000, -1.280000}},
	{{3, -1, -1, -3}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{3, -1, -1, -1}, -0.021040, {-0.530000, -0.470000, -0.390000, -1.260000, -8.180000}},
	{{3, -1, -1, 1}, -0.013560, {-0.550000, -0.290000, -0.270000, -0.810000, -5.270000}},
	{{3, -1, -1, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, 0, -3}, -0.000760, {-0.010000, -0.050000, 0.000000, -0.050000, -0.300000}},
	{{3, -1, 0, -1}, -0.025720, {-0.940000, -0.600000, -0.070000, -1.530000, -10.000000}},
	{{3, -1, 0, 1}, -0.000420, {-0.190000, 0.000000, -0.100000, -0.020000, -0.160000}},
	{{3, -1, 0, 3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, 1, -1}, -0.002750, {-0.110000, -0.060000, -0.060000, -0.160000, -1.070000}},
	{{3, -1, 1, 1}, -0.000300, {-0.050000, 0.000000, -0.020000, -0.020000, -0.120000}},
	{{3, -1, 2, -1}, -0.000270, {-0.010000, 0.000000, -0.010000, -0.020000, -0.100000}},
	{{3, -1, 2, 1}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{3, -1, 3, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, 3, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, -4, -1}, -0.000160, {0.000000, 0.000000, -0.010000, 0.000000, -0.060000}},
	{{3, 0, -4, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{3, 0, -3, -1}, -0.002870, {-0.040000, -0.060000, -0.160000, 0.000000, -1.120000}},
	{{3, 0, -3, 1}, 0.000150, {0.000000, 0.000000, 0.000000, 0.000000, 0.060000}},
	{{3, 0, -3, 3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, -2, -3}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{3, 0, -2, -1}, -0.039410, {-0.880000, -0.870000, -1.440000, 0.000000, -15.320000}},
	{{3, 0, -2, 1}, -0.048520, {-1.040000, -1.060000, -1.770000, 0.000000, -18.870000}},
	{{3, 0, -2, 3}, 0.000160, {0.000000, 0.010000, 0.000000, 0.000000, 0.060000}},
	{{3, 0, -1, -3}, -0.001280, {-0.010000, -0.090000, -0.020000, 0.000000, -0.500000}},
	{{3, 0, -1, -1}, -0.305170, {-7.430000, -6.740000, -5.660000, 0.080000, -118.660000}},
	{{3, 0, -1, 1}, -0.205930, {-7.880000, -4.390000, -4.050000, 0.120000, -80.070000}},
	{{3, 0, -1, 3}, 0.000380, {0.020000, 0.020000, 0.000000, 0.000000, 0.150000}},
	{{3, 0, 0, -3}, -0.010090, {-0.130000, -0.680000, 0.000000, 0.000000, -3.920000}},
	{{3, 0, 0, -1}, -0.351830, {-11.870000, -8.150000, -0.990000, 0.220000, -136.800000}},
	{{3, 0, 0, 1}, -0.028400, {-2.770000, -0.490000, -1.370000, 0.100000, -11.040000}},
	{{3, 0, 0, 3}, 0.000160, {0.000000, 0.010000, 0.000000, 0.000000, 0.060000}},
	{{3, 0, 1, -3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, 1, -1}, -0.036110, {-1.260000, -0.830000, -0.750000, 0.030000, -14.040000}},
	{{3, 0, 1, 1}, -0.006580, {-0.560000, -0.120000, -0.290000, 0.020000, -2.560000}},
	{{3, 0, 1, 3}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, 0, 2, -1}, -0.003220, {-0.120000, -0.070000, -0.130000, 0.000000, -1.250000}},
	{{3, 0, 2, 1}, -0.001080, {-0.080000, -0.020000, -0.060000, 0.000000, -0.420000}},
	{{3, 0, 3, -1}, -0.000270, {-0.010000, 0.000000, -0.020000, 0.000000, -0.110000}},
	{{3, 0, 3, 1}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{3, 0, 4, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, 4, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -4, -1}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{3, 1, -4, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -3, -1}, -0.000440, {-0.020000, 0.000000, -0.020000, -0.030000, -0.170000}},
	{{3, 1, -3, 1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{3, 1, -2, -1}, -0.001520, {-0.090000, -0.030000, -0.060000, -0.090000, -0.590000}},
	{{3, 1, -2, 1}, -0.002610, {-0.120000, -0.060000, -0.090000, -0.160000, -1.020000}},
	{{3, 1, -1, -3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.010000}},
	{{3, 1, -1, -1}, 0.013210, {0.230000, 0.290000, 0.250000, 0.790000, 5.140000}},
	{{3, 1, -1, 1}, 0.020830, {0.370000, 0.450000, 0.390000, 1.240000, 8.100000}},
	{{3, 1, -1, 3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 1, 0, -3}, 0.000310, {0.000000, 0.020000, 0.000000, 0.020000, 0.120000}},
	{{3, 1, 0, -1}, 0.034360, {0.680000, 0.770000, 0.090000, 2.050000, 13.360000}},
	{{3, 1, 0, 1}, 0.013510, {0.390000, 0.290000, 0.170000, 0.810000, 5.250000}},
	{{3, 1, 0, 3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{3, 1, 1, -1}, 0.004260, {0.090000, 0.090000, 0.090000, 0.250000, 1.660000}},
	{{3, 1, 1, 1}, 0.002580, {0.080000, 0.050000, 0.070000, 0.150000, 1.000000}},
	{{3, 1, 2, -1}, 0.000440, {0.000000, 0.000000, 0.020000, 0.030000, 0.170000}},
	{{3, 1, 2, 1}, 0.000350, {0.010000, 0.000000, 0.020000, 0.020000, 0.140000}},
	{{3, 1, 3, -1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, 1, 3, 1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, 2, -2, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 2, -2, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 2, -1, -1}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 2, -1, 1}, -0.000100, {0.000000, 0.000000, 0.000000, -0.010000, -0.040000}},
	{{3, 2, 0, -1}, -0.000560, {0.000000, -0.010000, 0.000000, -0.070000, -0.220000}},
	{{3, 2, 0, 1}, -0.000160, {0.000000, 0.000000, 0.000000, -0.020000, -0.060000}},
	{{3, 2, 1, -1}, -0.000090, {0.000000, 0.000000, 0.000000, -0.010000, -0.030000}},
	{{3, 2, 1, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 2, 2, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 3, -1, -3}, 0.000010, {0.000000, 0.000000, -0.020000, -0.010000, 0.030000}},
	{{3, 3, -1, -1}, 0.000000, {-0.010000, 0.000000, -0.010000, -0.020000, 0.010000}},
	{{3, 3, -1, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -4, -2, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -4, -1, -1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, -4, -1, 1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, -4, 0, -1}, 0.000080, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, -4, 0, 1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{4, -4, 1, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, -2, -1}, 0.000130, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, -3, -2, 1}, 0.000590, {0.030000, 0.010000, 0.020000, 0.110000, 0.000000}},
	{{4, -3, -1, -1}, 0.001650, {0.070000, 0.040000, 0.030000, 0.300000, 0.000000}},
	{{4, -3, -1, 1}, 0.001340, {0.070000, 0.030000, 0.030000, 0.240000, 0.000000}},
	{{4, -3, 0, -3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, 0, -1}, 0.001610, {0.080000, 0.040000, 0.000000, 0.290000, 0.000000}},
	{{4, -3, 0, 1}, 0.000800, {0.050000, 0.020000, 0.010000, 0.140000, 0.000000}},
	{{4, -3, 1, -1}, 0.000240, {0.010000, 0.000000, 0.000000, 0.040000, 0.000000}},
	{{4, -3, 1, 1}, 0.000170, {0.010000, 0.000000, 0.000000, 0.030000, 0.000000}},
	{{4, -3, 2, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, 2, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -4, -1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -3, -1}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -3, 1}, 0.000110, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{4, -2, -2, -3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -2, -1}, 0.002830, {0.110000, 0.060000, 0.100000, 0.340000, 0.000000}},
	{{4, -2, -2, 1}, 0.012300, {0.500000, 0.270000, 0.450000, 1.470000, 0.000000}},
	{{4, -2, -2, 3}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -1, -3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -1, -1}, 0.034620, {1.290000, 0.770000, 0.650000, 4.140000, 0.000000}},
	{{4, -2, -1, 1}, 0.023800, {1.250000, 0.520000, 0.530000, 2.850000, 0.000000}},
	{{4, -2, -1, 3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 0, -3}, 0.000290, {0.000000, 0.020000, 0.000000, 0.040000, 0.000000}},
	{{4, -2, 0, -1}, 0.028990, {1.410000, 0.650000, 0.180000, 3.460000, 0.000000}},
	{{4, -2, 0, 1}, 0.012700, {0.790000, 0.270000, 0.200000, 1.520000, 0.000000}},
	{{4, -2, 0, 3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 1, -3}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 1, -1}, 0.004170, {0.210000, 0.090000, 0.100000, 0.500000, 0.000000}},
	{{4, -2, 1, 1}, 0.002550, {0.170000, 0.060000, 0.080000, 0.300000, 0.000000}},
	{{4, -2, 2, -1}, 0.000470, {0.030000, 0.010000, 0.020000, 0.060000, 0.000000}},
	{{4, -2, 2, 1}, 0.000370, {0.030000, 0.000000, 0.020000, 0.040000, 0.000000}},
	{{4, -2, 3, -1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 3, 1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -6, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -5, -1}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -4, -1}, -0.000580, {-0.020000, -0.010000, -0.040000, -0.030000, 0.000000}},
	{{4, -1, -4, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -3, -3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -3, -1}, -0.000900, {-0.030000, -0.020000, -0.050000, -0.050000, 0.000000}},
	{{4, -1, -3, 1}, 0.001910, {0.120000, 0.040000, 0.100000, 0.110000, 0.000000}},
	{{4, -1, -3, 3}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -2, -3}, -0.000330, {-0.010000, -0.020000, -0.010000, -0.020000, 0.000000}},
	{{4, -1, -2, -1}, 0.052510, {1.990000, 1.160000, 1.920000, 3.140000, 0.000000}},
	{{4, -1, -2, 1}, 0.213760, {8.240000, 4.680000, 7.800000, 12.770000, 0.000000}},
	{{4, -1, -2, 3}, -0.000600, {-0.020000, -0.040000, -0.020000, -0.040000, 0.000000}},
	{{4, -1, -1, -3}, -0.000650, {-0.040000, -0.040000, -0.010000, -0.040000, 0.000000}},
	{{4, -1, -1, -1}, 0.595800, {21.190000, 13.270000, 11.160000, 35.530000, 0.020000}},
	{{4, -1, -1, 1}, 0.338820, {16.920000, 7.360000, 7.740000, 20.210000, 0.000000}},
	{{4, -1, -1, 3}, -0.000750, {-0.040000, -0.050000, -0.020000, -0.040000, 0.000000}},
	{{4, -1, 0, -5}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 0, -3}, 0.005340, {0.130000, 0.360000, 0.000000, 0.320000, 0.000000}},
	{{4, -1, 0, -1}, 0.414960, {19.000000, 9.230000, 2.870000, 24.710000, 0.000000}},
	{{4, -1, 0, 1}, 0.157910, {9.240000, 3.410000, 2.730000, 9.410000, 0.000000}},
	{{4, -1, 0, 3}, -0.000370, {-0.020000, -0.020000, 0.000000, -0.020000, 0.000000}},
	{{4, -1, 1, -3}, -0.000620, {-0.020000, -0.040000, -0.010000, -0.040000, 0.000000}},
	{{4, -1, 1, -1}, 0.056860, {2.690000, 1.240000, 1.350000, 3.380000, 0.000000}},
	{{4, -1, 1, 1}, 0.030090, {1.830000, 0.650000, 0.930000, 1.790000, 0.000000}},
	{{4, -1, 1, 3}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 2, -3}, -0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 2, -1}, 0.006140, {0.300000, 0.130000, 0.250000, 0.370000, 0.000000}},
	{{4, -1, 2, 1}, 0.004210, {0.260000, 0.090000, 0.200000, 0.250000, 0.000000}},
	{{4, -1, 2, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 3, -3}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 3, -1}, 0.000600, {0.030000, 0.010000, 0.040000, 0.040000, 0.000000}},
	{{4, -1, 3, 1}, 0.000500, {0.030000, 0.010000, 0.030000, 0.030000, 0.000000}},
	{{4, -1, 4, -1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 4, 1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -7, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -6, -1}, -0.000150, {0.000000, 0.000000, -0.020000, 0.000000, 0.000000}},
	{{4, 0, -6, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -5, -1}, -0.001160, {-0.050000, -0.030000, -0.110000, 0.000000, 0.000000}},
	{{4, 0, -4, -3}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -4, -1}, -0.006800, {-0.280000, -0.150000, -0.500000, 0.000000, 0.000000}},
	{{4, 0, -4, 1}, 0.000290, {0.000000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{4, 0, -4, 3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -3, -3}, -0.000660, {-0.020000, -0.040000, -0.040000, 0.000000, 0.000000}},
	{{4, 0, -3, -1}, -0.007710, {-0.290000, -0.170000, -0.420000, 0.000000, 0.000000}},
	{{4, 0, -3, 1}, 0.021740, {1.300000, 0.470000, 1.190000, 0.020000, 0.000000}},
	{{4, 0, -3, 3}, -0.001270, {-0.040000, -0.090000, -0.070000, 0.000000, 0.000000}},
	{{4, 0, -2, -3}, -0.003900, {-0.140000, -0.260000, -0.140000, 0.000000, 0.000000}},
	{{4, 0, -2, -1}, 0.633710, {23.670000, 13.990000, 23.160000, -0.030000, 0.080000}},
	{{4, 0, -2, 1}, 2.413890, {90.530000, 52.840000, 87.950000, -0.350000, 0.070000}},
	{{4, 0, -2, 3}, -0.006320, {-0.240000, -0.420000, -0.240000, 0.000000, 0.000000}},
	{{4, 0, -2, 5}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -1, -5}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -1, -3}, -0.005540, {-0.340000, -0.370000, -0.100000, 0.000000, 0.000000}},
	{{4, 0, -1, -1}, 6.579620, {223.570000, 146.750000, 123.070000, -1.940000, 0.260000}},
	{{4, 0, -1, 1}, 2.998500, {142.570000, 65.020000, 71.120000, -0.780000, 0.060000}},
	{{4, 0, -1, 3}, -0.006640, {-0.310000, -0.440000, -0.190000, 0.000000, 0.000000}},
	{{4, 0, -1, 5}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 0, -5}, -0.000130, {0.000000, -0.010000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 0, -3}, 0.062570, {1.510000, 4.190000, -0.040000, -0.030000, 0.020000}},
	{{4, 0, 0, -1}, 3.674490, {157.550000, 81.630000, 29.570000, -1.610000, 0.060000}},
	{{4, 0, 0, 1}, 1.191880, {65.390000, 25.660000, 23.110000, -0.450000, 0.080000}},
	{{4, 0, 0, 3}, -0.002880, {-0.150000, -0.190000, -0.080000, 0.000000, 0.000000}},
	{{4, 0, 1, -3}, -0.005520, {-0.150000, -0.380000, -0.110000, 0.000000, 0.000000}},
	{{4, 0, 1, -1}, 0.473380, {20.490000, 10.320000, 11.590000, -0.250000, 0.020000}},
	{{4, 0, 1, 1}, 0.212590, {11.970000, 4.560000, 6.920000, -0.100000, 0.010000}},
	{{4, 0, 1, 3}, -0.000680, {-0.040000, -0.040000, -0.030000, 0.000000, 0.000000}},
	{{4, 0, 2, -3}, -0.000900, {-0.020000, -0.060000, -0.030000, 0.000000, 0.000000}},
	{{4, 0, 2, -1}, 0.048340, {2.100000, 1.030000, 2.040000, -0.030000, 0.000000}},
	{{4, 0, 2, 1}, 0.028280, {1.600000, 0.600000, 1.370000, -0.020000, 0.000000}},
	{{4, 0, 2, 3}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 3, -3}, -0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 3, -1}, 0.004490, {0.200000, 0.090000, 0.270000, 0.000000, 0.000000}},
	{{4, 0, 3, 1}, 0.003230, {0.180000, 0.070000, 0.210000, 0.000000, 0.000000}},
	{{4, 0, 3, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 4, -1}, 0.000400, {0.020000, 0.000000, 0.030000, 0.000000, 0.000000}},
	{{4, 0, 4, 1}, 0.000340, {0.020000, 0.000000, 0.030000, 0.000000, 0.000000}},
	{{4, 0, 5, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 5, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -5, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -4, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -4, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -3, -1}, 0.000630, {0.050000, 0.010000, 0.030000, 0.040000, 0.000000}},
	{{4, 1, -3, 1}, 0.001920, {0.190000, 0.040000, 0.100000, 0.110000, 0.000000}},
	{{4, 1, -2, -3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -2, -1}, -0.002030, {0.570000, -0.050000, -0.080000, -0.120000, 0.000000}},
	{{4, 1, -2, 1}, -0.029570, {0.540000, -0.670000, -1.080000, -1.780000, 0.000000}},
	{{4, 1, -2, 3}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -1, -3}, -0.000150, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -1, -1}, -0.171910, {-3.930000, -3.890000, -3.200000, -10.300000, -0.020000}},
	{{4, 1, -1, 1}, -0.050970, {-1.360000, -1.110000, -1.240000, -3.060000, -0.020000}},
	{{4, 1, -1, 3}, 0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 0, -3}, -0.003040, {-0.090000, -0.200000, 0.000000, -0.180000, 0.000000}},
	{{4, 1, 0, -1}, -0.113080, {-4.830000, -2.510000, -0.930000, -6.760000, -0.020000}},
	{{4, 1, 0, 1}, -0.025490, {-1.260000, -0.540000, -0.520000, -1.530000, 0.000000}},
	{{4, 1, 0, 3}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 1, -3}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 1, -1}, -0.016920, {-0.790000, -0.370000, -0.420000, -1.010000, 0.000000}},
	{{4, 1, 1, 1}, -0.005580, {-0.320000, -0.120000, -0.190000, -0.330000, 0.000000}},
	{{4, 1, 1, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 2, -3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 2, -1}, -0.001960, {-0.100000, -0.040000, -0.080000, -0.120000, 0.000000}},
	{{4, 1, 2, 1}, -0.000880, {-0.050000, -0.020000, -0.040000, -0.050000, 0.000000}},
	{{4, 1, 3, -1}, -0.000200, {-0.010000, 0.000000, -0.010000, -0.010000, 0.000000}},
	{{4, 1, 3, 1}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 4, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 4, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -3, -1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -3, 1}, -0.000200, {-0.010000, 0.000000, -0.010000, -0.020000, 0.000000}},
	{{4, 2, -2, -3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -2, -1}, -0.001140, {-0.070000, -0.020000, -0.040000, -0.140000, 0.000000}},
	{{4, 2, -2, 1}, -0.002770, {-0.160000, -0.060000, -0.100000, -0.330000, 0.000000}},
	{{4, 2, -1, -3}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -1, -1}, -0.004380, {-0.250000, -0.090000, -0.080000, -0.520000, 0.000000}},
	{{4, 2, -1, 1}, -0.001790, {-0.120000, -0.040000, -0.050000, -0.210000, 0.000000}},
	{{4, 2, 0, -1}, -0.000560, {-0.030000, -0.010000, -0.020000, -0.070000, 0.000000}},
	{{4, 2, 0, 1}, -0.000250, {-0.020000, 0.000000, -0.010000, -0.030000, 0.000000}},
	{{4, 2, 1, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, 1, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 3, -2, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 3, -1, -1}, 0.000080, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, 3, -1, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 3, 0, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -2, -2, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, -2, -2, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, -2, -1, -1}, -0.000100, {0.000000, 0.000000, 0.000000, -0.010000, -0.040000}},
	{{5, -2, -1, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -2, 0, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, -3, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{5, -1, -3, 1}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{5, -1, -2, -1}, -0.000570, {-0.020000, -0.010000, -0.020000, -0.030000, -0.220000}},
	{{5, -1, -2, 1}, -0.000610, {-0.040000, -0.010000, -0.020000, -0.040000, -0.240000}},
	{{5, -1, -1, -3}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, -1, -1}, -0.001270, {-0.070000, -0.030000, -0.030000, -0.080000, -0.500000}},
	{{5, -1, -1, 1}, -0.000290, {-0.030000, 0.000000, -0.010000, -0.020000, -0.110000}},
	{{5, -1, 0, -3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, -1, 0, -1}, -0.000320, {-0.030000, 0.000000, 0.000000, -0.020000, -0.120000}},
	{{5, -1, 1, -1}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 0, -4, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, -3, -1}, -0.000330, {-0.010000, 0.000000, -0.020000, 0.000000, -0.130000}},
	{{5, 0, -3, 1}, -0.001240, {-0.050000, -0.030000, -0.070000, 0.000000, -0.480000}},
	{{5, 0, -2, -1}, -0.005050, {-0.210000, -0.110000, -0.190000, 0.000000, -1.960000}},
	{{5, 0, -2, 1}, -0.005190, {-0.290000, -0.110000, -0.200000, 0.000000, -2.020000}},
	{{5, 0, -2, 3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, -1, -3}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{5, 0, -1, -1}, -0.010490, {-0.540000, -0.240000, -0.220000, 0.010000, -4.080000}},
	{{5, 0, -1, 1}, -0.002450, {-0.210000, -0.050000, -0.090000, 0.000000, -0.950000}},
	{{5, 0, -1, 3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, 0, -3}, -0.000410, {-0.010000, -0.030000, 0.000000, 0.000000, -0.160000}},
	{{5, 0, 0, -1}, -0.002540, {-0.190000, -0.060000, -0.070000, 0.000000, -0.990000}},
	{{5, 0, 0, 1}, -0.000270, {-0.050000, 0.000000, -0.030000, 0.000000, -0.100000}},
	{{5, 0, 1, -3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{5, 0, 1, -1}, -0.000450, {-0.030000, -0.010000, -0.020000, 0.000000, -0.170000}},
	{{5, 0, 1, 1}, -0.000060, {-0.010000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 0, 2, -1}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 0, 2, 1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 1, -3, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 1, -3, 1}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 1, -2, -1}, 0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.060000}},
	{{5, 1, -2, 1}, 0.000410, {0.010000, 0.000000, 0.020000, 0.020000, 0.160000}},
	{{5, 1, -1, -1}, 0.000970, {0.040000, 0.020000, 0.020000, 0.060000, 0.380000}},
	{{5, 1, -1, 1}, 0.000530, {0.030000, 0.010000, 0.010000, 0.030000, 0.210000}},
	{{5, 1, 0, -3}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 1, 0, -1}, 0.000510, {0.020000, 0.010000, 0.000000, 0.030000, 0.200000}},
	{{5, 1, 0, 1}, 0.000230, {0.010000, 0.000000, 0.000000, 0.010000, 0.090000}},
	{{5, 1, 1, -1}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{5, 1, 1, 1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{5, 1, 2, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 2, -1, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 2, 0, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -3, -3, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -3, -2, -1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -3, -2, 1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{6, -3, -1, -1}, 0.000100, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{6, -3, -1, 1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{6, -3, 0, -1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -3, 0, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -3, 1, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -3, -1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -3, 1}, 0.000330, {0.020000, 0.000000, 0.020000, 0.040000, 0.000000}},
	{{6, -2, -2, -1}, 0.000880, {0.050000, 0.020000, 0.030000, 0.100000, 0.000000}},
	{{6, -2, -2, 1}, 0.000870, {0.060000, 0.020000, 0.040000, 0.100000, 0.000000}},
	{{6, -2, -1, -3}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -1, -1}, 0.001370, {0.090000, 0.030000, 0.030000, 0.160000, 0.000000}},
	{{6, -2, -1, 1}, 0.000780, {0.060000, 0.020000, 0.020000, 0.090000, 0.000000}},
	{{6, -2, 0, -1}, 0.000670, {0.050000, 0.010000, 0.010000, 0.080000, 0.000000}},
	{{6, -2, 0, 1}, 0.000320, {0.030000, 0.000000, 0.000000, 0.040000, 0.000000}},
	{{6, -2, 1, -1}, 0.000130, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{6, -2, 1, 1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 2, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 2, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -4, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -4, 1}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -3, -1}, 0.000890, {0.050000, 0.020000, 0.050000, 0.050000, 0.000000}},
	{{6, -1, -3, 1}, 0.004150, {0.240000, 0.090000, 0.230000, 0.250000, 0.000000}},
	{{6, -1, -3, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -2, -1}, 0.010910, {0.590000, 0.240000, 0.400000, 0.650000, 0.000000}},
	{{6, -1, -2, 1}, 0.009390, {0.640000, 0.200000, 0.380000, 0.560000, 0.000000}},
	{{6, -1, -2, 3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -1, -3}, 0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -1, -1}, 0.014860, {0.960000, 0.330000, 0.350000, 0.880000, 0.000000}},
	{{6, -1, -1, 1}, 0.007570, {0.590000, 0.160000, 0.240000, 0.450000, 0.000000}},
	{{6, -1, -1, 3}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 0, -3}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 0, -1}, 0.006520, {0.470000, 0.140000, 0.120000, 0.390000, 0.000000}},
	{{6, -1, 0, 1}, 0.002880, {0.240000, 0.060000, 0.090000, 0.170000, 0.000000}},
	{{6, -1, 0, 3}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 1, -1}, 0.001220, {0.090000, 0.030000, 0.040000, 0.070000, 0.000000}},
	{{6, -1, 1, 1}, 0.000630, {0.060000, 0.010000, 0.030000, 0.040000, 0.000000}},
	{{6, -1, 2, -1}, 0.000170, {0.010000, 0.000000, 0.000000, 0.010000, 0.000000}},
	{{6, -1, 2, 1}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 3, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, 3, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -4, -1}, 0.000140, {0.000000, 0.000000, 0.010000, 0.000000, 0.000000}},
	{{6, 0, -4, 1}, 0.000720, {0.050000, 0.020000, 0.050000, 0.000000, 0.000000}},
	{{6, 0, -4, 3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -3, -1}, 0.007020, {0.400000, 0.150000, 0.380000, 0.000000, 0.000000}},
	{{6, 0, -3, 1}, 0.031180, {1.770000, 0.680000, 1.710000, 0.000000, 0.000000}},
	{{6, 0, -3, 3}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -2, -3}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -2, -1}, 0.080960, {4.280000, 1.790000, 3.000000, -0.040000, 0.000000}},
	{{6, 0, -2, 1}, 0.059630, {3.970000, 1.280000, 2.460000, -0.030000, 0.000000}},
	{{6, 0, -2, 3}, -0.000210, {-0.010000, -0.010000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -1, -3}, 0.001070, {0.040000, 0.070000, 0.020000, 0.000000, 0.000000}},
	{{6, 0, -1, -1}, 0.094030, {5.840000, 2.080000, 2.280000, -0.070000, 0.000000}},
	{{6, 0, -1, 1}, 0.042170, {3.170000, 0.890000, 1.370000, -0.030000, 0.000000}},
	{{6, 0, -1, 3}, -0.000140, {-0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 0, -3}, 0.000600, {0.040000, 0.040000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 0, -1}, 0.036740, {2.540000, 0.800000, 0.730000, -0.030000, 0.000000}},
	{{6, 0, 0, 1}, 0.014650, {1.190000, 0.310000, 0.470000, -0.010000, 0.000000}},
	{{6, 0, 0, 3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 1, -3}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 1, -1}, 0.006540, {0.460000, 0.140000, 0.220000, 0.000000, 0.000000}},
	{{6, 0, 1, 1}, 0.003050, {0.250000, 0.060000, 0.130000, 0.000000, 0.000000}},
	{{6, 0, 1, 3}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 2, -3}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 2, -1}, 0.000880, {0.060000, 0.020000, 0.040000, 0.000000, 0.000000}},
	{{6, 0, 2, 1}, 0.000480, {0.040000, 0.010000, 0.030000, 0.000000, 0.000000}},
	{{6, 0, 3, -1}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 3, 1}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 4, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -4, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -3, -1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -3, 1}, -0.000540, {0.000000, -0.010000, -0.030000, -0.030000, 0.000000}},
	{{6, 1, -2, -1}, -0.002560, {-0.080000, -0.060000, -0.090000, -0.150000, 0.000000}},
	{{6, 1, -2, 1}, -0.001370, {-0.050000, -0.030000, -0.060000, -0.080000, 0.000000}},
	{{6, 1, -1, -3}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -1, -1}, -0.003500, {-0.190000, -0.080000, -0.080000, -0.210000, 0.000000}},
	{{6, 1, -1, 1}, -0.001160, {-0.070000, -0.020000, -0.040000, -0.070000, 0.000000}},
	{{6, 1, 0, -3}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 0, -1}, -0.001530, {-0.100000, -0.030000, -0.030000, -0.090000, 0.000000}},
	{{6, 1, 0, 1}, -0.000470, {-0.040000, 0.000000, -0.020000, -0.030000, 0.000000}},
	{{6, 1, 1, -1}, -0.000310, {-0.020000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{6, 1, 1, 1}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 2, -1}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 2, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -3, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -3, 1}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -2, -1}, -0.000090, {0.000000, 0.000000, 0.000000, -0.010000, 0.000000}},
	{{6, 2, -2, 1}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -1, -1}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -1, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -1, -3, -1}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -1, -3, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -1, -2, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{7, -1, -2, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -1, -1, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -4, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -3, -1}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{7, 0, -3, 1}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{7, 0, -2, -1}, -0.000240, {-0.020000, 0.000000, 0.000000, 0.000000, -0.090000}},
	{{7, 0, -2, 1}, -0.000100, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{7, 0, -1, -3}, -0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -1, -1}, -0.000130, {-0.010000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{7, 0, -1, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{7, 0, 0, -1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, -0.010000}},
	{{7, 1, -2, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 1, -2, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 1, -1, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 1, -1, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -3, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -3, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -2, -1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -2, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -1, -1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -1, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, 0, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -4, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -4, 1}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -3, -1}, 0.000190, {0.010000, 0.000000, 0.010000, 0.010000, 0.000000}},
	{{8, -1, -3, 1}, 0.000220, {0.020000, 0.000000, 0.010000, 0.010000, 0.000000}},
	{{8, -1, -2, -1}, 0.000380, {0.030000, 0.000000, 0.020000, 0.020000, 0.000000}},
	{{8, -1, -2, 1}, 0.000250, {0.020000, 0.000000, 0.010000, 0.010000, 0.000000}},
	{{8, -1, -1, -1}, 0.000290, {0.030000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{8, -1, -1, 1}, 0.000150, {0.020000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, 0, -1}, 0.000110, {0.010000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, 0, 1}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, 1, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, 1, 1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -5, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -4, -1}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -4, 1}, 0.000420, {0.030000, 0.000000, 0.030000, 0.000000, 0.000000}},
	{{8, 0, -3, -1}, 0.001070, {0.080000, 0.020000, 0.060000, 0.000000, 0.000000}},
	{{8, 0, -3, 1}, 0.001080, {0.090000, 0.020000, 0.060000, 0.000000, 0.000000}},
	{{8, 0, -2, -3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -2, -1}, 0.001890, {0.150000, 0.040000, 0.080000, 0.000000, 0.000000}},
	{{8, 0, -2, 1}, 0.001110, {0.110000, 0.020000, 0.050000, 0.000000, 0.000000}},
	{{8, 0, -1, -3}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -1, -1}, 0.001300, {0.120000, 0.030000, 0.040000, 0.000000, 0.000000}},
	{{8, 0, -1, 1}, 0.000600, {0.060000, 0.010000, 0.030000, 0.000000, 0.000000}},
	{{8, 0, 0, -1}, 0.000450, {0.040000, 0.000000, 0.010000, 0.000000, 0.000000}},
	{{8, 0, 0, 1}, 0.000200, {0.020000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 1, -1}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 1, 1}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 2, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -3, -1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -3, 1}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -2, -1}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -2, 1}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -1, -1}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -1, 1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, 0, -1}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -4, -1}, 0.000010, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -4, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -3, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -3, 1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -2, -1}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -2, 1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -1, -1}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}}
};


static const struct main_problem main_elp3 [ELP3_SIZE] = 
{
	{{0, 0, 0, 0}, 385000.527190, {-7992.630000, -11.060000, 21578.080000, -4.530000, 11.390000}},
	{{0, 0, 0, 2}, -3.148370, {-204.480000, -138.940000, 159.640000, -0.390000, 0.120000}},
	{{0, 0, 0, 4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 1, -4}, 0.000380, {0.030000, 0.030000, -0.030000, 0.000000, 0.000000}},
	{{0, 0, 1, -2}, 79.661830, {-359.450000, 3583.790000, 1454.020000, -2.370000, 0.850000}},
	{{0, 0, 1, 0}, -20905.322060, {6888.230000, -35.830000, -380331.740000, 22.310000, 1.770000}},
	{{0, 0, 1, 2}, -0.103260, {-9.140000, -4.530000, 8.080000, 0.000000, 0.020000}},
	{{0, 0, 2, -4}, -0.008370, {0.070000, -0.750000, -0.310000, 0.000000, 0.000000}},
	{{0, 0, 2, -2}, -4.421240, {18.290000, -198.910000, -161.900000, 0.140000, -0.040000}},
	{{0, 0, 2, 0}, -569.923320, {374.440000, -1.990000, -20737.330000, 5.790000, 0.440000}},
	{{0, 0, 2, 2}, -0.001020, {-0.370000, -0.040000, 0.620000, 0.000000, 0.000000}},
	{{0, 0, 3, -4}, 0.000330, {0.000000, 0.030000, 0.020000, 0.000000, 0.000000}},
	{{0, 0, 3, -2}, -0.001110, {0.000000, 0.000000, -0.050000, 0.000000, 0.000000}},
	{{0, 0, 3, 0}, -23.210320, {26.490000, -0.140000, -1266.640000, 0.630000, 0.050000}},
	{{0, 0, 3, 2}, 0.000260, {0.000000, 0.000000, 0.060000, 0.000000, 0.000000}},
	{{0, 0, 4, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 4, -2}, 0.000270, {0.000000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{0, 0, 4, 0}, -1.116930, {1.980000, 0.000000, -81.260000, 0.060000, 0.000000}},
	{{0, 0, 4, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 5, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 0, 5, 0}, -0.058880, {0.150000, 0.000000, -5.350000, 0.000000, 0.000000}},
	{{0, 0, 6, 0}, -0.003290, {0.000000, 0.000000, -0.360000, 0.000000, 0.000000}},
	{{0, 0, 7, 0}, -0.000190, {0.000000, 0.000000, -0.020000, 0.000000, 0.000000}},
	{{0, 1, -6, 0}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -5, 0}, -0.001740, {-0.030000, 0.000000, -0.160000, -0.100000, 0.000000}},
	{{0, 1, -4, 0}, -0.026740, {-0.560000, 0.000000, -1.940000, -1.600000, 0.000000}},
	{{0, 1, -3, 0}, -0.422420, {-9.350000, 0.200000, -23.040000, -25.300000, 0.000000}},
	{{0, 1, -3, 2}, 0.000150, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -2, -2}, -0.000190, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -2, 0}, -7.002930, {-161.630000, 3.290000, -254.780000, -419.550000, -0.120000}},
	{{0, 1, -2, 2}, -0.050200, {-1.170000, -2.240000, -1.830000, -3.010000, 0.000000}},
	{{0, 1, -2, 4}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, -1, -2}, -0.007690, {-0.150000, -0.340000, -0.040000, -0.460000, 0.000000}},
	{{0, 1, -1, 0}, -129.624760, {-3122.770000, 61.800000, -2362.460000, -7767.840000, -0.740000}},
	{{0, 1, -1, 2}, 0.334650, {7.260000, 14.910000, 5.990000, 20.060000, 0.000000}},
	{{0, 1, -1, 4}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 0, -2}, -0.185680, {-4.480000, -8.290000, 0.540000, -11.120000, 0.000000}},
	{{0, 1, 0, 0}, 48.890100, {1082.400000, -25.990000, 156.780000, 2926.500000, -3.760000}},
	{{0, 1, 0, 2}, -0.158030, {-3.350000, -7.060000, -0.080000, -9.460000, -0.030000}},
	{{0, 1, 1, -4}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 1, -2}, -0.248110, {-2.720000, -11.080000, -4.500000, -14.870000, 0.000000}},
	{{0, 1, 1, 0}, 104.758960, {2165.070000, -47.620000, 1929.100000, 6279.070000, -0.600000}},
	{{0, 1, 1, 2}, -0.006820, {-0.050000, -0.310000, -0.170000, -0.410000, 0.000000}},
	{{0, 1, 2, -4}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 2, -2}, 0.032650, {0.360000, 1.450000, 1.200000, 1.960000, 0.000000}},
	{{0, 1, 2, 0}, 5.751050, {119.470000, -2.620000, 210.760000, 344.760000, -0.090000}},
	{{0, 1, 2, 2}, -0.000300, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 3, -2}, -0.000800, {-0.040000, -0.040000, -0.040000, -0.050000, 0.000000}},
	{{0, 1, 3, 0}, 0.355090, {7.330000, -0.160000, 19.480000, 21.290000, 0.000000}},
	{{0, 1, 4, -2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 1, 4, 0}, 0.023040, {0.470000, 0.000000, 1.680000, 1.380000, 0.000000}},
	{{0, 1, 5, 0}, 0.001530, {0.030000, 0.000000, 0.140000, 0.090000, 0.000000}},
	{{0, 1, 6, 0}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -5, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, -4, 0}, -0.000660, {-0.020000, 0.000000, -0.050000, -0.080000, 0.000000}},
	{{0, 2, -3, 0}, -0.009380, {-0.290000, 0.000000, -0.510000, -1.120000, 0.000000}},
	{{0, 2, -2, 0}, -0.136180, {-4.100000, 0.090000, -4.960000, -16.310000, 0.000000}},
	{{0, 2, -2, 2}, -0.000990, {-0.030000, -0.040000, -0.040000, -0.120000, 0.000000}},
	{{0, 2, -1, -2}, -0.000310, {0.000000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{0, 2, -1, 0}, -2.117280, {-59.780000, 1.220000, -38.700000, -253.610000, 0.000000}},
	{{0, 2, -1, 2}, 0.004500, {0.120000, 0.200000, 0.080000, 0.540000, 0.000000}},
	{{0, 2, 0, -2}, -0.005580, {-0.140000, -0.250000, 0.000000, -0.670000, 0.000000}},
	{{0, 2, 0, 0}, 1.065750, {16.470000, -0.600000, 3.280000, 127.540000, 0.000000}},
	{{0, 2, 0, 2}, -0.003420, {-0.070000, -0.150000, 0.000000, -0.410000, 0.000000}},
	{{0, 2, 1, -2}, -0.002370, {0.000000, -0.110000, -0.040000, -0.280000, 0.000000}},
	{{0, 2, 1, 0}, 1.165620, {22.200000, -0.390000, 21.490000, 139.600000, 0.000000}},
	{{0, 2, 1, 2}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 2, 2, -2}, 0.000180, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{0, 2, 2, 0}, 0.050720, {0.700000, 0.000000, 1.860000, 6.070000, 0.000000}},
	{{0, 2, 3, 0}, 0.002280, {0.000000, 0.000000, 0.130000, 0.270000, 0.000000}},
	{{0, 2, 4, 0}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -3, 0}, -0.000210, {0.000000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{0, 3, -2, 0}, -0.002870, {-0.100000, 0.000000, -0.100000, -0.510000, 0.000000}},
	{{0, 3, -2, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, -1, 0}, -0.038940, {-1.140000, 0.030000, -0.710000, -6.990000, 0.000000}},
	{{0, 3, -1, 2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, 0, -2}, -0.000170, {0.000000, 0.000000, 0.000000, -0.030000, 0.000000}},
	{{0, 3, 0, 0}, 0.021270, {0.030000, 0.000000, 0.080000, 3.820000, 0.000000}},
	{{0, 3, 0, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, 1, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 3, 1, 0}, 0.019120, {0.390000, 0.000000, 0.350000, 3.430000, 0.000000}},
	{{0, 3, 2, 0}, 0.000780, {0.000000, 0.000000, 0.030000, 0.140000, 0.000000}},
	{{0, 3, 3, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 4, -2, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{0, 4, -1, 0}, -0.000730, {-0.020000, 0.000000, 0.000000, -0.170000, 0.000000}},
	{{0, 4, 0, 0}, 0.000340, {0.000000, 0.000000, 0.000000, 0.080000, 0.000000}},
	{{0, 4, 1, 0}, 0.000370, {0.000000, 0.000000, 0.000000, 0.090000, 0.000000}},
	{{1, -4, 0, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{1, -3, -1, 0}, 0.000350, {0.000000, 0.000000, 0.000000, 0.060000, 0.130000}},
	{{1, -3, 0, 0}, -0.001610, {0.000000, 0.000000, 0.000000, -0.290000, -0.630000}},
	{{1, -2, -3, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -2, -2, 0}, 0.000290, {0.000000, 0.000000, 0.000000, 0.040000, 0.110000}},
	{{1, -2, -1, 0}, 0.008440, {0.100000, 0.000000, 0.170000, 1.010000, 3.280000}},
	{{1, -2, 0, -2}, -0.000240, {0.000000, 0.000000, 0.000000, -0.030000, -0.090000}},
	{{1, -2, 0, 0}, -0.029480, {0.180000, 0.000000, -0.030000, -3.520000, -11.460000}},
	{{1, -2, 0, 2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -2, 1, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -2, 1, 0}, 0.001590, {0.160000, 0.000000, 0.030000, 0.190000, 0.620000}},
	{{1, -2, 2, 0}, 0.000360, {0.030000, 0.000000, 0.000000, 0.040000, 0.140000}},
	{{1, -2, 3, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, -4, 0}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{1, -1, -3, 0}, 0.000650, {0.000000, 0.000000, 0.040000, 0.040000, 0.250000}},
	{{1, -1, -2, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, -2, 0}, -0.004220, {-0.240000, 0.000000, -0.130000, -0.260000, -1.640000}},
	{{1, -1, -2, 2}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{1, -1, -1, -2}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{1, -1, -1, 0}, 0.114110, {0.000000, -0.020000, 2.310000, 6.800000, 44.370000}},
	{{1, -1, -1, 2}, 0.000210, {0.000000, 0.000000, 0.000000, 0.000000, 0.080000}},
	{{1, -1, 0, -2}, -0.013660, {-0.210000, -0.610000, 0.000000, -0.820000, -5.310000}},
	{{1, -1, 0, 0}, 0.497570, {32.610000, -1.420000, 0.140000, 30.000000, 193.460000}},
	{{1, -1, 0, 2}, -0.000740, {-0.030000, -0.030000, 0.000000, -0.040000, -0.290000}},
	{{1, -1, 1, -2}, 0.000440, {0.000000, 0.020000, 0.000000, 0.030000, 0.170000}},
	{{1, -1, 1, 0}, 0.109980, {5.320000, -0.170000, 2.140000, 6.590000, 42.760000}},
	{{1, -1, 1, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{1, -1, 2, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, -1, 2, 0}, 0.011210, {0.520000, 0.000000, 0.420000, 0.670000, 4.360000}},
	{{1, -1, 3, 0}, 0.000970, {0.040000, 0.000000, 0.050000, 0.060000, 0.380000}},
	{{1, -1, 4, 0}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 0, -6, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 0, -5, 0}, -0.000430, {0.000000, 0.000000, -0.040000, 0.000000, -0.170000}},
	{{1, 0, -4, 0}, -0.006360, {-0.180000, 0.000000, -0.460000, 0.000000, -2.470000}},
	{{1, 0, -3, -2}, -0.000190, {0.000000, 0.000000, 0.000000, 0.000000, -0.070000}},
	{{1, 0, -3, 0}, -0.099380, {-2.830000, 0.090000, -5.450000, -0.040000, -38.640000}},
	{{1, 0, -3, 2}, -0.000480, {0.000000, -0.020000, -0.030000, 0.000000, -0.190000}},
	{{1, 0, -2, -2}, -0.002780, {-0.040000, -0.120000, -0.100000, 0.000000, -1.080000}},
	{{1, 0, -2, 0}, -1.738520, {-48.130000, 1.590000, -63.710000, -0.500000, -675.990000}},
	{{1, 0, -2, 2}, 0.004570, {0.030000, 0.200000, 0.160000, 0.000000, 1.780000}},
	{{1, 0, -1, -2}, -0.042320, {-0.600000, -1.870000, -0.770000, 0.000000, -16.450000}},
	{{1, 0, -1, 0}, -8.379090, {-219.270000, 9.530000, -156.070000, -0.840000, -3257.990000}},
	{{1, 0, -1, 2}, -0.024710, {-0.500000, -1.080000, -0.460000, 0.000000, -9.610000}},
	{{1, 0, 0, -2}, -0.795640, {-11.230000, -35.240000, -0.220000, 0.000000, -309.370000}},
	{{1, 0, 0, 0}, 108.742650, {2351.060000, -120.480000, 69.820000, 2.010000, 42281.560000}},
	{{1, 0, 0, 2}, -0.018740, {-0.510000, -0.830000, -0.130000, 0.000000, -7.290000}},
	{{1, 0, 1, -4}, 0.000170, {0.000000, 0.000000, 0.000000, 0.000000, 0.060000}},
	{{1, 0, 1, -2}, 0.060550, {0.870000, 2.670000, 1.140000, 0.000000, 23.540000}},
	{{1, 0, 1, 0}, 6.321990, {138.540000, -6.740000, 118.100000, -0.560000, 2458.130000}},
	{{1, 0, 1, 2}, -0.001640, {-0.050000, -0.070000, -0.040000, 0.000000, -0.640000}},
	{{1, 0, 2, -2}, 0.002030, {0.000000, 0.090000, 0.070000, 0.000000, 0.790000}},
	{{1, 0, 2, 0}, 0.378520, {7.870000, -0.400000, 13.920000, -0.090000, 147.180000}},
	{{1, 0, 2, 2}, -0.000130, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{1, 0, 3, -2}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{1, 0, 3, 0}, 0.023680, {0.460000, -0.020000, 1.300000, 0.000000, 9.210000}},
	{{1, 0, 4, 0}, 0.001520, {0.030000, 0.000000, 0.110000, 0.000000, 0.590000}},
	{{1, 0, 5, 0}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{1, 1, -5, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, 1, -4, 0}, 0.001010, {0.000000, 0.000000, 0.070000, 0.060000, 0.390000}},
	{{1, 1, -3, 0}, 0.017290, {0.210000, 0.000000, 0.950000, 1.040000, 6.720000}},
	{{1, 1, -3, 2}, 0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.050000}},
	{{1, 1, -2, -2}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 1, -2, 0}, 0.332260, {4.670000, -0.100000, 12.190000, 19.900000, 129.180000}},
	{{1, 1, -2, 2}, -0.001480, {0.000000, -0.070000, -0.050000, -0.090000, -0.580000}},
	{{1, 1, -1, -2}, 0.001560, {0.000000, 0.070000, 0.030000, 0.090000, 0.610000}},
	{{1, 1, -1, 0}, 0.851270, {-2.920000, -0.500000, 15.940000, 50.910000, 330.990000}},
	{{1, 1, -1, 2}, 0.003310, {-0.020000, 0.150000, 0.060000, 0.200000, 1.290000}},
	{{1, 1, 0, -2}, 0.033790, {0.040000, 1.480000, 0.110000, 2.020000, 13.140000}},
	{{1, 1, 0, 0}, -16.675330, {-4.780000, 10.810000, -19.360000, -997.670000, -6483.730000}},
	{{1, 1, 0, 2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{1, 1, 1, -2}, -0.005620, {0.000000, -0.250000, -0.110000, -0.340000, -2.180000}},
	{{1, 1, 1, 0}, -0.933350, {-1.070000, 0.640000, -18.080000, -55.840000, -362.910000}},
	{{1, 1, 2, -2}, -0.000370, {-0.020000, 0.000000, 0.000000, -0.020000, -0.140000}},
	{{1, 1, 2, 0}, -0.059040, {-0.120000, 0.040000, -2.220000, -3.530000, -22.960000}},
	{{1, 1, 3, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 1, 3, 0}, -0.003920, {0.000000, 0.000000, -0.220000, -0.230000, -1.520000}},
	{{1, 1, 4, 0}, -0.000270, {0.000000, 0.000000, -0.020000, 0.000000, -0.100000}},
	{{1, 2, -4, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 2, -3, 0}, 0.000280, {0.000000, 0.000000, 0.000000, 0.030000, 0.110000}},
	{{1, 2, -2, 0}, 0.003240, {0.140000, 0.000000, 0.120000, 0.390000, 1.260000}},
	{{1, 2, -1, 0}, 0.004380, {0.140000, 0.000000, 0.080000, 0.520000, 1.700000}},
	{{1, 2, 0, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 2, 0, 0}, 0.037290, {0.600000, -0.030000, 0.070000, 4.470000, 14.500000}},
	{{1, 2, 1, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{1, 2, 1, 0}, 0.006460, {0.120000, 0.000000, 0.130000, 0.770000, 2.510000}},
	{{1, 2, 2, 0}, 0.000670, {0.000000, 0.000000, 0.030000, 0.080000, 0.260000}},
	{{1, 2, 3, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, 3, -2, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{1, 3, -1, 0}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{1, 3, 0, 0}, 0.000540, {0.000000, 0.000000, 0.000000, 0.100000, 0.210000}},
	{{1, 3, 1, 0}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{2, -6, 0, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -5, -1, 0}, -0.000120, {0.000000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{2, -5, 0, 0}, -0.000580, {-0.030000, 0.000000, 0.000000, -0.170000, 0.000000}},
	{{2, -5, 1, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, -2, 0}, 0.000360, {0.000000, 0.000000, 0.000000, 0.090000, 0.000000}},
	{{2, -4, -1, 0}, -0.004260, {-0.080000, 0.000000, -0.080000, -1.020000, 0.000000}},
	{{2, -4, 0, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -4, 0, 0}, -0.015780, {-0.660000, 0.000000, 0.000000, -3.780000, 0.000000}},
	{{2, -4, 1, 0}, -0.001130, {-0.050000, 0.000000, -0.020000, -0.270000, 0.000000}},
	{{2, -4, 2, 0}, -0.000090, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{2, -3, -4, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -3, 0}, 0.000460, {0.000000, 0.000000, 0.020000, 0.080000, 0.000000}},
	{{2, -3, -2, 0}, 0.011160, {0.260000, 0.000000, 0.410000, 2.000000, 0.000000}},
	{{2, -3, -2, 2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, -1, -2}, 0.000260, {0.000000, 0.000000, 0.000000, 0.050000, 0.000000}},
	{{2, -3, -1, 0}, -0.148080, {-2.640000, 0.030000, -2.710000, -26.580000, 0.000000}},
	{{2, -3, -1, 2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, 0, -2}, 0.001040, {0.030000, 0.050000, 0.000000, 0.190000, 0.000000}},
	{{2, -3, 0, 0}, -0.410760, {-15.670000, 0.090000, -0.510000, -73.710000, 0.000000}},
	{{2, -3, 1, -2}, 0.000270, {0.000000, 0.000000, 0.000000, 0.050000, 0.000000}},
	{{2, -3, 1, 0}, -0.028550, {-1.200000, 0.000000, -0.560000, -5.120000, 0.000000}},
	{{2, -3, 2, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -3, 2, 0}, -0.002090, {-0.100000, 0.000000, -0.080000, -0.380000, 0.000000}},
	{{2, -3, 3, 0}, -0.000160, {0.000000, 0.000000, 0.000000, -0.030000, 0.000000}},
	{{2, -2, -5, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, -4, 0}, 0.000670, {0.000000, 0.000000, 0.050000, 0.080000, 0.000000}},
	{{2, -2, -3, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, -3, 0}, 0.015170, {0.230000, 0.000000, 0.830000, 1.810000, 0.000000}},
	{{2, -2, -2, -2}, 0.000410, {0.000000, 0.000000, 0.000000, 0.050000, 0.000000}},
	{{2, -2, -2, 0}, 0.343040, {6.870000, -0.030000, 12.500000, 41.040000, 0.000000}},
	{{2, -2, -2, 2}, 0.000990, {0.000000, 0.040000, 0.040000, 0.120000, 0.000000}},
	{{2, -2, -1, -2}, 0.009570, {0.130000, 0.430000, 0.170000, 1.150000, 0.000000}},
	{{2, -2, -1, 0}, -4.950490, {-84.900000, 0.910000, -90.350000, -592.240000, 0.030000}},
	{{2, -2, -1, 2}, 0.001680, {0.040000, 0.080000, 0.040000, 0.200000, 0.000000}},
	{{2, -2, 0, -2}, 0.028390, {0.780000, 1.270000, -0.110000, 3.400000, 0.000000}},
	{{2, -2, 0, 0}, -9.885190, {-346.350000, 1.990000, -14.480000, -1182.310000, 0.070000}},
	{{2, -2, 1, -4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 1, -2}, 0.007920, {0.090000, 0.360000, 0.140000, 0.950000, 0.000000}},
	{{2, -2, 1, 0}, -0.657580, {-25.020000, 0.180000, -13.070000, -78.640000, 0.000000}},
	{{2, -2, 2, -2}, 0.000840, {0.020000, 0.040000, 0.030000, 0.100000, 0.000000}},
	{{2, -2, 2, 0}, -0.046080, {-1.860000, 0.000000, -1.760000, -5.510000, 0.000000}},
	{{2, -2, 3, -2}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -2, 3, 0}, -0.003350, {-0.140000, 0.000000, -0.190000, -0.400000, 0.000000}},
	{{2, -2, 4, 0}, -0.000250, {0.000000, 0.000000, -0.020000, -0.030000, 0.000000}},
	{{2, -2, 5, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -6, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -5, 0}, 0.001190, {0.000000, 0.000000, 0.110000, 0.070000, 0.000000}},
	{{2, -1, -4, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, -4, 0}, 0.023340, {0.280000, 0.000000, 1.700000, 1.400000, 0.000000}},
	{{2, -1, -3, -2}, 0.000790, {0.000000, 0.040000, 0.040000, 0.050000, 0.000000}},
	{{2, -1, -3, 0}, 0.495060, {7.680000, 0.000000, 27.040000, 29.620000, 0.000000}},
	{{2, -1, -3, 2}, -0.000460, {0.000000, -0.020000, -0.020000, -0.030000, 0.000000}},
	{{2, -1, -2, -2}, 0.015180, {0.170000, 0.680000, 0.540000, 0.910000, 0.000000}},
	{{2, -1, -2, 0}, 10.056540, {188.870000, -1.290000, 366.360000, 601.570000, -0.030000}},
	{{2, -1, -2, 2}, 0.030240, {0.360000, 1.360000, 1.100000, 1.810000, 0.000000}},
	{{2, -1, -1, -2}, 0.323360, {4.560000, 14.420000, 5.730000, 19.340000, 0.000000}},
	{{2, -1, -1, 0}, -152.143140, {-2564.200000, 30.400000, -2771.740000, -9097.840000, 0.060000}},
	{{2, -1, -1, 2}, 0.037340, {0.840000, 1.680000, 0.850000, 2.230000, 0.000000}},
	{{2, -1, 0, -4}, -0.000350, {0.000000, -0.030000, 0.000000, -0.020000, 0.000000}},
	{{2, -1, 0, -2}, 0.657100, {17.830000, 29.300000, -2.920000, 39.260000, 0.000000}},
	{{2, -1, 0, 0}, -204.593570, {-6583.800000, 38.790000, -377.950000, -12225.820000, 0.270000}},
	{{2, -1, 0, 2}, 0.001080, {-0.090000, 0.050000, 0.210000, 0.060000, 0.000000}},
	{{2, -1, 1, -4}, -0.000850, {0.000000, -0.080000, 0.000000, -0.050000, 0.000000}},
	{{2, -1, 1, -2}, 0.209420, {1.810000, 9.460000, 3.820000, 12.500000, 0.000000}},
	{{2, -1, 1, 0}, -12.831850, {-434.140000, 2.980000, -260.020000, -766.510000, 0.020000}},
	{{2, -1, 1, 2}, 0.000000, {0.000000, 0.000000, 0.020000, 0.000000, 0.000000}},
	{{2, -1, 2, -4}, 0.000130, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 2, -2}, 0.018040, {0.340000, 0.810000, 0.660000, 1.080000, 0.000000}},
	{{2, -1, 2, 0}, -0.848830, {-29.750000, 0.220000, -32.800000, -50.680000, 0.000000}},
	{{2, -1, 3, -2}, 0.001270, {0.030000, 0.060000, 0.070000, 0.080000, 0.000000}},
	{{2, -1, 3, 0}, -0.058500, {-2.100000, 0.000000, -3.330000, -3.490000, 0.000000}},
	{{2, -1, 4, -2}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, -1, 4, 0}, -0.004130, {-0.150000, 0.000000, -0.310000, -0.250000, 0.000000}},
	{{2, -1, 5, 0}, -0.000300, {0.000000, 0.000000, -0.030000, 0.000000, 0.000000}},
	{{2, -1, 6, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -7, 0}, 0.000200, {0.000000, 0.000000, 0.030000, 0.000000, 0.000000}},
	{{2, 0, -6, 0}, 0.003040, {0.060000, 0.000000, 0.330000, 0.000000, 0.000000}},
	{{2, 0, -5, -2}, 0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -5, 0}, 0.047400, {0.930000, 0.000000, 4.320000, 0.000000, 0.000000}},
	{{2, 0, -5, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -4, -2}, 0.001880, {0.030000, 0.080000, 0.140000, 0.000000, 0.000000}},
	{{2, 0, -4, 0}, 0.778540, {15.430000, -0.130000, 56.710000, 0.050000, 0.000000}},
	{{2, 0, -4, 2}, 0.000480, {0.020000, 0.020000, 0.040000, 0.000000, 0.000000}},
	{{2, 0, -3, -2}, 0.029100, {0.440000, 1.300000, 1.570000, 0.000000, 0.000000}},
	{{2, 0, -3, 0}, 14.402620, {282.850000, -2.350000, 786.990000, 0.580000, 0.140000}},
	{{2, 0, -3, 2}, -0.020080, {-0.430000, -0.890000, -1.090000, 0.000000, 0.000000}},
	{{2, 0, -3, 4}, -0.000180, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -2, -4}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -2, -2}, 0.472630, {7.200000, 21.060000, 16.920000, 0.000000, 0.000000}},
	{{2, 0, -2, 0}, 246.157680, {4806.360000, -51.780000, 8962.910000, -0.430000, 1.110000}},
	{{2, 0, -2, 2}, 0.774050, {9.680000, 34.650000, 28.170000, -0.040000, 0.000000}},
	{{2, 0, -2, 4}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -1, -4}, -0.000390, {0.000000, -0.040000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, -1, -2}, 8.751700, {133.450000, 390.010000, 155.980000, -0.280000, 0.200000}},
	{{2, 0, -1, 0}, -3699.104680, {-63127.050000, 818.000000, -67236.740000, 147.860000, -15.950000}},
	{{2, 0, -1, 2}, 0.596330, {12.130000, 26.760000, 14.460000, -0.080000, 0.030000}},
	{{2, 0, 0, -4}, -0.007450, {-0.110000, -0.670000, -0.100000, 0.000000, 0.000000}},
	{{2, 0, 0, -2}, 10.321290, {282.080000, 460.160000, -60.760000, -1.290000, 0.060000}},
	{{2, 0, 0, 0}, -2955.966510, {-86674.510000, 507.990000, -7597.690000, 323.540000, -19.090000}},
	{{2, 0, 0, 2}, 0.031430, {-0.690000, 1.430000, 2.990000, 0.000000, 0.000000}},
	{{2, 0, 1, -4}, -0.018660, {-0.110000, -1.670000, -0.330000, 0.000000, 0.000000}},
	{{2, 0, 1, -2}, 4.131180, {20.860000, 186.870000, 75.090000, -0.760000, 0.000000}},
	{{2, 0, 1, 0}, -170.732740, {-4963.300000, 29.720000, -3579.160000, 26.820000, -1.820000}},
	{{2, 0, 1, 2}, 0.001810, {-0.120000, 0.080000, 0.320000, 0.000000, 0.000000}},
	{{2, 0, 2, -4}, 0.002190, {0.000000, 0.200000, 0.080000, 0.000000, 0.000000}},
	{{2, 0, 2, -2}, 0.283990, {2.900000, 12.830000, 10.350000, -0.060000, 0.000000}},
	{{2, 0, 2, 0}, -10.444720, {-300.480000, 1.810000, -410.750000, 2.240000, -0.170000}},
	{{2, 0, 2, 2}, 0.000140, {0.000000, 0.000000, 0.030000, 0.000000, 0.000000}},
	{{2, 0, 3, -4}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 3, -2}, 0.018110, {0.190000, 0.820000, 0.990000, 0.000000, 0.000000}},
	{{2, 0, 3, 0}, -0.669680, {-19.020000, 0.120000, -38.590000, 0.190000, 0.000000}},
	{{2, 0, 4, -2}, 0.001190, {0.000000, 0.050000, 0.090000, 0.000000, 0.000000}},
	{{2, 0, 4, 0}, -0.044220, {-1.240000, 0.000000, -3.360000, 0.000000, 0.000000}},
	{{2, 0, 5, -2}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 0, 5, 0}, -0.002980, {-0.080000, 0.000000, -0.280000, 0.000000, 0.000000}},
	{{2, 0, 6, 0}, -0.000200, {0.000000, 0.000000, -0.020000, 0.000000, 0.000000}},
	{{2, 1, -6, 0}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -5, 0}, 0.001160, {0.080000, 0.000000, 0.110000, 0.070000, 0.000000}},
	{{2, 1, -4, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -4, 0}, 0.014170, {1.080000, 0.000000, 1.030000, 0.850000, 0.000000}},
	{{2, 1, -3, -2}, 0.000210, {0.020000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, -3, 0}, 0.168580, {15.790000, -0.240000, 9.160000, 10.170000, 0.050000}},
	{{2, 1, -3, 2}, 0.000300, {0.000000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{2, 1, -2, -2}, 0.000520, {0.270000, 0.020000, 0.000000, 0.030000, 0.000000}},
	{{2, 1, -2, 0}, 0.143680, {122.130000, -1.910000, 4.580000, 9.230000, 0.130000}},
	{{2, 1, -2, 2}, -0.002030, {0.310000, -0.100000, -0.080000, -0.120000, 0.000000}},
	{{2, 1, -1, -2}, -0.047360, {2.580000, -2.160000, -0.890000, -2.820000, 0.000000}},
	{{2, 1, -1, 0}, 24.209350, {-837.260000, 13.300000, 449.340000, 1443.450000, 0.260000}},
	{{2, 1, -1, 2}, -0.005880, {-0.100000, -0.260000, -0.140000, -0.350000, 0.000000}},
	{{2, 1, 0, -4}, 0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 0, -2}, -0.135720, {-4.940000, -6.040000, 0.540000, -8.130000, 0.030000}},
	{{2, 1, 0, 0}, 30.824980, {873.360000, -8.400000, 94.400000, 1844.570000, 3.860000}},
	{{2, 1, 0, 2}, -0.001430, {-0.040000, -0.060000, -0.040000, -0.090000, 0.000000}},
	{{2, 1, 1, -4}, 0.000400, {0.000000, 0.040000, 0.000000, 0.020000, 0.000000}},
	{{2, 1, 1, -2}, -0.055270, {1.020000, -2.520000, -1.020000, -3.290000, 0.000000}},
	{{2, 1, 1, 0}, 2.616500, {90.880000, -1.010000, 56.020000, 156.640000, 0.490000}},
	{{2, 1, 1, 2}, -0.000150, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 2, -4}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 2, -2}, -0.005370, {-0.030000, -0.240000, -0.200000, -0.320000, 0.000000}},
	{{2, 1, 2, 0}, 0.212520, {8.110000, -0.090000, 8.450000, 12.720000, 0.050000}},
	{{2, 1, 3, -2}, -0.000440, {0.000000, -0.020000, -0.020000, -0.030000, 0.000000}},
	{{2, 1, 3, 0}, 0.017040, {0.680000, 0.000000, 0.990000, 1.020000, 0.000000}},
	{{2, 1, 4, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 1, 4, 0}, 0.001350, {0.060000, 0.000000, 0.100000, 0.080000, 0.000000}},
	{{2, 1, 5, 0}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -4, 0}, -0.000410, {0.000000, 0.000000, -0.030000, -0.050000, 0.000000}},
	{{2, 2, -3, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, -3, 0}, -0.010360, {-0.290000, 0.000000, -0.580000, -1.250000, 0.000000}},
	{{2, 2, -2, -2}, -0.000550, {0.000000, -0.020000, -0.020000, -0.070000, 0.000000}},
	{{2, 2, -2, 0}, -0.108880, {-2.720000, 0.000000, -3.960000, -13.050000, 0.000000}},
	{{2, 2, -2, 2}, -0.000460, {0.000000, -0.020000, 0.000000, -0.060000, 0.000000}},
	{{2, 2, -1, -2}, -0.010720, {-0.370000, -0.470000, -0.170000, -1.280000, 0.000000}},
	{{2, 2, -1, 0}, 2.353800, {79.520000, -0.720000, 42.860000, 282.050000, -0.060000}},
	{{2, 2, -1, 2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, 0, -2}, 0.000800, {0.020000, 0.040000, 0.040000, 0.100000, 0.000000}},
	{{2, 2, 0, 0}, 0.147640, {4.880000, -0.050000, 4.900000, 17.690000, -0.290000}},
	{{2, 2, 1, -2}, 0.001870, {0.110000, 0.070000, 0.000000, 0.220000, 0.000000}},
	{{2, 2, 1, 0}, 0.009120, {0.290000, 0.000000, 0.460000, 1.090000, -0.040000}},
	{{2, 2, 2, -2}, 0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 2, 2, 0}, 0.000360, {0.000000, 0.000000, 0.030000, 0.040000, 0.000000}},
	{{2, 3, -3, 0}, -0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, -2, 0}, -0.000520, {-0.020000, 0.000000, -0.020000, -0.090000, 0.000000}},
	{{2, 3, -1, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{2, 3, -1, 0}, 0.002080, {0.140000, 0.000000, 0.030000, 0.370000, 0.000000}},
	{{2, 3, 0, 0}, -0.000240, {-0.020000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{2, 4, -1, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -4, -1, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -4, 0, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -3, -2, 0}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{3, -3, -1, 0}, 0.000650, {0.030000, 0.000000, 0.000000, 0.120000, 0.250000}},
	{{3, -3, 0, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -3, 0, 0}, -0.000550, {0.000000, 0.000000, 0.000000, -0.100000, -0.210000}},
	{{3, -3, 1, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -2, -3, 0}, -0.000160, {0.000000, 0.000000, 0.000000, -0.020000, -0.060000}},
	{{3, -2, -2, 0}, 0.002240, {0.030000, 0.000000, 0.080000, 0.270000, 0.870000}},
	{{3, -2, -1, -2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -2, -1, 0}, 0.013890, {0.550000, 0.000000, 0.260000, 1.660000, 5.400000}},
	{{3, -2, 0, -2}, 0.000700, {0.000000, 0.030000, 0.000000, 0.080000, 0.270000}},
	{{3, -2, 0, 0}, -0.010480, {-0.230000, 0.000000, 0.040000, -1.250000, -4.070000}},
	{{3, -2, 1, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -2, 1, 0}, -0.000670, {0.000000, 0.000000, 0.000000, -0.080000, -0.260000}},
	{{3, -2, 2, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, -4, 0}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{3, -1, -3, 0}, -0.003340, {-0.050000, 0.000000, -0.180000, -0.200000, -1.300000}},
	{{3, -1, -2, -2}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{3, -1, -2, 0}, 0.052930, {0.920000, 0.000000, 1.930000, 3.170000, 20.580000}},
	{{3, -1, -2, 2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, -1, -1, -2}, -0.000890, {0.000000, -0.040000, 0.000000, -0.050000, -0.340000}},
	{{3, -1, -1, 0}, 0.255610, {9.610000, -0.150000, 4.830000, 15.240000, 99.380000}},
	{{3, -1, 0, -2}, 0.014410, {0.210000, 0.640000, 0.000000, 0.860000, 5.610000}},
	{{3, -1, 0, 0}, -0.157080, {-2.880000, -0.040000, 0.830000, -9.420000, -61.080000}},
	{{3, -1, 1, -2}, 0.000490, {0.000000, 0.020000, 0.000000, 0.030000, 0.190000}},
	{{3, -1, 1, 0}, -0.008870, {-0.030000, 0.000000, -0.090000, -0.540000, -3.450000}},
	{{3, -1, 2, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, -1, 2, 0}, -0.000300, {0.000000, 0.000000, 0.000000, 0.000000, -0.120000}},
	{{3, 0, -5, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, -4, 0}, -0.001700, {0.000000, 0.000000, -0.120000, 0.000000, -0.660000}},
	{{3, 0, -3, -2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, -3, 0}, -0.048430, {-0.720000, 0.000000, -2.650000, -0.030000, -18.830000}},
	{{3, 0, -3, 2}, -0.000130, {0.000000, 0.000000, 0.000000, 0.000000, -0.050000}},
	{{3, 0, -2, -2}, -0.002060, {0.000000, -0.090000, -0.070000, 0.000000, -0.800000}},
	{{3, 0, -2, 0}, 0.862430, {16.640000, -0.340000, 31.480000, 0.130000, 335.340000}},
	{{3, 0, -2, 2}, -0.001010, {-0.030000, -0.040000, -0.040000, 0.000000, -0.390000}},
	{{3, 0, -1, -2}, -0.008680, {0.000000, -0.390000, -0.140000, 0.000000, -3.380000}},
	{{3, 0, -1, 0}, 3.258230, {117.770000, -2.270000, 61.910000, -1.340000, 1266.880000}},
	{{3, 0, -1, 2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{3, 0, 0, -4}, -0.000180, {0.000000, 0.000000, 0.000000, 0.000000, -0.070000}},
	{{3, 0, 0, -2}, 0.200990, {2.460000, 8.950000, -0.040000, -0.070000, 78.150000}},
	{{3, 0, 0, 0}, -1.418930, {-19.430000, -0.690000, 10.760000, -0.630000, -551.710000}},
	{{3, 0, 0, 2}, -0.000150, {0.000000, 0.000000, 0.000000, 0.000000, -0.060000}},
	{{3, 0, 1, -4}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, 0, 1, -2}, 0.006710, {0.020000, 0.300000, 0.120000, 0.000000, 2.610000}},
	{{3, 0, 1, 0}, -0.065450, {0.720000, -0.100000, -0.320000, -0.110000, -25.450000}},
	{{3, 0, 1, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 0, 2, -2}, 0.000350, {0.000000, 0.000000, 0.000000, 0.000000, 0.140000}},
	{{3, 0, 2, 0}, -0.001110, {0.210000, 0.000000, 0.030000, 0.000000, -0.430000}},
	{{3, 0, 3, 0}, 0.000160, {0.030000, 0.000000, 0.000000, 0.000000, 0.060000}},
	{{3, 0, 4, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -5, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -4, 0}, -0.000650, {-0.030000, 0.000000, -0.050000, -0.040000, -0.250000}},
	{{3, 1, -3, 0}, -0.006800, {-0.290000, 0.000000, -0.370000, -0.410000, -2.640000}},
	{{3, 1, -3, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 1, -2, -2}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, -0.040000}},
	{{3, 1, -2, 0}, 0.038100, {2.030000, 0.000000, 1.370000, 2.290000, 14.820000}},
	{{3, 1, -2, 2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{3, 1, -1, -2}, -0.000230, {0.000000, 0.000000, 0.000000, 0.000000, -0.090000}},
	{{3, 1, -1, 0}, -0.212590, {-4.000000, 0.170000, -4.030000, -12.700000, -82.660000}},
	{{3, 1, -1, 2}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{3, 1, 0, -2}, -0.008080, {-0.120000, -0.360000, 0.000000, -0.480000, -3.140000}},
	{{3, 1, 0, 0}, -0.107660, {-3.220000, 0.120000, -1.090000, -6.420000, -41.860000}},
	{{3, 1, 1, -2}, -0.000180, {0.000000, 0.000000, 0.000000, 0.000000, -0.070000}},
	{{3, 1, 1, 0}, -0.014480, {-0.440000, 0.000000, -0.370000, -0.860000, -5.630000}},
	{{3, 1, 2, 0}, -0.001500, {-0.050000, 0.000000, -0.070000, -0.090000, -0.580000}},
	{{3, 1, 3, 0}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, -0.060000}},
	{{3, 2, -3, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{3, 2, -2, 0}, 0.000320, {0.050000, 0.000000, 0.000000, 0.040000, 0.120000}},
	{{3, 2, -1, 0}, 0.000990, {-0.050000, 0.000000, 0.020000, 0.120000, 0.390000}},
	{{3, 2, 0, -2}, 0.000090, {0.000000, 0.000000, 0.000000, 0.020000, 0.040000}},
	{{3, 2, 0, 0}, 0.001620, {0.040000, 0.000000, 0.000000, 0.190000, 0.630000}},
	{{3, 2, 1, 0}, 0.000280, {0.000000, 0.000000, 0.000000, 0.030000, 0.110000}},
	{{3, 2, 2, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 3, -2, -2}, 0.000000, {-0.030000, 0.000000, -0.030000, 0.000000, -0.070000}},
	{{3, 3, -2, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{3, 3, -1, 0}, 0.000100, {0.000000, 0.000000, 0.000000, 0.020000, 0.040000}},
	{{3, 3, 0, -2}, 0.000020, {0.080000, -0.060000, 0.070000, 0.080000, -0.050000}},
	{{4, -5, -1, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -5, 0, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -4, -2, 0}, -0.000220, {0.000000, 0.000000, 0.000000, -0.050000, 0.000000}},
	{{4, -4, -1, 0}, -0.000780, {-0.050000, 0.000000, 0.000000, -0.190000, 0.000000}},
	{{4, -4, 0, 0}, -0.000450, {-0.030000, 0.000000, 0.000000, -0.110000, 0.000000}},
	{{4, -4, 1, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, -3, 0}, -0.000110, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{4, -3, -2, 0}, -0.005130, {-0.220000, 0.000000, -0.190000, -0.920000, 0.000000}},
	{{4, -3, -1, -2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -3, -1, 0}, -0.015710, {-0.870000, 0.000000, -0.310000, -2.820000, 0.000000}},
	{{4, -3, 0, -2}, -0.000220, {0.000000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{4, -3, 0, 0}, -0.008170, {-0.540000, 0.000000, -0.080000, -1.470000, 0.000000}},
	{{4, -3, 1, 0}, -0.001140, {-0.080000, 0.000000, -0.030000, -0.210000, 0.000000}},
	{{4, -3, 2, 0}, -0.000130, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{4, -2, -5, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -4, 0}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -3, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -3, 0}, -0.002390, {-0.120000, 0.000000, -0.130000, -0.290000, 0.000000}},
	{{4, -2, -3, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -2, -2}, -0.000360, {0.000000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{4, -2, -2, 0}, -0.108340, {-4.380000, 0.040000, -3.950000, -12.960000, 0.000000}},
	{{4, -2, -2, 2}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, -1, -2}, -0.001450, {-0.040000, -0.060000, -0.030000, -0.170000, 0.000000}},
	{{4, -2, -1, 0}, -0.279060, {-14.760000, 0.110000, -5.610000, -33.360000, 0.000000}},
	{{4, -2, -1, 2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 0, -2}, -0.004030, {-0.180000, -0.180000, 0.000000, -0.480000, 0.000000}},
	{{4, -2, 0, 0}, -0.128060, {-8.090000, 0.050000, -1.350000, -15.300000, -0.020000}},
	{{4, -2, 1, -2}, 0.000230, {0.000000, 0.000000, 0.000000, 0.030000, 0.000000}},
	{{4, -2, 1, 0}, -0.017280, {-1.130000, 0.000000, -0.450000, -2.060000, 0.000000}},
	{{4, -2, 2, -2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -2, 2, 0}, -0.001840, {-0.120000, 0.000000, -0.080000, -0.220000, 0.000000}},
	{{4, -2, 3, 0}, -0.000180, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{4, -1, -6, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -5, 0}, -0.000410, {0.000000, 0.000000, -0.040000, -0.020000, 0.000000}},
	{{4, -1, -4, -2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -4, 0}, -0.002300, {-0.060000, 0.000000, -0.170000, -0.140000, 0.000000}},
	{{4, -1, -3, -2}, -0.000590, {-0.020000, -0.030000, -0.030000, -0.040000, 0.000000}},
	{{4, -1, -3, 0}, -0.043160, {-2.190000, 0.020000, -2.360000, -2.590000, 0.000000}},
	{{4, -1, -3, 2}, 0.000770, {0.020000, 0.030000, 0.040000, 0.050000, 0.000000}},
	{{4, -1, -2, -2}, -0.006610, {-0.250000, -0.290000, -0.240000, -0.400000, 0.000000}},
	{{4, -1, -2, 0}, -1.897100, {-73.130000, 0.790000, -69.170000, -113.340000, -0.120000}},
	{{4, -1, -2, 2}, 0.001600, {0.070000, 0.070000, 0.060000, 0.100000, 0.000000}},
	{{4, -1, -1, -4}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, -1, -2}, -0.026980, {-0.670000, -1.200000, -0.500000, -1.610000, 0.000000}},
	{{4, -1, -1, 0}, -3.958120, {-199.780000, 1.540000, -80.750000, -236.160000, 0.150000}},
	{{4, -1, -1, 2}, 0.000690, {0.030000, 0.030000, 0.030000, 0.040000, 0.000000}},
	{{4, -1, 0, -4}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 0, -2}, -0.057890, {-2.540000, -2.570000, 0.140000, -3.440000, -0.020000}},
	{{4, -1, 0, 0}, -1.571450, {-94.020000, 0.590000, -18.480000, -93.650000, -0.260000}},
	{{4, -1, 0, 2}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 1, -4}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 1, -2}, 0.002720, {0.120000, 0.120000, 0.070000, 0.160000, 0.000000}},
	{{4, -1, 1, 0}, -0.202860, {-12.450000, 0.080000, -5.510000, -12.080000, -0.030000}},
	{{4, -1, 2, -2}, 0.000550, {0.020000, 0.020000, 0.020000, 0.030000, 0.000000}},
	{{4, -1, 2, 0}, -0.020790, {-1.290000, 0.000000, -0.920000, -1.240000, 0.000000}},
	{{4, -1, 3, -2}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, -1, 3, 0}, -0.001940, {-0.120000, 0.000000, -0.120000, -0.120000, 0.000000}},
	{{4, -1, 4, 0}, -0.000170, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -7, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -6, 0}, -0.000550, {-0.020000, 0.000000, -0.060000, 0.000000, 0.000000}},
	{{4, 0, -5, -2}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -5, 0}, -0.005420, {-0.210000, 0.000000, -0.490000, 0.000000, 0.000000}},
	{{4, 0, -4, -2}, -0.000720, {-0.030000, -0.030000, -0.050000, 0.000000, 0.000000}},
	{{4, 0, -4, 0}, -0.029390, {-0.870000, 0.000000, -2.140000, 0.000000, 0.000000}},
	{{4, 0, -4, 2}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -3, -2}, -0.007440, {-0.270000, -0.330000, -0.410000, 0.000000, 0.000000}},
	{{4, 0, -3, 0}, -0.514230, {-25.810000, 0.280000, -28.100000, -0.190000, -0.150000}},
	{{4, 0, -3, 2}, 0.009250, {0.290000, 0.410000, 0.500000, 0.000000, 0.000000}},
	{{4, 0, -2, -4}, -0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -2, -2}, -0.079820, {-2.910000, -3.540000, -2.910000, 0.000000, 0.000000}},
	{{4, 0, -2, 0}, -21.636270, {-808.810000, 9.470000, -788.010000, 2.770000, -1.210000}},
	{{4, 0, -2, 2}, 0.014830, {0.600000, 0.660000, 0.610000, 0.000000, 0.000000}},
	{{4, 0, -1, -4}, -0.000800, {-0.020000, -0.070000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, -1, -2}, -0.321760, {-7.980000, -14.290000, -5.950000, 0.150000, -0.110000}},
	{{4, 0, -1, 0}, -34.782450, {-1678.730000, 13.500000, -725.230000, 8.970000, 0.880000}},
	{{4, 0, -1, 2}, 0.005500, {0.250000, 0.250000, 0.210000, 0.000000, 0.000000}},
	{{4, 0, 0, -4}, 0.000320, {0.000000, 0.030000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 0, -2}, -0.507930, {-21.440000, -22.550000, 1.370000, 0.280000, -0.170000}},
	{{4, 0, 0, 0}, -11.649930, {-657.420000, 4.130000, -155.600000, 4.420000, -2.170000}},
	{{4, 0, 0, 2}, 0.000670, {0.020000, 0.030000, 0.050000, 0.000000, 0.000000}},
	{{4, 0, 1, -4}, 0.000500, {0.000000, 0.040000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 1, -2}, 0.019380, {0.760000, 0.890000, 0.570000, 0.000000, 0.000000}},
	{{4, 0, 1, 0}, -1.422550, {-81.300000, 0.500000, -40.470000, 0.680000, -0.210000}},
	{{4, 0, 1, 2}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 2, -2}, 0.004000, {0.160000, 0.180000, 0.170000, 0.000000, 0.000000}},
	{{4, 0, 2, 0}, -0.139220, {-7.970000, 0.050000, -6.330000, 0.080000, 0.000000}},
	{{4, 0, 3, -2}, 0.000440, {0.000000, 0.020000, 0.030000, 0.000000, 0.000000}},
	{{4, 0, 3, 0}, -0.012430, {-0.710000, 0.000000, -0.780000, 0.000000, 0.000000}},
	{{4, 0, 4, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 0, 4, 0}, -0.001060, {-0.060000, 0.000000, -0.090000, 0.000000, 0.000000}},
	{{4, 0, 5, 0}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -5, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -4, 0}, 0.000930, {0.050000, 0.000000, 0.070000, 0.060000, 0.000000}},
	{{4, 1, -3, 0}, -0.023990, {-2.480000, 0.030000, -1.300000, -1.430000, 0.000000}},
	{{4, 1, -3, 2}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -2, -2}, 0.000360, {-0.050000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{4, 1, -2, 0}, 0.236960, {-7.250000, 0.120000, 8.690000, 14.250000, 0.020000}},
	{{4, 1, -2, 2}, -0.000220, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, -1, -2}, 0.015510, {0.500000, 0.690000, 0.290000, 0.920000, 0.000000}},
	{{4, 1, -1, 0}, 0.578810, {16.490000, -0.100000, 12.270000, 34.720000, 0.130000}},
	{{4, 1, -1, 2}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 0, -2}, 0.019690, {0.950000, 0.870000, 0.000000, 1.180000, 0.000000}},
	{{4, 1, 0, 0}, 0.244530, {12.940000, -0.100000, 3.440000, 14.630000, 0.040000}},
	{{4, 1, 0, 2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 1, -4}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 1, -2}, 0.000130, {0.030000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 1, 0}, 0.036820, {2.170000, -0.020000, 1.070000, 2.200000, 0.000000}},
	{{4, 1, 2, -2}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 1, 2, 0}, 0.004300, {0.270000, 0.000000, 0.200000, 0.260000, 0.000000}},
	{{4, 1, 3, 0}, 0.000450, {0.030000, 0.000000, 0.030000, 0.030000, 0.000000}},
	{{4, 1, 4, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -4, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -3, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, -3, 0}, 0.002520, {0.170000, 0.000000, 0.140000, 0.300000, 0.000000}},
	{{4, 2, -2, -2}, 0.000210, {0.000000, 0.000000, 0.000000, 0.030000, 0.000000}},
	{{4, 2, -2, 0}, 0.026580, {1.570000, 0.000000, 0.970000, 3.180000, 0.000000}},
	{{4, 2, -1, -2}, -0.000640, {-0.040000, -0.030000, 0.000000, -0.080000, 0.000000}},
	{{4, 2, -1, 0}, 0.018680, {1.310000, 0.000000, 0.450000, 2.240000, 0.000000}},
	{{4, 2, 0, -2}, 0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 2, 0, 0}, 0.001360, {0.110000, 0.000000, 0.090000, 0.160000, 0.000000}},
	{{4, 2, 1, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{4, 3, -2, 0}, -0.000150, {0.000000, 0.000000, 0.000000, -0.030000, 0.000000}},
	{{4, 3, -1, 0}, -0.000200, {0.000000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{4, 3, 0, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -3, -2, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -2, -3, 0}, 0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{5, -2, -2, 0}, 0.000440, {0.030000, 0.000000, 0.000000, 0.050000, 0.170000}},
	{{5, -2, -1, -2}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -2, -1, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, -2, 0, 0}, -0.000160, {0.000000, 0.000000, 0.000000, -0.020000, -0.060000}},
	{{5, -2, 1, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, -4, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, -3, 0}, 0.001280, {0.060000, 0.000000, 0.070000, 0.080000, 0.500000}},
	{{5, -1, -2, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, -2, 0}, 0.005730, {0.320000, 0.000000, 0.220000, 0.340000, 2.230000}},
	{{5, -1, -1, -2}, 0.000340, {0.000000, 0.000000, 0.000000, 0.020000, 0.130000}},
	{{5, -1, -1, 0}, -0.000560, {0.070000, 0.000000, 0.020000, -0.040000, -0.220000}},
	{{5, -1, 0, -2}, 0.000210, {0.000000, 0.000000, 0.000000, 0.000000, 0.080000}},
	{{5, -1, 0, 0}, -0.001530, {-0.060000, 0.000000, 0.000000, -0.090000, -0.600000}},
	{{5, -1, 1, -2}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, -1, 1, 0}, -0.000190, {0.000000, 0.000000, 0.000000, 0.000000, -0.070000}},
	{{5, 0, -4, 0}, 0.000260, {0.000000, 0.000000, 0.020000, 0.000000, 0.100000}},
	{{5, 0, -3, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, -3, 0}, 0.011490, {0.490000, 0.000000, 0.630000, 0.000000, 4.470000}},
	{{5, 0, -3, 2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 0, -2, -2}, 0.000300, {0.000000, 0.000000, 0.000000, 0.000000, 0.120000}},
	{{5, 0, -2, 0}, 0.045910, {2.500000, -0.040000, 1.730000, -0.030000, 17.850000}},
	{{5, 0, -1, -2}, 0.002810, {0.100000, 0.120000, 0.050000, 0.000000, 1.090000}},
	{{5, 0, -1, 0}, -0.002480, {0.570000, -0.020000, 0.220000, -0.040000, -0.960000}},
	{{5, 0, 0, -2}, 0.001420, {0.070000, 0.060000, 0.000000, 0.000000, 0.550000}},
	{{5, 0, 0, 0}, -0.008140, {-0.250000, 0.000000, 0.070000, 0.000000, -3.170000}},
	{{5, 0, 1, -2}, 0.000200, {0.000000, 0.000000, 0.000000, 0.000000, 0.080000}},
	{{5, 0, 1, 0}, -0.000890, {0.000000, 0.000000, 0.000000, 0.000000, -0.350000}},
	{{5, 0, 2, 0}, -0.000060, {0.000000, 0.000000, 0.000000, 0.000000, -0.020000}},
	{{5, 1, -4, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 1, -3, 0}, 0.000380, {0.040000, 0.000000, 0.020000, 0.020000, 0.150000}},
	{{5, 1, -2, 0}, -0.002560, {-0.070000, 0.000000, -0.100000, -0.150000, -1.000000}},
	{{5, 1, -1, -2}, -0.000150, {0.000000, 0.000000, 0.000000, 0.000000, -0.060000}},
	{{5, 1, -1, 0}, -0.003110, {-0.160000, 0.000000, -0.080000, -0.190000, -1.210000}},
	{{5, 1, 0, -2}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{5, 1, 0, 0}, -0.001110, {-0.070000, 0.000000, -0.030000, -0.070000, -0.430000}},
	{{5, 1, 1, 0}, -0.000200, {0.000000, 0.000000, 0.000000, 0.000000, -0.080000}},
	{{5, 1, 2, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{5, 2, -1, 0}, 0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.030000}},
	{{5, 2, 0, 0}, 0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -4, -2, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -4, -1, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -3, -3, 0}, -0.000120, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{6, -3, -2, 0}, -0.000440, {-0.030000, 0.000000, 0.000000, -0.080000, 0.000000}},
	{{6, -3, -1, 0}, -0.000430, {-0.040000, 0.000000, 0.000000, -0.080000, 0.000000}},
	{{6, -3, 0, 0}, -0.000170, {0.000000, 0.000000, 0.000000, -0.030000, 0.000000}},
	{{6, -3, 1, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -4, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -3, 0}, -0.001950, {-0.120000, 0.000000, -0.110000, -0.230000, 0.000000}},
	{{6, -2, -2, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -2, 0}, -0.006180, {-0.440000, 0.000000, -0.240000, -0.740000, 0.000000}},
	{{6, -2, -1, -2}, -0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, -1, 0}, -0.005410, {-0.440000, 0.000000, -0.140000, -0.650000, 0.000000}},
	{{6, -2, 0, -2}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -2, 0, 0}, -0.001940, {-0.170000, 0.000000, -0.040000, -0.230000, 0.000000}},
	{{6, -2, 1, 0}, -0.000350, {-0.030000, 0.000000, 0.000000, -0.040000, 0.000000}},
	{{6, -2, 2, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -4, 0}, -0.000850, {-0.060000, 0.000000, -0.060000, -0.050000, 0.000000}},
	{{6, -1, -3, -2}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -3, 0}, -0.024360, {-1.430000, 0.000000, -1.330000, -1.450000, 0.000000}},
	{{6, -1, -3, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -2, -2}, -0.000410, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{6, -1, -2, 0}, -0.066780, {-4.610000, 0.040000, -2.600000, -3.980000, 0.000000}},
	{{6, -1, -2, 2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, -1, -1, -2}, -0.001210, {-0.070000, -0.050000, -0.020000, -0.070000, 0.000000}},
	{{6, -1, -1, 0}, -0.051910, {-4.100000, 0.030000, -1.420000, -3.090000, 0.000000}},
	{{6, -1, 0, -2}, -0.000490, {-0.040000, -0.020000, 0.000000, -0.030000, 0.000000}},
	{{6, -1, 0, 0}, -0.017090, {-1.470000, 0.000000, -0.420000, -1.010000, 0.000000}},
	{{6, -1, 1, 0}, -0.002960, {-0.260000, 0.000000, -0.110000, -0.180000, 0.000000}},
	{{6, -1, 2, 0}, -0.000390, {-0.040000, 0.000000, -0.020000, -0.020000, 0.000000}},
	{{6, -1, 3, 0}, -0.000050, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -5, 0}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -4, 0}, -0.006590, {-0.450000, 0.000000, -0.480000, 0.000000, 0.000000}},
	{{6, 0, -4, 2}, 0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -3, -2}, -0.000270, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -3, 0}, -0.183160, {-10.480000, 0.120000, -10.020000, 0.050000, -0.020000}},
	{{6, 0, -3, 2}, 0.000280, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -2, -2}, -0.003260, {-0.130000, -0.140000, -0.120000, 0.000000, 0.000000}},
	{{6, 0, -2, 0}, -0.422500, {-28.360000, 0.260000, -16.580000, 0.190000, 0.000000}},
	{{6, 0, -2, 2}, 0.000200, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, -1, -2}, -0.007850, {-0.440000, -0.350000, -0.130000, 0.000000, 0.000000}},
	{{6, 0, -1, 0}, -0.286630, {-21.860000, 0.160000, -8.120000, 0.180000, -0.030000}},
	{{6, 0, -1, 2}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 0, -4}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 0, -2}, -0.002700, {-0.190000, -0.120000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 0, 0}, -0.085870, {-7.100000, 0.050000, -2.250000, 0.070000, -0.020000}},
	{{6, 0, 1, 0}, -0.014200, {-1.200000, 0.000000, -0.550000, 0.000000, 0.000000}},
	{{6, 0, 2, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 2, 0}, -0.001820, {-0.160000, 0.000000, -0.100000, 0.000000, 0.000000}},
	{{6, 0, 3, 0}, -0.000200, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 0, 4, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -4, 0}, -0.000240, {-0.040000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -3, 0}, 0.002780, {-0.060000, 0.000000, 0.150000, 0.170000, 0.000000}},
	{{6, 1, -2, -2}, 0.000190, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, -2, 0}, 0.009480, {0.350000, 0.000000, 0.370000, 0.570000, 0.000000}},
	{{6, 1, -1, -2}, 0.000420, {0.030000, 0.000000, 0.000000, 0.020000, 0.000000}},
	{{6, 1, -1, 0}, 0.007800, {0.490000, 0.000000, 0.220000, 0.470000, 0.000000}},
	{{6, 1, 0, -2}, 0.000160, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 1, 0, 0}, 0.002720, {0.210000, 0.000000, 0.070000, 0.160000, 0.000000}},
	{{6, 1, 1, 0}, 0.000520, {0.040000, 0.000000, 0.020000, 0.030000, 0.000000}},
	{{6, 1, 2, 0}, 0.000080, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -4, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{6, 2, -3, 0}, 0.000340, {0.030000, 0.000000, 0.020000, 0.040000, 0.000000}},
	{{6, 2, -2, 0}, 0.000440, {0.040000, 0.000000, 0.000000, 0.050000, 0.000000}},
	{{6, 2, -1, 0}, 0.000140, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -1, -4, 0}, 0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, -1, -3, 0}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.040000}},
	{{7, -1, -2, 0}, 0.000060, {0.000000, 0.000000, 0.000000, 0.000000, 0.020000}},
	{{7, -1, -1, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -4, 0}, 0.000150, {0.000000, 0.000000, 0.000000, 0.000000, 0.060000}},
	{{7, 0, -3, 0}, 0.000660, {0.050000, 0.000000, 0.040000, 0.000000, 0.260000}},
	{{7, 0, -2, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -2, 0}, 0.000320, {0.040000, 0.000000, 0.000000, 0.000000, 0.130000}},
	{{7, 0, -1, -2}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 0, -1, 0}, -0.000080, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{7, 0, 0, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{7, 1, -3, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{7, 1, -2, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, -0.030000}},
	{{7, 1, -1, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -4, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -3, 0}, -0.000130, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, -2, 0}, -0.000160, {0.000000, 0.000000, 0.000000, -0.020000, 0.000000}},
	{{8, -2, -1, 0}, -0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -2, 0, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -4, 0}, -0.000330, {-0.030000, 0.000000, -0.020000, -0.020000, 0.000000}},
	{{8, -1, -3, 0}, -0.001090, {-0.100000, 0.000000, -0.060000, -0.070000, 0.000000}},
	{{8, -1, -2, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -2, 0}, -0.001260, {-0.120000, 0.000000, -0.060000, -0.080000, 0.000000}},
	{{8, -1, -1, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, -1, 0}, -0.000700, {-0.080000, 0.000000, -0.030000, -0.040000, 0.000000}},
	{{8, -1, 0, 0}, -0.000220, {-0.020000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, -1, 1, 0}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -5, 0}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -4, 0}, -0.001840, {-0.140000, 0.000000, -0.130000, 0.000000, 0.000000}},
	{{8, 0, -3, -2}, -0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -3, 0}, -0.005390, {-0.460000, 0.000000, -0.310000, 0.000000, 0.000000}},
	{{8, 0, -2, -2}, -0.000120, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -2, 0}, -0.005590, {-0.530000, 0.000000, -0.250000, 0.000000, 0.000000}},
	{{8, 0, -1, -2}, -0.000090, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, -1, 0}, -0.002850, {-0.290000, 0.000000, -0.110000, 0.000000, 0.000000}},
	{{8, 0, 0, -2}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 0, 0}, -0.000830, {-0.090000, 0.000000, -0.030000, 0.000000, 0.000000}},
	{{8, 0, 1, 0}, -0.000160, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 0, 2, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -4, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -3, 0}, 0.000150, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -2, 0}, 0.000190, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, -1, 0}, 0.000110, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{8, 1, 0, 0}, 0.000040, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, -1, -3, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, -1, -2, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -5, 0}, -0.000020, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -4, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -3, 0}, -0.000100, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -2, 0}, -0.000070, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}},
	{{10, 0, -1, 0}, -0.000030, {0.000000, 0.000000, 0.000000, 0.000000, 0.000000}}
};


static const struct earth_pert earth_pert_elp4 [ELP4_SIZE] = 
{
	{0, {0, 0, 0, 1}, 270.000000, 0.000030, 0.075000},
	{0, {0, 0, 0, 2}, 0.000000, 0.000370, 0.037000},
	{0, {0, 0, 1, -2}, 180.000000, 0.004800, 0.074000},
	{0, {0, 0, 1, -1}, 90.000000, 0.000010, 5.997000},
	{0, {0, 0, 2, -2}, 0.000000, 0.000850, 2.998000},
	{0, {0, 0, 2, 0}, 180.000000, 0.000250, 0.038000},
	{0, {0, 0, 3, -2}, 0.000000, 0.000030, 0.077000},
	{0, {0, 0, 3, 0}, 180.000000, 0.000020, 0.025000},
	{0, {0, 0, 4, 0}, 180.000000, 0.000010, 0.019000},
	{0, {0, 1, -2, 0}, 180.000000, 0.000030, 0.039000},
	{0, {0, 1, -1, 0}, 180.000000, 0.000480, 0.082000},
	{0, {0, 1, -1, 2}, 180.000000, 0.000010, 0.069000},
	{0, {0, 1, 0, 0}, 180.000000, 0.000470, 1.000000},
	{0, {0, 1, 1, -2}, 180.000000, 0.000050, 0.079000},
	{0, {0, 1, 1, 0}, 180.000000, 0.000190, 0.070000},
	{0, {0, 1, 2, 0}, 180.000000, 0.000010, 0.036000},
	{0, {0, 2, -1, 0}, 180.000000, 0.000030, 0.089000},
	{0, {1, -1, -1, 0}, 180.000000, 0.000010, 0.530000},
	{0, {1, -1, 0, 0}, 180.000000, 0.000150, 0.088000},
	{0, {1, -1, 1, 0}, 180.000000, 0.000010, 0.041000},
	{0, {1, 0, -2, 0}, 180.000000, 0.000010, 0.071000},
	{0, {1, 0, -1, 0}, 180.000000, 0.000040, 1.127000},
	{0, {1, 0, 0, -2}, 0.000000, 0.000010, 0.069000},
	{0, {1, 0, 0, 0}, 180.000000, 0.001000, 0.081000},
	{0, {1, 0, 1, 0}, 180.000000, 0.000060, 0.039000},
	{0, {1, 1, -1, 0}, 0.000000, 0.000190, 8.850000},
	{0, {1, 1, 0, 0}, 180.000000, 0.000700, 0.075000},
	{0, {1, 1, 1, 0}, 180.000000, 0.000050, 0.038000},
	{0, {2, -1, -2, 0}, 180.000000, 0.000020, 0.360000},
	{0, {2, -1, -1, 0}, 0.000000, 0.000610, 0.095000},
	{0, {2, -1, 0, -2}, 0.000000, 0.000020, 0.322000},
	{0, {2, -1, 0, 0}, 0.000000, 0.000010, 0.042000},
	{0, {2, -1, 1, -2}, 0.000000, 0.000040, 0.099000},
	{0, {2, 0, -3, 2}, 180.000000, 0.000010, 0.085000},
	{0, {2, 0, -2, 0}, 180.000000, 0.000770, 0.564000},
	{0, {2, 0, -2, 2}, 0.000000, 0.000060, 0.040000},
	{0, {2, 0, -1, -2}, 180.000000, 0.000050, 0.065000},
	{0, {2, 0, -1, 0}, 0.000000, 0.022060, 0.087000},
	{0, {2, 0, 0, -2}, 0.000000, 0.000640, 0.474000},
	{0, {2, 0, 0, 0}, 0.000000, 0.001020, 0.040000},
	{0, {2, 0, 1, -2}, 0.000000, 0.000890, 0.090000},
	{0, {2, 0, 1, 0}, 0.000000, 0.000040, 0.026000},
	{0, {2, 0, 2, -2}, 0.000000, 0.000070, 0.041000},
	{0, {2, 1, -2, 0}, 0.000000, 0.000060, 1.292000},
	{0, {2, 1, -1, 0}, 180.000000, 0.000060, 0.080000},
	{0, {2, 1, 0, -2}, 180.000000, 0.000020, 0.903000},
	{0, {2, 1, 0, 0}, 180.000000, 0.000010, 0.039000},
	{0, {2, 2, -1, 0}, 0.000000, 0.000090, 0.074000},
	{0, {3, 0, -1, 0}, 180.000000, 0.000010, 0.042000},
	{0, {4, -1, -2, 0}, 0.000000, 0.000020, 0.046000},
	{0, {4, -1, -1, 0}, 0.000000, 0.000020, 0.028000},
	{0, {4, 0, -2, 0}, 0.000000, 0.000260, 0.044000},
	{0, {4, 0, -1, -2}, 0.000000, 0.000020, 0.107000},
	{0, {4, 0, -1, 0}, 0.000000, 0.000190, 0.028000},
	{0, {4, 0, 0, -2}, 0.000000, 0.000020, 0.044000},
	{0, {4, 0, 0, 0}, 0.000000, 0.000020, 0.020000},
	{0, {4, 0, 1, -2}, 0.000000, 0.000010, 0.028000},
	{1, {-6, 0, 0, -1}, 0.001000, 0.000010, 0.013000},
	{1, {-6, 0, 1, -1}, 0.001000, 0.000030, 0.016000},
	{1, {-6, 0, 2, -1}, 0.000680, 0.000030, 0.021000},
	{1, {-6, 0, 3, -1}, 0.000360, 0.000010, 0.029000},
	{1, {-4, -1, 0, -1}, 180.001030, 0.000010, 0.020000},
	{1, {-4, -1, 1, -1}, 180.000810, 0.000020, 0.027000},
	{1, {-4, -1, 1, 1}, 180.000720, 0.000020, 0.096000},
	{1, {-4, 0, -2, -1}, 0.000990, 0.000020, 0.013000},
	{1, {-4, 0, -2, 1}, 180.000500, 0.000010, 0.020000},
	{1, {-4, 0, -1, -1}, 0.001090, 0.000140, 0.016000},
	{1, {-4, 0, -1, 1}, 180.000500, 0.000090, 0.028000},
	{1, {-4, 0, 0, -1}, 0.001000, 0.000750, 0.020000},
	{1, {-4, 0, 0, 1}, 180.000170, 0.000110, 0.044000},
	{1, {-4, 0, 1, -3}, 180.000930, 0.000020, 0.016000},
	{1, {-4, 0, 1, -1}, 0.000800, 0.001410, 0.028000},
	{1, {-4, 0, 1, 1}, 0.000910, 0.000220, 0.106000},
	{1, {-4, 0, 2, -3}, 180.000910, 0.000010, 0.020000},
	{1, {-4, 0, 2, -1}, 0.000290, 0.000650, 0.043000},
	{1, {-4, 1, -1, -1}, 0.000980, 0.000020, 0.016000},
	{1, {-4, 1, 0, -1}, 0.000990, 0.000100, 0.021000},
	{1, {-4, 1, 1, -1}, 0.000800, 0.000170, 0.028000},
	{1, {-4, 1, 1, 1}, 0.000820, 0.000020, 0.119000},
	{1, {-4, 1, 2, -1}, 0.000300, 0.000060, 0.045000},
	{1, {-4, 2, 0, -1}, 0.000940, 0.000010, 0.021000},
	{1, {-4, 2, 1, -1}, 0.000980, 0.000010, 0.029000},
	{1, {-3, 0, 0, -1}, 0.000820, 0.000040, 0.027000},
	{1, {-3, 0, 0, 1}, 180.000730, 0.000230, 0.097000},
	{1, {-3, 0, 1, -1}, 180.000680, 0.000060, 0.042000},
	{1, {-3, 0, 1, 1}, 180.000720, 0.000030, 0.340000},
	{1, {-3, 1, 0, 1}, 180.000720, 0.000020, 0.107000},
	{1, {-2, -2, 1, -1}, 180.000310, 0.000020, 0.074000},
	{1, {-2, -2, 1, 1}, 180.000290, 0.000010, 0.075000},
	{1, {-2, -1, -2, -1}, 180.001230, 0.000020, 0.019000},
	{1, {-2, -1, -2, 1}, 0.000560, 0.000010, 0.039000},
	{1, {-2, -1, -1, -1}, 180.001190, 0.000120, 0.026000},
	{1, {-2, -1, -1, 1}, 0.000650, 0.000090, 0.082000},
	{1, {-2, -1, 0, -1}, 180.001090, 0.000530, 0.039000},
	{1, {-2, -1, 0, 1}, 180.000760, 0.001230, 0.949000},
	{1, {-2, -1, 1, -1}, 180.000470, 0.000530, 0.080000},
	{1, {-2, -1, 2, -1}, 180.001480, 0.000060, 1.388000},
	{1, {-2, 0, -3, -1}, 0.001220, 0.000090, 0.015000},
	{1, {-2, 0, -3, 1}, 180.000440, 0.000050, 0.027000},
	{1, {-2, 0, -2, -3}, 180.000930, 0.000010, 0.013000},
	{1, {-2, 0, -2, -1}, 0.001190, 0.000970, 0.019000},
	{1, {-2, 0, -2, 1}, 180.000500, 0.000650, 0.041000},
	{1, {-2, 0, -1, -3}, 180.001010, 0.000080, 0.015000},
	{1, {-2, 0, -1, -1}, 0.001130, 0.009130, 0.026000},
	{1, {-2, 0, -1, 1}, 180.000490, 0.008870, 0.089000},
	{1, {-2, 0, 0, -3}, 180.000920, 0.000370, 0.019000},
	{1, {-2, 0, 0, -1}, 0.001000, 0.065690, 0.040000},
	{1, {-2, 0, 0, 0}, 90.000000, 0.000060, 0.088000},
	{1, {-2, 0, 0, 1}, 0.000760, 0.047460, 0.487000},
	{1, {-2, 0, 0, 3}, 180.000770, 0.000130, 0.035000},
	{1, {-2, 0, 1, -3}, 180.000730, 0.000440, 0.026000},
	{1, {-2, 0, 1, -1}, 0.000290, 0.049620, 0.087000},
	{1, {-2, 0, 1, 1}, 0.000450, 0.000260, 0.065000},
	{1, {-2, 0, 1, 3}, 180.000760, 0.000010, 0.024000},
	{1, {-2, 0, 2, -3}, 180.000430, 0.000010, 0.040000},
	{1, {-2, 0, 2, -1}, 180.002080, 0.002490, 0.581000},
	{1, {-2, 0, 2, 1}, 180.000700, 0.000480, 0.035000},
	{1, {-2, 0, 3, -1}, 180.001550, 0.000450, 0.067000},
	{1, {-2, 0, 3, 1}, 180.000730, 0.000080, 0.024000},
	{1, {-2, 0, 4, -1}, 180.001450, 0.000050, 0.035000},
	{1, {-2, 1, -2, -1}, 0.001180, 0.000080, 0.020000},
	{1, {-2, 1, -2, 1}, 180.000490, 0.000040, 0.043000},
	{1, {-2, 1, -1, -1}, 0.001110, 0.000720, 0.027000},
	{1, {-2, 1, -1, 1}, 180.000520, 0.000490, 0.098000},
	{1, {-2, 1, 0, -3}, 180.000910, 0.000030, 0.020000},
	{1, {-2, 1, 0, -1}, 0.000980, 0.004820, 0.042000},
	{1, {-2, 1, 0, 1}, 0.000750, 0.001870, 0.327000},
	{1, {-2, 1, 1, -3}, 180.000890, 0.000020, 0.027000},
	{1, {-2, 1, 1, -1}, 0.000310, 0.002250, 0.095000},
	{1, {-2, 1, 1, 1}, 180.000780, 0.000050, 0.061000},
	{1, {-2, 1, 2, -1}, 180.002250, 0.000090, 0.368000},
	{1, {-2, 1, 2, 1}, 180.000710, 0.000030, 0.034000},
	{1, {-2, 1, 3, -1}, 180.001640, 0.000010, 0.063000},
	{1, {-2, 2, -1, -1}, 0.001110, 0.000040, 0.028000},
	{1, {-2, 2, -1, 1}, 180.000540, 0.000020, 0.109000},
	{1, {-2, 2, 0, -1}, 0.000970, 0.000240, 0.044000},
	{1, {-2, 2, 0, 1}, 0.000720, 0.000060, 0.247000},
	{1, {-2, 2, 1, -1}, 0.000310, 0.000080, 0.105000},
	{1, {-2, 3, 0, -1}, 0.000940, 0.000010, 0.046000},
	{1, {-1, -1, -1, -1}, 0.001220, 0.000040, 0.037000},
	{1, {-1, -1, 0, -1}, 0.001070, 0.000190, 0.075000},
	{1, {-1, -1, 0, 1}, 0.000000, 0.000010, 0.075000},
	{1, {-1, -1, 1, -1}, 180.001490, 0.000010, 5.998000},
	{1, {-1, 0, -2, -1}, 180.001310, 0.000030, 0.026000},
	{1, {-1, 0, -1, -1}, 180.001310, 0.000230, 0.039000},
	{1, {-1, 0, -1, 1}, 180.001220, 0.000020, 0.857000},
	{1, {-1, 0, 0, -3}, 0.000930, 0.000010, 0.025000},
	{1, {-1, 0, 0, -1}, 180.001340, 0.000750, 0.081000},
	{1, {-1, 0, 0, 1}, 180.000670, 0.000560, 0.069000},
	{1, {-1, 0, 1, -1}, 0.001270, 0.000280, 1.200000},
	{1, {-1, 0, 1, 1}, 180.000720, 0.000020, 0.036000},
	{1, {-1, 0, 2, -1}, 0.001290, 0.000060, 0.071000},
	{1, {-1, 1, 0, -1}, 179.999900, 0.000040, 0.088000},
	{1, {-1, 1, 0, 1}, 180.000720, 0.000010, 0.065000},
	{1, {0, -2, -1, -1}, 180.001380, 0.000020, 0.065000},
	{1, {0, -2, 0, -1}, 0.000720, 0.000030, 0.487000},
	{1, {0, -2, 1, -1}, 0.001160, 0.000070, 0.089000},
	{1, {0, -1, -3, -1}, 180.001330, 0.000030, 0.024000},
	{1, {0, -1, -2, -1}, 180.001330, 0.000290, 0.036000},
	{1, {0, -1, -2, 1}, 0.000250, 0.000030, 1.389000},
	{1, {0, -1, -1, -3}, 0.000900, 0.000010, 0.024000},
	{1, {0, -1, -1, -1}, 180.001410, 0.001870, 0.070000},
	{1, {0, -1, -1, 1}, 359.999280, 0.000080, 0.080000},
	{1, {0, -1, 0, -3}, 0.000920, 0.000010, 0.036000},
	{1, {0, -1, 0, -1}, 0.000670, 0.002820, 0.949000},
	{1, {0, -1, 0, 1}, 0.000450, 0.000100, 0.039000},
	{1, {0, -1, 1, -1}, 0.001180, 0.003870, 0.082000},
	{1, {0, -1, 1, 1}, 0.000700, 0.000260, 0.026000},
	{1, {0, -1, 2, -1}, 0.001220, 0.000470, 0.039000},
	{1, {0, -1, 2, 1}, 0.000700, 0.000040, 0.019000},
	{1, {0, -1, 3, -1}, 0.001220, 0.000050, 0.026000},
	{1, {0, 0, -5, -1}, 0.001270, 0.000010, 0.015000},
	{1, {0, 0, -4, -1}, 0.001290, 0.000160, 0.019000},
	{1, {0, 0, -3, -3}, 180.001130, 0.000030, 0.015000},
	{1, {0, 0, -3, -1}, 0.001290, 0.002280, 0.025000},
	{1, {0, 0, -3, 1}, 180.000290, 0.000130, 0.077000},
	{1, {0, 0, -2, -3}, 180.001090, 0.000320, 0.019000},
	{1, {0, 0, -2, -1}, 0.001280, 0.032790, 0.038000},
	{1, {0, 0, -2, 1}, 180.000240, 0.003870, 3.574000},
	{1, {0, 0, -1, -3}, 180.001020, 0.002610, 0.025000},
	{1, {0, 0, -1, -1}, 0.001270, 0.491410, 0.075000},
	{1, {0, 0, -1, 0}, 90.000000, 0.000100, 8.847000},
	{1, {0, 0, -1, 1}, 0.000510, 0.050360, 0.074000},
	{1, {0, 0, -1, 3}, 180.000600, 0.000170, 0.025000},
	{1, {0, 0, 0, -5}, 0.000860, 0.000030, 0.019000},
	{1, {0, 0, 0, -3}, 180.000860, 0.014920, 0.037000},
	{1, {0, 0, 0, -1}, 0.000940, 7.063040, 18.613000},
	{1, {0, 0, 0, 0}, 270.000000, 0.000270, 0.075000},
	{1, {0, 0, 0, 1}, 0.000710, 0.360610, 0.037000},
	{1, {0, 0, 0, 3}, 180.000710, 0.000740, 0.019000},
	{1, {0, 0, 1, -3}, 180.000540, 0.000500, 0.073000},
	{1, {0, 0, 1, -1}, 0.001270, 0.493310, 0.076000},
	{1, {0, 0, 1, 0}, 270.000000, 0.000020, 0.038000},
	{1, {0, 0, 1, 1}, 0.000700, 0.038380, 0.025000},
	{1, {0, 0, 1, 3}, 180.000740, 0.000150, 0.015000},
	{1, {0, 0, 2, -3}, 180.000610, 0.000040, 2.582000},
	{1, {0, 0, 2, -1}, 0.001260, 0.034020, 0.038000},
	{1, {0, 0, 2, 1}, 0.000690, 0.003310, 0.019000},
	{1, {0, 0, 2, 3}, 180.000730, 0.000020, 0.012000},
	{1, {0, 0, 3, -1}, 0.001250, 0.002420, 0.025000},
	{1, {0, 0, 3, 1}, 0.000670, 0.000270, 0.015000},
	{1, {0, 0, 4, -1}, 0.001250, 0.000170, 0.019000},
	{1, {0, 0, 4, 1}, 0.000670, 0.000020, 0.013000},
	{1, {0, 0, 5, -1}, 0.001270, 0.000010, 0.015000},
	{1, {0, 1, -3, -1}, 0.001330, 0.000040, 0.026000},
	{1, {0, 1, -2, -1}, 0.001350, 0.000370, 0.039000},
	{1, {0, 1, -2, 1}, 180.000500, 0.000030, 0.781000},
	{1, {0, 1, -1, -3}, 180.000900, 0.000010, 0.026000},
	{1, {0, 1, -1, -1}, 0.001430, 0.002490, 0.081000},
	{1, {0, 1, -1, 1}, 0.002720, 0.000020, 0.069000},
	{1, {0, 1, 0, -1}, 180.000790, 0.002400, 1.057000},
	{1, {0, 1, 0, 1}, 180.000760, 0.000340, 0.036000},
	{1, {0, 1, 1, -1}, 180.001160, 0.002920, 0.070000},
	{1, {0, 1, 1, 1}, 180.000730, 0.000220, 0.024000},
	{1, {0, 1, 2, -1}, 180.001210, 0.000370, 0.036000},
	{1, {0, 1, 2, 1}, 180.000710, 0.000040, 0.018000},
	{1, {0, 1, 3, -1}, 180.001220, 0.000040, 0.025000},
	{1, {0, 2, -1, -1}, 0.001460, 0.000040, 0.088000},
	{1, {0, 2, 0, -1}, 180.000720, 0.000030, 0.514000},
	{1, {0, 2, 1, -1}, 180.001190, 0.000030, 0.066000},
	{1, {1, -1, 0, -1}, 180.000800, 0.000030, 0.088000},
	{1, {1, 0, -2, -1}, 0.001820, 0.000030, 0.070000},
	{1, {1, 0, -1, -1}, 179.999290, 0.000110, 1.063000},
	{1, {1, 0, -1, 1}, 180.000520, 0.000020, 0.039000},
	{1, {1, 0, 0, -1}, 180.000880, 0.003420, 0.081000},
	{1, {1, 0, 0, 1}, 180.000720, 0.000210, 0.026000},
	{1, {1, 0, 1, -1}, 180.001040, 0.000430, 0.039000},
	{1, {1, 0, 1, 1}, 180.000710, 0.000040, 0.019000},
	{1, {1, 0, 2, -1}, 180.001100, 0.000040, 0.026000},
	{1, {1, 1, -1, -1}, 180.000070, 0.000060, 16.874000},
	{1, {1, 1, 0, -1}, 0.000590, 0.000640, 0.075000},
	{1, {1, 1, 0, 1}, 0.000720, 0.000030, 0.025000},
	{1, {1, 1, 1, -1}, 0.000850, 0.000070, 0.038000},
	{1, {2, -3, 0, -1}, 0.000940, 0.000010, 0.046000},
	{1, {2, -2, -1, -1}, 0.000400, 0.000100, 0.106000},
	{1, {2, -2, -1, 1}, 0.000720, 0.000010, 0.028000},
	{1, {2, -2, 0, -1}, 0.000900, 0.000310, 0.044000},
	{1, {2, -2, 0, 1}, 0.000720, 0.000020, 0.020000},
	{1, {2, -2, 1, -1}, 0.001040, 0.000050, 0.028000},
	{1, {2, -1, -3, -1}, 180.001620, 0.000010, 0.062000},
	{1, {2, -1, -2, -1}, 180.002960, 0.000060, 0.354000},
	{1, {2, -1, -2, 1}, 0.000510, 0.000030, 0.042000},
	{1, {2, -1, -1, -1}, 0.000410, 0.002880, 0.096000},
	{1, {2, -1, -1, 1}, 0.000690, 0.000370, 0.027000},
	{1, {2, -1, 0, -1}, 0.000910, 0.006460, 0.042000},
	{1, {2, -1, 0, 1}, 0.000720, 0.000310, 0.020000},
	{1, {2, -1, 1, -1}, 0.001030, 0.000910, 0.027000},
	{1, {2, -1, 1, 1}, 0.000690, 0.000060, 0.016000},
	{1, {2, -1, 2, -1}, 0.001060, 0.000100, 0.020000},
	{1, {2, 0, -4, -1}, 180.001530, 0.000050, 0.035000},
	{1, {2, 0, -3, -1}, 180.001730, 0.000370, 0.066000},
	{1, {2, 0, -3, 1}, 180.000030, 0.000050, 0.085000},
	{1, {2, 0, -2, -3}, 0.001210, 0.000020, 0.035000},
	{1, {2, 0, -2, -1}, 180.003220, 0.001420, 0.547000},
	{1, {2, 0, -2, 1}, 0.000520, 0.000670, 0.040000},
	{1, {2, 0, -1, -1}, 0.000420, 0.064560, 0.088000},
	{1, {2, 0, -1, 1}, 0.000710, 0.008150, 0.026000},
	{1, {2, 0, -1, 3}, 180.000360, 0.000040, 0.015000},
	{1, {2, 0, 0, -3}, 179.998270, 0.000060, 0.463000},
	{1, {2, 0, 0, -1}, 0.000900, 0.096420, 0.041000},
	{1, {2, 0, 0, 1}, 0.000700, 0.004800, 0.019000},
	{1, {2, 0, 0, 3}, 180.000380, 0.000020, 0.013000},
	{1, {2, 0, 1, -3}, 180.001140, 0.000140, 0.090000},
	{1, {2, 0, 1, -1}, 0.001020, 0.012340, 0.026000},
	{1, {2, 0, 1, 1}, 0.000700, 0.000800, 0.015000},
	{1, {2, 0, 2, -3}, 180.001180, 0.000020, 0.041000},
	{1, {2, 0, 2, -1}, 0.001070, 0.001260, 0.020000},
	{1, {2, 0, 2, 1}, 0.000730, 0.000090, 0.013000},
	{1, {2, 0, 3, -1}, 0.001110, 0.000120, 0.016000},
	{1, {2, 0, 3, 1}, 0.000620, 0.000010, 0.011000},
	{1, {2, 1, -1, -1}, 180.000040, 0.000170, 0.080000},
	{1, {2, 1, -1, 1}, 180.000730, 0.000060, 0.025000},
	{1, {2, 1, 0, -1}, 180.000880, 0.001130, 0.039000},
	{1, {2, 1, 0, 1}, 180.000730, 0.000050, 0.019000},
	{1, {2, 1, 1, -1}, 180.000980, 0.000210, 0.026000},
	{1, {2, 1, 1, 1}, 180.000990, 0.000010, 0.015000},
	{1, {2, 1, 2, -1}, 180.001050, 0.000030, 0.019000},
	{1, {2, 2, -1, -1}, 180.000330, 0.000050, 0.074000},
	{1, {3, 0, -2, -1}, 179.999610, 0.000010, 0.095000},
	{1, {3, 0, -1, -1}, 180.000700, 0.000130, 0.042000},
	{1, {3, 0, -1, 1}, 180.000720, 0.000010, 0.020000},
	{1, {3, 1, -1, -1}, 0.000730, 0.000010, 0.040000},
	{1, {3, 1, 0, -1}, 0.000880, 0.000010, 0.026000},
	{1, {4, -2, -1, -1}, 0.000910, 0.000020, 0.029000},
	{1, {4, -2, 0, -1}, 0.000940, 0.000010, 0.021000},
	{1, {4, -1, -2, -1}, 0.000410, 0.000080, 0.046000},
	{1, {4, -1, -2, 1}, 0.000920, 0.000010, 0.021000},
	{1, {4, -1, -1, -1}, 0.000770, 0.000240, 0.028000},
	{1, {4, -1, -1, 1}, 0.000710, 0.000020, 0.016000},
	{1, {4, -1, 0, -1}, 0.000900, 0.000150, 0.021000},
	{1, {4, -1, 1, -1}, 0.000910, 0.000030, 0.016000},
	{1, {4, 0, -3, -1}, 359.998180, 0.000010, 0.104000},
	{1, {4, 0, -3, 1}, 0.000560, 0.000010, 0.027000},
	{1, {4, 0, -2, -1}, 0.000420, 0.000880, 0.044000},
	{1, {4, 0, -2, 1}, 0.000700, 0.000140, 0.020000},
	{1, {4, 0, -1, -1}, 0.000780, 0.002170, 0.028000},
	{1, {4, 0, -1, 1}, 0.000710, 0.000160, 0.016000},
	{1, {4, 0, 0, -1}, 0.000900, 0.001150, 0.020000},
	{1, {4, 0, 0, 1}, 0.000720, 0.000060, 0.013000},
	{1, {4, 0, 1, -1}, 0.000980, 0.000210, 0.016000},
	{1, {4, 0, 1, 1}, 0.000380, 0.000010, 0.011000},
	{1, {4, 0, 2, -1}, 0.000930, 0.000030, 0.013000},
	{1, {4, 1, -1, -1}, 180.000770, 0.000040, 0.027000},
	{1, {4, 1, 0, -1}, 180.000890, 0.000030, 0.020000},
	{1, {6, 0, -3, -1}, 0.000370, 0.000010, 0.029000},
	{1, {6, 0, -2, -1}, 0.000670, 0.000040, 0.021000},
	{1, {6, 0, -1, -1}, 0.000900, 0.000040, 0.016000},
	{1, {6, 0, 0, -1}, 0.000900, 0.000020, 0.013000},
	{2, {-2, -1, 0, 0}, 0.000000, 0.000010, 1.000000},
	{2, {-2, 0, -1, -2}, 180.000000, 0.000040, 0.026000},
	{2, {-2, 0, -1, 0}, 0.000000, 0.000130, 0.089000},
	{2, {-2, 0, 0, -2}, 180.000000, 0.000270, 0.040000},
	{2, {-2, 0, 0, 0}, 180.000000, 0.000430, 0.500000},
	{2, {-2, 0, 1, -2}, 180.000000, 0.000250, 0.086000},
	{2, {-2, 0, 1, 0}, 180.000000, 0.000020, 0.066000},
	{2, {-2, 0, 2, -2}, 0.000000, 0.000010, 0.600000},
	{2, {-2, 1, 0, -2}, 180.000000, 0.000020, 0.042000},
	{2, {-2, 1, 0, 0}, 180.000000, 0.000030, 0.333000},
	{2, {-2, 1, 1, -2}, 180.000000, 0.000010, 0.094000},
	{2, {0, -1, 0, -2}, 180.000000, 0.000030, 0.903000},
	{2, {0, -1, 1, -2}, 180.000000, 0.000020, 0.082000},
	{2, {0, 0, -2, -2}, 180.000000, 0.000160, 0.038000},
	{2, {0, 0, -2, 0}, 0.000000, 0.000090, 4.424000},
	{2, {0, 0, -1, -4}, 0.000000, 0.000010, 0.025000},
	{2, {0, 0, -1, -2}, 180.000000, 0.002390, 0.075000},
	{2, {0, 0, -1, -1}, 270.000000, 0.000010, 16.863000},
	{2, {0, 0, -1, 0}, 180.000000, 0.000800, 0.074000},
	{2, {0, 0, 0, -4}, 0.000000, 0.000070, 0.037000},
	{2, {0, 0, 0, -2}, 180.000000, 0.036380, 9.307000},
	{2, {0, 0, 0, -1}, 90.000000, 0.000030, 0.075000},
	{2, {0, 0, 0, 0}, 180.000000, 0.002390, 0.037000},
	{2, {0, 0, 1, -2}, 180.000000, 0.002410, 0.076000},
	{2, {0, 0, 1, 0}, 180.000000, 0.000250, 0.025000},
	{2, {0, 0, 2, -2}, 180.000000, 0.000170, 0.038000},
	{2, {0, 0, 2, 0}, 180.000000, 0.000020, 0.019000},
	{2, {0, 1, 0, -2}, 0.000000, 0.000020, 1.120000},
	{2, {0, 1, 1, -2}, 0.000000, 0.000010, 0.071000},
	{2, {1, 0, 0, -2}, 0.000000, 0.000020, 0.082000},
	{2, {1, 1, 0, -2}, 180.000000, 0.000040, 0.075000},
	{2, {2, -1, -1, -2}, 180.000000, 0.000020, 0.096000},
	{2, {2, -1, 0, -2}, 180.000000, 0.000040, 0.042000},
	{2, {2, 0, -1, -2}, 180.000000, 0.000390, 0.088000},
	{2, {2, 0, -1, 0}, 180.000000, 0.000060, 0.026000},
	{2, {2, 0, 0, -2}, 180.000000, 0.000570, 0.041000},
	{2, {2, 0, 0, 0}, 180.000000, 0.000030, 0.019000},
	{2, {2, 0, 1, -2}, 180.000000, 0.000070, 0.026000},
	{2, {4, 0, -1, -2}, 180.000000, 0.000010, 0.028000}
};

static const struct earth_pert earth_pert_elp5 [ELP5_SIZE] = 
{
	{0, {0, 0, 0, 3}, 0.000000, 0.000030, 0.025000},
	{0, {0, 0, 1, -3}, 180.000000, 0.000210, 0.037000},
	{0, {0, 0, 1, -1}, 0.000000, 0.000560, 5.997000},
	{0, {0, 0, 1, 1}, 0.000000, 0.000470, 0.037000},
	{0, {0, 0, 2, -3}, 0.000000, 0.000040, 0.073000},
	{0, {0, 0, 2, -1}, 180.000000, 0.001440, 0.076000},
	{0, {0, 0, 2, 1}, 0.000000, 0.000030, 0.025000},
	{0, {0, 0, 3, -1}, 180.000000, 0.000070, 0.038000},
	{0, {0, 1, -1, -1}, 180.000000, 0.000020, 0.039000},
	{0, {0, 1, -1, 1}, 180.000000, 0.000020, 0.857000},
	{0, {0, 1, 0, -1}, 180.000000, 0.000040, 0.081000},
	{0, {0, 1, 0, 1}, 180.000000, 0.000040, 0.069000},
	{0, {0, 1, 1, -1}, 180.000000, 0.000010, 1.200000},
	{0, {0, 1, 1, 1}, 180.000000, 0.000020, 0.036000},
	{0, {1, 0, 0, -1}, 180.000000, 0.000040, 0.949000},
	{0, {1, 0, 0, 1}, 180.000000, 0.000050, 0.039000},
	{0, {1, 1, -1, -1}, 0.000000, 0.000010, 0.075000},
	{0, {1, 1, -1, 1}, 0.000000, 0.000010, 0.074000},
	{0, {1, 1, 0, -1}, 180.000000, 0.000030, 18.600000},
	{0, {1, 1, 0, 1}, 180.000000, 0.000030, 0.037000},
	{0, {2, -1, -1, -1}, 0.000000, 0.000030, 0.340000},
	{0, {2, -1, -1, 1}, 0.000000, 0.000040, 0.042000},
	{0, {2, -1, 0, -1}, 180.000000, 0.000060, 0.097000},
	{0, {2, 0, -2, -1}, 180.000000, 0.000050, 0.066000},
	{0, {2, 0, -2, 1}, 180.000000, 0.000210, 0.086000},
	{0, {2, 0, -1, -1}, 0.000000, 0.001260, 0.515000},
	{0, {2, 0, -1, 1}, 0.000000, 0.001080, 0.040000},
	{0, {2, 0, 0, -3}, 0.000000, 0.000040, 0.064000},
	{0, {2, 0, 0, -1}, 180.000000, 0.002170, 0.088000},
	{0, {2, 0, 0, 1}, 0.000000, 0.000130, 0.026000},
	{0, {2, 0, 1, -3}, 0.000000, 0.000030, 0.440000},
	{0, {2, 0, 1, -1}, 180.000000, 0.000080, 0.041000},
	{0, {2, 0, 2, -1}, 180.000000, 0.000020, 0.026000},
	{0, {2, 1, -1, -1}, 180.000000, 0.000010, 1.063000},
	{0, {2, 1, 0, -1}, 0.000000, 0.000090, 0.081000},
	{0, {2, 2, 0, -1}, 0.000000, 0.000010, 0.075000},
	{0, {4, 0, -2, 1}, 0.000000, 0.000030, 0.027000},
	{0, {4, 0, -1, -1}, 0.000000, 0.000010, 0.044000},
	{0, {4, 0, -1, 1}, 0.000000, 0.000020, 0.020000},
	{0, {4, 0, 0, -1}, 180.000000, 0.000010, 0.028000},
	{1, {-6, 0, 0, 0}, 0.000760, 0.000020, 0.016000},
	{1, {-6, 0, 1, 0}, 0.000750, 0.000050, 0.021000},
	{1, {-6, 0, 2, 0}, 0.000750, 0.000040, 0.029000},
	{1, {-4, -1, 0, 0}, 180.000750, 0.000060, 0.027000},
	{1, {-4, -1, 1, 0}, 180.000740, 0.000080, 0.042000},
	{1, {-4, 0, -2, 0}, 0.000760, 0.000030, 0.016000},
	{1, {-4, 0, -1, -2}, 0.000950, 0.000020, 0.013000},
	{1, {-4, 0, -1, 0}, 0.000750, 0.000250, 0.020000},
	{1, {-4, 0, -1, 2}, 180.000460, 0.000010, 0.044000},
	{1, {-4, 0, 0, -2}, 0.000940, 0.000090, 0.016000},
	{1, {-4, 0, 0, 0}, 0.000730, 0.001880, 0.028000},
	{1, {-4, 0, 0, 2}, 0.000720, 0.000090, 0.108000},
	{1, {-4, 0, 1, -2}, 0.000830, 0.000170, 0.020000},
	{1, {-4, 0, 1, 0}, 0.000710, 0.003220, 0.044000},
	{1, {-4, 0, 2, -2}, 0.000550, 0.000090, 0.027000},
	{1, {-4, 0, 2, 0}, 0.000700, 0.000290, 0.104000},
	{1, {-4, 1, -1, 0}, 0.000750, 0.000030, 0.021000},
	{1, {-4, 1, 0, -2}, 0.000940, 0.000010, 0.016000},
	{1, {-4, 1, 0, 0}, 0.000750, 0.000210, 0.028000},
	{1, {-4, 1, 1, -2}, 0.000940, 0.000020, 0.021000},
	{1, {-4, 1, 1, 0}, 0.000720, 0.000290, 0.046000},
	{1, {-4, 1, 2, -2}, 0.000930, 0.000010, 0.028000},
	{1, {-4, 1, 2, 0}, 0.000720, 0.000020, 0.116000},
	{1, {-4, 2, 0, 0}, 0.000720, 0.000010, 0.029000},
	{1, {-4, 2, 1, 0}, 0.000720, 0.000020, 0.048000},
	{1, {-3, -1, 0, 0}, 0.000720, 0.000020, 0.040000},
	{1, {-3, 0, -1, 0}, 180.000720, 0.000020, 0.027000},
	{1, {-3, 0, 0, 0}, 180.000740, 0.000170, 0.042000},
	{1, {-3, 0, 0, 2}, 180.000720, 0.000010, 0.322000},
	{1, {-3, 0, 1, 0}, 180.000730, 0.000140, 0.095000},
	{1, {-3, 0, 2, 0}, 180.000720, 0.000020, 0.360000},
	{1, {-3, 1, 0, 0}, 180.000720, 0.000010, 0.044000},
	{1, {-2, -2, 0, 0}, 180.000370, 0.000130, 0.075000},
	{1, {-2, -2, 1, 0}, 180.000720, 0.000050, 8.853000},
	{1, {-2, -1, -2, 0}, 180.000750, 0.000030, 0.026000},
	{1, {-2, -1, -1, -2}, 180.000950, 0.000010, 0.019000},
	{1, {-2, -1, -1, 0}, 180.000730, 0.000410, 0.039000},
	{1, {-2, -1, 0, -2}, 180.000940, 0.000060, 0.026000},
	{1, {-2, -1, 0, 0}, 180.000710, 0.005890, 0.081000},
	{1, {-2, -1, 0, 2}, 180.000790, 0.000070, 0.069000},
	{1, {-2, -1, 1, -2}, 180.000660, 0.000050, 0.039000},
	{1, {-2, -1, 1, 0}, 180.000740, 0.000340, 1.127000},
	{1, {-2, -1, 2, 0}, 0.000720, 0.000030, 0.071000},
	{1, {-2, 0, -3, -2}, 0.000940, 0.000010, 0.013000},
	{1, {-2, 0, -3, 0}, 0.000770, 0.000070, 0.020000},
	{1, {-2, 0, -2, -2}, 0.001110, 0.000140, 0.015000},
	{1, {-2, 0, -2, 0}, 0.000770, 0.001100, 0.026000},
	{1, {-2, 0, -2, 2}, 180.000470, 0.000020, 0.091000},
	{1, {-2, 0, -1, -2}, 0.001040, 0.001040, 0.019000},
	{1, {-2, 0, -1, 0}, 0.000750, 0.016470, 0.041000},
	{1, {-2, 0, -1, 2}, 180.000590, 0.000480, 0.450000},
	{1, {-2, 0, 0, -4}, 180.000900, 0.000010, 0.015000},
	{1, {-2, 0, 0, -2}, 0.000930, 0.005620, 0.026000},
	{1, {-2, 0, 0, 0}, 0.000720, 0.298540, 0.088000},
	{1, {-2, 0, 0, 2}, 0.000770, 0.002730, 0.065000},
	{1, {-2, 0, 1, -4}, 180.000880, 0.000020, 0.019000},
	{1, {-2, 0, 1, -2}, 0.000650, 0.005620, 0.040000},
	{1, {-2, 0, 1, 0}, 0.000710, 0.073320, 0.530000},
	{1, {-2, 0, 1, 2}, 0.000720, 0.000430, 0.035000},
	{1, {-2, 0, 2, -2}, 179.999510, 0.000020, 0.085000},
	{1, {-2, 0, 2, 0}, 0.000660, 0.006720, 0.066000},
	{1, {-2, 0, 2, 2}, 0.000720, 0.000030, 0.024000},
	{1, {-2, 0, 3, 0}, 0.000630, 0.000630, 0.035000},
	{1, {-2, 0, 4, 0}, 0.000610, 0.000050, 0.024000},
	{1, {-2, 1, -2, -2}, 0.000940, 0.000010, 0.016000},
	{1, {-2, 1, -2, 0}, 0.000750, 0.000060, 0.027000},
	{1, {-2, 1, -1, -2}, 0.001040, 0.000080, 0.020000},
	{1, {-2, 1, -1, 0}, 0.000750, 0.000860, 0.042000},
	{1, {-2, 1, -1, 2}, 180.000600, 0.000030, 0.311000},
	{1, {-2, 1, 0, -2}, 0.000940, 0.000380, 0.027000},
	{1, {-2, 1, 0, 0}, 0.000720, 0.014040, 0.096000},
	{1, {-2, 1, 0, 2}, 0.000760, 0.000110, 0.061000},
	{1, {-2, 1, 1, -2}, 0.000650, 0.000250, 0.042000},
	{1, {-2, 1, 1, 0}, 0.000710, 0.003280, 0.346000},
	{1, {-2, 1, 1, 2}, 0.000730, 0.000010, 0.034000},
	{1, {-2, 1, 2, 0}, 0.000680, 0.000280, 0.062000},
	{1, {-2, 1, 3, 0}, 0.000720, 0.000020, 0.034000},
	{1, {-2, 2, -1, 0}, 0.000740, 0.000030, 0.044000},
	{1, {-2, 2, 0, -2}, 0.000930, 0.000020, 0.028000},
	{1, {-2, 2, 0, 0}, 0.000730, 0.000510, 0.107000},
	{1, {-2, 2, 1, -2}, 0.000910, 0.000010, 0.044000},
	{1, {-2, 2, 1, 0}, 0.000720, 0.000120, 0.257000},
	{1, {-2, 2, 2, 0}, 0.000720, 0.000010, 0.058000},
	{1, {-2, 3, 0, 0}, 0.000720, 0.000020, 0.119000},
	{1, {-1, -1, -1, 0}, 0.000720, 0.000020, 0.075000},
	{1, {-1, -1, 0, -2}, 0.000940, 0.000020, 0.037000},
	{1, {-1, -1, 0, 0}, 0.000720, 0.000360, 25770.018000},
	{1, {-1, 0, -2, 0}, 180.000720, 0.000020, 0.039000},
	{1, {-1, 0, -1, -2}, 180.001120, 0.000030, 0.026000},
	{1, {-1, 0, -1, 0}, 180.000720, 0.000290, 0.082000},
	{1, {-1, 0, 0, -2}, 180.000990, 0.000130, 0.039000},
	{1, {-1, 0, 0, 0}, 180.000730, 0.002120, 1.000000},
	{1, {-1, 0, 0, 2}, 180.000690, 0.000050, 0.036000},
	{1, {-1, 0, 1, 0}, 180.000740, 0.000170, 0.070000},
	{1, {-1, 0, 2, 0}, 180.000710, 0.000040, 0.036000},
	{1, {0, -2, -1, 0}, 180.000720, 0.000030, 0.530000},
	{1, {0, -2, 1, 0}, 180.000710, 0.000050, 0.041000},
	{1, {0, -1, -3, 0}, 180.000720, 0.000010, 0.036000},
	{1, {0, -1, -2, -2}, 180.001190, 0.000040, 0.024000},
	{1, {0, -1, -2, 0}, 180.000800, 0.000140, 0.071000},
	{1, {0, -1, -1, -2}, 180.001140, 0.000180, 0.036000},
	{1, {0, -1, -1, 0}, 180.000760, 0.002270, 1.127000},
	{1, {0, -1, 0, -2}, 180.001920, 0.000020, 0.069000},
	{1, {0, -1, 0, 0}, 180.000580, 0.002520, 0.081000},
	{1, {0, -1, 1, -2}, 0.002020, 0.000040, 0.819000},
	{1, {0, -1, 1, 0}, 180.000680, 0.002760, 0.039000},
	{1, {0, -1, 2, 0}, 180.000650, 0.000310, 0.026000},
	{1, {0, -1, 3, 0}, 180.000690, 0.000030, 0.019000},
	{1, {0, 0, -4, -2}, 0.001210, 0.000030, 0.015000},
	{1, {0, 0, -4, 0}, 0.000640, 0.000050, 0.025000},
	{1, {0, 0, -3, -2}, 0.001190, 0.000330, 0.019000},
	{1, {0, 0, -3, 0}, 0.000690, 0.000910, 0.038000},
	{1, {0, 0, -2, -4}, 180.000890, 0.000010, 0.015000},
	{1, {0, 0, -2, -2}, 0.001160, 0.003770, 0.025000},
	{1, {0, 0, -2, 0}, 0.000670, 0.017450, 0.076000},
	{1, {0, 0, -2, 2}, 180.000380, 0.000330, 0.073000},
	{1, {0, 0, -1, -4}, 180.000980, 0.000080, 0.019000},
	{1, {0, 0, -1, -2}, 0.001090, 0.039770, 0.037000},
	{1, {0, 0, -1, 0}, 0.000750, 0.455860, 8.847000},
	{1, {0, 0, -1, 2}, 0.000620, 0.004370, 0.037000},
	{1, {0, 0, 0, -4}, 180.000860, 0.000340, 0.025000},
	{1, {0, 0, 0, -2}, 0.000860, 0.326220, 0.074000},
	{1, {0, 0, 0, -1}, 270.000000, 0.000010, 18.613000},
	{1, {0, 0, 0, 0}, 180.000710, 8.045080, 0.075000},
	{1, {0, 0, 0, 1}, 270.000000, 0.000010, 0.037000},
	{1, {0, 0, 0, 2}, 0.000710, 0.008340, 0.025000},
	{1, {0, 0, 0, 4}, 180.000320, 0.000020, 0.015000},
	{1, {0, 0, 1, -4}, 180.000670, 0.000090, 0.037000},
	{1, {0, 0, 1, -2}, 0.004640, 0.002390, 4.536000},
	{1, {0, 0, 1, 0}, 180.000690, 0.415710, 0.038000},
	{1, {0, 0, 1, 2}, 0.000700, 0.001330, 0.019000},
	{1, {0, 0, 2, -2}, 0.001470, 0.000790, 0.077000},
	{1, {0, 0, 2, 0}, 180.000660, 0.024030, 0.025000},
	{1, {0, 0, 2, 2}, 0.000710, 0.000150, 0.015000},
	{1, {0, 0, 3, -2}, 0.001370, 0.000070, 0.038000},
	{1, {0, 0, 3, 0}, 180.000620, 0.001460, 0.019000},
	{1, {0, 0, 3, 2}, 0.000750, 0.000020, 0.013000},
	{1, {0, 0, 4, 0}, 180.000580, 0.000090, 0.015000},
	{1, {0, 1, -3, 0}, 0.000720, 0.000010, 0.039000},
	{1, {0, 1, -2, -2}, 0.001190, 0.000040, 0.026000},
	{1, {0, 1, -2, 0}, 0.000770, 0.000140, 0.082000},
	{1, {0, 1, -1, -2}, 0.001140, 0.000230, 0.039000},
	{1, {0, 1, -1, 0}, 0.000740, 0.002570, 0.898000},
	{1, {0, 1, -1, 2}, 0.000870, 0.000010, 0.036000},
	{1, {0, 1, 0, -2}, 0.000710, 0.000030, 0.080000},
	{1, {0, 1, 0, 0}, 0.000950, 0.002060, 0.070000},
	{1, {0, 1, 0, 2}, 180.000720, 0.000020, 0.024000},
	{1, {0, 1, 1, -2}, 180.002170, 0.000030, 1.283000},
	{1, {0, 1, 1, 0}, 0.000700, 0.002120, 0.036000},
	{1, {0, 1, 2, 0}, 0.000650, 0.000250, 0.024000},
	{1, {0, 1, 3, 0}, 0.000690, 0.000020, 0.018000},
	{1, {0, 2, -1, 0}, 0.000720, 0.000040, 0.473000},
	{1, {0, 2, 0, 0}, 0.000880, 0.000020, 0.065000},
	{1, {0, 2, 1, 0}, 0.000720, 0.000020, 0.035000},
	{1, {1, 0, -2, 0}, 0.000720, 0.000040, 1.292000},
	{1, {1, 0, -1, 0}, 180.001370, 0.000030, 0.080000},
	{1, {1, 0, 0, -2}, 180.001020, 0.000030, 0.903000},
	{1, {1, 0, 0, 0}, 0.000710, 0.002180, 0.039000},
	{1, {1, 0, 1, -2}, 180.001310, 0.000010, 0.082000},
	{1, {1, 0, 1, 0}, 0.000670, 0.000260, 0.026000},
	{1, {1, 0, 2, 0}, 0.000680, 0.000020, 0.019000},
	{1, {1, 1, -1, 0}, 0.000220, 0.000080, 0.074000},
	{1, {1, 1, 0, -2}, 0.000280, 0.000010, 9.303000},
	{1, {1, 1, 0, 0}, 180.000730, 0.000320, 0.037000},
	{1, {1, 1, 1, 0}, 180.000700, 0.000040, 0.025000},
	{1, {2, -2, -1, 0}, 180.000710, 0.000130, 0.044000},
	{1, {2, -2, 0, -2}, 0.001020, 0.000020, 0.108000},
	{1, {2, -2, 0, 0}, 180.000700, 0.000150, 0.028000},
	{1, {2, -2, 1, 0}, 180.000690, 0.000020, 0.020000},
	{1, {2, -1, -2, -2}, 180.001460, 0.000020, 0.062000},
	{1, {2, -1, -2, 0}, 0.000910, 0.000020, 0.094000},
	{1, {2, -1, -1, -2}, 180.002530, 0.000030, 0.334000},
	{1, {2, -1, -1, 0}, 180.000730, 0.003710, 0.042000},
	{1, {2, -1, -1, 2}, 0.000720, 0.000020, 0.020000},
	{1, {2, -1, 0, -2}, 0.001010, 0.000490, 0.097000},
	{1, {2, -1, 0, 0}, 180.000700, 0.003150, 0.027000},
	{1, {2, -1, 0, 2}, 0.000730, 0.000010, 0.016000},
	{1, {2, -1, 1, -2}, 0.001120, 0.000080, 0.043000},
	{1, {2, -1, 1, 0}, 180.000660, 0.000430, 0.020000},
	{1, {2, -1, 2, 0}, 180.000670, 0.000040, 0.016000},
	{1, {2, 0, -4, 0}, 180.000720, 0.000010, 0.067000},
	{1, {2, 0, -3, -2}, 180.001380, 0.000070, 0.035000},
	{1, {2, 0, -3, 0}, 180.000740, 0.000130, 0.602000},
	{1, {2, 0, -2, -2}, 180.001500, 0.000380, 0.066000},
	{1, {2, 0, -2, 0}, 0.001640, 0.000330, 0.086000},
	{1, {2, 0, -2, 2}, 0.000620, 0.000100, 0.026000},
	{1, {2, 0, -1, -4}, 180.000830, 0.000010, 0.035000},
	{1, {2, 0, -1, -2}, 180.002400, 0.000660, 0.501000},
	{1, {2, 0, -1, 0}, 180.000730, 0.083500, 0.040000},
	{1, {2, 0, -1, 2}, 0.000690, 0.000330, 0.019000},
	{1, {2, 0, 0, -4}, 180.000720, 0.000040, 0.064000},
	{1, {2, 0, 0, -2}, 0.001020, 0.010050, 0.089000},
	{1, {2, 0, 0, 0}, 180.000700, 0.046380, 0.026000},
	{1, {2, 0, 0, 2}, 0.000730, 0.000180, 0.015000},
	{1, {2, 0, 1, -2}, 0.001120, 0.001390, 0.041000},
	{1, {2, 0, 1, 0}, 180.000670, 0.005630, 0.019000},
	{1, {2, 0, 1, 2}, 0.000720, 0.000040, 0.013000},
	{1, {2, 0, 2, -2}, 0.001150, 0.000140, 0.026000},
	{1, {2, 0, 2, 0}, 180.000620, 0.000540, 0.015000},
	{1, {2, 0, 3, -2}, 0.000930, 0.000010, 0.020000},
	{1, {2, 0, 3, 0}, 180.000660, 0.000050, 0.013000},
	{1, {2, 1, -2, 0}, 180.000720, 0.000020, 0.079000},
	{1, {2, 1, -1, -2}, 0.001210, 0.000010, 1.006000},
	{1, {2, 1, -1, 0}, 0.000740, 0.000550, 0.039000},
	{1, {2, 1, 0, -2}, 180.001030, 0.000190, 0.082000},
	{1, {2, 1, 0, 0}, 0.000710, 0.000490, 0.026000},
	{1, {2, 1, 1, -2}, 180.001140, 0.000030, 0.039000},
	{1, {2, 1, 1, 0}, 0.000690, 0.000090, 0.019000},
	{1, {2, 1, 2, 0}, 0.000670, 0.000010, 0.015000},
	{1, {2, 2, -1, 0}, 0.000710, 0.000050, 0.037000},
	{1, {3, 0, -2, 0}, 0.000720, 0.000020, 0.042000},
	{1, {3, 0, -1, 0}, 0.000700, 0.000080, 0.027000},
	{1, {3, 0, 0, 0}, 0.000720, 0.000010, 0.020000},
	{1, {4, -2, -1, 0}, 180.000720, 0.000010, 0.021000},
	{1, {4, -1, -2, 0}, 180.000700, 0.000080, 0.028000},
	{1, {4, -1, -1, -2}, 0.000740, 0.000020, 0.046000},
	{1, {4, -1, -1, 0}, 180.000690, 0.000130, 0.021000},
	{1, {4, -1, 0, -2}, 0.000960, 0.000020, 0.029000},
	{1, {4, -1, 0, 0}, 180.000670, 0.000060, 0.016000},
	{1, {4, -1, 1, 0}, 180.000660, 0.000010, 0.013000},
	{1, {4, 0, -3, 0}, 180.000340, 0.000010, 0.043000},
	{1, {4, 0, -2, 0}, 180.000740, 0.000970, 0.028000},
	{1, {4, 0, -1, -2}, 0.000740, 0.000190, 0.044000},
	{1, {4, 0, -1, 0}, 180.000710, 0.001130, 0.020000},
	{1, {4, 0, -1, 2}, 0.000560, 0.000010, 0.013000},
	{1, {4, 0, 0, -2}, 0.000960, 0.000190, 0.028000},
	{1, {4, 0, 0, 0}, 180.000670, 0.000430, 0.016000},
	{1, {4, 0, 1, -2}, 0.001030, 0.000040, 0.020000},
	{1, {4, 0, 1, 0}, 180.000660, 0.000070, 0.013000},
	{1, {4, 1, -2, 0}, 0.000720, 0.000010, 0.027000},
	{1, {4, 1, -1, 0}, 0.000690, 0.000020, 0.020000},
	{1, {6, 0, -3, 0}, 180.000690, 0.000010, 0.021000},
	{1, {6, 0, -2, 0}, 180.000670, 0.000020, 0.016000},
	{1, {6, 0, -1, 0}, 180.000660, 0.000010, 0.013000},
	{2, {-4, 0, 0, -1}, 180.000000, 0.000020, 0.028000},
	{2, {-4, 0, 1, -1}, 180.000000, 0.000030, 0.044000},
	{2, {-2, -1, 0, -1}, 0.000000, 0.000060, 0.081000},
	{2, {-2, 0, -2, -1}, 180.000000, 0.000010, 0.026000},
	{2, {-2, 0, -1, -1}, 180.000000, 0.000160, 0.041000},
	{2, {-2, 0, 0, -3}, 180.000000, 0.000030, 0.026000},
	{2, {-2, 0, 0, -1}, 180.000000, 0.002930, 0.088000},
	{2, {-2, 0, 0, 1}, 180.000000, 0.000140, 0.065000},
	{2, {-2, 0, 1, -3}, 180.000000, 0.000030, 0.040000},
	{2, {-2, 0, 1, -1}, 180.000000, 0.000720, 0.545000},
	{2, {-2, 0, 1, 1}, 180.000000, 0.000010, 0.035000},
	{2, {-2, 0, 2, -1}, 180.000000, 0.000070, 0.066000},
	{2, {-2, 1, 0, -1}, 180.000000, 0.000140, 0.096000},
	{2, {-2, 1, 1, -1}, 180.000000, 0.000030, 0.353000},
	{2, {-1, 0, 0, -1}, 0.000000, 0.000020, 1.057000},
	{2, {0, -1, -1, -1}, 0.000000, 0.000020, 1.063000},
	{2, {0, -1, 0, -1}, 0.000000, 0.000030, 0.081000},
	{2, {0, -1, 1, -1}, 0.000000, 0.000030, 0.039000},
	{2, {0, 0, -3, -1}, 180.000000, 0.000010, 0.038000},
	{2, {0, 0, -2, -3}, 180.000000, 0.000020, 0.025000},
	{2, {0, 0, -2, -1}, 180.000000, 0.000200, 0.076000},
	{2, {0, 0, -2, 1}, 180.000000, 0.000050, 0.073000},
	{2, {0, 0, -1, -3}, 180.000000, 0.000190, 0.037000},
	{2, {0, 0, -1, -1}, 180.000000, 0.004410, 16.863000},
	{2, {0, 0, -1, 1}, 180.000000, 0.000060, 0.037000},
	{2, {0, 0, 0, -3}, 180.000000, 0.001560, 0.074000},
	{2, {0, 0, 0, -1}, 0.000000, 0.080420, 0.075000},
	{2, {0, 0, 0, 1}, 180.000000, 0.000030, 0.025000},
	{2, {0, 0, 1, -1}, 0.000000, 0.004250, 0.038000},
	{2, {0, 0, 2, -1}, 0.000000, 0.000260, 0.025000},
	{2, {0, 0, 3, -1}, 0.000000, 0.000020, 0.019000},
	{2, {0, 1, -1, -1}, 180.000000, 0.000020, 0.944000},
	{2, {0, 1, 1, -1}, 180.000000, 0.000020, 0.036000},
	{2, {1, 0, 0, -1}, 180.000000, 0.000020, 0.039000},
	{2, {1, 1, -1, -1}, 180.000000, 0.000020, 0.074000},
	{2, {2, -1, -1, -1}, 0.000000, 0.000040, 0.042000},
	{2, {2, -1, 0, -1}, 0.000000, 0.000030, 0.027000},
	{2, {2, 0, -1, -1}, 0.000000, 0.000850, 0.040000},
	{2, {2, 0, 0, -3}, 180.000000, 0.000050, 0.089000},
	{2, {2, 0, 0, -1}, 0.000000, 0.000490, 0.026000},
	{2, {2, 0, 1, -1}, 0.000000, 0.000060, 0.019000},
	{2, {4, 0, -1, -1}, 0.000000, 0.000010, 0.020000}
};

static const struct earth_pert earth_pert_elp6 [ELP6_SIZE] = 
{
	{0, {0, 0, 0, 0}, 90.000000, 0.043010, 99999.999000},
	{0, {0, 0, 0, 1}, 180.000000, 0.000030, 0.075000},
	{0, {0, 0, 0, 2}, 270.000000, 0.000040, 0.037000},
	{0, {0, 0, 1, -2}, 270.000000, 0.004440, 0.074000},
	{0, {0, 0, 1, 0}, 90.000000, 0.005310, 0.075000},
	{0, {0, 0, 2, -2}, 90.000000, 0.000260, 2.998000},
	{0, {0, 0, 2, 0}, 90.000000, 0.000420, 0.038000},
	{0, {0, 0, 2, 2}, 270.000000, 0.000040, 0.019000},
	{0, {0, 0, 3, -2}, 270.000000, 0.000020, 0.077000},
	{0, {0, 0, 3, 0}, 90.000000, 0.000030, 0.025000},
	{0, {0, 1, -2, 0}, 270.000000, 0.000040, 0.039000},
	{0, {0, 1, -1, 0}, 270.000000, 0.000370, 0.082000},
	{0, {0, 1, 0, 0}, 90.000000, 0.000090, 1.000000},
	{0, {0, 1, 1, -2}, 270.000000, 0.000050, 0.079000},
	{0, {0, 1, 1, 0}, 90.000000, 0.000170, 0.070000},
	{0, {0, 1, 2, 0}, 90.000000, 0.000020, 0.036000},
	{0, {0, 2, 0, 0}, 270.000000, 0.000020, 0.500000},
	{0, {1, -1, 0, 0}, 90.000000, 0.000120, 0.088000},
	{0, {1, 0, -1, 0}, 270.000000, 0.000050, 1.127000},
	{0, {1, 0, 0, 0}, 90.000000, 0.000880, 0.081000},
	{0, {1, 0, 1, 0}, 90.000000, 0.000060, 0.039000},
	{0, {1, 1, -1, 0}, 270.000000, 0.000040, 8.850000},
	{0, {1, 1, 0, 0}, 90.000000, 0.000640, 0.075000},
	{0, {1, 1, 1, 0}, 90.000000, 0.000040, 0.038000},
	{0, {2, -1, -1, 0}, 270.000000, 0.000530, 0.095000},
	{0, {2, -1, 1, -2}, 270.000000, 0.000030, 0.099000},
	{0, {2, 0, -3, 0}, 90.000000, 0.000030, 0.067000},
	{0, {2, 0, -2, 0}, 90.000000, 0.000820, 0.564000},
	{0, {2, 0, -2, 2}, 270.000000, 0.000030, 0.040000},
	{0, {2, 0, -1, 0}, 270.000000, 0.019610, 0.087000},
	{0, {2, 0, -1, 2}, 270.000000, 0.000030, 0.026000},
	{0, {2, 0, 0, -2}, 90.000000, 0.000210, 0.474000},
	{0, {2, 0, 0, 0}, 270.000000, 0.000470, 0.040000},
	{0, {2, 0, 1, -2}, 270.000000, 0.000710, 0.090000},
	{0, {2, 0, 2, -2}, 270.000000, 0.000050, 0.041000},
	{0, {2, 1, -1, 0}, 90.000000, 0.000080, 0.080000},
	{0, {2, 1, 0, 0}, 90.000000, 0.000030, 0.039000},
	{0, {2, 2, -1, 0}, 270.000000, 0.000090, 0.074000},
	{0, {4, -1, -1, 0}, 270.000000, 0.000020, 0.028000},
	{0, {4, 0, -2, 0}, 270.000000, 0.000170, 0.044000},
	{0, {4, 0, -1, 0}, 270.000000, 0.000170, 0.028000},
	{0, {4, 0, 0, 0}, 270.000000, 0.000020, 0.020000},
	{1, {-6, 0, 1, -1}, 90.000940, 0.000020, 0.016000},
	{1, {-6, 0, 2, -1}, 90.000700, 0.000030, 0.021000},
	{1, {-4, -1, 1, -1}, 270.000940, 0.000030, 0.027000},
	{1, {-4, 0, -1, -1}, 90.001030, 0.000120, 0.016000},
	{1, {-4, 0, -1, 1}, 270.000270, 0.000050, 0.028000},
	{1, {-4, 0, 0, -1}, 90.000960, 0.000750, 0.020000},
	{1, {-4, 0, 0, 1}, 90.000860, 0.000400, 0.044000},
	{1, {-4, 0, 1, -1}, 90.000790, 0.001490, 0.028000},
	{1, {-4, 0, 1, 1}, 90.000790, 0.000270, 0.106000},
	{1, {-4, 0, 2, -1}, 90.000280, 0.000460, 0.043000},
	{1, {-4, 0, 2, 1}, 90.000670, 0.000080, 0.261000},
	{1, {-4, 1, 0, -1}, 90.000950, 0.000100, 0.021000},
	{1, {-4, 1, 0, 1}, 90.000720, 0.000050, 0.046000},
	{1, {-4, 1, 1, -1}, 90.000790, 0.000170, 0.028000},
	{1, {-4, 1, 1, 1}, 90.000720, 0.000020, 0.119000},
	{1, {-4, 1, 2, -1}, 90.000290, 0.000040, 0.045000},
	{1, {-3, 0, 0, -1}, 90.000920, 0.000080, 0.027000},
	{1, {-3, 0, 0, 1}, 270.000720, 0.000180, 0.097000},
	{1, {-3, 0, 1, -1}, 270.000690, 0.000070, 0.042000},
	{1, {-2, -2, 1, -1}, 270.000240, 0.000020, 0.074000},
	{1, {-2, -1, -1, -1}, 270.001090, 0.000140, 0.026000},
	{1, {-2, -1, -1, 1}, 90.000590, 0.000060, 0.082000},
	{1, {-2, -1, 0, -1}, 270.000970, 0.000960, 0.039000},
	{1, {-2, -1, 0, 1}, 90.000720, 0.000120, 0.949000},
	{1, {-2, -1, 1, -1}, 270.000470, 0.000440, 0.080000},
	{1, {-2, -1, 1, 1}, 90.000650, 0.000050, 0.070000},
	{1, {-2, -1, 2, -1}, 90.000720, 0.000020, 1.388000},
	{1, {-2, 0, -3, -1}, 90.001170, 0.000070, 0.015000},
	{1, {-2, 0, -3, 1}, 270.000470, 0.000030, 0.027000},
	{1, {-2, 0, -2, -1}, 90.001130, 0.000800, 0.019000},
	{1, {-2, 0, -2, 1}, 270.000440, 0.000440, 0.041000},
	{1, {-2, 0, -1, -1}, 90.001080, 0.009250, 0.026000},
	{1, {-2, 0, -1, 1}, 270.000460, 0.006170, 0.089000},
	{1, {-2, 0, -1, 3}, 90.000740, 0.000030, 0.064000},
	{1, {-2, 0, 0, -1}, 90.000960, 0.095540, 0.040000},
	{1, {-2, 0, 0, 0}, 180.000000, 0.000050, 0.088000},
	{1, {-2, 0, 0, 1}, 270.000790, 0.008540, 0.487000},
	{1, {-2, 0, 1, -3}, 270.000880, 0.000030, 0.026000},
	{1, {-2, 0, 1, -1}, 90.000280, 0.038550, 0.087000},
	{1, {-2, 0, 1, 1}, 270.000700, 0.007850, 0.065000},
	{1, {-2, 0, 2, -3}, 270.000300, 0.000020, 0.040000},
	{1, {-2, 0, 2, -1}, 90.002160, 0.002800, 0.581000},
	{1, {-2, 0, 2, 1}, 270.000710, 0.000400, 0.035000},
	{1, {-2, 0, 3, -1}, 90.001590, 0.000470, 0.067000},
	{1, {-2, 0, 3, 1}, 270.000910, 0.000020, 0.024000},
	{1, {-2, 0, 4, -1}, 90.001490, 0.000040, 0.035000},
	{1, {-2, 1, -2, -1}, 90.001120, 0.000070, 0.020000},
	{1, {-2, 1, -2, 1}, 270.000500, 0.000020, 0.043000},
	{1, {-2, 1, -1, -1}, 90.001090, 0.000690, 0.027000},
	{1, {-2, 1, -1, 1}, 270.000480, 0.000280, 0.098000},
	{1, {-2, 1, 0, -1}, 90.000960, 0.006570, 0.042000},
	{1, {-2, 1, 0, 1}, 270.000770, 0.000560, 0.327000},
	{1, {-2, 1, 1, -1}, 90.000290, 0.001600, 0.095000},
	{1, {-2, 1, 1, 1}, 270.000710, 0.000290, 0.061000},
	{1, {-2, 1, 2, -1}, 90.002270, 0.000110, 0.368000},
	{1, {-2, 2, -1, -1}, 90.000940, 0.000030, 0.028000},
	{1, {-2, 2, 0, -1}, 90.000950, 0.000320, 0.044000},
	{1, {-2, 2, 0, 1}, 270.000720, 0.000030, 0.247000},
	{1, {-2, 2, 1, -1}, 90.000300, 0.000050, 0.105000},
	{1, {-1, -1, -1, -1}, 90.001210, 0.000030, 0.037000},
	{1, {-1, -1, 0, -1}, 90.001070, 0.000180, 0.075000},
	{1, {-1, -1, 0, 1}, 270.000520, 0.000040, 0.075000},
	{1, {-1, 0, -1, -1}, 270.001280, 0.000180, 0.039000},
	{1, {-1, 0, -1, 1}, 270.000720, 0.000050, 0.857000},
	{1, {-1, 0, 0, -1}, 270.001370, 0.000630, 0.081000},
	{1, {-1, 0, 0, 1}, 90.000680, 0.000750, 0.069000},
	{1, {-1, 0, 1, -1}, 270.001230, 0.000140, 1.200000},
	{1, {-1, 0, 1, 1}, 90.000720, 0.000040, 0.036000},
	{1, {-1, 0, 2, -1}, 270.001290, 0.000060, 0.071000},
	{1, {-1, 1, 0, -1}, 269.999920, 0.000030, 0.088000},
	{1, {0, -2, -1, -1}, 270.001370, 0.000020, 0.065000},
	{1, {0, -2, 1, -1}, 270.001150, 0.000060, 0.089000},
	{1, {0, -1, -3, -1}, 270.001270, 0.000020, 0.024000},
	{1, {0, -1, -2, -1}, 270.001340, 0.000220, 0.036000},
	{1, {0, -1, -2, 1}, 270.000730, 0.000030, 1.389000},
	{1, {0, -1, -1, -1}, 270.001400, 0.001810, 0.070000},
	{1, {0, -1, -1, 1}, 90.001620, 0.000100, 0.080000},
	{1, {0, -1, 0, -1}, 90.000670, 0.000280, 0.949000},
	{1, {0, -1, 0, 1}, 90.000870, 0.000130, 0.039000},
	{1, {0, -1, 1, -1}, 270.001180, 0.003410, 0.082000},
	{1, {0, -1, 1, 1}, 270.000000, 0.000030, 0.026000},
	{1, {0, -1, 2, -1}, 270.001210, 0.000340, 0.039000},
	{1, {0, -1, 3, -1}, 270.001270, 0.000030, 0.026000},
	{1, {0, 0, -4, -1}, 90.001280, 0.000100, 0.019000},
	{1, {0, 0, -3, -1}, 90.001280, 0.001500, 0.025000},
	{1, {0, 0, -3, 1}, 270.000000, 0.000060, 0.077000},
	{1, {0, 0, -2, -1}, 90.001280, 0.024690, 0.038000},
	{1, {0, 0, -2, 1}, 90.000620, 0.004850, 3.574000},
	{1, {0, 0, -1, -1}, 90.001280, 0.452760, 0.075000},
	{1, {0, 0, -1, 1}, 270.000610, 0.085080, 0.074000},
	{1, {0, 0, 0, -3}, 90.000670, 0.000120, 0.037000},
	{1, {0, 0, 0, -1}, 90.000010, 0.028090, 18.613000},
	{1, {0, 0, 0, 0}, 180.000000, 0.000250, 0.075000},
	{1, {0, 0, 0, 1}, 90.000500, 0.003900, 0.037000},
	{1, {0, 0, 1, -3}, 270.000370, 0.001080, 0.073000},
	{1, {0, 0, 1, -1}, 270.001260, 0.456480, 0.076000},
	{1, {0, 0, 1, 1}, 90.000240, 0.000250, 0.025000},
	{1, {0, 0, 2, -3}, 270.002800, 0.000040, 2.582000},
	{1, {0, 0, 2, -1}, 270.001260, 0.024880, 0.038000},
	{1, {0, 0, 2, 1}, 90.000000, 0.000020, 0.019000},
	{1, {0, 0, 3, -1}, 270.001260, 0.001530, 0.025000},
	{1, {0, 0, 3, 1}, 270.000000, 0.000020, 0.015000},
	{1, {0, 0, 4, -1}, 270.001260, 0.000100, 0.019000},
	{1, {0, 1, -3, -1}, 90.001270, 0.000030, 0.026000},
	{1, {0, 1, -2, -1}, 90.001340, 0.000270, 0.039000},
	{1, {0, 1, -2, 1}, 90.000720, 0.000050, 0.781000},
	{1, {0, 1, -1, -1}, 90.001430, 0.002180, 0.081000},
	{1, {0, 1, -1, 1}, 270.000840, 0.000250, 0.069000},
	{1, {0, 1, 0, -1}, 90.000800, 0.000240, 1.057000},
	{1, {0, 1, 0, 1}, 90.000640, 0.000150, 0.036000},
	{1, {0, 1, 1, -1}, 90.001160, 0.002790, 0.070000},
	{1, {0, 1, 2, -1}, 90.001210, 0.000280, 0.036000},
	{1, {0, 1, 3, -1}, 90.001270, 0.000020, 0.025000},
	{1, {0, 2, -1, -1}, 90.001470, 0.000030, 0.088000},
	{1, {0, 2, 1, -1}, 90.001200, 0.000030, 0.066000},
	{1, {1, -1, 0, -1}, 90.000800, 0.000020, 0.088000},
	{1, {1, 0, -2, -1}, 90.001800, 0.000030, 0.070000},
	{1, {1, 0, -1, -1}, 269.999530, 0.000060, 1.063000},
	{1, {1, 0, -1, 1}, 90.000720, 0.000020, 0.039000},
	{1, {1, 0, 0, -1}, 90.000880, 0.002990, 0.081000},
	{1, {1, 0, 0, 1}, 90.000510, 0.000020, 0.026000},
	{1, {1, 0, 1, -1}, 90.001040, 0.000310, 0.039000},
	{1, {1, 0, 2, -1}, 90.000900, 0.000020, 0.026000},
	{1, {1, 1, 0, -1}, 270.000580, 0.000590, 0.075000},
	{1, {1, 1, 1, -1}, 270.000850, 0.000050, 0.038000},
	{1, {2, -2, -1, -1}, 270.000410, 0.000070, 0.106000},
	{1, {2, -2, 0, -1}, 270.000930, 0.000360, 0.044000},
	{1, {2, -2, 1, -1}, 270.000940, 0.000030, 0.028000},
	{1, {2, -1, -2, -1}, 270.002810, 0.000080, 0.354000},
	{1, {2, -1, -2, 1}, 270.000590, 0.000030, 0.042000},
	{1, {2, -1, -1, -1}, 270.000420, 0.002180, 0.096000},
	{1, {2, -1, -1, 1}, 270.000390, 0.000060, 0.027000},
	{1, {2, -1, 0, -1}, 270.000920, 0.007450, 0.042000},
	{1, {2, -1, 0, 1}, 270.000000, 0.000020, 0.020000},
	{1, {2, -1, 1, -1}, 270.001050, 0.000750, 0.027000},
	{1, {2, -1, 2, -1}, 270.001120, 0.000070, 0.020000},
	{1, {2, 0, -4, -1}, 270.001480, 0.000040, 0.035000},
	{1, {2, 0, -3, -1}, 270.001680, 0.000420, 0.066000},
	{1, {2, 0, -3, 1}, 90.000240, 0.000060, 0.085000},
	{1, {2, 0, -2, -3}, 270.001220, 0.000020, 0.035000},
	{1, {2, 0, -2, -1}, 270.003000, 0.001770, 0.547000},
	{1, {2, 0, -2, 1}, 270.000640, 0.000780, 0.040000},
	{1, {2, 0, -1, -3}, 270.001200, 0.000180, 0.065000},
	{1, {2, 0, -1, -1}, 270.000430, 0.053430, 0.088000},
	{1, {2, 0, -1, 1}, 270.000620, 0.000590, 0.026000},
	{1, {2, 0, 0, -1}, 270.000920, 0.106890, 0.041000},
	{1, {2, 0, 0, 1}, 270.000950, 0.000020, 0.019000},
	{1, {2, 0, 1, -3}, 90.001070, 0.000100, 0.090000},
	{1, {2, 0, 1, -1}, 270.001050, 0.009920, 0.026000},
	{1, {2, 0, 2, -1}, 270.001110, 0.000840, 0.020000},
	{1, {2, 0, 3, -1}, 270.001150, 0.000070, 0.016000},
	{1, {2, 1, -2, -1}, 90.000720, 0.000020, 1.208000},
	{1, {2, 1, -1, -1}, 90.000080, 0.000160, 0.080000},
	{1, {2, 1, 0, -1}, 90.000920, 0.001150, 0.039000},
	{1, {2, 1, 1, -1}, 90.001040, 0.000160, 0.026000},
	{1, {2, 2, -1, -1}, 90.000330, 0.000050, 0.074000},
	{1, {3, 0, -1, -1}, 90.000700, 0.000120, 0.042000},
	{1, {3, 0, 0, -1}, 270.000960, 0.000070, 0.027000},
	{1, {4, -1, -2, -1}, 270.000420, 0.000060, 0.046000},
	{1, {4, -1, -1, -1}, 270.000780, 0.000200, 0.028000},
	{1, {4, -1, 0, -1}, 270.000930, 0.000110, 0.021000},
	{1, {4, 0, -2, -1}, 270.000420, 0.000630, 0.044000},
	{1, {4, 0, -1, -1}, 270.000780, 0.001760, 0.028000},
	{1, {4, 0, 0, -1}, 270.000930, 0.000840, 0.020000},
	{1, {4, 0, 1, -1}, 270.001050, 0.000130, 0.016000},
	{1, {4, 1, -1, -1}, 90.000940, 0.000030, 0.027000},
	{1, {6, 0, -2, -1}, 270.000700, 0.000030, 0.021000},
	{1, {6, 0, -1, -1}, 270.000940, 0.000020, 0.016000},
	{2, {-2, 0, -1, -2}, 270.000000, 0.000050, 0.026000},
	{2, {-2, 0, -1, 0}, 90.000000, 0.000090, 0.089000},
	{2, {-2, 0, 0, -2}, 270.000000, 0.000470, 0.040000},
	{2, {-2, 0, 0, 0}, 90.000000, 0.000040, 0.500000},
	{2, {-2, 0, 1, -2}, 270.000000, 0.000190, 0.086000},
	{2, {-2, 1, 0, -2}, 270.000000, 0.000040, 0.042000},
	{2, {0, -1, 0, 0}, 90.000000, 0.000020, 0.039000},
	{2, {0, 0, -2, -2}, 270.000000, 0.000120, 0.038000},
	{2, {0, 0, -2, 0}, 270.000000, 0.000050, 4.424000},
	{2, {0, 0, -1, -2}, 270.000000, 0.002190, 0.075000},
	{2, {0, 0, -1, 0}, 90.000000, 0.000770, 0.074000},
	{2, {0, 0, 0, -2}, 270.000000, 0.000280, 9.307000},
	{2, {0, 0, 0, -1}, 0.000000, 0.000030, 0.075000},
	{2, {0, 0, 0, 0}, 90.000000, 0.004480, 0.037000},
	{2, {0, 0, 1, -2}, 90.000000, 0.002230, 0.076000},
	{2, {0, 0, 1, 0}, 90.000000, 0.000500, 0.025000},
	{2, {0, 0, 2, -2}, 90.000000, 0.000120, 0.038000},
	{2, {0, 0, 2, 0}, 90.000000, 0.000060, 0.019000},
	{2, {1, 0, 0, -2}, 270.000000, 0.000020, 0.082000},
	{2, {1, 0, 0, 0}, 90.000000, 0.000030, 0.026000},
	{2, {1, 1, 0, -2}, 90.000000, 0.000040, 0.075000},
	{2, {2, -1, 0, -2}, 90.000000, 0.000040, 0.042000},
	{2, {2, 0, -1, -2}, 90.000000, 0.000320, 0.088000},
	{2, {2, 0, -1, 0}, 90.000000, 0.000090, 0.026000},
	{2, {2, 0, 0, -2}, 90.000000, 0.000560, 0.041000},
	{2, {2, 0, 0, 0}, 90.000000, 0.000050, 0.019000},
	{2, {2, 0, 1, -2}, 90.000000, 0.000050, 0.026000}
};

static const struct earth_pert earth_pert_elp7 [ELP7_SIZE] = 
{
	{1, {-2, 0, 0, -1}, 180.000000, 0.000030, 0.040000},
	{1, {-2, 0, 0, 1}, 180.000000, 0.000020, 0.487000},
	{1, {-2, 0, 1, -1}, 180.000000, 0.000020, 0.087000},
	{1, {0, 0, -2, -1}, 180.000000, 0.000010, 0.038000},
	{1, {0, 0, -1, -1}, 180.000000, 0.000210, 0.075000},
	{1, {0, 0, -1, 1}, 180.000000, 0.000020, 0.074000},
	{1, {0, 0, 0, -1}, 180.000000, 0.003000, 18.613000},
	{1, {0, 0, 0, 1}, 180.000000, 0.000150, 0.037000},
	{1, {0, 0, 1, -1}, 180.000000, 0.000210, 0.076000},
	{1, {0, 0, 1, 1}, 180.000000, 0.000020, 0.025000},
	{1, {0, 0, 2, -1}, 180.000000, 0.000020, 0.038000},
	{1, {2, 0, -1, -1}, 180.000000, 0.000030, 0.088000},
	{1, {2, 0, 0, -1}, 180.000000, 0.000040, 0.041000},
	{2, {0, 0, 0, -2}, 0.000000, 0.000040, 9.307000}
};

static const struct earth_pert earth_pert_elp8 [ELP8_SIZE] =
{
	{1, {-2, 0, 0, 0}, 180.000000, 0.000120, 0.088000},
	{1, {-2, 0, 1, 0}, 180.000000, 0.000030, 0.530000},
	{1, {0, 0, -1, -2}, 180.000000, 0.000010, 0.037000},
	{1, {0, 0, -1, 0}, 180.000000, 0.000190, 8.847000},
	{1, {0, 0, 0, -2}, 180.000000, 0.000140, 0.074000},
	{1, {0, 0, 0, 0}, 0.000000, 0.003420, 0.075000},
	{1, {0, 0, 1, 0}, 0.000000, 0.000180, 0.038000},
	{1, {0, 0, 2, 0}, 0.000000, 0.000010, 0.025000},
	{1, {2, 0, -1, 0}, 0.000000, 0.000040, 0.040000},
	{1, {2, 0, 0, 0}, 0.000000, 0.000020, 0.026000},
	{2, {0, 0, 0, -1}, 180.000000, 0.000090, 0.075000}
};

static const struct earth_pert earth_pert_elp9 [ELP9_SIZE] = 
{
	{0, {0, 0, 0, 0}, 270.000000, 0.000040, 99999.999000},
	{1, {-2, 0, 0, -1}, 270.000000, 0.000040, 0.040000},
	{1, {-2, 0, 1, -1}, 270.000000, 0.000020, 0.087000},
	{1, {0, 0, -1, -1}, 270.000000, 0.000190, 0.075000},
	{1, {0, 0, -1, 1}, 90.000000, 0.000030, 0.074000},
	{1, {0, 0, 1, -1}, 90.000000, 0.000190, 0.076000},
	{1, {2, 0, -1, -1}, 90.000000, 0.000020, 0.088000},
	{1, {2, 0, 0, -1}, 90.000000, 0.000040, 0.041000}
};

static const struct planet_pert plan_pert_elp10 [ELP10_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2}, 359.998310, 0.000200, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2}, 359.982540, 0.000070, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 359.936740, 0.009620, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2}, 180.035080, 0.000020, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 359.958640, 0.000480, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0}, 359.943750, 0.000050, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 180.001750, 0.000040, 0.071000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 180.018100, 0.000710, 1.127000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 97.018100, 0.000110, 0.949000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 180.015290, 0.004140, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 248.645910, 0.000020, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, -1}, 259.468000, 0.000010, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 180.017440, 0.000290, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -4, 0}, 180.945220, 0.000010, 0.035000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 185.233510, 0.000030, 0.067000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, -2}, 0.042080, 0.000010, 0.035000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 0.078450, 0.002120, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 0.122040, 0.037260, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 2}, 180.102460, 0.000080, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -2}, 0.236690, 0.000240, 0.474000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 0.099940, 0.015850, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2}, 180.111930, 0.000050, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, -2}, 180.015930, 0.000070, 0.090000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 0.116880, 0.001350, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 359.933350, 0.000090, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -1, 0}, 180.124560, 0.000060, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, 0, -1}, 214.900870, 0.000010, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -3, 0}, 0.564020, 0.000060, 0.103000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -2, 0}, 0.122670, 0.000490, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -1, 0}, 0.114760, 0.000570, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, 0, -2}, 0.020340, 0.000020, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 0.170480, 0.000200, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, 1, 0}, 0.110190, 0.000050, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 6, -1, 0}, 0.123720, 0.000010, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0}, 319.837980, 0.000020, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 1, 0}, 49.171040, 0.000050, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -2, 0}, 261.188640, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0}, 261.051780, 0.000310, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 260.136670, 0.000740, 164.772000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0}, 261.051780, 0.000310, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0}, 261.188640, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, -1, 0}, 47.398080, 0.000040, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 314.650280, 0.000020, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, 0}, 153.556420, 0.000030, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0}, 333.584190, 0.000150, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 333.767450, 0.000350, 82.386000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0}, 333.584190, 0.000150, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 0}, 153.556420, 0.000030, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, -2, -2, 0, 0}, 146.218010, 0.000070, 0.040000},
	{{0, 0, 0, 0, 0, 0, 1, -2, -2, 1, 0}, 255.188350, 0.000180, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, -2, -2, 2, 0}, 282.494070, 0.000020, 0.564000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, -2, 0}, 101.059520, 0.000080, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, -1, 0}, 101.147090, 0.001250, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 0}, 95.097310, 0.002970, 4234.399000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 1, 0}, 101.147090, 0.001250, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 2, 0}, 94.537330, 0.000080, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 2, -2, 0}, 282.494060, 0.000020, 0.564000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 2, -1, 0}, 255.290880, 0.000180, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 2, 0, 0}, 146.451320, 0.000070, 0.040000},
	{{0, 0, 0, 0, 0, 0, 1, 0, -2, -1, 0}, 184.372050, 0.000030, 0.026000},
	{{0, 0, 0, 0, 0, 0, 1, 0, -2, 0, 0}, 187.931480, 0.000170, 0.040000},
	{{0, 0, 0, 0, 0, 0, 1, 0, -2, 1, 0}, 173.348890, 0.000300, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, -2, 0}, 237.229130, 0.000030, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0}, 240.145080, 0.000470, 0.076000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0}, 242.328730, 0.001100, 84.021000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0}, 240.301670, 0.000470, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0}, 237.200810, 0.000030, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 2, -1, 0}, 175.303970, 0.000300, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0}, 189.591040, 0.000170, 0.040000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 2, 1, 0}, 186.066110, 0.000030, 0.026000},
	{{0, 0, 0, 0, 0, 0, 2, -4, 0, 0, 0}, 348.773020, 0.000010, 2117.199000},
	{{0, 0, 0, 0, 0, 0, 2, -2, 0, 0, 0}, 359.694280, 0.000050, 85.722000},
	{{0, 0, 0, 0, 0, 0, 2, 0, -2, 1, 0}, 161.931690, 0.000020, 0.087000},
	{{0, 0, 0, 0, 0, 0, 2, 0, 0, -1, 0}, 341.875690, 0.000130, 0.076000},
	{{0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0}, 341.495090, 0.000300, 42.010000},
	{{0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0}, 341.875690, 0.000130, 0.075000},
	{{0, 0, 0, 0, 0, 0, 2, 0, 2, -1, 0}, 161.931690, 0.000020, 0.087000},
	{{0, 0, 0, 0, 0, 0, 3, 0, 0, -1, 0}, 152.666110, 0.000010, 0.076000},
	{{0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0}, 169.572460, 0.000020, 28.007000},
	{{0, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0}, 152.666110, 0.000010, 0.075000},
	{{0, 0, 0, 0, 0, 1, -3, 0, -2, 0, 0}, 290.104910, 0.000010, 0.040000},
	{{0, 0, 0, 0, 0, 1, -3, 0, -2, 1, 0}, 125.752920, 0.000010, 0.087000},
	{{0, 0, 0, 0, 0, 1, -3, 0, 0, -1, 0}, 306.446770, 0.000080, 0.075000},
	{{0, 0, 0, 0, 0, 1, -3, 0, 0, 0, 0}, 312.562400, 0.000150, 568.851000},
	{{0, 0, 0, 0, 0, 1, -3, 0, 0, 1, 0}, 306.446770, 0.000080, 0.075000},
	{{0, 0, 0, 0, 0, 1, -3, 0, 2, -1, 0}, 125.752920, 0.000010, 0.087000},
	{{0, 0, 0, 0, 0, 1, -3, 0, 2, 0, 0}, 289.809720, 0.000010, 0.040000},
	{{0, 0, 0, 0, 0, 1, -2, 0, 0, 0, 0}, 271.996750, 0.000010, 98.581000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -4, 0, 0}, 267.905870, 0.000050, 0.020000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -4, 1, 0}, 268.663580, 0.000110, 0.028000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -4, 2, 0}, 269.919760, 0.000060, 0.044000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -3, 0, 0}, 268.039390, 0.000010, 0.027000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, -2, 0}, 266.758800, 0.000060, 0.020000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, -1, 0}, 266.271430, 0.000390, 0.026000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, -1, 2}, 87.848400, 0.000010, 0.090000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, -2}, 267.942600, 0.000010, 0.019000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 0}, 267.682270, 0.003900, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 2}, 267.860530, 0.000080, 0.467000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 1, 0}, 269.197970, 0.005840, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 1, 2}, 87.848400, 0.000010, 0.065000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 2, 0}, 272.363420, 0.000200, 0.553000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0}, 87.452040, 0.000120, 0.081000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -1, 1, 0}, 87.848400, 0.000020, 1.086000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -3, 0}, 260.456770, 0.000030, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -2, 0}, 260.879680, 0.000580, 0.038000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, -2}, 81.509860, 0.000020, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0}, 260.787140, 0.008540, 0.076000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 2}, 261.509860, 0.000010, 0.073000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0}, 260.214090, 0.019010, 29.457000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, -2}, 261.509860, 0.000010, 0.074000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0}, 260.756370, 0.008500, 0.075000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 2}, 81.509860, 0.000020, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0}, 260.827400, 0.000580, 0.038000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 3, 0}, 260.374480, 0.000030, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 1, -1, 0}, 87.249610, 0.000020, 1.172000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 1, 0, -1}, 66.178080, 0.000020, 0.981000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0}, 87.691390, 0.000100, 0.081000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -2, 0}, 272.859860, 0.000190, 0.575000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -1, -2}, 87.249690, 0.000010, 0.065000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -1, 0}, 268.861710, 0.005830, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, -2}, 267.238460, 0.000080, 0.482000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 0}, 267.106880, 0.003920, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 2}, 267.159100, 0.000010, 0.019000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 1, -2}, 87.249690, 0.000010, 0.089000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 1, 0}, 266.098690, 0.000380, 0.026000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 2, 0}, 266.301730, 0.000050, 0.019000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 3, -2, 0}, 267.090520, 0.000010, 0.094000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 3, 0, 0}, 267.084410, 0.000010, 0.027000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 4, -2, 0}, 269.498020, 0.000060, 0.043000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 4, -1, 0}, 268.419740, 0.000110, 0.028000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 4, 0, 0}, 266.954440, 0.000050, 0.020000},
	{{0, 0, 0, 0, 0, 2, -3, 0, 0, 0, 0}, 211.809410, 0.000030, 31.066000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, -1, 0}, 166.003970, 0.000040, 0.026000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, 0, 0}, 168.358590, 0.000220, 0.041000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, 1, 0}, 162.809390, 0.000490, 0.088000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, 2, 0}, 164.041600, 0.000010, 0.543000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -1, 0, 1}, 324.971620, 0.000010, 0.892000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, -2, 0}, 325.004450, 0.000030, 0.038000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, -1, 0}, 326.155300, 0.000500, 0.076000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0}, 326.833400, 0.001110, 14.729000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 1, 0}, 326.421670, 0.000510, 0.075000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 2, 0}, 324.958520, 0.000030, 0.038000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 2, -2, 0}, 165.606270, 0.000010, 0.586000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 2, -1, 0}, 163.996850, 0.000430, 0.087000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 2, 0, 0}, 177.843610, 0.000140, 0.040000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 2, 1, 0}, 169.745600, 0.000030, 0.026000},
	{{0, 0, 0, 0, 0, 3, 0, 0, -2, 0, 0}, 48.747290, 0.000030, 0.041000},
	{{0, 0, 0, 0, 0, 3, 0, 0, -2, 1, 0}, 64.882000, 0.000030, 0.088000},
	{{0, 0, 0, 0, 0, 3, 0, 0, 0, -1, 0}, 259.336320, 0.000030, 0.076000},
	{{0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0}, 272.757250, 0.000100, 9.819000},
	{{0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0}, 259.336320, 0.000030, 0.075000},
	{{0, 0, 0, 0, 0, 3, 0, 0, 2, 0, 0}, 48.780470, 0.000010, 0.040000},
	{{0, 0, 0, 0, 0, 5, 0, 0, 0, -1, 0}, 309.553480, 0.000020, 0.076000},
	{{0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0}, 307.749060, 0.000040, 5.891000},
	{{0, 0, 0, 0, 0, 5, 0, 0, 0, 1, 0}, 309.553480, 0.000020, 0.074000},
	{{0, 0, 0, 0, 1, -5, 0, 0, -2, 0, 0}, 200.353690, 0.000080, 0.040000},
	{{0, 0, 0, 0, 1, -5, 0, 0, -2, 1, 0}, 193.557430, 0.000160, 0.086000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 0, -1, 0}, 258.010730, 0.000120, 0.075000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 0, 0, 0}, 269.352850, 0.000220, 11.705000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 0, 1, 0}, 252.228920, 0.000120, 0.076000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 2, -1, 0}, 187.232290, 0.000170, 0.088000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 2, 0, 0}, 193.554500, 0.000090, 0.041000},
	{{0, 0, 0, 0, 1, -4, 0, 0, 0, 0, 0}, 190.619950, 0.000020, 19.422000},
	{{0, 0, 0, 0, 1, -3, 0, 0, -2, 0, 0}, 134.888460, 0.000050, 0.040000},
	{{0, 0, 0, 0, 1, -3, 0, 0, -2, 1, 0}, 123.440260, 0.000090, 0.087000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 0, -1, 0}, 235.512580, 0.000100, 0.075000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 0, 0, 0}, 274.554630, 0.000400, 57.013000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 0, 1, 0}, 235.512580, 0.000100, 0.076000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 2, -1, 0}, 120.517450, 0.000090, 0.087000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 2, 0, 0}, 131.884200, 0.000050, 0.040000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, -1, 0}, 355.569270, 0.000040, 0.026000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, 0, 0}, 352.347870, 0.000250, 0.040000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, 1, 0}, 6.183260, 0.000460, 0.087000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, 2, 0}, 34.778020, 0.000010, 0.559000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, -2, 0}, 298.258580, 0.000040, 0.038000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, -1, 0}, 292.795120, 0.000620, 0.076000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 0, 0}, 273.876300, 0.001290, 60.947000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 1, 0}, 292.623920, 0.000630, 0.075000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 2, 0}, 297.734140, 0.000040, 0.038000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, -2, 0}, 31.067820, 0.000010, 0.569000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, -1, 0}, 3.957950, 0.000460, 0.087000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, 0, 0}, 350.335850, 0.000250, 0.040000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, 1, 0}, 353.653950, 0.000040, 0.026000},
	{{0, 0, 0, 0, 1, -1, 0, 0, -2, -1, 0}, 177.145810, 0.000030, 0.026000},
	{{0, 0, 0, 0, 1, -1, 0, 0, -2, 0, 0}, 177.145810, 0.000170, 0.041000},
	{{0, 0, 0, 0, 1, -1, 0, 0, -2, 1, 0}, 177.263910, 0.000320, 0.087000},
	{{0, 0, 0, 0, 1, -1, 0, 0, -2, 2, 0}, 177.145810, 0.000010, 0.548000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 0, -2, 0}, 175.974130, 0.000010, 0.038000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 0, -1, 0}, 176.593500, 0.000120, 0.076000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0}, 348.754120, 0.000220, 19.859000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 0, 1, 0}, 176.411290, 0.000120, 0.075000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 0, 2, 0}, 175.991310, 0.000010, 0.038000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 2, -2, 0}, 176.873320, 0.000010, 0.580000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 2, -1, 0}, 176.955200, 0.000320, 0.087000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 2, 0, 0}, 176.873330, 0.000160, 0.040000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 2, 1, 0}, 176.873330, 0.000030, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -6, 0, 0}, 177.977310, 0.000010, 0.013000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -6, 1, 0}, 354.883200, 0.000020, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -6, 2, 0}, 354.681770, 0.000020, 0.021000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, -2, 0}, 176.559380, 0.000010, 0.013000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, -1, 0}, 348.734380, 0.000060, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 0, 0}, 0.269030, 0.000400, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 1, 0}, 0.196990, 0.001020, 0.028000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 1, 2}, 355.976110, 0.000020, 0.108000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 2, 0}, 1.476260, 0.000780, 0.044000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 3, 0}, 351.560750, 0.000030, 0.104000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -3, 0, 0}, 279.656300, 0.000050, 0.027000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -3, 1, 0}, 204.051580, 0.000050, 0.042000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -3, 2, 0}, 71.271240, 0.000030, 0.095000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -3, 0}, 355.569110, 0.000020, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -2, 0}, 344.565210, 0.000210, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, -2}, 175.119880, 0.000020, 0.015000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, 0}, 350.458160, 0.002860, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, 2}, 169.142220, 0.000080, 0.090000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, -2}, 174.543800, 0.000050, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 0}, 355.134540, 0.033090, 0.041000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 2}, 354.999650, 0.000720, 0.456000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, -2}, 180.410950, 0.000130, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, 0}, 359.809460, 0.057560, 0.088000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, 2}, 353.421670, 0.000030, 0.065000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 2, 0}, 5.195360, 0.002530, 0.538000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 3, 0}, 21.271650, 0.000120, 0.066000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, -1, 0}, 196.411790, 0.000100, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, -1, 1}, 78.503080, 0.000070, 0.083000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, -1}, 258.878050, 0.000080, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0}, 188.328080, 0.001000, 0.081000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 1}, 78.904330, 0.000340, 0.879000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 1, -1}, 258.535950, 0.000080, 0.080000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 1, 0}, 192.246550, 0.000160, 1.030000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 1, 1}, 78.483390, 0.000050, 0.069000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 2, 0}, 155.945960, 0.000020, 0.070000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -4, 0}, 289.448770, 0.000010, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -3, 0}, 292.783160, 0.000190, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -2, -2}, 122.504590, 0.000010, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -2, 0}, 295.891190, 0.002730, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, -2}, 113.490870, 0.000080, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 0}, 294.984140, 0.040460, 0.076000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 2}, 292.251620, 0.000060, 0.073000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -2}, 257.494800, 0.000030, 0.037000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1}, 256.855030, 0.000020, 0.075000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0}, 286.696280, 0.086340, 11.862000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 2}, 211.840370, 0.000030, 0.037000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, -2}, 293.460320, 0.000100, 0.074000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0}, 293.671100, 0.040400, 0.075000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 2}, 112.536790, 0.000080, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 2, 0}, 293.089410, 0.002790, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 2, 2}, 122.475740, 0.000010, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 3, 0}, 291.651120, 0.000190, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 4, 0}, 288.786280, 0.000010, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -2, 0}, 207.989790, 0.000010, 0.071000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, -1}, 66.058850, 0.000060, 0.070000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, 0}, 186.723340, 0.000130, 1.246000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, 1}, 258.552830, 0.000100, 0.079000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, -1}, 77.028950, 0.000410, 1.032000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0}, 177.953290, 0.000740, 0.080000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1}, 258.554740, 0.000090, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 1, -1}, 105.428940, 0.000060, 0.081000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0}, 174.338690, 0.000070, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 2, -1}, 77.200360, 0.000010, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -3, 0}, 26.873540, 0.000120, 0.067000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -2, 0}, 7.909490, 0.002370, 0.592000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, -2}, 352.299720, 0.000030, 0.065000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, 0}, 356.137180, 0.052740, 0.086000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, 2}, 177.368290, 0.000120, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, -2}, 345.349300, 0.000690, 0.494000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 346.268720, 0.028480, 0.040000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 2}, 173.972480, 0.000040, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, -2}, 163.490620, 0.000070, 0.089000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 0}, 337.949660, 0.002550, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 2}, 172.039270, 0.000010, 0.015000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 2, 0}, 331.014620, 0.000200, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 3, 0}, 356.169220, 0.000020, 0.015000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, -1, -1}, 358.709830, 0.000010, 0.095000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, -1, 0}, 155.030440, 0.000040, 0.042000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, 0, -1}, 178.411280, 0.000020, 0.042000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, 0, 0}, 22.351320, 0.000020, 0.027000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -3, 0}, 350.397180, 0.000030, 0.102000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -2, 0}, 355.551170, 0.000700, 0.043000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -1, -2}, 348.736530, 0.000020, 0.106000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -1, 0}, 347.838210, 0.000890, 0.028000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 0, -2}, 347.030930, 0.000010, 0.044000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 0, 0}, 342.847000, 0.000340, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 1, 0}, 356.225900, 0.000060, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 2, 0}, 166.652130, 0.000010, 0.013000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 6, -2, 0}, 351.098400, 0.000020, 0.021000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 6, -1, 0}, 343.772500, 0.000010, 0.016000},
	{{0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0}, 272.589050, 0.000020, 8.457000},
	{{0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0}, 94.564490, 0.000040, 6.570000},
	{{0, 0, 0, 0, 1, 3, 0, 0, 0, 0, 0}, 37.108410, 0.000020, 5.372000},
	{{0, 0, 0, 0, 2, -7, 0, 0, 0, -1, 0}, 1.583250, 0.000010, 0.075000},
	{{0, 0, 0, 0, 2, -7, 0, 0, 0, 0, 0}, 355.255110, 0.000080, 14.487000},
	{{0, 0, 0, 0, 2, -7, 0, 0, 0, 1, 0}, 1.583250, 0.000010, 0.076000},
	{{0, 0, 0, 0, 2, -6, 0, 0, -2, 0, 0}, 101.182940, 0.000030, 0.040000},
	{{0, 0, 0, 0, 2, -6, 0, 0, -2, 1, 0}, 101.182920, 0.000040, 0.087000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 0, -1, 0}, 108.513560, 0.000040, 0.075000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 0, 0, 0}, 110.073080, 0.000040, 28.507000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 0, 1, 0}, 108.513560, 0.000040, 0.076000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 2, -1, 0}, 100.402350, 0.000040, 0.087000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 2, 0, 0}, 100.402350, 0.000030, 0.040000},
	{{0, 0, 0, 0, 2, -6, 3, 0, -2, 0, 0}, 15.092230, 0.000030, 0.040000},
	{{0, 0, 0, 0, 2, -6, 3, 0, -2, 1, 0}, 171.284420, 0.000080, 0.087000},
	{{0, 0, 0, 0, 2, -6, 3, 0, -2, 2, 0}, 180.217900, 0.000010, 0.564000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, -2, 0}, 0.043910, 0.000040, 0.038000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, -1, 0}, 359.847760, 0.000640, 0.075000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, 0, 0}, 358.470670, 0.001460, 1597.835000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, 1, 0}, 359.847760, 0.000640, 0.075000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, 2, 0}, 0.043910, 0.000040, 0.038000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 2, -2, 0}, 180.217940, 0.000010, 0.564000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 2, -1, 0}, 171.193450, 0.000080, 0.087000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 2, 0, 0}, 14.875320, 0.000040, 0.040000},
	{{0, 0, 0, 0, 2, -6, 4, -2, 0, 0, 0}, 0.410990, 0.000010, 2566.169000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 0, 0}, 256.074550, 0.000020, 0.020000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 1, 0}, 190.135540, 0.000120, 0.028000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 2, 0}, 177.025680, 0.000180, 0.044000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -2, 0}, 331.248390, 0.000080, 0.020000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -1, 0}, 334.646370, 0.000600, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -1, 2}, 165.960950, 0.000020, 0.090000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 0, 0}, 259.598900, 0.001550, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 0, 2}, 280.679190, 0.000030, 0.475000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, -2}, 344.542000, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, 0}, 178.712680, 0.014000, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 2, 0}, 173.174560, 0.001310, 0.564000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 3, 0}, 170.011260, 0.000110, 0.067000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 4, 0}, 166.784710, 0.000010, 0.035000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -1, -1, 0}, 165.960950, 0.000020, 0.039000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -1, 0, 0}, 62.251280, 0.000050, 0.081000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -1, 1, 0}, 353.433850, 0.000060, 1.129000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -4, 0}, 345.960950, 0.000020, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -3, 0}, 346.651570, 0.000330, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, -2}, 165.960950, 0.000020, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, 0}, 346.459960, 0.004630, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, -2}, 166.306890, 0.000130, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 0}, 346.487040, 0.068260, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 2}, 346.068760, 0.000120, 0.074000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, -2}, 342.387920, 0.000040, 0.037000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, 0}, 347.766530, 0.163760, 883.328000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, 2}, 342.387920, 0.000040, 0.037000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, -2}, 346.068760, 0.000120, 0.074000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, 0}, 346.489720, 0.068260, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, 2}, 166.306890, 0.000130, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, 0}, 346.461920, 0.004630, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, 2}, 165.960950, 0.000020, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 3, 0}, 346.652670, 0.000330, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 4, 0}, 345.960950, 0.000020, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 1, -1, 0}, 353.370220, 0.000060, 1.126000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 1, 0, 0}, 72.263970, 0.000050, 0.081000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 1, 1, 0}, 165.960950, 0.000020, 0.039000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -4, 0}, 166.814010, 0.000010, 0.035000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -3, 0}, 169.975810, 0.000120, 0.067000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -2, 0}, 173.135360, 0.001320, 0.563000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, 0}, 178.608540, 0.014080, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, 2}, 344.542000, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 0, -2}, 278.189360, 0.000030, 0.474000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 0, 0}, 255.533600, 0.001550, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 1, -2}, 165.960950, 0.000020, 0.090000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 1, 0}, 334.579650, 0.000590, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 2, 0}, 330.626670, 0.000080, 0.020000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, -2, 0}, 177.219430, 0.000180, 0.044000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, -1, 0}, 189.857570, 0.000130, 0.028000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, 0, 0}, 253.415930, 0.000020, 0.020000},
	{{0, 0, 0, 0, 2, -4, 0, 0, -2, -1, 0}, 250.785510, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, -4, 0, 0, -2, 0, 0}, 250.785500, 0.000110, 0.040000},
	{{0, 0, 0, 0, 2, -4, 0, 0, -2, 1, 0}, 250.141600, 0.000200, 0.087000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, -1, 0}, 262.699570, 0.000050, 0.076000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, 0, 0}, 315.358140, 0.000060, 30.473000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, 1, 0}, 263.039640, 0.000050, 0.075000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 2, -1, 0}, 250.405810, 0.000200, 0.087000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 2, 0, 0}, 251.032150, 0.000100, 0.040000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 2, 1, 0}, 251.032150, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, -3, 0, 0, -2, -1, 0}, 300.404270, 0.000020, 0.026000},
	{{0, 0, 0, 0, 2, -3, 0, 0, -2, 0, 0}, 300.404270, 0.000130, 0.041000},
	{{0, 0, 0, 0, 2, -3, 0, 0, -2, 1, 0}, 300.345160, 0.000220, 0.088000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, -2, 0}, 300.719450, 0.000010, 0.038000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, -1, 0}, 300.845190, 0.000210, 0.076000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, 0, 0}, 301.994650, 0.000280, 14.978000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, 1, 0}, 300.842490, 0.000210, 0.075000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, 2, 0}, 300.719370, 0.000010, 0.038000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 2, -1, 0}, 300.295740, 0.000200, 0.087000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 2, 0, 0}, 300.370050, 0.000120, 0.040000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 2, 1, 0}, 300.369910, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -4, 1, 0}, 359.181660, 0.000010, 0.028000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, -1, 0}, 359.176990, 0.000050, 0.026000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, 0, 0}, 359.175180, 0.000290, 0.041000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, 1, 0}, 359.391490, 0.000540, 0.088000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, 2, 0}, 359.181660, 0.000020, 0.533000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, -2, 0}, 356.787320, 0.000020, 0.038000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, -1, 0}, 356.716540, 0.000220, 0.076000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, 0, 0}, 356.943340, 0.000340, 9.929000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, 1, 0}, 356.113360, 0.000200, 0.075000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, 2, 0}, 356.835120, 0.000020, 0.038000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, -2, 0}, 358.653890, 0.000020, 0.598000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, -1, 0}, 358.805790, 0.000490, 0.086000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, 0, 0}, 358.646900, 0.000260, 0.040000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, 1, 0}, 358.653850, 0.000040, 0.026000},
	{{0, 0, 0, 0, 2, -1, 0, 0, -2, 0, 0}, 165.338700, 0.000020, 0.041000},
	{{0, 0, 0, 0, 2, -1, 0, 0, 0, 0, 0}, 355.118260, 0.000070, 7.426000},
	{{0, 0, 0, 0, 2, -1, 0, 0, 2, 0, 0}, 160.289130, 0.000020, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -4, 1, 0}, 134.386320, 0.000040, 0.028000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -4, 2, 0}, 119.989220, 0.000020, 0.044000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, -1, 0}, 11.330480, 0.000080, 0.026000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 0, 0}, 18.034210, 0.000650, 0.041000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 0, 2}, 22.015610, 0.000020, 0.439000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 1, -1}, 132.889910, 0.000030, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 1, 0}, 34.782870, 0.000990, 0.088000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 2, -1}, 131.862280, 0.000020, 0.087000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 2, 0}, 57.793560, 0.000050, 0.515000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -1, 0, 0}, 140.963500, 0.000080, 0.082000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -1, 0, 1}, 46.107530, 0.000050, 0.818000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -1, 1, -1}, 336.538960, 0.000030, 0.081000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -3, 0}, 319.081350, 0.000020, 0.025000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -2, 0}, 317.518690, 0.000280, 0.038000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -1, -1}, 133.314700, 0.000020, 0.038000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -1, 0}, 318.598290, 0.004260, 0.076000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -1}, 133.171160, 0.000350, 0.075000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0}, 316.177030, 0.008170, 5.931000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, -1}, 132.889910, 0.002280, 540.002000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0}, 317.842380, 0.004250, 0.074000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 2, -1}, 133.672900, 0.000140, 0.075000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 2, 0}, 316.092720, 0.000300, 0.037000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 3, -1}, 133.314700, 0.000020, 0.038000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 3, 0}, 320.208990, 0.000020, 0.025000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 1, 0, -1}, 109.054240, 0.000090, 1.130000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0}, 154.023870, 0.000030, 0.080000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -3, 0}, 247.153100, 0.000010, 0.067000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -2, 0}, 80.734620, 0.000050, 0.623000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -1, 0}, 353.565290, 0.001240, 0.086000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 0, -2}, 334.628290, 0.000040, 0.516000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 0, -1}, 313.846070, 0.000020, 0.087000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0}, 333.893300, 0.001270, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 1, -1}, 132.889910, 0.000030, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 1, 0}, 330.392360, 0.000140, 0.026000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 4, -2, 0}, 8.914550, 0.000010, 0.043000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 4, -1, 0}, 321.136910, 0.000020, 0.027000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 0}, 350.593900, 0.000010, 0.020000},
	{{0, 0, 0, 0, 2, 5, 0, 0, 2, -3, 0}, 119.788600, 0.000020, 0.068000},
	{{0, 0, 0, 0, 2, 5, 0, 0, 2, -2, 0}, 119.788600, 0.000020, 0.697000},
	{{0, 0, 0, 0, 2, 5, 0, 0, 2, -1, 0}, 119.788600, 0.000020, 0.085000},
	{{0, 0, 0, 0, 2, 5, 0, 0, 2, 0, 0}, 119.788600, 0.000020, 0.040000},
	{{0, 0, 0, 0, 3, -7, 0, 0, 0, 0, 0}, 56.265880, 0.000050, 65.464000},
	{{0, 0, 0, 0, 3, -6, 0, 0, 0, 0, 0}, 24.631630, 0.000020, 20.316000},
	{{0, 0, 0, 0, 3, -5, 0, 0, -2, -1, 0}, 84.563250, 0.000040, 0.026000},
	{{0, 0, 0, 0, 3, -5, 0, 0, -2, 0, 0}, 83.710820, 0.000210, 0.041000},
	{{0, 0, 0, 0, 3, -5, 0, 0, -2, 1, 0}, 84.492310, 0.000380, 0.088000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, -2, 0}, 88.644950, 0.000020, 0.038000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, -1, 0}, 88.126670, 0.000280, 0.076000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, 0, 0}, 86.229030, 0.000510, 12.023000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, 1, 0}, 88.110110, 0.000280, 0.075000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, 2, 0}, 87.566730, 0.000020, 0.038000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, -2, 0}, 84.802060, 0.000020, 0.591000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, -1, 0}, 84.314610, 0.000380, 0.086000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, 0, 0}, 84.801570, 0.000210, 0.040000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, 1, 0}, 84.802100, 0.000030, 0.026000},
	{{0, 0, 0, 0, 3, -4, 0, 0, -2, 0, 0}, 120.936000, 0.000030, 0.041000},
	{{0, 0, 0, 0, 3, -4, 0, 0, -2, 1, 0}, 120.934480, 0.000050, 0.088000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 0, -1, 0}, 122.742310, 0.000020, 0.076000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 0, 0, 0}, 161.954320, 0.000020, 8.538000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 0, 1, 0}, 122.742310, 0.000020, 0.075000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 2, -1, 0}, 120.503650, 0.000040, 0.086000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 2, 0, 0}, 120.503650, 0.000030, 0.040000},
	{{0, 0, 0, 0, 3, -3, 0, 0, -2, 0, 0}, 342.073910, 0.000040, 0.041000},
	{{0, 0, 0, 0, 3, -3, 0, 0, -2, 1, 0}, 342.073910, 0.000060, 0.088000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 0, -1, 0}, 350.340540, 0.000020, 0.076000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 0, 0, 0}, 69.789280, 0.000040, 6.620000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 0, 1, 0}, 350.340540, 0.000020, 0.075000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 2, -1, 0}, 337.345170, 0.000040, 0.086000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 2, 0, 0}, 337.345190, 0.000030, 0.040000},
	{{0, 0, 0, 0, 3, -2, 0, 0, -2, 0, 0}, 356.810540, 0.000030, 0.041000},
	{{0, 0, 0, 0, 3, -2, 0, 0, -2, 1, 0}, 356.810540, 0.000040, 0.089000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 0, -1, 0}, 335.801590, 0.000040, 0.077000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 0, 0, 0}, 332.189000, 0.000090, 5.405000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 0, 1, 0}, 335.801590, 0.000040, 0.074000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 2, -1, 0}, 346.517310, 0.000040, 0.086000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 2, 0, 0}, 347.946880, 0.000020, 0.040000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -4, 2, 0}, 324.195900, 0.000020, 0.044000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -2, 0, 0}, 110.593530, 0.000100, 0.041000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -2, 1, 0}, 87.868330, 0.000080, 0.089000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -1, 1, -1}, 326.393340, 0.000020, 0.081000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, -2, 0}, 314.350810, 0.000020, 0.038000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, -1, 0}, 313.535020, 0.000320, 0.077000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0}, 310.219190, 0.000520, 3.954000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 1, 0}, 315.894880, 0.000360, 0.074000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 2, 0}, 314.123740, 0.000020, 0.037000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 1, 0, -1}, 115.200650, 0.000010, 1.249000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 2, -1, 0}, 1.892530, 0.000040, 0.085000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 2, 0, 0}, 325.417690, 0.000050, 0.040000},
	{{0, 0, 0, 0, 4, -11, 3, 0, 0, 0, 0}, 47.870580, 0.000050, 1975.368000},
	{{0, 0, 0, 0, 4, -10, 0, 0, -2, 0, 0}, 39.193620, 0.000020, 0.040000},
	{{0, 0, 0, 0, 4, -10, 0, 0, -2, 1, 0}, 13.367380, 0.000070, 0.087000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, -2, 0}, 177.394040, 0.000020, 0.038000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, -1, 0}, 178.522400, 0.000270, 0.075000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, 0, 0}, 184.689140, 0.000750, 441.664000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, 1, 0}, 178.522400, 0.000270, 0.075000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, 2, 0}, 177.394040, 0.000020, 0.038000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 2, -1, 0}, 13.118720, 0.000070, 0.087000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 2, 0, 0}, 37.901350, 0.000020, 0.040000},
	{{0, 0, 0, 0, 4, -9, 0, 0, 0, 0, 0}, 263.490040, 0.000020, 31.562000},
	{{0, 0, 0, 0, 4, -8, 0, 0, 0, 0, 0}, 311.035890, 0.000030, 15.237000},
	{{0, 0, 0, 0, 4, -7, 0, 0, 0, 0, 0}, 188.325940, 0.000030, 10.042000},
	{{0, 0, 0, 0, 4, -6, 0, 0, 0, 0, 0}, 54.719500, 0.000020, 7.489000},
	{{0, 0, 0, 0, 4, -5, 0, 0, -2, 0, 0}, 74.669640, 0.000020, 0.041000},
	{{0, 0, 0, 0, 4, -5, 0, 0, -2, 1, 0}, 74.669640, 0.000030, 0.088000},
	{{0, 0, 0, 0, 4, -5, 0, 0, 0, -1, 0}, 95.686040, 0.000020, 0.076000},
	{{0, 0, 0, 0, 4, -5, 0, 0, 0, 0, 0}, 248.087340, 0.000050, 5.971000},
	{{0, 0, 0, 0, 4, -5, 0, 0, 0, 1, -1}, 345.247850, 0.000070, 1389.349000},
	{{0, 0, 0, 0, 4, -5, 0, 0, 0, 1, 0}, 95.686040, 0.000020, 0.074000},
	{{0, 0, 0, 0, 4, -5, 0, 0, 2, -1, 0}, 81.340840, 0.000030, 0.086000},
	{{0, 0, 0, 0, 4, -5, 0, 0, 2, 0, 0}, 81.350180, 0.000020, 0.040000},
	{{0, 0, 0, 0, 4, -4, 0, 0, 0, 0, 0}, 2.658620, 0.000030, 4.965000},
	{{0, 0, 0, 0, 4, -3, 0, 0, 0, 0, 0}, 14.009810, 0.000010, 4.249000},
	{{0, 0, 0, 0, 4, 0, 0, 0, -2, 0, 0}, 114.003200, 0.000010, 0.041000},
	{{0, 0, 0, 0, 4, 0, 0, 0, 0, -1, 0}, 306.230840, 0.000010, 0.077000},
	{{0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0}, 300.535860, 0.000020, 2.965000},
	{{0, 0, 0, 0, 4, 0, 0, 0, 0, 1, 0}, 306.230840, 0.000010, 0.074000},
	{{0, 0, 0, 0, 4, 0, 0, 0, 0, 2, -2}, 117.634940, 0.000020, 270.001000},
	{{0, 0, 0, 0, 6, -5, 0, 0, 2, -3, 0}, 320.021870, 0.000020, 0.068000},
	{{0, 0, 0, 0, 6, -5, 0, 0, 2, -2, 0}, 320.021870, 0.000020, 0.695000},
	{{0, 0, 0, 0, 6, -5, 0, 0, 2, -1, 0}, 320.021870, 0.000020, 0.085000},
	{{0, 0, 0, 0, 6, -5, 0, 0, 2, 0, 0}, 320.021870, 0.000020, 0.040000},
	{{0, 0, 0, 1, -2, 0, 0, 0, -2, 0, 0}, 150.154020, 0.000020, 0.041000},
	{{0, 0, 0, 1, -2, 0, 0, 0, -2, 1, 0}, 330.222320, 0.000030, 0.090000},
	{{0, 0, 0, 1, -1, 0, 0, 0, -2, 0, 0}, 357.163340, 0.000010, 0.041000},
	{{0, 0, 0, 1, -1, 0, 0, 0, 0, -1, 0}, 175.453280, 0.000010, 0.078000},
	{{0, 0, 0, 1, -1, 0, 0, 0, 0, 1, 0}, 175.453280, 0.000010, 0.073000},
	{{0, 0, 0, 1, 0, -1, 0, 0, 0, 0, 0}, 171.793410, 0.000010, 2.009000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -4, 0, 0}, 39.411790, 0.000010, 0.020000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -4, 2, 0}, 38.910860, 0.000010, 0.045000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, -1, 0}, 39.081110, 0.000080, 0.027000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 0}, 40.902040, 0.000880, 0.041000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 2}, 38.574250, 0.000020, 0.379000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 1, 0}, 39.205570, 0.001300, 0.091000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 2, 0}, 38.867320, 0.000080, 0.434000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, -1, 1}, 128.708470, 0.000020, 0.086000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 0, -1}, 308.374410, 0.000010, 0.040000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 1}, 128.332970, 0.000080, 0.631000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 2, -1}, 308.374410, 0.000010, 0.799000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0}, 20.121280, 0.000090, 0.079000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0}, 206.829430, 0.001650, 1.881000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0}, 346.932500, 0.000050, 0.073000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0}, 9.973690, 0.000010, 0.037000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, -2, 1}, 308.758760, 0.000010, 5.303000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, -1, -1}, 128.685760, 0.000030, 0.073000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, -1, 1}, 308.708470, 0.000120, 0.077000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, -1}, 128.805320, 0.000230, 1.915000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0}, 29.723970, 0.000040, 0.078000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1}, 308.772910, 0.000050, 0.038000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 1, -1}, 128.685760, 0.000030, 0.079000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -2, 0}, 34.254000, 0.000060, 0.805000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -1, 0}, 30.333590, 0.000870, 0.083000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 0, -2}, 26.418650, 0.000010, 0.635000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 0, 0}, 26.550920, 0.000330, 0.040000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 1, 0}, 30.522860, 0.000040, 0.026000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 4, -1, 0}, 28.775010, 0.000010, 0.027000},
	{{0, 0, 0, 2, -3, 0, 0, 0, 0, 0, 0}, 13.206790, 0.000010, 1.234000},
	{{0, 0, 0, 2, -2, 0, 0, 0, -2, 0, 0}, 4.744620, 0.000010, 0.042000},
	{{0, 0, 0, 2, -2, 0, 0, 0, 0, 0, 0}, 0.166380, 0.000050, 1.118000},
	{{0, 0, 0, 2, -1, 0, 0, 0, -2, 0, 0}, 26.036380, 0.000010, 0.042000},
	{{0, 0, 0, 2, 0, -2, 0, 0, -2, 0, 0}, 27.147220, 0.000030, 0.042000},
	{{0, 0, 0, 2, 0, -2, 0, 0, -2, 1, 0}, 27.147220, 0.000040, 0.095000},
	{{0, 0, 0, 2, 0, -2, 0, 0, 0, -1, 0}, 23.589790, 0.000010, 0.082000},
	{{0, 0, 0, 2, 0, -2, 0, 0, 0, 0, 0}, 15.823210, 0.000070, 1.005000},
	{{0, 0, 0, 2, 0, -2, 0, 0, 0, 1, 0}, 23.589790, 0.000010, 0.070000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -4, -1, 0}, 309.502660, 0.000010, 0.016000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -4, 0, 0}, 124.907250, 0.000050, 0.021000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -4, 1, 0}, 125.500390, 0.000090, 0.028000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -4, 2, 0}, 129.583220, 0.000040, 0.046000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -3, 2, -1}, 343.795320, 0.000010, 0.044000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, -2, 0}, 135.391050, 0.000020, 0.020000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, -1, 0}, 129.441000, 0.000240, 0.027000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 0}, 132.936600, 0.002240, 0.042000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 2}, 133.769760, 0.000030, 0.315000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 1, 0}, 134.977890, 0.002180, 0.096000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 2, 0}, 136.907600, 0.000070, 0.352000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, -2, -1}, 163.741950, 0.000020, 0.020000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, -1, -1}, 163.738060, 0.000150, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, -1, 1}, 163.751760, 0.000030, 0.090000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 0, -1}, 163.711850, 0.000810, 0.040000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 0, 1}, 344.275310, 0.000270, 0.472000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 1, -1}, 343.797790, 0.000760, 0.087000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 2, -1}, 343.760570, 0.000140, 0.561000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 3, -1}, 343.760770, 0.000010, 0.066000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -2, 0}, 147.907600, 0.000100, 0.039000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 0}, 157.820750, 0.001030, 0.082000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, -1}, 343.721990, 0.000020, 0.081000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 183.352870, 0.003210, 0.940000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0}, 210.568120, 0.000430, 0.070000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 0}, 262.257620, 0.000040, 0.036000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -3, -1}, 163.748350, 0.000050, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -2, -1}, 163.748350, 0.000740, 0.038000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, -3}, 343.771010, 0.000030, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, -1}, 163.746860, 0.010930, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, 1}, 343.541630, 0.000200, 0.074000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, -3}, 343.825680, 0.000080, 0.037000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, -1}, 163.721990, 0.063690, 104.137000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 0}, 46.573690, 0.000020, 0.074000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 1}, 343.756500, 0.001720, 0.037000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, -3}, 163.705490, 0.000020, 0.074000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, -1}, 163.749840, 0.010900, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, 1}, 343.749480, 0.000210, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 2, -1}, 163.748350, 0.000740, 0.038000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 3, -1}, 163.748350, 0.000050, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -2, 0}, 18.893320, 0.000020, 1.407000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -1, 0}, 320.290870, 0.000090, 0.080000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, -2}, 281.411340, 0.000010, 0.958000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, -1}, 343.721990, 0.000020, 0.081000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0}, 279.954940, 0.000190, 0.039000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 1, 0}, 308.309280, 0.000030, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -3, -1}, 343.760770, 0.000010, 0.067000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -2, -1}, 343.760770, 0.000140, 0.567000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -1, -1}, 343.793080, 0.000830, 0.087000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -1, 1}, 343.751800, 0.000040, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 0, -1}, 163.719630, 0.000670, 0.040000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 0, 1}, 343.751830, 0.000020, 0.019000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 1, -1}, 163.738060, 0.000150, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 2, -1}, 163.741950, 0.000020, 0.020000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 5, -2, -1}, 343.795320, 0.000010, 0.044000},
	{{0, 0, 0, 3, -2, 0, 0, 0, -2, 0, 0}, 207.958680, 0.000010, 0.043000},
	{{0, 0, 0, 3, -2, 0, 0, 0, 2, -1, 0}, 31.109310, 0.000030, 0.077000},
	{{0, 0, 0, 3, 0, 0, 0, 0, -2, 0, 0}, 326.009280, 0.000030, 0.043000},
	{{0, 0, 0, 3, 0, 0, 0, 0, -2, 1, 0}, 325.940900, 0.000030, 0.101000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 0, -1, 0}, 279.577170, 0.000030, 0.086000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0}, 268.261710, 0.000160, 0.627000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0}, 293.391210, 0.000010, 0.067000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 1, 0, -1}, 2.518960, 0.000020, 1.847000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -3, 0}, 146.587330, 0.000010, 0.074000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -2, 0}, 75.419930, 0.000010, 5.588000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -1, 0}, 90.422490, 0.000110, 0.076000},
	{{0, 0, 0, 3, 1, 0, 0, 0, 2, -3, 0}, 105.224100, 0.000010, 0.075000},
	{{0, 0, 0, 3, 1, 0, 0, 0, 2, -1, 0}, 285.224100, 0.000010, 0.076000},
	{{0, 0, 0, 4, -2, 0, 0, 0, 2, -1, 0}, 236.752600, 0.000020, 0.074000},
	{{0, 0, 0, 4, -1, 0, 0, 0, 0, 0, 0}, 256.669940, 0.000010, 0.490000},
	{{0, 0, 0, 4, 0, 0, 0, 0, -2, 0, 0}, 37.016470, 0.000050, 0.044000},
	{{0, 0, 0, 4, 0, 0, 0, 0, -2, 1, 0}, 37.430350, 0.000050, 0.107000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0}, 349.801730, 0.000020, 0.470000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, 0, -2}, 142.187340, 0.000010, 52.068000},
	{{0, 0, 1, -8, 3, 0, 0, 0, -3, 1, 2}, 235.589430, 0.000010, 166.090000},
	{{0, 0, 1, -8, 3, 0, 0, 0, 2, -1, 0}, 235.637320, 0.000010, 0.118000},
	{{0, 0, 1, -8, 3, 0, 0, 0, 2, 0, 0}, 235.639700, 0.000030, 0.046000},
	{{0, 0, 1, -7, 2, 0, 0, 0, -2, 0, 0}, 51.767520, 0.000010, 0.037000},
	{{0, 0, 1, -7, 2, 0, 0, 0, -2, 2, 0}, 51.767520, 0.000010, 1.283000},
	{{0, 0, 1, -6, 0, 0, 0, 0, 2, 0, 0}, 119.905420, 0.000020, 0.044000},
	{{0, 0, 1, -6, 1, 0, 0, 0, -2, 0, 2}, 77.246130, 0.000020, 578.012000},
	{{0, 0, 1, -5, -2, 0, 0, 0, -2, 1, 0}, 356.214980, 0.000010, 0.075000},
	{{0, 0, 1, -5, -2, 0, 0, 0, -2, 3, 0}, 176.214980, 0.000010, 0.076000},
	{{0, 0, 1, -5, -1, 0, 0, 0, -2, 1, 0}, 208.940370, 0.000020, 0.076000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 1, 0}, 81.698360, 0.000040, 0.076000},
	{{0, 0, 1, -5, 0, 0, 0, 0, 0, 0, 0}, 247.045130, 0.000040, 0.603000},
	{{0, 0, 1, -5, 2, 0, 0, 0, -2, 1, 0}, 112.915390, 0.000020, 0.077000},
	{{0, 0, 1, -4, -1, 0, 0, 0, -2, 1, 0}, 52.506180, 0.000010, 0.079000},
	{{0, 0, 1, -4, -1, 0, 0, 0, -2, 3, 0}, 52.506180, 0.000010, 0.072000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 0, 0}, 225.009620, 0.000030, 0.039000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 1, 0}, 174.066980, 0.000030, 0.079000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 2, 0}, 47.868230, 0.000010, 1.545000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, -1, 1}, 345.164560, 0.000060, 0.075000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 0, -1}, 165.714810, 0.000030, 0.037000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 0, 1}, 345.867860, 0.000380, 13.704000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 1, 1}, 345.164560, 0.000060, 0.076000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, -1, 0}, 9.972170, 0.000090, 0.070000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 0, 0}, 15.112140, 0.000830, 0.888000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 1, 0}, 31.496300, 0.000350, 0.082000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 2, 0}, 18.534820, 0.000020, 0.039000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 1, 0, -1}, 167.844740, 0.000010, 0.459000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, -2, 0}, 41.778530, 0.000040, 0.345000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, -1, 0}, 41.785180, 0.000850, 0.097000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 0, -2}, 41.500840, 0.000010, 0.309000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 0, 0}, 39.884480, 0.000780, 0.042000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 1, 0}, 41.149430, 0.000110, 0.027000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 4, -1, 0}, 43.659210, 0.000020, 0.028000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 4, 0, 0}, 43.148060, 0.000020, 0.021000},
	{{0, 0, 1, -4, 0, 2, 0, 0, -1, 0, 1}, 241.061750, 0.000010, 197.046000},
	{{0, 0, 1, -4, 1, 0, 0, 0, 2, -2, 0}, 277.352360, 0.000010, 0.355000},
	{{0, 0, 1, -4, 1, 0, 0, 0, 2, 0, 0}, 277.352360, 0.000010, 0.042000},
	{{0, 0, 1, -4, 2, 0, 0, 0, 0, 0, 0}, 122.725220, 0.000040, 1.044000},
	{{0, 0, 1, -4, 2, 0, 0, 0, 2, -1, 0}, 115.726130, 0.000020, 0.095000},
	{{0, 0, 1, -4, 2, 0, 0, 0, 2, 0, 0}, 102.260170, 0.000020, 0.042000},
	{{0, 0, 1, -4, 3, 0, 0, 0, 0, 0, 0}, 137.233450, 0.000030, 1.144000},
	{{0, 0, 1, -4, 3, 0, 0, 0, 2, 0, 0}, 137.466240, 0.000010, 0.042000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, -2, 0}, 228.863240, 0.000010, 0.019000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 0, 0}, 236.420110, 0.000050, 0.039000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 1, 0}, 126.309910, 0.000150, 0.083000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 2, 0}, 8.587050, 0.000010, 0.848000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 3, 0}, 302.285160, 0.000020, 0.069000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 0, -1}, 201.081610, 0.000020, 0.038000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 0, 0}, 122.429170, 0.000020, 0.077000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 0, 1}, 20.964410, 0.000140, 2.180000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 1, -1}, 201.284650, 0.000090, 0.076000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, -1, 0}, 280.018860, 0.000280, 0.072000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 0, 0}, 301.978680, 0.001590, 1.681000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 1, 0}, 293.641130, 0.000220, 0.079000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 1, 0, -1}, 24.275500, 0.000060, 0.607000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 1, 1, -1}, 21.284650, 0.000020, 0.086000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, -2, 0}, 356.474540, 0.000010, 0.422000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, -1, 0}, 81.339960, 0.000450, 0.092000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 0, 0}, 74.854250, 0.000320, 0.041000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 1, 0}, 80.572140, 0.000040, 0.027000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 4, -1, 0}, 81.047780, 0.000010, 0.028000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 4, 0, 0}, 262.653490, 0.000020, 0.020000},
	{{0, 0, 1, -3, 1, 0, 0, 0, 0, 0, 0}, 161.603150, 0.000020, 1.958000},
	{{0, 0, 1, -2, -3, 0, 0, 0, 0, 0, 0}, 103.732700, 0.000020, 3.162000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -6, 2, 0}, 318.975170, 0.000010, 0.021000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, -1, 0}, 318.639560, 0.000050, 0.016000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 0, 0}, 319.655120, 0.000260, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 0, 2}, 318.481120, 0.000030, 0.044000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 1, 0}, 318.283950, 0.000660, 0.028000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 1, 2}, 318.430150, 0.000010, 0.106000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 2, 0}, 321.100290, 0.000430, 0.043000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 0, 0}, 317.241400, 0.000020, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 0, 1}, 273.341080, 0.000050, 0.042000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 1, 0}, 137.988440, 0.000020, 0.042000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 1, 1}, 93.267750, 0.000040, 0.095000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -3, 0}, 318.830360, 0.000020, 0.015000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -2, 0}, 317.096010, 0.000210, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -1, 0}, 316.905220, 0.002410, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -1, 2}, 137.025180, 0.000070, 0.089000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, -2}, 139.622460, 0.000040, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 0}, 318.229430, 0.023010, 0.040000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 2}, 318.000100, 0.000540, 0.489000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, -2}, 141.081900, 0.000070, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, 0}, 320.919880, 0.031940, 0.087000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, 2}, 319.461430, 0.000020, 0.065000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 2, 0}, 327.676880, 0.000880, 0.585000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 3, 0}, 343.193580, 0.000030, 0.067000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, -1, 0}, 137.202000, 0.000070, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, -1, 1}, 273.314720, 0.000070, 0.082000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, -1}, 232.986990, 0.000030, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 0}, 139.080290, 0.000570, 0.080000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 1}, 56.720620, 0.000120, 1.010000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 1, -1}, 232.978240, 0.000010, 0.079000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 1, 0}, 144.710370, 0.000050, 1.214000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 1, 1}, 93.314720, 0.000050, 0.070000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 3, -1}, 232.978240, 0.000010, 0.072000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -4, 0}, 310.957510, 0.000010, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -3, 0}, 313.252460, 0.000300, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -2, -2}, 134.710380, 0.000030, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -2, 0}, 313.271560, 0.004310, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, -2}, 134.828290, 0.000150, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 0}, 313.303470, 0.063230, 0.075000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 2}, 313.240760, 0.000120, 0.074000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, -2}, 143.302880, 0.000150, 0.037000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, 0}, 318.137760, 0.324550, 15.781000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, 2}, 145.384880, 0.000130, 0.037000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, -2}, 312.476180, 0.000090, 0.073000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, 0}, 313.479200, 0.064060, 0.076000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, 2}, 134.828290, 0.000150, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, 0}, 313.526660, 0.004330, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, 2}, 134.711400, 0.000030, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 3, 0}, 313.187880, 0.000300, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 4, 0}, 311.140080, 0.000010, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, -1, 0}, 143.540520, 0.000070, 1.052000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, -1, 1}, 244.814030, 0.000030, 0.080000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, -1}, 52.653080, 0.000120, 0.895000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, 0}, 141.663730, 0.000670, 0.081000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 1, 0}, 137.131960, 0.000090, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -3, 0}, 341.198290, 0.000030, 0.066000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -2, 0}, 325.202890, 0.001110, 0.544000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, -2}, 319.840050, 0.000020, 0.065000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, 0}, 321.961250, 0.035490, 0.088000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, 2}, 141.948310, 0.000080, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, -2}, 320.045790, 0.000540, 0.461000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, 0}, 320.197580, 0.025130, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, 2}, 139.806380, 0.000040, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, -2}, 138.189750, 0.000070, 0.090000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, 0}, 319.042230, 0.002550, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, 2}, 140.124750, 0.000010, 0.015000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 2, 0}, 317.567240, 0.000220, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 3, -1, 0}, 140.028160, 0.000030, 0.042000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 3, 0, 0}, 321.385220, 0.000020, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -3, 0}, 323.772310, 0.000010, 0.104000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -2, 0}, 322.004140, 0.000490, 0.044000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -1, -2}, 320.262100, 0.000010, 0.107000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -1, 0}, 321.235250, 0.000700, 0.028000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, 0, 0}, 319.084760, 0.000300, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, 1, 0}, 319.304050, 0.000060, 0.016000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 6, -2, 0}, 320.023250, 0.000020, 0.021000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 6, -1, 0}, 319.612940, 0.000010, 0.016000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, -1, 0}, 33.824930, 0.000030, 0.026000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, 0, 0}, 33.609300, 0.000210, 0.040000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, 1, 0}, 34.903050, 0.000350, 0.087000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, 2, 0}, 33.824930, 0.000010, 0.562000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, -2, 0}, 26.344710, 0.000020, 0.038000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, -1, 0}, 27.524860, 0.000360, 0.075000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 0, 0}, 31.833980, 0.001970, 220.858000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 1, 0}, 27.502670, 0.000360, 0.075000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 2, 0}, 26.348720, 0.000020, 0.038000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, -2, 0}, 33.774990, 0.000010, 0.565000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, -1, 0}, 34.853370, 0.000350, 0.087000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, 0, 0}, 33.562570, 0.000210, 0.040000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, 1, 0}, 33.774990, 0.000030, 0.026000},
	{{0, 0, 1, -2, 1, 0, 0, 0, -2, 0, 0}, 195.158930, 0.000040, 0.040000},
	{{0, 0, 1, -2, 1, 0, 0, 0, -2, 1, 0}, 195.757640, 0.000050, 0.087000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 0, -1, 0}, 193.105970, 0.000060, 0.076000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 0, 0, 0}, 196.888330, 0.000260, 47.766000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 0, 1, 0}, 193.105970, 0.000060, 0.075000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 2, -1, 0}, 194.233830, 0.000050, 0.087000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 2, 0, 0}, 196.008160, 0.000030, 0.040000},
	{{0, 0, 1, -2, 2, 0, 0, 0, 0, 0, 0}, 7.227640, 0.000010, 9.502000},
	{{0, 0, 1, -2, 3, 0, 0, 0, 0, 0, 0}, 199.122210, 0.000010, 5.276000},
	{{0, 0, 1, -1, -2, 0, 0, 0, -2, 0, 0}, 121.100220, 0.000020, 0.041000},
	{{0, 0, 1, -1, -2, 0, 0, 0, 0, -1, 0}, 301.791810, 0.000010, 0.077000},
	{{0, 0, 1, -1, -2, 0, 0, 0, 0, 1, 0}, 301.791810, 0.000010, 0.074000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -6, 2, 0}, 0.649000, 0.000010, 0.021000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -4, 0, 0}, 0.735340, 0.000050, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -4, 1, 0}, 0.656060, 0.000150, 0.028000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -4, 2, 0}, 0.655370, 0.000090, 0.044000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -3, 2, 0}, 0.604890, 0.000010, 0.099000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, -2, 0}, 0.646350, 0.000030, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, -1, 0}, 0.648040, 0.000390, 0.027000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, -1, 2}, 180.627410, 0.000010, 0.094000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, -2}, 180.648060, 0.000010, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 0}, 0.655410, 0.004660, 0.041000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 2}, 0.637490, 0.000090, 0.388000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 1, 0}, 0.680350, 0.006920, 0.091000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 1, 2}, 180.627410, 0.000010, 0.063000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 2, 0}, 0.684200, 0.000320, 0.446000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 3, 0}, 0.634930, 0.000020, 0.065000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 0, 0}, 180.470950, 0.000170, 0.084000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 0, 1}, 92.769820, 0.000040, 0.657000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 1, 0}, 180.627410, 0.000010, 0.738000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -2, 0}, 0.528290, 0.000220, 0.038000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -1, 0}, 0.539300, 0.003420, 0.078000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0}, 0.883940, 0.010510, 2.135000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 1, -2}, 181.111350, 0.000020, 0.076000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 1, 0}, 0.432880, 0.002960, 0.073000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 2, 0}, 0.394120, 0.000190, 0.037000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 3, -2}, 181.111350, 0.000020, 0.075000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 3, 0}, 0.286990, 0.000010, 0.025000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, -1, 1}, 274.240360, 0.000040, 0.077000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 0, -1}, 94.553170, 0.000130, 1.708000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 0, 0}, 0.283300, 0.000130, 0.078000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 0, 1}, 274.465150, 0.000020, 0.038000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -2, 0}, 359.855770, 0.000150, 0.766000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -1, 0}, 0.349360, 0.004500, 0.084000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, -2}, 0.250860, 0.000070, 0.610000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, 0}, 0.325280, 0.002180, 0.040000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 1, 0}, 0.337940, 0.000220, 0.026000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 2, 0}, 0.288760, 0.000020, 0.019000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 3, -2, 0}, 180.197430, 0.000010, 0.090000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 4, -2, 0}, 0.419490, 0.000070, 0.043000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 4, -1, 0}, 0.352460, 0.000070, 0.027000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 4, 0, 0}, 0.306290, 0.000050, 0.020000},
	{{0, 0, 1, -1, 1, 0, 0, 0, 2, 0, 0}, 212.066860, 0.000010, 0.040000},
	{{0, 0, 1, -1, 3, 0, 0, 0, 1, -2, 1}, 127.674560, 0.000030, 1023.362000},
	{{0, 0, 1, 0, -6, 0, 0, 0, 0, 0, 0}, 334.155380, 0.000030, 2.024000},
	{{0, 0, 1, 0, -6, 5, 0, 0, 0, 0, 0}, 198.894870, 0.000040, 1.506000},
	{{0, 0, 1, 0, -5, 0, 0, 0, -2, 0, 0}, 327.392280, 0.000050, 0.041000},
	{{0, 0, 1, 0, -5, 0, 0, 0, -2, 1, 0}, 328.069380, 0.000060, 0.092000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 0, -1, 0}, 323.413150, 0.000070, 0.079000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 0, 0, 0}, 322.872090, 0.000300, 1.729000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 0, 1, 0}, 323.413150, 0.000070, 0.072000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 2, -1, 0}, 326.881740, 0.000020, 0.083000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 2, 0, 0}, 325.924620, 0.000020, 0.040000},
	{{0, 0, 1, 0, -5, 2, 0, 0, -2, 0, 0}, 312.396440, 0.000010, 0.042000},
	{{0, 0, 1, 0, -5, 2, 0, 0, 0, 0, 0}, 302.199210, 0.000070, 1.547000},
	{{0, 0, 1, 0, -5, 3, 0, 0, -2, 0, 0}, 310.903870, 0.000020, 0.042000},
	{{0, 0, 1, 0, -5, 3, 0, 0, 0, 0, 0}, 309.514390, 0.000050, 1.470000},
	{{0, 0, 1, 0, -5, 4, 0, 0, 0, 0, 0}, 186.073100, 0.000020, 1.400000},
	{{0, 0, 1, 0, -5, 5, 0, 0, -2, 0, 0}, 183.850270, 0.000040, 0.042000},
	{{0, 0, 1, 0, -5, 5, 0, 0, -2, 1, 0}, 184.610910, 0.000040, 0.093000},
	{{0, 0, 1, 0, -5, 5, 0, 0, 0, -1, 0}, 180.243080, 0.000040, 0.080000},
	{{0, 0, 1, 0, -5, 5, 0, 0, 0, 0, 0}, 172.896020, 0.000180, 1.337000},
	{{0, 0, 1, 0, -5, 5, 0, 0, 0, 1, 0}, 180.243080, 0.000040, 0.071000},
	{{0, 0, 1, 0, -5, 5, 0, 0, 2, -1, 0}, 337.153960, 0.000030, 0.082000},
	{{0, 0, 1, 0, -5, 7, 0, 0, 0, 0, 0}, 167.613980, 0.000020, 1.225000},
	{{0, 0, 1, 0, -5, 10, 0, 0, 0, 0, 0}, 343.193160, 0.000020, 1.089000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -4, 1, 0}, 317.608410, 0.000020, 0.028000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, -1, 0}, 317.226040, 0.000050, 0.027000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 0, 0}, 317.726090, 0.000450, 0.042000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 1, 0}, 317.451000, 0.000640, 0.092000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 2, 0}, 317.771530, 0.000020, 0.410000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -1, -1, 1}, 121.204910, 0.000020, 0.087000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -1, 0, 1}, 122.262080, 0.000020, 0.583000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, -2, 0}, 313.486450, 0.000040, 0.039000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, -1, 0}, 313.567500, 0.000590, 0.079000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 0, 0}, 313.059060, 0.002670, 1.509000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 1, 0}, 312.993760, 0.000500, 0.072000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 2, 0}, 313.515920, 0.000040, 0.037000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, -2, 1}, 301.445250, 0.000040, 17.401000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, -1, 1}, 301.204880, 0.000120, 0.076000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, 0, -1}, 120.559300, 0.000100, 2.558000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, 0, 0}, 313.392910, 0.000020, 0.077000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, 0, 1}, 300.642030, 0.000020, 0.038000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 2, -2, 0}, 128.401080, 0.000020, 0.900000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 2, -1, 0}, 332.011770, 0.000120, 0.082000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 2, 0, 0}, 316.318440, 0.000140, 0.039000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 2, 1, 0}, 316.995350, 0.000010, 0.026000},
	{{0, 0, 1, 0, -4, 2, 0, 0, -2, 0, 0}, 313.238330, 0.000060, 0.042000},
	{{0, 0, 1, 0, -4, 2, 0, 0, -2, 1, 0}, 313.705810, 0.000070, 0.093000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 0, -1, 0}, 308.340300, 0.000060, 0.080000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 0, 0, 0}, 304.377160, 0.000270, 1.369000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 0, 1, 0}, 308.340300, 0.000060, 0.071000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 1, -3, 1}, 281.301920, 0.000010, 0.075000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 1, -2, 1}, 281.091910, 0.000120, 95.906000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 1, -1, 1}, 101.054640, 0.000060, 0.075000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 1, 0, -1}, 100.992070, 0.000010, 3.095000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 2, -1, 0}, 15.127370, 0.000010, 0.082000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 2, 0, 0}, 314.730200, 0.000010, 0.039000},
	{{0, 0, 1, 0, -4, 3, 0, 0, -2, 0, 0}, 6.008750, 0.000040, 0.042000},
	{{0, 0, 1, 0, -4, 3, 0, 0, -2, 1, 0}, 6.008740, 0.000030, 0.093000},
	{{0, 0, 1, 0, -4, 3, 0, 0, 0, -1, 0}, 5.632450, 0.000020, 0.080000},
	{{0, 0, 1, 0, -4, 3, 0, 0, 0, 0, 0}, 356.244750, 0.000130, 1.308000},
	{{0, 0, 1, 0, -4, 3, 0, 0, 0, 1, 0}, 5.632450, 0.000020, 0.071000},
	{{0, 0, 1, 0, -4, 3, 0, 0, 2, -1, 0}, 160.084160, 0.000030, 0.082000},
	{{0, 0, 1, 0, -4, 4, 0, 0, -2, 0, 0}, 239.615910, 0.000020, 0.042000},
	{{0, 0, 1, 0, -4, 4, 0, 0, 0, 0, 0}, 238.966610, 0.000050, 1.252000},
	{{0, 0, 1, 0, -4, 5, 0, 0, -2, 0, 0}, 117.638950, 0.000080, 0.042000},
	{{0, 0, 1, 0, -4, 5, 0, 0, -2, 1, 0}, 118.321610, 0.000110, 0.094000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 0, -1, 0}, 111.880520, 0.000110, 0.080000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 0, 0, 0}, 107.791830, 0.000550, 1.201000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 0, 1, 0}, 110.217530, 0.000090, 0.071000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 1, 0, -1}, 271.915290, 0.000070, 4.520000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 2, -3, 0}, 300.304060, 0.000020, 0.070000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 2, -2, 0}, 274.527340, 0.000010, 1.062000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 2, -1, 0}, 98.109670, 0.000040, 0.081000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 2, 0, 0}, 127.648240, 0.000030, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 0, 0}, 308.927910, 0.000050, 0.021000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 1, 0}, 309.203520, 0.000130, 0.028000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 2, 0}, 310.426360, 0.000060, 0.045000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -3, 0, 0}, 313.106030, 0.000010, 0.028000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, -2, 0}, 308.980800, 0.000040, 0.020000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, -1, 0}, 309.252620, 0.000390, 0.027000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, -2}, 128.814140, 0.000010, 0.020000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, 0}, 309.452720, 0.004360, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, 2}, 309.616750, 0.000070, 0.350000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 1, 0}, 309.402230, 0.005870, 0.093000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 2, 0}, 307.957890, 0.000270, 0.397000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 3, 0}, 307.851030, 0.000020, 0.063000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, -2, 1}, 290.661520, 0.000050, 0.040000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, -1, 1}, 290.634350, 0.000510, 0.087000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 0, -1}, 291.845220, 0.000030, 0.040000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 0, 0}, 128.694610, 0.000200, 0.086000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 0, 1}, 112.175510, 0.000090, 0.555000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 1, -1}, 291.450990, 0.000050, 0.085000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 1, 0}, 131.160830, 0.000020, 0.612000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 1, 1}, 111.361120, 0.000030, 0.066000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -2, 0}, 306.403030, 0.000310, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -1, -2}, 125.230970, 0.000020, 0.025000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -1, 0}, 306.558230, 0.004580, 0.080000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 0, 0}, 304.606990, 0.023140, 1.339000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 1, 0}, 304.889430, 0.004150, 0.071000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 1, 2}, 125.230970, 0.000020, 0.024000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 2, 0}, 304.625670, 0.000270, 0.037000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -3, 1}, 290.621810, 0.000070, 0.076000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -2, -1}, 290.922320, 0.000020, 0.037000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -2, 1}, 290.644890, 0.001580, 37.265000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -1, -1}, 111.025270, 0.000160, 0.074000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -1, 0}, 304.959300, 0.000120, 7.147000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -1, 1}, 110.668540, 0.002470, 0.075000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 0, -1}, 110.936720, 0.001190, 3.261000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 0, 0}, 308.030010, 0.000330, 0.076000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 0, 1}, 291.624250, 0.000060, 0.038000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 1, -1}, 111.025270, 0.000160, 0.077000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 1, 0}, 307.993150, 0.000020, 0.038000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 1, 1}, 290.924050, 0.000020, 0.025000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -3, 0}, 294.031540, 0.000030, 0.070000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -2, 0}, 111.891380, 0.000310, 0.974000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -1, 0}, 88.258410, 0.001470, 0.082000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 0, -2}, 308.873160, 0.000050, 0.735000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 0, 0}, 317.178540, 0.000830, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 1, 0}, 314.527590, 0.000100, 0.026000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 3, -3, 1}, 290.661560, 0.000020, 0.087000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 3, -2, 1}, 110.697730, 0.000020, 0.040000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 3, -1, 1}, 110.669680, 0.000020, 0.026000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -3, 0}, 112.951760, 0.000200, 0.096000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -2, 0}, 112.277200, 0.000500, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -1, 0}, 111.447310, 0.000300, 0.027000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, 0, 0}, 105.446950, 0.000030, 0.020000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 6, -3, 0}, 112.984140, 0.000020, 0.028000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 6, -2, 0}, 113.019720, 0.000010, 0.021000},
	{{0, 0, 1, 0, -3, 1, 0, 0, -2, 0, 0}, 130.317200, 0.000020, 0.042000},
	{{0, 0, 1, 0, -3, 1, 0, 0, 0, 0, 0}, 115.944100, 0.000080, 1.280000},
	{{0, 0, 1, 0, -3, 1, 0, 0, 2, -1, 0}, 104.375100, 0.000040, 0.082000},
	{{0, 0, 1, 0, -3, 2, 0, 0, -2, -1, 0}, 356.285510, 0.000010, 0.027000},
	{{0, 0, 1, 0, -3, 2, 0, 0, -2, 0, 0}, 356.285520, 0.000140, 0.042000},
	{{0, 0, 1, 0, -3, 2, 0, 0, -2, 1, 0}, 356.335060, 0.000180, 0.094000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 0, -1, 0}, 355.207300, 0.000150, 0.080000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 0, 0, 0}, 353.301120, 0.000590, 1.227000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 0, 1, 0}, 355.023340, 0.000110, 0.071000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 2, -3, 0}, 0.641870, 0.000020, 0.070000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 2, -2, 0}, 1.165610, 0.000020, 1.043000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 2, -1, 0}, 357.658830, 0.000060, 0.081000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 2, 0, 0}, 357.611550, 0.000050, 0.039000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 4, -3, 0}, 177.905690, 0.000010, 0.095000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 4, -2, 0}, 177.492660, 0.000010, 0.042000},
	{{0, 0, 1, 0, -3, 3, 0, 0, -2, 0, 0}, 60.487790, 0.000070, 0.042000},
	{{0, 0, 1, 0, -3, 3, 0, 0, -2, 1, 0}, 60.502120, 0.000070, 0.094000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 0, -1, 0}, 60.356730, 0.000050, 0.081000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 0, 0, 0}, 60.307290, 0.000210, 1.178000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 0, 1, 0}, 60.356730, 0.000050, 0.071000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 2, -1, 0}, 57.640290, 0.000020, 0.081000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 2, 0, 0}, 58.491420, 0.000010, 0.039000},
	{{0, 0, 1, 0, -3, 4, 0, 0, -2, 0, 0}, 296.759590, 0.000020, 0.042000},
	{{0, 0, 1, 0, -3, 4, 0, 0, 0, 0, 0}, 291.955680, 0.000030, 1.133000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -4, 1, 0}, 172.516500, 0.000010, 0.028000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, -1, 0}, 172.555210, 0.000040, 0.027000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 0, 0}, 172.569760, 0.000410, 0.042000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 1, 0}, 172.464180, 0.000550, 0.095000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 2, 0}, 172.516320, 0.000020, 0.372000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -1, 0, 0}, 172.581860, 0.000030, 0.087000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, -2, 0}, 173.039740, 0.000020, 0.039000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, -1, 0}, 172.862100, 0.000380, 0.081000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 0, 0}, 172.326350, 0.001710, 1.091000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 1, 0}, 172.944150, 0.000250, 0.071000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 2, 0}, 173.008150, 0.000020, 0.036000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 1, -1, 0}, 172.587010, 0.000060, 33.536000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 1, 0, -1}, 12.258800, 0.000010, 7.303000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 1, 0, 0}, 352.581860, 0.000170, 0.075000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 2, -3, 0}, 1.541210, 0.000010, 0.071000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 2, -1, 0}, 171.320920, 0.000120, 0.081000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 2, 0, 0}, 172.450150, 0.000080, 0.039000},
	{{0, 0, 1, 0, -3, 6, -3, 0, 0, 0, 0}, 349.498380, 0.000020, 1.093000},
	{{0, 0, 1, 0, -2, -5, 0, 0, 0, 0, 0}, 321.165170, 0.000030, 1.511000},
	{{0, 0, 1, 0, -2, -2, 0, 0, 0, 0, 0}, 97.393120, 0.000030, 1.310000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -6, 1, 0}, 306.290790, 0.000020, 0.017000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -6, 2, 0}, 305.914260, 0.000030, 0.021000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, -1, 0}, 305.665310, 0.000070, 0.016000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 0, 0}, 306.661660, 0.000380, 0.021000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 1, 0}, 306.606290, 0.000900, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 1, 2}, 306.354470, 0.000010, 0.117000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 2, 0}, 305.829230, 0.000600, 0.045000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 3, 0}, 301.605410, 0.000030, 0.113000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 0, 0}, 308.207510, 0.000010, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 1, 0}, 126.165010, 0.000060, 0.043000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 1, 1}, 280.640010, 0.000010, 0.104000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -3, 0}, 305.766300, 0.000030, 0.016000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -2, 0}, 304.559170, 0.000260, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -1, -2}, 125.589290, 0.000020, 0.016000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -1, 0}, 305.553720, 0.003130, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -1, 2}, 125.692530, 0.000070, 0.097000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, -2}, 124.640400, 0.000070, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 0}, 306.028040, 0.034740, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 2}, 306.271970, 0.000500, 0.340000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, -2}, 125.606050, 0.000130, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, 0}, 305.994160, 0.045700, 0.094000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, 2}, 305.373310, 0.000020, 0.062000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 2, 0}, 305.970850, 0.001960, 0.384000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 3, 0}, 308.155630, 0.000100, 0.063000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -2, 1}, 280.516230, 0.000050, 0.041000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -1, -1}, 280.506170, 0.000030, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -1, 0}, 125.783750, 0.000150, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -1, 1}, 280.518640, 0.000690, 0.088000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, -1}, 280.508280, 0.000160, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 0}, 125.857040, 0.002330, 0.087000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 1}, 100.502690, 0.001040, 0.530000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, -1}, 280.538880, 0.000400, 0.085000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, 0}, 125.981960, 0.000250, 0.582000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, 1}, 100.550300, 0.000180, 0.066000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 2, -1}, 280.516410, 0.000030, 0.644000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 2, 0}, 125.809930, 0.000020, 0.067000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -3, 0}, 300.042240, 0.000200, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -2, 0}, 300.115070, 0.002610, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, -2}, 122.267210, 0.000090, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, 0}, 301.001670, 0.037800, 0.080000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, 2}, 291.773860, 0.000020, 0.069000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, -2}, 118.849710, 0.000020, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, -1}, 100.514480, 0.000020, 0.079000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 0}, 301.005990, 0.164250, 1.203000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 2}, 121.444260, 0.000110, 0.036000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, 0}, 301.497680, 0.028890, 0.071000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, 2}, 122.034290, 0.000080, 0.024000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 2, 0}, 301.266710, 0.002020, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 3, 0}, 301.522720, 0.000130, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -3, 0}, 308.254100, 0.000010, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -3, 1}, 280.540490, 0.000020, 0.076000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, -1}, 100.522540, 0.000080, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, 0}, 310.578720, 0.000180, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, 1}, 280.537250, 0.000550, 8.998000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, -1}, 100.523300, 0.001550, 0.074000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 0}, 305.890400, 0.003270, 17.980000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 1}, 100.524470, 0.004450, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, -3}, 283.508100, 0.000010, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, -1}, 100.530100, 0.011830, 4.497000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 0}, 306.193170, 0.006970, 0.076000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 1}, 280.506100, 0.002030, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, -1}, 100.524170, 0.001650, 0.077000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, 0}, 306.138740, 0.000470, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, 1}, 280.506990, 0.000240, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 2, -1}, 100.523210, 0.000110, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 2, 0}, 306.090150, 0.000030, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 2, 1}, 280.507380, 0.000020, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -4, 0}, 292.644920, 0.000010, 0.036000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -3, 0}, 275.013050, 0.000040, 0.070000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -2, 0}, 288.469890, 0.000490, 1.061000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, 0}, 301.711050, 0.018190, 0.081000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, 2}, 130.795140, 0.000030, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, -2}, 304.986120, 0.000400, 0.784000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, 0}, 303.968000, 0.008720, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, 2}, 125.808930, 0.000020, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 1, -2}, 125.009960, 0.000020, 0.083000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 1, 0}, 303.242760, 0.000990, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 2, 0}, 305.074960, 0.000100, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -2, -1}, 280.518400, 0.000020, 0.501000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -2, 0}, 305.544060, 0.000030, 0.088000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -2, 1}, 100.524100, 0.000060, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -1, -1}, 280.472280, 0.000070, 0.089000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -1, 0}, 305.923180, 0.000120, 0.041000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 0, -1}, 100.660500, 0.000030, 0.041000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 0, 0}, 305.898910, 0.000080, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 0, 1}, 280.507220, 0.000030, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -3, 0}, 103.085550, 0.000180, 0.095000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -2, 0}, 289.480980, 0.000690, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -1, 0}, 289.229820, 0.000980, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, 0, 0}, 297.360320, 0.000190, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, 1, 0}, 304.959580, 0.000010, 0.016000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 6, -3, 0}, 286.192750, 0.000020, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 6, -2, 0}, 283.290880, 0.000040, 0.021000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 6, -1, 0}, 283.058910, 0.000010, 0.016000},
	{{0, 0, 1, 0, -2, 1, 0, 0, -2, 0, 0}, 182.976990, 0.000060, 0.042000},
	{{0, 0, 1, 0, -2, 1, 0, 0, -2, 1, 0}, 182.976990, 0.000070, 0.094000},
	{{0, 0, 1, 0, -2, 1, 0, 0, 0, -1, 0}, 182.533130, 0.000050, 0.081000},
	{{0, 0, 1, 0, -2, 1, 0, 0, 0, 0, 0}, 181.621760, 0.000190, 1.156000},
	{{0, 0, 1, 0, -2, 1, 0, 0, 0, 1, 0}, 182.533130, 0.000050, 0.071000},
	{{0, 0, 1, 0, -2, 1, 0, 0, 2, -1, 0}, 181.109350, 0.000030, 0.081000},
	{{0, 0, 1, 0, -2, 1, 0, 0, 2, 0, 0}, 181.109370, 0.000020, 0.039000},
	{{0, 0, 1, 0, -2, 2, 0, 0, -2, -1, 0}, 28.726000, 0.000010, 0.027000},
	{{0, 0, 1, 0, -2, 2, 0, 0, -2, 0, 0}, 28.726000, 0.000100, 0.042000},
	{{0, 0, 1, 0, -2, 2, 0, 0, -2, 1, 0}, 29.404560, 0.000130, 0.094000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 0, -1, 0}, 23.139300, 0.000100, 0.081000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 0, 0, 0}, 22.877820, 0.000390, 1.112000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 0, 1, 0}, 20.609650, 0.000070, 0.071000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 1, -1, 0}, 12.805190, 0.000080, 81.442000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 1, 0, -1}, 114.869110, 0.000020, 6.474000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 1, 0, 0}, 191.063710, 0.000070, 0.075000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 2, -1, 0}, 3.514770, 0.000030, 0.081000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 2, 0, 0}, 9.774070, 0.000020, 0.039000},
	{{0, 0, 1, 0, -2, 3, 0, 0, -2, 0, 0}, 177.030370, 0.000020, 0.042000},
	{{0, 0, 1, 0, -2, 3, 0, 0, 0, 0, 0}, 237.177380, 0.000060, 1.072000},
	{{0, 0, 1, 0, -2, 3, 0, 0, 1, 0, -1}, 108.707340, 0.000040, 8.297000},
	{{0, 0, 1, 0, -2, 4, 0, 0, -2, 0, 0}, 348.120640, 0.000060, 0.042000},
	{{0, 0, 1, 0, -2, 4, 0, 0, -2, 1, 0}, 348.120650, 0.000070, 0.095000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 0, -1, 0}, 349.133730, 0.000050, 0.081000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 0, 0, 0}, 350.556370, 0.000260, 1.034000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 0, 1, 0}, 349.133730, 0.000050, 0.070000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 1, 0, -1}, 186.903520, 0.000010, 11.550000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 2, -1, 0}, 351.988180, 0.000030, 0.080000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 2, 0, 0}, 346.480270, 0.000010, 0.039000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -4, 1, 0}, 244.139120, 0.000020, 0.028000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -4, 2, 0}, 269.654400, 0.000010, 0.046000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, -1, 0}, 128.307630, 0.000050, 0.027000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 0, 0}, 193.449750, 0.000280, 0.042000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 1, 0}, 244.372350, 0.000780, 0.095000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 2, 0}, 253.996870, 0.000060, 0.360000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, -2, 0}, 97.684470, 0.000060, 0.039000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, -1, 0}, 112.556070, 0.000420, 0.082000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 0, 0}, 200.609980, 0.000680, 0.999000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 1, 0}, 256.234950, 0.000370, 0.070000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 2, 0}, 259.546500, 0.000030, 0.036000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 1, 0, -1}, 266.230980, 0.000040, 19.000000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 1, 0, 1}, 86.299260, 0.000050, 0.037000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 2, -3, 0}, 343.748280, 0.000010, 0.071000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 2, -2, 0}, 215.126220, 0.000010, 1.294000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 2, -1, 0}, 86.056160, 0.000070, 0.080000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 2, 0, 0}, 181.739040, 0.000030, 0.039000},
	{{0, 0, 1, 0, -2, 6, 0, 0, 1, 0, -1}, 90.458640, 0.000030, 53.519000},
	{{0, 0, 1, 0, -2, 7, 0, 0, 1, 0, -1}, 48.458300, 0.000010, 65.520000},
	{{0, 0, 1, 0, -1, -5, 0, 0, -2, 0, 0}, 318.207290, 0.000040, 0.042000},
	{{0, 0, 1, 0, -1, -5, 0, 0, -2, 1, 0}, 318.207630, 0.000050, 0.093000},
	{{0, 0, 1, 0, -1, -5, 0, 0, 0, -1, 0}, 314.506090, 0.000040, 0.080000},
	{{0, 0, 1, 0, -1, -5, 0, 0, 0, 0, 0}, 310.643600, 0.000190, 1.341000},
	{{0, 0, 1, 0, -1, -5, 0, 0, 0, 1, 0}, 314.506090, 0.000040, 0.071000},
	{{0, 0, 1, 0, -1, -5, 0, 0, 2, 0, 0}, 319.241700, 0.000010, 0.039000},
	{{0, 0, 1, 0, -1, -3, 0, 0, 0, 0, 0}, 338.799030, 0.000010, 1.229000},
	{{0, 0, 1, 0, -1, -2, 0, 0, -2, 0, 0}, 107.019420, 0.000030, 0.042000},
	{{0, 0, 1, 0, -1, -2, 0, 0, -2, 1, 0}, 107.019440, 0.000020, 0.094000},
	{{0, 0, 1, 0, -1, -2, 0, 0, 0, -1, 0}, 107.019610, 0.000010, 0.081000},
	{{0, 0, 1, 0, -1, -2, 0, 0, 0, 0, 0}, 106.344980, 0.000120, 1.180000},
	{{0, 0, 1, 0, -1, -2, 0, 0, 0, 1, 0}, 107.019610, 0.000010, 0.071000},
	{{0, 0, 1, 0, -1, -1, 0, 0, -2, 0, 0}, 310.206860, 0.000010, 0.042000},
	{{0, 0, 1, 0, -1, -1, 0, 0, 0, 0, 0}, 307.277790, 0.000050, 1.134000},
	{{0, 0, 1, 0, -1, -1, 0, 0, 1, 0, -1}, 293.883070, 0.000010, 5.813000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, -1, 0}, 1.895890, 0.000010, 0.012000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 0, 0}, 0.491900, 0.000030, 0.014000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 1, 0}, 1.354640, 0.000080, 0.017000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 2, 0}, 6.795500, 0.000090, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 3, 0}, 1.729020, 0.000040, 0.030000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -5, 1, 0}, 2.102600, 0.000010, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -2, 0}, 1.067740, 0.000050, 0.013000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -1, 0}, 359.988010, 0.000280, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -1, 2}, 1.768350, 0.000010, 0.029000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 0, 0}, 2.846470, 0.001880, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 0, 2}, 1.782340, 0.000050, 0.046000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 1, -2}, 181.698440, 0.000020, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 1, 0}, 2.423160, 0.004430, 0.028000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 1, 2}, 2.139080, 0.000020, 0.118000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 2, -2}, 181.669130, 0.000010, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 2, 0}, 2.189600, 0.002820, 0.045000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 3, 0}, 1.642970, 0.000070, 0.114000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, -2, 0}, 1.839380, 0.000010, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, -1, 0}, 1.675040, 0.000040, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, 0, 0}, 1.480380, 0.000150, 0.028000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, 1, 0}, 183.900710, 0.000090, 0.044000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, 2, 0}, 182.249840, 0.000080, 0.103000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -3, 0}, 1.632240, 0.000110, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -2, 0}, 1.599540, 0.001190, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -2, 2}, 181.818980, 0.000020, 0.043000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -1, -2}, 181.651240, 0.000070, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -1, 0}, 1.965100, 0.014550, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -1, 2}, 181.609440, 0.000350, 0.098000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, -2}, 181.666370, 0.000400, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 0}, 1.802800, 0.164970, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 2}, 1.802140, 0.002280, 0.331000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, -2}, 181.715580, 0.000450, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, 0}, 1.743330, 0.211180, 0.095000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, 2}, 181.639800, 0.000060, 0.061000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, -2}, 181.540350, 0.000030, 0.041000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, 0}, 1.709050, 0.008890, 0.372000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, 2}, 181.734320, 0.000050, 0.034000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 3, 0}, 2.185500, 0.000530, 0.063000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 4, 0}, 2.210860, 0.000040, 0.034000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -2, 0}, 0.652030, 0.000080, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -1, 0}, 0.560290, 0.000800, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -1, 1}, 277.892670, 0.000040, 0.089000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, -2}, 180.710180, 0.000030, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, -1}, 274.616020, 0.000010, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, 0}, 0.621110, 0.009780, 0.087000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, 1}, 96.664150, 0.000080, 0.508000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 1, -1}, 275.641690, 0.000030, 0.086000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 1, 0}, 0.518380, 0.000740, 0.555000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 1, 1}, 93.048320, 0.000010, 0.066000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 2, 0}, 0.733640, 0.000080, 0.066000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -4, 0}, 0.968310, 0.000040, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -3, 0}, 0.892730, 0.000670, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -2, -2}, 181.164830, 0.000060, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -2, 0}, 1.256950, 0.009430, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -2, 2}, 181.751470, 0.000030, 0.801000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, -2}, 181.354100, 0.000310, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, 0}, 1.235820, 0.143470, 0.081000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, 2}, 358.136640, 0.000060, 0.069000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, -2}, 183.266440, 0.000080, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0}, 1.228900, 0.638800, 1.092000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 2}, 181.204100, 0.000320, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, -2}, 348.262080, 0.000040, 0.079000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, 0}, 1.111680, 0.109930, 0.071000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, 2}, 181.161540, 0.000270, 0.024000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 2, -2}, 183.120050, 0.000020, 1.718000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 2, 0}, 1.036370, 0.007660, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 2, 2}, 180.938950, 0.000040, 0.018000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 3, 0}, 1.112850, 0.000550, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 4, 0}, 1.064010, 0.000040, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -3, 0}, 181.137640, 0.000050, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -2, -1}, 97.007400, 0.000010, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -2, 0}, 180.862750, 0.000490, 0.076000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -2, 1}, 277.389040, 0.000010, 5.117000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, -2}, 181.066670, 0.000030, 0.037000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, -1}, 96.642870, 0.000210, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, 0}, 0.697360, 0.023380, 34.860000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, 1}, 96.675090, 0.000240, 0.074000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, 2}, 181.066670, 0.000030, 0.037000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, -2}, 180.734330, 0.000110, 0.074000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, -1}, 96.790660, 0.001600, 7.243000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 0}, 180.709130, 0.067110, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 1}, 276.849400, 0.000350, 0.037000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 2}, 0.710190, 0.000140, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, -1}, 96.642870, 0.000210, 0.076000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, 0}, 180.711410, 0.004600, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, 1}, 276.810410, 0.000040, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, 2}, 0.710190, 0.000020, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 2, -2}, 180.461070, 0.000010, 0.077000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 2, 0}, 180.708310, 0.000330, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 3, 0}, 180.710190, 0.000020, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -4, 0}, 182.379150, 0.000010, 0.037000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -3, 0}, 182.167740, 0.000080, 0.071000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -2, 0}, 179.691450, 0.000830, 1.165000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -1, -2}, 1.629340, 0.000030, 0.069000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -1, 0}, 0.579200, 0.051080, 0.081000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -1, 2}, 180.816800, 0.000110, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, -2}, 0.311180, 0.001620, 0.839000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, 0}, 0.433960, 0.031110, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, 2}, 181.516280, 0.000050, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 1, -2}, 179.202900, 0.000080, 0.083000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 1, 0}, 0.427240, 0.003460, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 2, 0}, 1.428080, 0.000310, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 3, 0}, 0.655520, 0.000030, 0.015000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -3, 0}, 0.737340, 0.000030, 0.573000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -2, 0}, 0.744240, 0.000610, 0.087000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -1, 0}, 180.691060, 0.000660, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 0, 0}, 180.745400, 0.000600, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 1, 0}, 180.710150, 0.000090, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -3, 0}, 181.429440, 0.000020, 0.094000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -2, 0}, 1.315600, 0.000690, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -1, -2}, 0.221720, 0.000030, 0.097000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -1, 0}, 359.771090, 0.000930, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 0, -2}, 0.283650, 0.000020, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 0, 0}, 1.644090, 0.000370, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 1, 0}, 0.632620, 0.000080, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 5, -1, 0}, 180.709290, 0.000020, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 6, -2, 0}, 0.812010, 0.000020, 0.021000},
	{{0, 0, 1, 0, -1, 1, 0, 0, -2, 0, 0}, 225.458220, 0.000040, 0.042000},
	{{0, 0, 1, 0, -1, 1, 0, 0, -2, 1, 0}, 225.458220, 0.000040, 0.095000},
	{{0, 0, 1, 0, -1, 1, 0, 0, 0, -1, 0}, 219.577810, 0.000010, 0.081000},
	{{0, 0, 1, 0, -1, 1, 0, 0, 0, 0, 0}, 206.653930, 0.000090, 1.053000},
	{{0, 0, 1, 0, -1, 1, 0, 0, 0, 1, 0}, 219.577810, 0.000010, 0.070000},
	{{0, 0, 1, 0, -1, 1, 0, 0, 1, 0, -1}, 278.337010, 0.000010, 9.604000},
	{{0, 0, 1, 0, -1, 2, 0, 0, -2, 0, 0}, 49.887170, 0.000030, 0.042000},
	{{0, 0, 1, 0, -1, 2, 0, 0, -2, 1, 0}, 48.164150, 0.000040, 0.095000},
	{{0, 0, 1, 0, -1, 2, 0, 0, 0, -1, 0}, 36.616540, 0.000010, 0.081000},
	{{0, 0, 1, 0, -1, 2, 0, 0, 0, 0, 0}, 14.774250, 0.000070, 1.017000},
	{{0, 0, 1, 0, -1, 2, 0, 0, 0, 1, 0}, 36.616540, 0.000010, 0.070000},
	{{0, 0, 1, 0, -1, 3, 0, 0, 0, 0, 0}, 189.440460, 0.000020, 0.983000},
	{{0, 0, 1, 0, -1, 4, 0, 0, 1, 0, -1}, 43.794170, 0.000030, 439.132000},
	{{0, 0, 1, 0, -1, 5, 0, 0, -2, 0, 0}, 234.934380, 0.000010, 0.042000},
	{{0, 0, 1, 0, -1, 5, 0, 0, 0, 0, 0}, 222.793490, 0.000020, 0.921000},
	{{0, 0, 1, 0, -1, 5, 0, 0, 1, 0, -1}, 105.768990, 0.000040, 31.575000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, -1, 0}, 314.848970, 0.000030, 0.027000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, 0, 0}, 314.552120, 0.000180, 0.042000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, 1, 0}, 314.865320, 0.000250, 0.094000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, -1, 0}, 311.708870, 0.000230, 0.080000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, 0, 0}, 307.675620, 0.000930, 1.204000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, 1, 0}, 310.486770, 0.000170, 0.071000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, 2, 0}, 312.430340, 0.000010, 0.037000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 1, -1, 1}, 109.268870, 0.000020, 0.075000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 1, 0, -1}, 109.148540, 0.000070, 4.474000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 1, 0, 0}, 309.967760, 0.000030, 0.076000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 2, -3, 0}, 198.397260, 0.000010, 0.070000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 2, -1, 0}, 298.497000, 0.000110, 0.081000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 2, 0, 0}, 313.309020, 0.000040, 0.039000},
	{{0, 0, 1, 0, 0, -4, 0, 0, -2, 0, 0}, 108.780120, 0.000040, 0.042000},
	{{0, 0, 1, 0, 0, -4, 0, 0, -2, 1, 0}, 109.044540, 0.000050, 0.094000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 0, -1, 0}, 110.457120, 0.000040, 0.081000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 0, 0, 0}, 113.275430, 0.000190, 1.157000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 0, 1, 0}, 110.457120, 0.000040, 0.071000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 1, -1, 0}, 110.385510, 0.000010, 43.858000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 1, 0, -1}, 299.237790, 0.000030, 5.276000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 2, -1, 0}, 108.766290, 0.000020, 0.081000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -4, 1, 0}, 16.832840, 0.000010, 0.028000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, -1, 0}, 16.685560, 0.000040, 0.027000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 0, 0}, 16.509390, 0.000380, 0.042000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 1, 0}, 17.035480, 0.000460, 0.094000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 2, 0}, 17.045710, 0.000010, 0.374000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -1, 0, 0}, 17.014660, 0.000080, 0.087000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -1, 0, 1}, 206.547760, 0.000040, 0.512000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, -2, 0}, 16.928960, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, -1, 0}, 16.840040, 0.000370, 0.081000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 0, 0}, 16.547440, 0.001720, 1.113000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 1, 0}, 16.767870, 0.000270, 0.071000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 2, 0}, 16.931900, 0.000020, 0.036000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, -1, -1}, 206.530660, 0.000050, 0.075000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, -1, 0}, 16.974030, 0.000450, 89.713000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, -1, 1}, 206.530710, 0.000070, 0.074000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, -1}, 206.521040, 0.000370, 6.426000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, 0}, 197.017380, 0.000370, 0.075000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, 1}, 26.522780, 0.000080, 0.037000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 1, -1}, 206.530660, 0.000050, 0.076000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 1, 0}, 197.014670, 0.000030, 0.038000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 2, -1, 0}, 16.794340, 0.000130, 0.081000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 2, 0, 0}, 16.944540, 0.000070, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -4, 0, 0}, 285.950260, 0.000030, 0.021000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -4, 1, 0}, 285.822110, 0.000070, 0.028000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -4, 2, 0}, 285.946790, 0.000050, 0.045000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, -2, 0}, 286.005820, 0.000030, 0.020000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, -1, 0}, 285.681580, 0.000210, 0.027000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 0, 0}, 285.716650, 0.002450, 0.042000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 0, 2}, 286.277240, 0.000040, 0.329000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 1, 0}, 285.986620, 0.003120, 0.095000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 2, 0}, 286.408250, 0.000140, 0.370000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, -1, 1}, 293.922210, 0.000050, 0.089000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 0, -1}, 293.921920, 0.000020, 0.040000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 0, 0}, 286.300100, 0.000080, 0.087000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 0, 1}, 113.922090, 0.000180, 0.504000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 1, -1}, 293.922090, 0.000060, 0.086000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 1, 1}, 113.922180, 0.000040, 0.066000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, -2, 0}, 285.614710, 0.000170, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, -1, 0}, 285.656970, 0.002450, 0.081000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 0, 0}, 285.556000, 0.010960, 1.073000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 1, 0}, 285.692710, 0.001860, 0.070000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 2, 0}, 285.633240, 0.000120, 0.036000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 3, 0}, 105.976840, 0.000010, 0.025000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -2, -1}, 113.922170, 0.000030, 0.038000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -2, 0}, 110.516660, 0.000010, 0.076000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -2, 1}, 293.922310, 0.000020, 4.720000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, -1}, 113.922170, 0.000390, 0.075000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, 0}, 285.929790, 0.000100, 22.176000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, 1}, 113.922190, 0.000380, 0.074000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, -1}, 113.922220, 0.003070, 8.220000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 0}, 106.272910, 0.000660, 0.075000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 1}, 293.922220, 0.000730, 0.037000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 1, -1}, 113.922170, 0.000390, 0.076000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 1, 0}, 106.272930, 0.000040, 0.038000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 1, 1}, 293.922210, 0.000080, 0.025000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 2, -1}, 113.922170, 0.000030, 0.038000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, -2, 0}, 107.465500, 0.000020, 1.188000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, -1, 0}, 286.691280, 0.000620, 0.081000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, 0, -2}, 286.406760, 0.000020, 0.851000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, 0, 0}, 286.250590, 0.000420, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, 1, 0}, 286.073650, 0.000060, 0.026000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 3, -1, -1}, 293.922070, 0.000030, 0.088000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 3, -1, 1}, 293.922210, 0.000020, 0.026000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 4, -2, 0}, 283.116320, 0.000010, 0.042000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 4, -1, 0}, 286.499690, 0.000010, 0.027000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, -2, 0}, 0.722160, 0.000010, 0.013000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 0, 0}, 0.220810, 0.000120, 0.021000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 1, 0}, 0.669070, 0.000270, 0.028000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 2, 0}, 0.700820, 0.000130, 0.045000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -3, 0, 0}, 0.844420, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, -2, 0}, 0.684890, 0.000090, 0.020000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, -1, 0}, 0.643940, 0.000850, 0.027000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, -1, 2}, 180.697330, 0.000020, 0.098000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 0, -2}, 180.661540, 0.000020, 0.020000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 0, 0}, 0.725060, 0.009590, 0.042000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 0, 2}, 0.712520, 0.000140, 0.325000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 1, 0}, 0.684920, 0.012110, 0.095000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 1, 2}, 180.697330, 0.000020, 0.061000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 2, 0}, 0.755170, 0.000530, 0.365000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 3, 0}, 0.811290, 0.000030, 0.063000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -1, -1, 0}, 0.296480, 0.000020, 0.041000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -1, 0, 0}, 358.506480, 0.000040, 0.088000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -1, 0, 1}, 169.361600, 0.000030, 0.495000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -3, 0}, 0.447990, 0.000030, 0.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -2, 0}, 0.484170, 0.000580, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -1, -2}, 180.456160, 0.000030, 0.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -1, 0}, 0.457990, 0.008630, 0.081000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -1, 2}, 0.464610, 0.000010, 0.069000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 0, -2}, 180.526630, 0.000030, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0}, 0.432960, 0.038970, 1.035000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 2}, 180.599610, 0.000020, 0.036000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 1, -2}, 0.464610, 0.000010, 0.079000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 1, 0}, 0.404770, 0.006540, 0.070000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 1, 2}, 180.456160, 0.000030, 0.024000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 2, 0}, 0.410530, 0.000440, 0.036000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 3, 0}, 0.286880, 0.000030, 0.025000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -2, 0}, 181.886570, 0.000020, 0.076000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -1, -1}, 170.106570, 0.000080, 0.075000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -1, 0}, 181.444880, 0.000010, 12.652000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -1, 1}, 170.161040, 0.000060, 0.074000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, -1}, 170.126320, 0.000660, 11.401000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 0}, 180.312630, 0.001540, 0.075000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 1}, 350.123120, 0.000200, 0.037000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 1, -1}, 170.106570, 0.000080, 0.076000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 1, 0}, 180.318360, 0.000110, 0.038000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 1, 1}, 350.123120, 0.000020, 0.025000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, -2, 0}, 179.996010, 0.000110, 1.238000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, -1, 0}, 0.182150, 0.002250, 0.080000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 0, -2}, 0.227880, 0.000090, 0.876000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 0, 0}, 0.144370, 0.001640, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 1, 0}, 0.410380, 0.000200, 0.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 3, -1, 0}, 180.296480, 0.000020, 0.040000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 4, -2, 0}, 0.271180, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 4, -1, 0}, 0.443690, 0.000030, 0.027000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 4, 0, 0}, 0.147000, 0.000020, 0.020000},
	{{0, 0, 1, 0, 0, 0, -3, 0, -2, 0, 0}, 92.895540, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, 0, -3, 0, 0, 0, 0}, 92.951490, 0.000070, 1.037000},
	{{0, 0, 1, 0, 0, 0, -3, 2, 0, 0, 0}, 100.705230, 0.000010, 1.024000},
	{{0, 0, 1, 0, 0, 0, -2, 0, -2, -1, 0}, 276.998750, 0.000020, 0.027000},
	{{0, 0, 1, 0, 0, 0, -2, 0, -2, 0, 0}, 276.998520, 0.000130, 0.042000},
	{{0, 0, 1, 0, 0, 0, -2, 0, -2, 1, 0}, 276.996290, 0.000180, 0.095000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 0, -1, 0}, 277.013340, 0.000150, 0.081000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 0, 0, 0}, 276.999930, 0.000680, 1.024000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 0, 1, 0}, 277.019240, 0.000110, 0.070000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 1, 0, -1}, 74.074920, 0.000040, 12.892000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 1, 0, 1}, 254.075090, 0.000020, 0.037000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 2, -1, 0}, 276.183120, 0.000020, 0.080000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 2, 0, 0}, 276.826180, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, 0, -1, -2, 0, 0, 0}, 273.086700, 0.000010, 1.025000},
	{{0, 0, 1, 0, 0, 0, -1, 0, -2, -1, 0}, 353.644410, 0.000040, 0.027000},
	{{0, 0, 1, 0, 0, 0, -1, 0, -2, 0, 0}, 353.727370, 0.000230, 0.042000},
	{{0, 0, 1, 0, 0, 0, -1, 0, -2, 1, 0}, 353.572970, 0.000310, 0.095000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 0, -1, 0}, 354.944610, 0.000250, 0.082000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0}, 356.071180, 0.001040, 1.012000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 0, 1, 0}, 355.466050, 0.000170, 0.070000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 0, 2, 0}, 354.708830, 0.000010, 0.036000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 1, 0, 0}, 176.643630, 0.000020, 0.075000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 2, -1, 0}, 7.271700, 0.000040, 0.080000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 2, 0, 0}, 358.448110, 0.000040, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, -2, -2, 0, 0}, 283.594470, 0.000090, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -2, -2, 1, 0}, 283.594960, 0.000120, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, -1, 0}, 283.586670, 0.000100, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 0, 0}, 283.573150, 0.000420, 1.012000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 1, 0}, 283.585740, 0.000090, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 1, 0, -1}, 131.785140, 0.000060, 15.174000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 1, 0, 1}, 311.785130, 0.000030, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 2, -1, 0}, 283.531880, 0.000010, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 2, 0, 0}, 283.568640, 0.000010, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -2, 0, 0}, 1.699660, 0.000090, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -2, 1, 0}, 1.716130, 0.000110, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 0}, 1.378500, 0.000090, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0}, 0.879070, 0.000410, 1.006000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, 0}, 1.378500, 0.000090, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 2, -1, 0}, 358.202650, 0.000010, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 2, 0, 0}, 0.348160, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 0, 0}, 72.280170, 0.000120, 0.021000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 1, 0}, 66.933950, 0.000120, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 2, 0}, 68.063770, 0.000070, 0.046000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -2, 0}, 60.297670, 0.000030, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -1, 0}, 67.945370, 0.000300, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 64.630660, 0.003090, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 1}, 103.346680, 0.000020, 0.097000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 2}, 61.970760, 0.000040, 0.322000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 63.155790, 0.003900, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 60.565400, 0.000190, 0.360000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 3, 0}, 89.515590, 0.000040, 0.062000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -2, 1}, 112.421270, 0.000010, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -1, -1}, 95.133710, 0.000020, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -1, 0}, 84.882270, 0.000020, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -1, 1}, 278.392870, 0.000100, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, -1}, 91.718700, 0.000220, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 108.921320, 0.000040, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 1}, 279.632890, 0.001120, 0.487000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, -1}, 91.642970, 0.000440, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, 1}, 287.430490, 0.000210, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 2, -1}, 88.904180, 0.000030, 0.581000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 2, 1}, 312.277070, 0.000030, 0.035000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -3, 0}, 91.642310, 0.000010, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -2, 0}, 90.348740, 0.000250, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 90.297810, 0.003550, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 281.288590, 0.000100, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 95.383940, 0.016990, 1.000000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 103.351810, 0.000080, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, -1}, 283.351350, 0.000010, 1.200000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 88.409240, 0.002670, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 89.853060, 0.000190, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -2, -1}, 276.127010, 0.000070, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, -1}, 274.427300, 0.000910, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 0}, 262.194150, 0.000080, 8.850000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 1}, 288.201320, 0.000850, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 298.979350, 0.004560, 18.600000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 264.995360, 0.001160, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1}, 112.295960, 0.006250, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, -1}, 274.148070, 0.001000, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0}, 264.803050, 0.000080, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 1}, 111.925070, 0.000700, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 2, -1}, 271.437340, 0.000060, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 2, 1}, 109.287900, 0.000070, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 293.732610, 0.000020, 0.071000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 303.054330, 0.000200, 1.292000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 16.061550, 0.002420, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -2}, 52.616150, 0.000040, 0.903000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -1}, 99.837470, 0.000060, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 45.434830, 0.000930, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 1, 0}, 57.734790, 0.000120, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -3, -1}, 77.063070, 0.000020, 0.066000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -2, -1}, 85.729300, 0.000010, 0.547000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -2, 1}, 289.297150, 0.000020, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -1, -1}, 96.602470, 0.000220, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -1, 0}, 264.882270, 0.000020, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -1, 1}, 111.961230, 0.000140, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, 0, -1}, 111.437770, 0.000210, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 1}, 111.961220, 0.000090, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, 1, -1}, 111.963950, 0.000030, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 4, -2, 0}, 35.668160, 0.000040, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 4, -1, 0}, 5.708280, 0.000030, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 4, 0, 0}, 354.151500, 0.000020, 0.020000},
	{{0, 0, 1, 0, 0, 0, 1, -2, -2, 0, 0}, 163.791360, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, 0, 1, -2, 0, 0, 0}, 176.834450, 0.000060, 1.000000},
	{{0, 0, 1, 0, 0, 0, 1, 0, -2, 0, 0}, 83.748990, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 0, 1, 0, 0, -1, 0}, 84.425060, 0.000010, 0.082000},
	{{0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0}, 86.976440, 0.000040, 0.988000},
	{{0, 0, 1, 0, 0, 0, 1, 0, 0, 1, 0}, 84.425060, 0.000010, 0.070000},
	{{0, 0, 1, 0, 0, 1, -3, 0, -2, 0, 0}, 24.731290, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, 1, -3, 0, 0, 0, 0}, 23.313550, 0.000030, 1.002000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -4, 1, 0}, 165.687700, 0.000010, 0.028000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, -1, 0}, 165.720630, 0.000040, 0.027000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, 0, 0}, 165.361760, 0.000440, 0.042000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, 1, 0}, 166.624760, 0.000470, 0.096000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, 2, 0}, 165.653090, 0.000030, 0.356000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 0, -1}, 334.357540, 0.000040, 0.040000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 0, 1}, 334.905040, 0.000040, 0.479000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 1, -1}, 154.072840, 0.000100, 0.087000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 2, -1}, 154.144830, 0.000010, 0.570000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 0, -1, 0}, 164.605350, 0.000220, 0.082000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0}, 167.081400, 0.000660, 0.967000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 0}, 171.442690, 0.000060, 0.070000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -2, -1}, 334.181740, 0.000070, 0.038000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -1, -1}, 334.181740, 0.000990, 0.075000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -1, 1}, 334.298320, 0.000020, 0.074000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 0, -1}, 334.276320, 0.005070, 50.462000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 1}, 334.188060, 0.000570, 0.037000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 1, -1}, 334.181740, 0.000990, 0.076000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 1, 1}, 334.189590, 0.000060, 0.025000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 2, -1}, 334.181740, 0.000070, 0.038000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 2, -1, 0}, 348.999770, 0.000020, 0.080000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 2, 0, 0}, 348.371320, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 3, -2, -1}, 154.144830, 0.000010, 0.557000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 3, -1, -1}, 154.044240, 0.000070, 0.087000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 3, 0, -1}, 334.241350, 0.000080, 0.040000},
	{{0, 0, 1, 0, 0, 2, 0, 0, -2, 0, 0}, 63.329970, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 2, 0, 0, -2, 1, 0}, 63.412850, 0.000020, 0.096000},
	{{0, 0, 1, 0, 0, 2, 0, 0, -1, 0, -1}, 236.290920, 0.000010, 0.040000},
	{{0, 0, 1, 0, 0, 2, 0, 0, -1, 1, -1}, 57.452820, 0.000010, 0.087000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 0, 0, 0}, 66.095020, 0.000040, 0.936000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, -1, -1}, 236.729330, 0.000170, 0.076000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 0, -1}, 236.290920, 0.000950, 70.769000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 0, 1}, 55.590230, 0.000030, 0.037000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 1, -1}, 236.729330, 0.000170, 0.075000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 3, -1, -1}, 57.452820, 0.000010, 0.087000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 3, 0, -1}, 236.290920, 0.000010, 0.040000},
	{{0, 0, 1, 0, 0, 3, 0, 0, 1, 0, -1}, 139.652310, 0.000010, 20.799000},
	{{0, 0, 1, 0, 1, -6, 3, 0, 0, 0, 0}, 192.392730, 0.000020, 1.091000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -4, 1, 0}, 11.668010, 0.000020, 0.028000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, -1, 0}, 11.693930, 0.000050, 0.027000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 0, 0}, 11.705270, 0.000450, 0.042000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 1, 0}, 11.621280, 0.000610, 0.095000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 2, 0}, 11.678160, 0.000020, 0.372000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -1, 0, 0}, 11.207610, 0.000040, 0.087000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, -2, 0}, 11.931440, 0.000020, 0.039000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, -1, 0}, 11.830280, 0.000410, 0.081000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 0, 0}, 11.178670, 0.001820, 1.093000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 1, 0}, 11.745290, 0.000290, 0.071000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 2, 0}, 11.960650, 0.000020, 0.036000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 1, -1, 0}, 10.915980, 0.000070, 36.292000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 1, 0, 0}, 191.207630, 0.000190, 0.075000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 2, -3, 0}, 189.789910, 0.000010, 0.071000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 2, -1, 0}, 8.787020, 0.000120, 0.081000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 2, 0, 0}, 10.383190, 0.000070, 0.039000},
	{{0, 0, 1, 0, 1, -4, 0, 0, -2, 0, 0}, 239.609960, 0.000020, 0.042000},
	{{0, 0, 1, 0, 1, -4, 0, 0, 0, 0, 0}, 239.605910, 0.000030, 1.054000},
	{{0, 0, 1, 0, 1, -3, 0, 0, -2, -1, 0}, 308.900790, 0.000020, 0.027000},
	{{0, 0, 1, 0, 1, -3, 0, 0, -2, 0, 0}, 308.900790, 0.000090, 0.042000},
	{{0, 0, 1, 0, 1, -3, 0, 0, -2, 1, 0}, 308.907050, 0.000120, 0.095000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 0, -1, 0}, 308.372610, 0.000090, 0.081000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 0, 0, 0}, 306.818220, 0.000400, 1.018000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 0, 1, 0}, 308.152540, 0.000070, 0.070000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 1, 0, -1}, 136.656530, 0.000010, 14.024000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 2, -1, 0}, 298.880180, 0.000010, 0.080000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 2, 0, 0}, 305.228580, 0.000010, 0.039000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -4, 1, 0}, 183.232210, 0.000010, 0.028000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, -1, 0}, 183.212510, 0.000050, 0.027000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, 0, 0}, 183.157740, 0.000450, 0.042000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, 1, 0}, 183.228920, 0.000570, 0.096000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, 2, 0}, 183.266140, 0.000030, 0.358000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, -2, 0}, 182.258350, 0.000020, 0.039000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, -1, 0}, 182.071200, 0.000430, 0.082000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 0, 0}, 181.054940, 0.001860, 0.984000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 1, 0}, 181.596780, 0.000270, 0.070000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 2, 0}, 182.367470, 0.000020, 0.036000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 1, 0, -1}, 79.182080, 0.000020, 26.769000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 1, 0, 0}, 0.571330, 0.000030, 0.075000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 2, -1, 0}, 175.518580, 0.000070, 0.080000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 2, 0, 0}, 179.153150, 0.000060, 0.039000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -2, 0, 0}, 66.363150, 0.000020, 0.042000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -2, 1, 0}, 66.363150, 0.000020, 0.096000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -1, 0, -1}, 273.735230, 0.000060, 0.040000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -1, 1, -1}, 94.199330, 0.000070, 0.087000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -1, 2, -1}, 93.990440, 0.000010, 0.565000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 0, 0, 0}, 34.372380, 0.000040, 0.952000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, -2, -1}, 273.911230, 0.000060, 0.038000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, -1, -1}, 273.911230, 0.000870, 0.075000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 0, -1}, 273.735230, 0.004910, 293.315000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 0, 1}, 274.417680, 0.000050, 0.037000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 1, -1}, 273.911230, 0.000870, 0.075000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 2, -1}, 273.911230, 0.000060, 0.038000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 3, -2, -1}, 93.990440, 0.000010, 0.563000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 3, -1, -1}, 94.199330, 0.000070, 0.087000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 3, 0, -1}, 273.735230, 0.000060, 0.040000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, -1, 0}, 72.577940, 0.000020, 0.016000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, 0, 0}, 246.273040, 0.000090, 0.021000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, 1, 0}, 249.376830, 0.000170, 0.028000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, 2, 0}, 251.658100, 0.000090, 0.046000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -3, 0, 0}, 247.551970, 0.000010, 0.028000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, -2, 0}, 244.678310, 0.000030, 0.020000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, -1, 0}, 241.020630, 0.000350, 0.027000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, 0}, 244.627270, 0.004080, 0.042000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, 2}, 245.484420, 0.000060, 0.313000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 1, 0}, 247.510340, 0.004740, 0.096000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 2, 0}, 251.712720, 0.000220, 0.350000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, -1, -1}, 75.536530, 0.000060, 0.026000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, -1, 1}, 76.898210, 0.000030, 0.090000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 0, -1}, 75.547880, 0.000410, 0.040000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 0, 0}, 59.881380, 0.000030, 0.089000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 0, 1}, 256.093040, 0.000360, 0.468000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 1, -1}, 255.894110, 0.000220, 0.087000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 1, 1}, 254.504880, 0.000020, 0.065000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 2, -1}, 255.376590, 0.000060, 0.554000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, -2, 0}, 226.444370, 0.000140, 0.039000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, -1, 0}, 227.426820, 0.001880, 0.082000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0}, 235.356960, 0.007200, 0.922000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0}, 241.158900, 0.001090, 0.070000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 2, 0}, 245.658000, 0.000050, 0.036000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -3, -1}, 75.627420, 0.000010, 0.025000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -2, -1}, 75.355870, 0.000290, 0.038000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -1, -1}, 75.575870, 0.004260, 0.076000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -1, 0}, 57.703210, 0.000020, 5.069000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -1, 1}, 255.798870, 0.000290, 0.073000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, -3}, 257.537170, 0.000030, 0.037000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, -1}, 75.471820, 0.025400, 32.746000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0}, 38.926340, 0.000070, 0.074000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 1}, 255.515320, 0.001530, 0.037000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 1, -1}, 75.578670, 0.004240, 0.075000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 1, 1}, 255.508520, 0.000160, 0.025000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 2, -1}, 75.577270, 0.000290, 0.038000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 3, -1}, 75.627420, 0.000010, 0.025000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, -2, 0}, 19.851000, 0.000040, 1.450000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, -1, 0}, 60.538650, 0.000170, 0.080000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, 0, 0}, 96.922480, 0.000100, 0.039000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, -2, -1}, 255.627420, 0.000050, 0.574000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, -1, -1}, 255.740480, 0.000330, 0.087000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, -1, 1}, 255.508610, 0.000030, 0.026000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 0, -1}, 75.477180, 0.000230, 0.040000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 0, 1}, 255.508800, 0.000020, 0.019000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 1, -1}, 75.536530, 0.000060, 0.026000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 4, -1, 0}, 67.037280, 0.000010, 0.027000},
	{{0, 0, 1, 0, 1, 5, 0, 0, 0, -1, 0}, 299.544010, 0.000020, 0.083000},
	{{0, 0, 1, 0, 1, 5, 0, 0, 0, 1, 0}, 299.544010, 0.000020, 0.069000},
	{{0, 0, 1, 0, 1, 5, 0, 0, 2, -2, 0}, 299.686450, 0.000010, 1.923000},
	{{0, 0, 1, 0, 1, 5, 0, 0, 2, 0, 0}, 299.686450, 0.000010, 0.038000},
	{{0, 0, 1, 0, 2, -8, 0, 0, 0, 0, 0}, 205.290390, 0.000030, 1.115000},
	{{0, 0, 1, 0, 2, -7, 0, 0, -2, 0, 0}, 113.766450, 0.000040, 0.042000},
	{{0, 0, 1, 0, 2, -7, 0, 0, -2, 1, 0}, 113.766450, 0.000050, 0.095000},
	{{0, 0, 1, 0, 2, -7, 0, 0, 0, -1, 0}, 113.669360, 0.000030, 0.081000},
	{{0, 0, 1, 0, 2, -7, 0, 0, 0, 0, 0}, 113.558640, 0.000160, 1.074000},
	{{0, 0, 1, 0, 2, -7, 0, 0, 0, 1, 0}, 113.669360, 0.000030, 0.070000},
	{{0, 0, 1, 0, 2, -7, 0, 0, 1, 0, -1}, 302.634600, 0.000040, 8.144000},
	{{0, 0, 1, 0, 2, -6, 0, 0, -2, 0, 0}, 191.225420, 0.000080, 0.042000},
	{{0, 0, 1, 0, 2, -6, 0, 0, -2, 1, 0}, 191.230190, 0.000080, 0.095000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, -1, 0}, 191.098350, 0.000060, 0.081000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, 0, 0}, 190.860720, 0.000280, 1.036000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, 1, 0}, 191.098350, 0.000060, 0.070000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 2, -1, 0}, 189.893820, 0.000020, 0.080000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 2, 0, 0}, 190.329940, 0.000020, 0.039000},
	{{0, 0, 1, 0, 2, -6, 3, 0, -2, 0, 0}, 257.327530, 0.000030, 0.042000},
	{{0, 0, 1, 0, 2, -6, 3, 0, -2, 1, 0}, 257.327530, 0.000020, 0.095000},
	{{0, 0, 1, 0, 2, -6, 3, 0, 0, -1, 0}, 257.327530, 0.000010, 0.082000},
	{{0, 0, 1, 0, 2, -6, 3, 0, 0, 0, 0}, 255.739600, 0.000090, 0.999000},
	{{0, 0, 1, 0, 2, -6, 3, 0, 0, 1, 0}, 257.327530, 0.000010, 0.070000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, -1, 0}, 67.015600, 0.000010, 0.016000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 0, 0}, 65.533010, 0.000050, 0.021000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 1, 0}, 66.527060, 0.000140, 0.028000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 2, 0}, 66.957990, 0.000080, 0.046000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, -2, 0}, 66.930710, 0.000040, 0.020000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, -1, 0}, 67.265640, 0.000320, 0.027000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, -2}, 246.820260, 0.000010, 0.020000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, 0}, 67.171100, 0.004230, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, 2}, 67.085340, 0.000060, 0.322000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 1, 0}, 66.729350, 0.005860, 0.095000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 2, 0}, 66.577090, 0.000290, 0.361000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 3, 0}, 67.222250, 0.000020, 0.062000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -1, -1, 1}, 58.999110, 0.000020, 0.089000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -1, 0, 0}, 255.302910, 0.000010, 0.088000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -1, 0, 1}, 239.044330, 0.000030, 0.487000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -3, 0}, 65.685120, 0.000010, 0.026000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -2, 0}, 66.660600, 0.000190, 0.039000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -1, 0}, 65.897320, 0.003310, 0.082000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 0, 0}, 65.649390, 0.016960, 1.001000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 1, 0}, 65.390640, 0.003130, 0.070000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 2, 0}, 64.963120, 0.000220, 0.036000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, -1, -1}, 239.055260, 0.000010, 0.075000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, -1, 0}, 246.605830, 0.000040, 8.940000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, -1, 1}, 239.053420, 0.000080, 0.074000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, -1}, 239.056180, 0.000700, 18.216000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, 0}, 245.308440, 0.000460, 0.075000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, 1}, 59.059280, 0.000640, 0.037000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 1, -1}, 239.055260, 0.000010, 0.076000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 1, 0}, 245.351940, 0.000030, 0.038000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 1, 1}, 59.059360, 0.000070, 0.025000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, -2, 0}, 259.236960, 0.000050, 1.290000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, -1, 0}, 65.187150, 0.000630, 0.080000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 0, -2}, 64.637060, 0.000040, 0.902000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 0, 0}, 62.225150, 0.000650, 0.039000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 1, 0}, 64.596150, 0.000100, 0.026000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 3, 0, -1}, 59.060880, 0.000020, 0.041000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 4, -2, 0}, 78.000110, 0.000010, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 4, -1, 0}, 64.471370, 0.000020, 0.027000},
	{{0, 0, 1, 0, 2, -4, 0, 0, -2, 0, 0}, 283.386470, 0.000020, 0.042000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 0, 0, 0}, 295.939490, 0.000100, 0.968000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, -1, -1}, 322.384080, 0.000020, 0.075000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, 0, -1}, 323.172350, 0.000130, 47.735000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, 0, 1}, 323.192130, 0.000020, 0.037000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, 1, -1}, 322.384080, 0.000020, 0.076000},
	{{0, 0, 1, 0, 2, -3, 0, 0, -2, 0, 0}, 183.775140, 0.000040, 0.042000},
	{{0, 0, 1, 0, 2, -3, 0, 0, -2, 1, 0}, 183.775140, 0.000040, 0.096000},
	{{0, 0, 1, 0, 2, -3, 0, 0, 0, -1, 0}, 183.775140, 0.000010, 0.082000},
	{{0, 0, 1, 0, 2, -3, 0, 0, 0, 0, 0}, 175.387630, 0.000090, 0.937000},
	{{0, 0, 1, 0, 2, -3, 0, 0, 0, 1, 0}, 183.775140, 0.000010, 0.070000},
	{{0, 0, 1, 0, 2, -3, 0, 0, 1, -1, -1}, 30.020940, 0.000030, 0.076000},
	{{0, 0, 1, 0, 2, -3, 0, 0, 1, 0, -1}, 30.290320, 0.000180, 76.932000},
	{{0, 0, 1, 0, 2, -3, 0, 0, 1, 1, -1}, 30.020940, 0.000030, 0.075000},
	{{0, 0, 1, 0, 2, -2, 0, 0, -2, 0, 0}, 240.323910, 0.000050, 0.042000},
	{{0, 0, 1, 0, 2, -2, 0, 0, -2, 1, 0}, 240.323910, 0.000060, 0.096000},
	{{0, 0, 1, 0, 2, -2, 0, 0, 0, -1, 0}, 235.668310, 0.000020, 0.082000},
	{{0, 0, 1, 0, 2, -2, 0, 0, 0, 0, 0}, 227.605870, 0.000090, 0.909000},
	{{0, 0, 1, 0, 2, -2, 0, 0, 0, 1, 0}, 235.668310, 0.000020, 0.070000},
	{{0, 0, 1, 0, 2, -2, 0, 0, 1, -1, -1}, 93.618380, 0.000020, 0.076000},
	{{0, 0, 1, 0, 2, -2, 0, 0, 1, 0, -1}, 95.389290, 0.000160, 21.301000},
	{{0, 0, 1, 0, 2, -2, 0, 0, 1, 1, -1}, 93.618380, 0.000020, 0.075000},
	{{0, 0, 1, 0, 2, 0, 0, 0, -2, -1, 0}, 248.300680, 0.000020, 0.027000},
	{{0, 0, 1, 0, 2, 0, 0, 0, -2, 0, 0}, 247.040350, 0.000100, 0.042000},
	{{0, 0, 1, 0, 2, 0, 0, 0, -2, 1, 0}, 257.947370, 0.000100, 0.097000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 0, -1, 0}, 229.803460, 0.000100, 0.083000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 0}, 229.898700, 0.000220, 0.856000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 0, 1, 0}, 232.387440, 0.000030, 0.069000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 1, -1, -1}, 75.795160, 0.000010, 0.076000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 1, 0, -1}, 81.426250, 0.000090, 8.708000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 1, 1, -1}, 75.795160, 0.000010, 0.075000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 2, -3, 0}, 213.300600, 0.000010, 0.072000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 2, -1, 0}, 42.224620, 0.000020, 0.079000},
	{{0, 0, 1, 0, 2, 5, 0, 0, 2, -2, 0}, 110.160340, 0.000010, 2.295000},
	{{0, 0, 1, 0, 2, 5, 0, 0, 2, 0, 0}, 110.160340, 0.000010, 0.038000},
	{{0, 0, 1, 0, 3, -10, 0, 0, 0, 0, 0}, 200.930490, 0.000020, 1.095000},
	{{0, 0, 1, 0, 3, -7, 0, 0, -2, 0, 0}, 12.467880, 0.000020, 0.042000},
	{{0, 0, 1, 0, 3, -7, 0, 0, 0, 0, 0}, 10.653710, 0.000040, 0.985000},
	{{0, 0, 1, 0, 3, -5, 0, 0, -2, 0, 0}, 328.930240, 0.000030, 0.042000},
	{{0, 0, 1, 0, 3, -5, 0, 0, -2, 1, 0}, 329.769280, 0.000030, 0.096000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 0, -1, 0}, 324.335590, 0.000010, 0.082000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 0, 0, 0}, 315.408980, 0.000050, 0.923000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 0, 1, 0}, 324.335590, 0.000010, 0.070000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 1, -1, -1}, 170.737230, 0.000030, 0.076000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 1, 0, -1}, 172.014800, 0.000190, 34.006000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 1, 1, -1}, 170.737230, 0.000030, 0.075000},
	{{0, 0, 1, 0, 3, -4, 0, 0, 0, 0, 0}, 355.877050, 0.000020, 0.895000},
	{{0, 0, 1, 0, 4, -10, 0, 0, -2, 0, 0}, 258.140340, 0.000040, 0.042000},
	{{0, 0, 1, 0, 4, -10, 0, 0, -2, 1, 0}, 258.140340, 0.000040, 0.095000},
	{{0, 0, 1, 0, 4, -10, 0, 0, 0, -1, 0}, 258.140340, 0.000020, 0.082000},
	{{0, 0, 1, 0, 4, -10, 0, 0, 0, 0, 0}, 256.500760, 0.000130, 1.002000},
	{{0, 0, 1, 0, 4, -10, 0, 0, 0, 1, 0}, 258.140340, 0.000020, 0.070000},
	{{0, 0, 1, 0, 4, -1, 0, 0, 2, -3, 0}, 306.949000, 0.000010, 0.073000},
	{{0, 0, 1, 0, 4, -1, 0, 0, 2, -1, 0}, 306.949000, 0.000010, 0.078000},
	{{0, 0, 1, 0, 5, -5, 0, 0, 0, -1, 0}, 139.777280, 0.000020, 0.083000},
	{{0, 0, 1, 0, 5, -5, 0, 0, 0, 1, 0}, 139.777280, 0.000020, 0.069000},
	{{0, 0, 1, 0, 5, -5, 0, 0, 2, -2, 0}, 138.957930, 0.000010, 1.915000},
	{{0, 0, 1, 0, 5, -5, 0, 0, 2, 0, 0}, 138.957930, 0.000010, 0.038000},
	{{0, 0, 1, 0, 5, -3, 0, 0, 2, -3, 0}, 68.550960, 0.000010, 0.073000},
	{{0, 0, 1, 0, 5, -3, 0, 0, 2, -1, 0}, 68.550960, 0.000010, 0.078000},
	{{0, 0, 1, 0, 5, -2, 0, 0, 2, -2, 0}, 127.141170, 0.000020, 2.379000},
	{{0, 0, 1, 0, 5, -2, 0, 0, 2, 0, 0}, 127.141170, 0.000020, 0.038000},
	{{0, 0, 1, 0, 6, -5, 0, 0, 2, -2, 0}, 310.393610, 0.000010, 2.284000},
	{{0, 0, 1, 0, 6, -5, 0, 0, 2, 0, 0}, 310.393610, 0.000010, 0.038000},
	{{0, 0, 1, 0, 6, -2, 0, 0, 2, -3, 0}, 117.757500, 0.000010, 0.074000},
	{{0, 0, 1, 0, 6, -2, 0, 0, 2, -1, 0}, 117.757500, 0.000010, 0.077000},
	{{0, 0, 1, 0, 10, -2, 0, 0, 2, -2, 0}, 259.853630, 0.000020, 884.771000},
	{{0, 0, 1, 0, 14, -12, 0, 0, 2, -2, 0}, 262.861940, 0.000020, 881.891000},
	{{0, 0, 1, 1, -2, 0, 0, 0, 2, -3, 0}, 358.155270, 0.000010, 0.073000},
	{{0, 0, 1, 1, -2, 0, 0, 0, 2, -1, 0}, 358.155270, 0.000010, 0.078000},
	{{0, 0, 1, 1, -1, 0, 0, 0, 2, -1, 0}, 26.169570, 0.000020, 0.077000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -2, -1, 0}, 274.128700, 0.000020, 0.027000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -2, 0, 0}, 271.856600, 0.000140, 0.043000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -2, 1, 0}, 278.929240, 0.000120, 0.101000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -1, 0, 1}, 156.992560, 0.000010, 0.387000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, -1, 0}, 252.582940, 0.000150, 0.085000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0}, 246.600470, 0.000530, 0.653000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0}, 256.441330, 0.000090, 0.068000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 1, 0, -1}, 335.074160, 0.000050, 2.092000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -2, 0}, 58.066530, 0.000020, 4.127000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -1, 0}, 61.768010, 0.000280, 0.077000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, 0, 0}, 59.599740, 0.000040, 0.038000},
	{{0, 0, 1, 1, 1, 0, 0, 0, 2, -1, 0}, 274.216650, 0.000020, 0.076000},
	{{0, 0, 1, 1, 2, 0, 0, 0, 2, -2, 0}, 302.508540, 0.000010, 13.564000},
	{{0, 0, 1, 1, 3, 0, 0, 0, 2, -2, 0}, 284.649770, 0.000010, 94.519000},
	{{0, 0, 1, 2, -3, 0, 0, 0, 2, -2, 0}, 59.881520, 0.000020, 27.444000},
	{{0, 0, 1, 2, -3, 0, 0, 0, 2, -1, 0}, 244.521680, 0.000040, 0.075000},
	{{0, 0, 1, 2, -2, 0, 0, 0, 0, 0, 0}, 209.286800, 0.000010, 0.528000},
	{{0, 0, 1, 2, -1, 0, 0, 0, 2, -1, 0}, 240.794570, 0.000020, 0.074000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -2, -1, 0}, 41.419040, 0.000010, 0.028000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -2, 0, 0}, 38.006990, 0.000150, 0.044000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -2, 1, 0}, 42.876700, 0.000100, 0.106000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -1, 0, -1}, 60.785060, 0.000050, 0.042000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -1, 1, -1}, 240.858400, 0.000040, 0.095000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 0, -1, 0}, 51.498930, 0.000030, 0.089000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 0, 1, 0}, 68.967790, 0.000010, 0.065000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, -1, -1}, 60.811420, 0.000070, 0.082000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, 0, -1}, 34.027510, 0.000020, 0.991000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, 1, -1}, 240.811420, 0.000050, 0.070000},
	{{0, 0, 1, 2, 1, 0, 0, 0, 2, 0, -2}, 281.767750, 0.000010, 24.912000},
	{{0, 0, 1, 3, -2, 0, 0, 0, 2, -1, 0}, 249.686740, 0.000020, 0.072000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, -3, 0}, 310.748340, 0.000010, 0.080000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, -1, 0}, 310.748340, 0.000010, 0.071000},
	{{0, 0, 1, 4, -2, 0, 0, 0, 2, -1, 0}, 278.818670, 0.000020, 0.069000},
	{{0, 0, 1, 4, -2, 0, 0, 0, 2, 0, 0}, 99.018940, 0.000020, 0.036000},
	{{0, 0, 1, 4, -1, 0, 0, 0, 2, 0, 0}, 125.417080, 0.000010, 0.036000},
	{{0, 0, 1, 5, -2, 0, 0, 0, 2, -1, 0}, 307.830830, 0.000020, 0.067000},
	{{0, 0, 1, 5, -2, 0, 0, 0, 2, 0, 0}, 308.078220, 0.000010, 0.035000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 1, 0}, 173.572390, 0.000010, 0.073000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 3, 0}, 173.572390, 0.000010, 0.078000},
	{{0, 0, 2, -8, 2, 0, 0, 0, -2, 0, 0}, 51.633150, 0.000020, 0.037000},
	{{0, 0, 2, -8, 3, 0, 0, 0, -2, 1, 0}, 150.663310, 0.000020, 0.074000},
	{{0, 0, 2, -8, 3, 0, 0, 0, -2, 3, 0}, 149.443490, 0.000020, 0.077000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 0, 0, 0}, 132.702900, 0.000240, 0.500000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 0, 1, 0}, 132.500100, 0.000090, 0.089000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, -2, 0}, 132.696290, 0.000020, 0.265000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, -1, 0}, 132.853830, 0.000470, 0.105000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, 0, 0}, 132.636050, 0.000560, 0.044000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, 1, 0}, 132.691050, 0.000060, 0.028000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 4, -1, 0}, 132.688180, 0.000040, 0.029000},
	{{0, 0, 2, -8, 5, 0, 0, 0, -2, 1, 0}, 288.001260, 0.000030, 0.075000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 1, 0}, 107.529210, 0.000010, 0.076000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 2, 0}, 202.419120, 0.000030, 19.147000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 3, 0}, 107.529210, 0.000010, 0.075000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 0, 0, 0}, 222.076170, 0.000020, 0.581000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 1, 1, -1}, 246.780220, 0.000020, 0.095000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 1, 2, -1}, 247.376100, 0.000010, 0.042000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 1, 0}, 55.732760, 0.000030, 0.079000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 3, 0}, 63.481690, 0.000010, 0.072000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -1, 0, 1}, 310.269490, 0.000020, 7.335000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 0, -1, 0}, 334.031540, 0.000010, 0.069000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 0, 0, 0}, 333.332550, 0.000160, 0.840000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 0, 1, 0}, 7.541640, 0.000080, 0.083000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 2, -1, 0}, 16.719170, 0.000150, 0.097000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 2, 0, 0}, 16.211130, 0.000170, 0.042000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 2, 1, 0}, 16.184430, 0.000010, 0.027000},
	{{0, 0, 2, -6, 0, 4, 0, 0, -1, 0, 1}, 310.171190, 0.000040, 1827.649000},
	{{0, 0, 2, -6, 2, 0, 0, 0, 0, -1, 0}, 67.951390, 0.000010, 0.070000},
	{{0, 0, 2, -6, 2, 0, 0, 0, 0, 0, 0}, 73.475960, 0.000070, 0.979000},
	{{0, 0, 2, -6, 2, 0, 0, 0, 0, 1, 0}, 67.951390, 0.000010, 0.082000},
	{{0, 0, 2, -6, 2, 0, 0, 0, 2, -1, 0}, 74.063370, 0.000050, 0.096000},
	{{0, 0, 2, -6, 2, 0, 0, 0, 2, 0, 0}, 73.924570, 0.000050, 0.042000},
	{{0, 0, 2, -6, 3, 0, 0, 0, 0, 0, 0}, 107.448730, 0.000060, 1.067000},
	{{0, 0, 2, -6, 3, 0, 0, 0, 2, 0, 0}, 105.853780, 0.000020, 0.042000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 0, 0}, 245.905240, 0.000030, 0.039000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 1, 0}, 116.312940, 0.000020, 0.082000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 0, 1}, 351.497360, 0.000070, 2.529000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 1, -1}, 171.961090, 0.000080, 0.076000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 2, -1}, 171.768670, 0.000020, 16.174000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, -1, 0}, 269.809670, 0.000180, 0.072000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 0, 0}, 279.162980, 0.001090, 1.519000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 1, 0}, 280.485890, 0.000190, 0.079000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 1, 0, -1}, 353.274290, 0.000030, 0.584000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, -1, 0}, 8.860170, 0.000170, 0.092000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, 0, 0}, 5.159940, 0.000150, 0.042000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, 1, 0}, 2.082730, 0.000010, 0.027000},
	{{0, 0, 2, -5, 3, 0, 0, 0, 0, 0, 0}, 137.742160, 0.000020, 2.466000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 0, 0}, 299.594850, 0.000080, 0.020000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 1, 0}, 302.022840, 0.000200, 0.028000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 2, 0}, 302.991300, 0.000120, 0.043000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -3, 0, 0}, 300.699630, 0.000020, 0.027000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -2, 0}, 297.811880, 0.000090, 0.019000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -1, 0}, 299.892520, 0.000710, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -1, 2}, 121.217140, 0.000010, 0.089000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, -2}, 122.025160, 0.000010, 0.019000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, 0}, 300.820140, 0.006910, 0.040000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, 2}, 300.952590, 0.000170, 0.505000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 1, -2}, 121.865090, 0.000020, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 1, 0}, 302.557530, 0.010240, 0.086000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 2, 0}, 306.850220, 0.000320, 0.607000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 3, 0}, 309.215380, 0.000020, 0.067000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -1, 0, 0}, 120.133500, 0.000160, 0.080000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -1, 0, 1}, 23.368340, 0.000060, 1.079000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -1, 1, 0}, 123.119330, 0.000020, 1.315000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -3, 0}, 297.641780, 0.000080, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -2, 0}, 297.938590, 0.001160, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, -2}, 118.833480, 0.000040, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, 0}, 297.825340, 0.017120, 0.075000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, 2}, 297.747340, 0.000030, 0.074000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, -2}, 123.139150, 0.000040, 0.037000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, 0}, 300.139130, 0.091780, 7.890000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, 1}, 23.325940, 0.000020, 0.075000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, 2}, 123.139150, 0.000040, 0.037000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, -2}, 297.747340, 0.000030, 0.073000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, 0}, 298.040830, 0.017700, 0.076000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, 2}, 118.833480, 0.000040, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 2, 0}, 297.878650, 0.001180, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 3, 0}, 297.597360, 0.000080, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, -1, 0}, 123.749700, 0.000030, 0.986000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, 0, -1}, 24.126890, 0.000070, 0.847000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, 0, 0}, 112.475820, 0.000310, 0.082000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, 1, 0}, 121.807110, 0.000020, 0.039000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -3, 0}, 308.375800, 0.000020, 0.066000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -2, 0}, 305.388740, 0.000450, 0.526000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, 0}, 303.411170, 0.012840, 0.088000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, 2}, 122.569620, 0.000030, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, -2}, 302.512950, 0.000190, 0.448000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, 0}, 302.715440, 0.008740, 0.041000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, 2}, 122.657930, 0.000020, 0.019000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 1, -2}, 122.771070, 0.000010, 0.091000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 1, 0}, 301.634270, 0.000860, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 2, 0}, 301.404100, 0.000090, 0.020000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 3, -1, 0}, 95.308280, 0.000020, 0.042000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 3, 0, 0}, 303.304410, 0.000020, 0.027000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, -2, 0}, 303.453460, 0.000150, 0.044000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, -1, 0}, 302.806300, 0.000260, 0.028000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, 0, 0}, 302.346440, 0.000110, 0.020000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, 1, 0}, 302.685590, 0.000020, 0.016000},
	{{0, 0, 2, -4, 0, 1, 0, 0, 0, 0, 0}, 199.206560, 0.000010, 10.777000},
	{{0, 0, 2, -4, 0, 2, 0, 0, 0, 0, 0}, 0.628210, 0.000060, 16.995000},
	{{0, 0, 2, -4, 1, 0, 0, 0, -2, 0, 0}, 155.281160, 0.000070, 0.040000},
	{{0, 0, 2, -4, 1, 0, 0, 0, -2, 1, 0}, 155.690210, 0.000110, 0.087000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 0, -1, 0}, 153.341010, 0.000120, 0.075000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 0, 0, 0}, 154.612920, 0.000770, 23.567000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 0, 1, 0}, 153.386900, 0.000120, 0.076000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 2, -1, 0}, 155.998540, 0.000120, 0.087000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 2, 0, 0}, 155.470360, 0.000070, 0.040000},
	{{0, 0, 2, -4, 2, 0, 0, 0, -2, -1, 0}, 0.614610, 0.000030, 0.026000},
	{{0, 0, 2, -4, 2, 0, 0, 0, -2, 0, 0}, 0.552560, 0.000190, 0.040000},
	{{0, 0, 2, -4, 2, 0, 0, 0, -2, 1, 0}, 0.851980, 0.000310, 0.087000},
	{{0, 0, 2, -4, 2, 0, 0, 0, -2, 2, 0}, 0.614620, 0.000010, 0.551000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, -2, 0}, 359.012360, 0.000020, 0.038000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, -1, 0}, 359.242570, 0.000340, 0.076000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 0, 0}, 0.035160, 0.001760, 23.883000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 1, 0}, 359.180710, 0.000330, 0.075000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 2, 0}, 359.019370, 0.000020, 0.038000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 2, -2, 0}, 0.508930, 0.000010, 0.577000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 2, -1, 0}, 0.725620, 0.000270, 0.087000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 2, 0, 0}, 0.508300, 0.000190, 0.040000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 2, 1, 0}, 0.538830, 0.000020, 0.026000},
	{{0, 0, 2, -4, 3, 0, 0, 0, 0, 0, 0}, 176.234170, 0.000050, 7.926000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, -1, 0}, 330.911740, 0.000010, 0.016000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, 0, 0}, 330.898790, 0.000080, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, 1, 0}, 330.819220, 0.000220, 0.028000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, 2, 0}, 330.923240, 0.000130, 0.044000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -3, 0, 0}, 331.118630, 0.000020, 0.027000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, -2, 0}, 331.702560, 0.000060, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, -1, 0}, 330.681150, 0.000680, 0.027000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, -2}, 150.766390, 0.000020, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, 0}, 330.977510, 0.007390, 0.041000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, 2}, 331.001420, 0.000140, 0.398000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 1, -2}, 150.799280, 0.000020, 0.026000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 1, 0}, 330.923950, 0.010850, 0.090000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 2, 0}, 331.076670, 0.000470, 0.459000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 3, 0}, 331.373410, 0.000030, 0.065000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 0, 0}, 150.675360, 0.000250, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 0, 1}, 52.850660, 0.000060, 0.686000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 1, 0}, 150.762500, 0.000040, 0.774000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -3, 0}, 329.735440, 0.000040, 0.025000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -2, 0}, 329.811470, 0.000570, 0.038000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, -2}, 150.043320, 0.000030, 0.025000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, 0}, 329.851530, 0.008490, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, 2}, 329.799710, 0.000010, 0.071000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, -2}, 150.746410, 0.000020, 0.038000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, 0}, 330.286950, 0.040140, 2.470000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, 2}, 150.746410, 0.000020, 0.037000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, -2}, 154.798340, 0.000030, 0.076000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, 0}, 329.781440, 0.007530, 0.073000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, 2}, 150.043320, 0.000030, 0.025000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 2, -2}, 153.556050, 0.000010, 13.999000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 2, 0}, 329.742120, 0.000520, 0.037000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 3, 0}, 329.656050, 0.000030, 0.025000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, -1, -1}, 53.532360, 0.000020, 0.072000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, -1, 1}, 233.385220, 0.000070, 0.077000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 0, -1}, 53.416270, 0.000220, 1.541000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 0, 0}, 331.109280, 0.000060, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 0, 1}, 233.395200, 0.000030, 0.038000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 1, -1}, 53.532360, 0.000020, 0.079000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -2, 0}, 331.043940, 0.000220, 0.730000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -1, -2}, 150.522470, 0.000010, 0.067000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -1, 0}, 331.231760, 0.006530, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, -2}, 330.500980, 0.000100, 0.587000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, 0}, 330.416420, 0.003680, 0.040000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 1, -2}, 150.522470, 0.000010, 0.087000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 1, 0}, 330.458660, 0.000380, 0.026000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 2, 0}, 330.438970, 0.000040, 0.019000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 4, -2, 0}, 331.083230, 0.000070, 0.043000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 4, -1, 0}, 330.732170, 0.000120, 0.027000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 4, 0, 0}, 330.838010, 0.000050, 0.020000},
	{{0, 0, 2, -3, 1, 0, 0, 0, 0, 0, 0}, 353.366560, 0.000020, 2.044000},
	{{0, 0, 2, -3, 1, 0, 0, 0, 2, 0, 0}, 183.009560, 0.000010, 0.040000},
	{{0, 0, 2, -3, 2, 0, 0, 0, 2, -3, 0}, 209.840560, 0.000010, 0.069000},
	{{0, 0, 2, -3, 2, 0, 0, 0, 2, -1, 0}, 209.840560, 0.000010, 0.083000},
	{{0, 0, 2, -3, 2, 0, 0, 0, 2, 0, 0}, 29.777520, 0.000010, 0.040000},
	{{0, 0, 2, -3, 3, 0, 0, 0, 0, 0, 0}, 351.969470, 0.000010, 1.520000},
	{{0, 0, 2, -2, -3, 0, 0, 0, 0, 0, 0}, 320.724180, 0.000010, 1.463000},
	{{0, 0, 2, -2, -2, 0, 0, 0, -2, 0, 0}, 120.937600, 0.000010, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -6, 0, 0}, 177.244200, 0.000010, 0.014000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -6, 1, 0}, 359.041980, 0.000020, 0.017000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -6, 2, 0}, 358.931110, 0.000040, 0.021000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, -1, 0}, 0.975460, 0.000090, 0.016000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 0, 0}, 357.170700, 0.000510, 0.021000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 0, 2}, 358.671430, 0.000010, 0.046000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 1, 0}, 357.618980, 0.001190, 0.028000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 1, 2}, 358.694520, 0.000020, 0.119000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 2, 0}, 358.451380, 0.000770, 0.045000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 3, 0}, 359.180010, 0.000030, 0.114000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -3, -1, 0}, 358.261920, 0.000010, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -3, 0, 0}, 358.929790, 0.000040, 0.028000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -3, 1, 0}, 176.346550, 0.000020, 0.044000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -3, 0}, 358.812150, 0.000040, 0.016000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -2, 0}, 359.089350, 0.000330, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -1, -2}, 178.913500, 0.000020, 0.016000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -1, 0}, 358.131180, 0.004040, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -1, 2}, 178.729980, 0.000070, 0.098000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, -2}, 179.099590, 0.000090, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 0}, 358.579750, 0.046120, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 2}, 358.767100, 0.000640, 0.329000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, -2}, 178.899310, 0.000170, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, 0}, 358.868730, 0.059040, 0.095000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, 2}, 359.286380, 0.000020, 0.061000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 2, 0}, 359.116210, 0.002540, 0.369000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 3, 0}, 358.226120, 0.000130, 0.063000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, -1, 0}, 2.195200, 0.000040, 0.041000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, -1, 1}, 279.512160, 0.000030, 0.089000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 0, -1}, 100.087150, 0.000010, 0.040000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 0, 0}, 0.469970, 0.001190, 0.087000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 0, 1}, 98.757840, 0.000060, 0.502000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 1, 0}, 1.623330, 0.000070, 0.548000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -3, 0}, 359.848720, 0.000210, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -2, 0}, 359.284740, 0.002740, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, -2}, 179.556950, 0.000110, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, 0}, 359.516370, 0.042130, 0.081000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, -2}, 178.520600, 0.000020, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0}, 359.764870, 0.194430, 1.068000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 2}, 179.692110, 0.000140, 0.036000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, 0}, 0.071170, 0.032590, 0.070000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, 2}, 179.664570, 0.000090, 0.024000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 2, 0}, 0.402260, 0.002290, 0.036000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 2, 2}, 179.667600, 0.000010, 0.018000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 3, 0}, 359.974110, 0.000150, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -3, 0}, 180.436210, 0.000020, 0.038000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -2, 0}, 180.502460, 0.000170, 0.076000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, -1}, 99.340310, 0.000140, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, 0}, 0.275480, 0.001390, 20.152000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, 1}, 99.532510, 0.000130, 0.074000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, -2}, 180.234880, 0.000020, 0.074000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, -1}, 99.526230, 0.001130, 8.537000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 0}, 180.276030, 0.012010, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 1}, 279.444070, 0.000280, 0.037000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 2}, 0.234860, 0.000020, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, -1}, 99.340310, 0.000140, 0.076000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, 0}, 180.230890, 0.000830, 0.038000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, 1}, 279.409210, 0.000030, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 2, 0}, 180.234890, 0.000060, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -3, 0}, 183.613550, 0.000010, 0.071000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -2, 0}, 180.687750, 0.000350, 1.194000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -1, 0}, 0.451560, 0.013150, 0.081000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -1, 2}, 179.963110, 0.000030, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, -2}, 0.844250, 0.000490, 0.854000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, 0}, 0.890770, 0.008750, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, 2}, 179.528100, 0.000020, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 1, -2}, 180.793720, 0.000020, 0.083000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 1, 0}, 1.041190, 0.001010, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 2, 0}, 359.617220, 0.000120, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, -2, 0}, 0.400360, 0.000060, 0.087000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, -1, 0}, 180.224540, 0.000140, 0.040000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, 0, 0}, 180.018150, 0.000090, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -2, 0}, 359.988570, 0.000160, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -1, 0}, 1.391660, 0.000270, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, 0, 0}, 0.786000, 0.000090, 0.020000},
	{{0, 0, 2, -2, 0, 2, 0, 0, -2, 0, 0}, 290.922360, 0.000020, 0.042000},
	{{0, 0, 2, -2, 0, 2, 0, 0, -2, 1, 0}, 290.922360, 0.000020, 0.095000},
	{{0, 0, 2, -2, 0, 2, 0, 0, 0, 0, 0}, 290.945540, 0.000030, 0.996000},
	{{0, 0, 2, -2, 1, 0, 0, 0, 0, 0, 0}, 97.772950, 0.000010, 0.980000},
	{{0, 0, 2, -2, 1, 0, 0, 0, 1, 0, -1}, 120.933360, 0.000010, 30.461000},
	{{0, 0, 2, -2, 1, 0, 0, 0, 2, -3, 0}, 204.719580, 0.000010, 0.071000},
	{{0, 0, 2, -2, 1, 0, 0, 0, 2, -1, 0}, 204.719580, 0.000010, 0.080000},
	{{0, 0, 2, -2, 2, 0, 0, 0, 1, 0, -1}, 165.354860, 0.000010, 19.427000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -4, 1, 0}, 255.724630, 0.000020, 0.029000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, -1, 0}, 255.535130, 0.000050, 0.027000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 0, 0}, 255.006210, 0.000500, 0.043000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 1, 0}, 257.411310, 0.000530, 0.100000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 2, 0}, 260.262740, 0.000030, 0.308000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, -1, 0}, 234.623980, 0.000390, 0.085000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 0, 0}, 228.749620, 0.001400, 0.681000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 1, 0}, 232.839710, 0.000170, 0.068000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, -1, -1}, 308.942390, 0.000020, 0.078000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, -1, 1}, 129.692010, 0.000020, 0.071000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 0, -1}, 309.056540, 0.000170, 2.412000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 0, 0}, 210.131220, 0.000020, 0.072000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 0, 1}, 128.959290, 0.000020, 0.037000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 1, -1}, 308.942390, 0.000020, 0.073000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -2, 0}, 44.315940, 0.000070, 3.271000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -1, 0}, 39.715290, 0.000550, 0.077000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, 0, 0}, 43.776410, 0.000090, 0.038000},
	{{0, 0, 2, -1, 2, 0, 0, 0, 2, -1, 0}, 281.918980, 0.000020, 0.076000},
	{{0, 0, 2, 0, -7, 0, 0, 0, 0, 0, 0}, 233.411290, 0.000010, 0.709000},
	{{0, 0, 2, 0, -7, 3, 0, 0, 0, 0, 0}, 197.993170, 0.000010, 0.662000},
	{{0, 0, 2, 0, -7, 5, 0, 0, -2, 0, 0}, 102.115250, 0.000020, 0.043000},
	{{0, 0, 2, 0, -7, 5, 0, 0, 0, 0, 0}, 102.483710, 0.000030, 0.633000},
	{{0, 0, 2, 0, -7, 10, 0, 0, 2, -3, 0}, 247.917360, 0.000020, 0.075000},
	{{0, 0, 2, 0, -7, 10, 0, 0, 2, -2, 0}, 77.168680, 0.000030, 40.542000},
	{{0, 0, 2, 0, -7, 10, 0, 0, 2, -1, 0}, 67.917360, 0.000020, 0.076000},
	{{0, 0, 2, 0, -6, 0, 0, 0, -2, 0, 0}, 218.520110, 0.000040, 0.043000},
	{{0, 0, 2, 0, -6, 0, 0, 0, -2, 1, 0}, 218.755200, 0.000040, 0.100000},
	{{0, 0, 2, 0, -6, 0, 0, 0, 0, -1, 0}, 219.604120, 0.000010, 0.085000},
	{{0, 0, 2, 0, -6, 0, 0, 0, 0, 0, 0}, 220.527070, 0.000100, 0.669000},
	{{0, 0, 2, 0, -6, 0, 0, 0, 0, 1, 0}, 219.604120, 0.000010, 0.068000},
	{{0, 0, 2, 0, -6, 0, 0, 0, 2, -1, 0}, 41.063970, 0.000050, 0.077000},
	{{0, 0, 2, 0, -6, 2, 0, 0, -2, 0, 0}, 199.259220, 0.000020, 0.043000},
	{{0, 0, 2, 0, -6, 2, 0, 0, 0, 0, 0}, 200.882520, 0.000030, 0.640000},
	{{0, 0, 2, 0, -6, 3, 0, 0, -2, 0, 0}, 217.473300, 0.000010, 0.043000},
	{{0, 0, 2, 0, -6, 3, 0, 0, 0, 0, 0}, 219.218270, 0.000030, 0.627000},
	{{0, 0, 2, 0, -6, 3, 0, 0, 2, -1, 0}, 210.600760, 0.000020, 0.076000},
	{{0, 0, 2, 0, -6, 4, 0, 0, -2, 0, 0}, 129.709010, 0.000020, 0.043000},
	{{0, 0, 2, 0, -6, 4, 0, 0, 0, 0, 0}, 129.858820, 0.000020, 0.614000},
	{{0, 0, 2, 0, -6, 4, 0, 0, 2, -1, 0}, 131.000690, 0.000020, 0.076000},
	{{0, 0, 2, 0, -6, 5, 0, 0, -2, 0, 0}, 80.019380, 0.000050, 0.043000},
	{{0, 0, 2, 0, -6, 5, 0, 0, -2, 1, 0}, 80.019420, 0.000040, 0.102000},
	{{0, 0, 2, 0, -6, 5, 0, 0, 0, -1, 0}, 79.275180, 0.000050, 0.086000},
	{{0, 0, 2, 0, -6, 5, 0, 0, 0, 0, 0}, 80.882660, 0.000100, 0.601000},
	{{0, 0, 2, 0, -6, 5, 0, 0, 0, 1, 0}, 80.019980, 0.000010, 0.067000},
	{{0, 0, 2, 0, -6, 5, 0, 0, 2, -3, 0}, 139.151690, 0.000020, 0.075000},
	{{0, 0, 2, 0, -6, 5, 0, 0, 2, -2, 0}, 255.401860, 0.000030, 9.083000},
	{{0, 0, 2, 0, -6, 5, 0, 0, 2, -1, 0}, 259.075760, 0.000190, 0.076000},
	{{0, 0, 2, 0, -6, 7, 0, 0, 0, 0, 0}, 353.833780, 0.000010, 0.577000},
	{{0, 0, 2, 0, -6, 8, 0, 0, 2, -2, 0}, 231.833930, 0.000030, 121.093000},
	{{0, 0, 2, 0, -6, 10, 0, 0, 0, 0, 0}, 161.671570, 0.000010, 0.545000},
	{{0, 0, 2, 0, -6, 10, 0, 0, 2, -3, 0}, 335.233450, 0.000020, 0.076000},
	{{0, 0, 2, 0, -6, 10, 0, 0, 2, -1, 0}, 155.233450, 0.000020, 0.075000},
	{{0, 0, 2, 0, -5, 0, 0, 0, -2, -1, 0}, 209.097530, 0.000030, 0.027000},
	{{0, 0, 2, 0, -5, 0, 0, 0, -2, 0, 0}, 209.172030, 0.000280, 0.043000},
	{{0, 0, 2, 0, -5, 0, 0, 0, -2, 1, 0}, 209.104700, 0.000320, 0.101000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, -2, 0}, 209.968750, 0.000020, 0.040000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, -1, 0}, 209.892660, 0.000390, 0.086000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, 0, 0}, 210.153740, 0.000840, 0.634000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, 1, 0}, 210.754930, 0.000140, 0.067000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 1, 0, -1}, 298.551090, 0.000010, 1.906000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, -2, 0}, 29.341020, 0.000120, 5.114000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, -1, 0}, 29.508030, 0.000780, 0.077000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, 0, 0}, 29.835930, 0.000080, 0.038000},
	{{0, 0, 2, 0, -5, 2, 0, 0, -2, 0, 0}, 190.259180, 0.000070, 0.043000},
	{{0, 0, 2, 0, -5, 2, 0, 0, -2, 1, 0}, 190.259180, 0.000060, 0.102000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 0, -1, 0}, 191.181470, 0.000080, 0.086000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 0, 0, 0}, 190.847890, 0.000160, 0.607000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 0, 1, 0}, 190.659570, 0.000030, 0.067000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 2, -3, 0}, 201.884550, 0.000010, 0.075000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 2, -2, 0}, 10.340540, 0.000030, 7.834000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 2, -1, 0}, 11.485890, 0.000240, 0.076000},
	{{0, 0, 2, 0, -5, 3, 0, 0, -2, 0, 0}, 214.006980, 0.000040, 0.043000},
	{{0, 0, 2, 0, -5, 3, 0, 0, -2, 1, 0}, 214.006980, 0.000040, 0.102000},
	{{0, 0, 2, 0, -5, 3, 0, 0, 0, -2, 0}, 33.612960, 0.000010, 0.040000},
	{{0, 0, 2, 0, -5, 3, 0, 0, 0, -1, 0}, 212.487170, 0.000040, 0.086000},
	{{0, 0, 2, 0, -5, 3, 0, 0, 0, 0, 0}, 212.697080, 0.000080, 0.595000},
	{{0, 0, 2, 0, -5, 3, 0, 0, 2, -3, 0}, 102.513000, 0.000020, 0.075000},
	{{0, 0, 2, 0, -5, 3, 0, 0, 2, -2, 0}, 34.694050, 0.000030, 10.673000},
	{{0, 0, 2, 0, -5, 3, 0, 0, 2, -1, 0}, 32.102570, 0.000160, 0.076000},
	{{0, 0, 2, 0, -5, 4, 0, 0, -2, 0, 0}, 64.014510, 0.000020, 0.043000},
	{{0, 0, 2, 0, -5, 4, 0, 0, 0, -1, 0}, 58.287730, 0.000030, 0.087000},
	{{0, 0, 2, 0, -5, 4, 0, 0, 0, 0, 0}, 62.337300, 0.000050, 0.583000},
	{{0, 0, 2, 0, -5, 4, 0, 0, 2, -3, 0}, 73.737070, 0.000030, 0.075000},
	{{0, 0, 2, 0, -5, 4, 0, 0, 2, -2, 0}, 239.284700, 0.000050, 16.738000},
	{{0, 0, 2, 0, -5, 4, 0, 0, 2, -1, 0}, 238.287470, 0.000160, 0.076000},
	{{0, 0, 2, 0, -5, 5, 0, 0, -2, -1, 0}, 56.732360, 0.000020, 0.028000},
	{{0, 0, 2, 0, -5, 5, 0, 0, -2, 0, 0}, 56.739990, 0.000140, 0.043000},
	{{0, 0, 2, 0, -5, 5, 0, 0, -2, 1, 0}, 56.746900, 0.000150, 0.103000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, -2, 0}, 53.800320, 0.000020, 0.040000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, -1, 0}, 54.492990, 0.000870, 0.087000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, 0, 0}, 55.929180, 0.000480, 0.572000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, 1, 0}, 56.482390, 0.000060, 0.067000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -3, 0}, 247.873350, 0.000040, 0.075000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -2, 0}, 233.933040, 0.002710, 38.763000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -1, 0}, 234.224550, 0.004100, 0.076000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, 0, 0}, 231.368390, 0.000280, 0.038000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, 1, 0}, 234.217210, 0.000020, 0.025000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 4, -3, 0}, 232.030120, 0.000050, 0.087000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 4, -2, 0}, 234.133890, 0.000080, 0.040000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 4, -1, 0}, 234.203160, 0.000040, 0.026000},
	{{0, 0, 2, 0, -5, 6, 0, 0, 2, -3, 0}, 168.606190, 0.000020, 0.075000},
	{{0, 0, 2, 0, -5, 6, 0, 0, 2, -2, 0}, 178.180810, 0.000070, 122.705000},
	{{0, 0, 2, 0, -5, 6, 0, 0, 2, -1, 0}, 348.606190, 0.000020, 0.075000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -4, 0, 0}, 199.892150, 0.000030, 0.021000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -4, 1, 0}, 199.900650, 0.000060, 0.029000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -4, 2, 0}, 199.902460, 0.000040, 0.047000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, -2, 0}, 199.122130, 0.000010, 0.020000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, -1, 0}, 199.859740, 0.000230, 0.028000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 0, 0}, 199.377040, 0.002480, 0.043000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 0, 2}, 199.648550, 0.000030, 0.265000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 1, 0}, 199.812120, 0.002580, 0.102000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 2, 0}, 199.551810, 0.000110, 0.291000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -1, 0, 0}, 20.205450, 0.000030, 0.093000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -1, 0, 1}, 295.247830, 0.000010, 0.368000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -3, 0}, 199.869280, 0.000010, 0.026000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -2, 0}, 200.261180, 0.000250, 0.040000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -1, 0}, 200.250560, 0.004250, 0.086000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 0, 0}, 200.474140, 0.006720, 0.601000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 1, 0}, 201.013440, 0.001120, 0.067000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 2, 0}, 201.043920, 0.000070, 0.035000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 1, 0, -1}, 289.340980, 0.000080, 1.642000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 1, 0, 0}, 21.432240, 0.000040, 0.071000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -3, 0}, 19.923610, 0.000100, 0.075000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -2, 0}, 19.834950, 0.002730, 8.990000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, -2}, 19.940000, 0.000020, 0.073000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, 0}, 19.760440, 0.013120, 0.076000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, 2}, 199.940000, 0.000030, 0.025000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, 0, -2}, 20.013700, 0.000010, 2.248000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, 0, 0}, 21.579310, 0.001050, 0.038000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, 1, 0}, 20.049400, 0.000080, 0.025000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -3, 0}, 19.639190, 0.000040, 0.088000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -2, 0}, 19.847860, 0.000200, 0.041000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -1, 0}, 20.010360, 0.000130, 0.026000},
	{{0, 0, 2, 0, -4, 1, 0, 0, -2, 0, 0}, 15.304100, 0.000020, 0.043000},
	{{0, 0, 2, 0, -4, 1, 0, 0, 0, 0, 0}, 15.655540, 0.000040, 0.589000},
	{{0, 0, 2, 0, -4, 1, 0, 0, 2, -3, 0}, 27.326750, 0.000010, 0.075000},
	{{0, 0, 2, 0, -4, 1, 0, 0, 2, -2, 0}, 192.354670, 0.000020, 12.939000},
	{{0, 0, 2, 0, -4, 1, 0, 0, 2, -1, 0}, 189.723030, 0.000060, 0.076000},
	{{0, 0, 2, 0, -4, 2, 0, 0, -2, -1, 0}, 182.704110, 0.000020, 0.028000},
	{{0, 0, 2, 0, -4, 2, 0, 0, -2, 0, 0}, 182.713540, 0.000180, 0.043000},
	{{0, 0, 2, 0, -4, 2, 0, 0, -2, 1, 0}, 182.722160, 0.000190, 0.103000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, -2, 0}, 182.193000, 0.000020, 0.040000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, -1, 0}, 182.416050, 0.000720, 0.087000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, 0, 0}, 182.286980, 0.000570, 0.578000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, 1, 0}, 182.461770, 0.000080, 0.067000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -2, 0}, 2.277870, 0.001290, 23.075000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -1, 0}, 2.382720, 0.003040, 0.076000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, 0, 0}, 2.257180, 0.000220, 0.038000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 4, -3, 0}, 359.107630, 0.000030, 0.087000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 4, -2, 0}, 2.244290, 0.000050, 0.040000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 4, -1, 0}, 2.368930, 0.000030, 0.026000},
	{{0, 0, 2, 0, -4, 3, 0, 0, -2, 0, 0}, 239.162340, 0.000070, 0.044000},
	{{0, 0, 2, 0, -4, 3, 0, 0, -2, 1, 0}, 239.162340, 0.000070, 0.103000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, -2, 0}, 57.234150, 0.000030, 0.040000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, -1, 0}, 237.189250, 0.000850, 0.087000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, 0, 0}, 237.953050, 0.000260, 0.567000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, 1, 0}, 238.751550, 0.000030, 0.067000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -4, 0}, 52.640180, 0.000020, 0.038000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -3, 0}, 52.610780, 0.000230, 0.075000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -2, 0}, 57.323170, 0.008190, 106.494000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -1, 0}, 57.163510, 0.004950, 0.075000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, 0, 0}, 57.218680, 0.000340, 0.038000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, 1, 0}, 57.146920, 0.000020, 0.025000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 4, -3, 0}, 58.914990, 0.000140, 0.087000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 4, -2, 0}, 57.349520, 0.000160, 0.040000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 4, -1, 0}, 57.204290, 0.000050, 0.026000},
	{{0, 0, 2, 0, -4, 4, -2, 0, 2, -2, 0}, 174.859960, 0.000400, 1326.783000},
	{{0, 0, 2, 0, -4, 4, 0, 0, -2, 0, 0}, 117.582380, 0.000020, 0.044000},
	{{0, 0, 2, 0, -4, 4, 0, 0, 0, -1, 0}, 296.938260, 0.000040, 0.087000},
	{{0, 0, 2, 0, -4, 4, 0, 0, 0, 0, 0}, 117.288630, 0.000030, 0.556000},
	{{0, 0, 2, 0, -4, 4, 0, 0, 2, -2, 0}, 295.363600, 0.000120, 40.721000},
	{{0, 0, 2, 0, -4, 4, 0, 0, 2, -1, 0}, 116.938350, 0.000200, 0.075000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -4, 1, 0}, 351.228380, 0.000020, 0.029000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, -1, 0}, 351.227390, 0.000050, 0.028000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 0, 0}, 351.236540, 0.000470, 0.044000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 1, 0}, 351.235500, 0.000500, 0.104000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 2, 0}, 351.230180, 0.000010, 0.277000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, -2, 0}, 170.984220, 0.000090, 0.041000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, -1, 0}, 171.197810, 0.001030, 0.088000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, 0, 0}, 351.467130, 0.001050, 0.546000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, 1, 0}, 351.292840, 0.000170, 0.066000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, 2, 0}, 349.149850, 0.000030, 0.035000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -3, 0}, 148.633060, 0.000050, 0.076000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -2, 0}, 170.863240, 0.001330, 17.093000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -1, 0}, 351.238590, 0.006320, 0.075000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, 0, -2}, 167.596220, 0.000010, 3.636000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, 0, 0}, 351.490830, 0.000350, 0.038000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, 1, 0}, 351.214740, 0.000030, 0.025000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, 2, 0}, 168.243170, 0.000010, 0.019000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 4, -3, 0}, 183.235860, 0.000020, 0.087000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 4, -2, 0}, 350.488140, 0.000070, 0.040000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 4, -1, 0}, 351.196890, 0.000060, 0.026000},
	{{0, 0, 2, 0, -4, 6, -3, 0, 0, 0, 0}, 168.762550, 0.000010, 0.546000},
	{{0, 0, 2, 0, -4, 6, -3, 0, 2, -1, 0}, 173.239910, 0.000030, 0.075000},
	{{0, 0, 2, 0, -3, -5, 0, 0, 0, 0, 0}, 219.397820, 0.000010, 0.634000},
	{{0, 0, 2, 0, -3, -1, 0, 0, 0, 0, 0}, 154.758350, 0.000010, 0.584000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -6, 1, 0}, 190.066980, 0.000010, 0.017000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, -1, 0}, 189.998460, 0.000040, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 0, 0}, 189.125780, 0.000190, 0.021000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 0, 2}, 190.235470, 0.000020, 0.048000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 1, 0}, 190.626470, 0.000430, 0.029000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 2, 0}, 190.340990, 0.000230, 0.047000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -3, 0, 0}, 190.192860, 0.000020, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -3, 1, 0}, 10.209720, 0.000020, 0.045000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -3, 0}, 190.116820, 0.000020, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -2, 0}, 190.279430, 0.000200, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -1, 0}, 190.292270, 0.002200, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -1, 2}, 10.250220, 0.000020, 0.106000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, -2}, 10.405970, 0.000040, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, 0}, 190.207510, 0.018410, 0.043000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, 2}, 190.220670, 0.000160, 0.259000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, -2}, 10.380900, 0.000040, 0.027000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, 0}, 190.297860, 0.018140, 0.103000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 2, 0}, 190.405480, 0.000750, 0.284000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 3, 0}, 190.329090, 0.000050, 0.060000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, -1, 0}, 10.085770, 0.000060, 0.042000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, -1, 1}, 187.732800, 0.000020, 0.096000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, 0, 0}, 11.038220, 0.000320, 0.094000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, 0, 1}, 292.549510, 0.000040, 0.357000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, 1, 0}, 10.428940, 0.000040, 0.380000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -3, 0}, 190.433920, 0.000110, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, -2}, 10.113120, 0.000020, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, 0}, 190.268690, 0.003200, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, 2}, 10.053970, 0.000040, 0.481000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, -2}, 10.173320, 0.000190, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 0}, 190.179700, 0.095180, 0.087000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 2}, 190.694190, 0.000010, 0.065000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, -2}, 8.630240, 0.000020, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 0}, 190.436000, 0.051670, 0.572000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 2}, 10.393900, 0.000060, 0.035000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, 0}, 190.515720, 0.008130, 0.067000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, 2}, 10.615300, 0.000030, 0.024000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 2, 0}, 190.677580, 0.000580, 0.035000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 3, 0}, 190.765760, 0.000040, 0.024000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, -2, 0}, 190.648340, 0.000040, 0.081000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, -1, -1}, 276.013230, 0.000030, 0.080000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, -1, 0}, 10.207560, 0.000440, 1.163000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, -1, 1}, 99.378190, 0.000030, 0.070000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 0, -1}, 278.286090, 0.000310, 1.442000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 0, 0}, 8.011310, 0.000390, 0.071000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 0, 1}, 100.504000, 0.000020, 0.036000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 1, -1}, 276.013230, 0.000030, 0.072000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 1, 0}, 8.097040, 0.000030, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -5, 0}, 10.153140, 0.000050, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -4, 0}, 10.153900, 0.000640, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, -2}, 190.077770, 0.000040, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, 0}, 10.151700, 0.009360, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, -2}, 190.010790, 0.000240, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 0}, 10.038350, 0.282810, 37.133000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 2}, 190.044350, 0.000290, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, -2}, 10.077010, 0.000700, 0.073000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 0}, 10.070010, 0.445320, 0.076000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 2}, 190.082550, 0.000920, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, -2}, 11.696790, 0.000140, 2.774000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, 0}, 10.085800, 0.031740, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, 2}, 190.082860, 0.000160, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 1, -2}, 190.206190, 0.000050, 0.078000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 1, 0}, 9.993650, 0.002230, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 1, 2}, 190.085870, 0.000020, 0.015000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 2, 0}, 10.101320, 0.000170, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 3, -2, 0}, 190.013050, 0.000130, 0.081000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 3, -1, 0}, 190.082850, 0.000170, 0.039000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 3, 0, 0}, 190.085850, 0.000020, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -4, 0}, 9.876140, 0.000120, 0.555000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -3, 0}, 9.991810, 0.004400, 0.087000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -3, 2}, 190.025390, 0.000020, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, -2}, 10.052060, 0.000040, 0.469000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, 0}, 9.967310, 0.008970, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, 2}, 190.068950, 0.000050, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, -2}, 190.049880, 0.000110, 0.090000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, 0}, 10.081500, 0.004470, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, 2}, 190.085350, 0.000020, 0.015000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, 0, 0}, 10.159160, 0.000660, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, 1, 0}, 10.372020, 0.000060, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -4, 0}, 9.993880, 0.000060, 0.044000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -3, 0}, 10.049520, 0.000170, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -2, 0}, 10.057480, 0.000150, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -1, 0}, 10.085110, 0.000050, 0.016000},
	{{0, 0, 2, 0, -3, 0, 1, 0, 2, -3, 0}, 0.730830, 0.000010, 0.075000},
	{{0, 0, 2, 0, -3, 0, 1, 0, 2, -2, 0}, 180.737490, 0.000020, 66.542000},
	{{0, 0, 2, 0, -3, 0, 1, 0, 2, -1, 0}, 180.730830, 0.000010, 0.076000},
	{{0, 0, 2, 0, -3, 0, 2, 0, 2, -2, 0}, 349.757140, 0.000300, 319.860000},
	{{0, 0, 2, 0, -3, 0, 2, 0, 2, -1, 0}, 349.777960, 0.000070, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, -2, 0, 0}, 3.602120, 0.000070, 0.044000},
	{{0, 0, 2, 0, -3, 1, 0, 0, -2, 1, 0}, 3.602120, 0.000070, 0.103000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -3, 0}, 181.058210, 0.000020, 0.026000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -2, 0}, 181.314150, 0.000200, 0.040000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -1, 0}, 181.397710, 0.001210, 0.087000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, 0, 0}, 5.950270, 0.000050, 0.561000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, 1, 0}, 3.602120, 0.000010, 0.067000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -4, 0}, 179.815680, 0.000020, 0.038000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -3, 0}, 179.822090, 0.000370, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -2, 0}, 181.297640, 0.011260, 142.500000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -1, 0}, 1.456380, 0.004790, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, 0, 0}, 1.462260, 0.000310, 0.038000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, 1, 0}, 1.438290, 0.000030, 0.025000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -3, 0}, 181.918740, 0.000180, 0.087000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -2, 0}, 181.250990, 0.000060, 0.040000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -1, 0}, 1.488460, 0.000030, 0.026000},
	{{0, 0, 2, 0, -3, 2, 0, 0, -2, 0, 0}, 202.892510, 0.000080, 0.044000},
	{{0, 0, 2, 0, -3, 2, 0, 0, -2, 1, 0}, 202.892510, 0.000080, 0.103000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 0, -2, 0}, 11.291520, 0.000010, 0.040000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 0, -1, 0}, 10.647590, 0.000180, 0.087000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 0, 0, 0}, 197.634210, 0.000150, 0.551000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 0, 1, 0}, 195.913620, 0.000030, 0.066000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -3, 0}, 1.447420, 0.000040, 0.076000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -2, 0}, 10.513720, 0.000330, 24.411000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -1, 0}, 191.465560, 0.001060, 0.075000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, 0, 0}, 193.457600, 0.000060, 0.038000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 4, -2, 0}, 191.142040, 0.000010, 0.040000},
	{{0, 0, 2, 0, -3, 3, 0, 0, 0, 0, 0}, 10.260920, 0.000010, 0.541000},
	{{0, 0, 2, 0, -3, 3, 0, 0, 2, -3, 0}, 254.912140, 0.000020, 0.076000},
	{{0, 0, 2, 0, -3, 3, 0, 0, 2, -1, 0}, 334.075210, 0.000020, 0.075000},
	{{0, 0, 2, 0, -3, 5, 0, 0, -2, 0, 0}, 76.384360, 0.000050, 0.044000},
	{{0, 0, 2, 0, -3, 5, 0, 0, -2, 1, 0}, 76.020450, 0.000040, 0.105000},
	{{0, 0, 2, 0, -3, 5, 0, 0, 0, -1, 0}, 77.505620, 0.000010, 0.088000},
	{{0, 0, 2, 0, -3, 5, 0, 0, 0, 0, 0}, 83.823840, 0.000040, 0.522000},
	{{0, 0, 2, 0, -3, 5, 0, 0, 0, 1, 0}, 77.505620, 0.000010, 0.066000},
	{{0, 0, 2, 0, -3, 5, 0, 0, 2, -2, 0}, 159.397840, 0.000020, 7.002000},
	{{0, 0, 2, 0, -3, 5, 0, 0, 2, -1, 0}, 130.218540, 0.000050, 0.075000},
	{{0, 0, 2, 0, -3, 5, 0, 0, 2, 0, 0}, 159.397840, 0.000020, 0.038000},
	{{0, 0, 2, 0, -2, -5, 0, 0, -2, 0, 0}, 208.355040, 0.000030, 0.043000},
	{{0, 0, 2, 0, -2, -5, 0, 0, -2, 1, 0}, 208.351470, 0.000030, 0.102000},
	{{0, 0, 2, 0, -2, -5, 0, 0, 0, -1, 0}, 209.411990, 0.000020, 0.086000},
	{{0, 0, 2, 0, -2, -5, 0, 0, 0, 0, 0}, 209.459790, 0.000070, 0.602000},
	{{0, 0, 2, 0, -2, -5, 0, 0, 2, -3, 0}, 209.884740, 0.000020, 0.075000},
	{{0, 0, 2, 0, -2, -5, 0, 0, 2, -2, 0}, 28.397520, 0.000010, 8.900000},
	{{0, 0, 2, 0, -2, -5, 0, 0, 2, -1, 0}, 29.411980, 0.000110, 0.076000},
	{{0, 0, 2, 0, -2, -3, 0, 0, 0, 0, 0}, 181.094960, 0.000010, 0.578000},
	{{0, 0, 2, 0, -2, -3, 0, 0, 2, -3, 0}, 178.909670, 0.000020, 0.075000},
	{{0, 0, 2, 0, -2, -3, 0, 0, 2, -1, 0}, 358.909670, 0.000020, 0.076000},
	{{0, 0, 2, 0, -2, -2, 0, 0, -2, 0, 0}, 336.864750, 0.000010, 0.044000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 0, -1, 0}, 345.693350, 0.000150, 0.087000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 0, 0, 0}, 339.009710, 0.000030, 0.567000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -3, 0}, 182.364080, 0.000010, 0.075000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -2, 0}, 165.357110, 0.001410, 95.036000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -1, 0}, 165.636090, 0.000910, 0.076000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, 0, 0}, 165.662160, 0.000060, 0.038000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 4, -3, 0}, 163.791480, 0.000030, 0.087000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 4, -2, 0}, 165.371580, 0.000030, 0.040000},
	{{0, 0, 2, 0, -2, -1, 0, 0, -2, 0, 0}, 146.975170, 0.000020, 0.044000},
	{{0, 0, 2, 0, -2, -1, 0, 0, 0, -1, 0}, 348.082620, 0.000040, 0.087000},
	{{0, 0, 2, 0, -2, -1, 0, 0, 0, 0, 0}, 150.521190, 0.000020, 0.556000},
	{{0, 0, 2, 0, -2, -1, 0, 0, 2, -3, 0}, 160.401090, 0.000040, 0.076000},
	{{0, 0, 2, 0, -2, -1, 0, 0, 2, -2, 0}, 349.511660, 0.000100, 42.689000},
	{{0, 0, 2, 0, -2, -1, 0, 0, 2, -1, 0}, 168.082490, 0.000190, 0.075000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -6, 1, 0}, 180.981620, 0.000040, 0.017000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -6, 2, 0}, 181.352400, 0.000030, 0.022000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -6, 3, 0}, 180.864550, 0.000010, 0.031000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, -1, 0}, 178.534330, 0.000120, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 0, 0}, 181.897610, 0.000930, 0.021000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 1, -2}, 0.862790, 0.000020, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 1, 0}, 181.419090, 0.002110, 0.029000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 1, 2}, 180.918460, 0.000020, 0.133000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 2, 0}, 181.280670, 0.001210, 0.047000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 3, 0}, 180.895330, 0.000040, 0.127000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -3, -1, 0}, 181.113480, 0.000040, 0.021000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -3, 0, 0}, 181.396270, 0.000050, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -3, 1, 0}, 0.953580, 0.000120, 0.045000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -3, 2, 0}, 1.140250, 0.000020, 0.114000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -3, 0}, 181.690190, 0.000030, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -2, 0}, 181.587090, 0.000220, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -1, -2}, 0.814450, 0.000040, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -1, 0}, 181.400700, 0.005270, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -1, 2}, 0.866420, 0.000160, 0.107000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, -2}, 0.800530, 0.000190, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 0}, 180.959180, 0.084080, 0.044000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 2}, 180.900690, 0.000790, 0.254000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, -2}, 0.823260, 0.000240, 0.027000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, 0}, 180.861100, 0.089110, 0.104000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, 2}, 0.962780, 0.000040, 0.058000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 2, 0}, 180.860090, 0.003800, 0.277000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 3, 0}, 180.986020, 0.000250, 0.059000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 4, 0}, 180.876770, 0.000020, 0.033000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, -2, 0}, 180.329000, 0.000030, 0.027000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, -1, 0}, 179.512670, 0.000060, 0.042000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, -1, 1}, 177.587180, 0.000040, 0.096000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 0, 0}, 1.337640, 0.001290, 0.095000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 0, 1}, 353.598030, 0.000060, 0.347000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 1, 0}, 0.462880, 0.000150, 0.368000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 2, 0}, 0.186060, 0.000020, 0.063000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -4, 0}, 0.070570, 0.000090, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -3, 0}, 0.014260, 0.001070, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -2, -2}, 180.061210, 0.000090, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -2, 0}, 359.985420, 0.014340, 0.041000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, -2}, 179.959240, 0.000370, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, 0}, 359.984500, 0.182560, 0.088000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, 2}, 2.460090, 0.000020, 0.065000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, -2}, 180.098680, 0.000070, 0.040000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, 0}, 180.436080, 0.184570, 0.546000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, 2}, 0.427630, 0.000110, 0.035000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 1, -2}, 0.367030, 0.000140, 0.085000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 1, 0}, 180.409270, 0.033370, 0.066000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 1, 2}, 0.311380, 0.000070, 0.024000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 2, 0}, 180.337740, 0.002300, 0.035000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 2, 2}, 0.512570, 0.000010, 0.018000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 3, 0}, 180.409990, 0.000150, 0.024000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, -2, 0}, 180.097180, 0.000160, 0.081000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, -1, -1}, 172.498020, 0.000010, 0.080000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, -1, 0}, 180.060300, 0.000680, 1.059000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, -1, 1}, 177.587180, 0.000020, 0.070000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 0, -1}, 203.821420, 0.000070, 1.286000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 0, 0}, 0.601560, 0.001280, 0.070000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 1, -1}, 172.498020, 0.000010, 0.071000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 1, 0}, 0.184460, 0.000110, 0.036000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -5, 0}, 0.054920, 0.000020, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -4, 0}, 0.056110, 0.000350, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -3, -2}, 180.051030, 0.000030, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -3, 0}, 0.066380, 0.005530, 0.076000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, -2}, 180.077330, 0.000290, 0.037000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, 0}, 0.086420, 0.245150, 17.430000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, 2}, 180.054520, 0.000110, 0.037000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, -2}, 180.119560, 0.002510, 0.074000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, 0}, 180.119770, 1.143070, 0.075000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, 2}, 0.122420, 0.002270, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, -2}, 0.102860, 0.001580, 3.621000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, 0}, 180.131790, 0.068630, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, 2}, 0.143400, 0.000380, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, -2}, 180.103270, 0.000450, 0.077000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, 0}, 180.178240, 0.005040, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, 2}, 0.121830, 0.000050, 0.015000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 2, -2}, 180.113720, 0.000040, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 2, 0}, 179.964600, 0.000340, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 3, 0}, 179.947930, 0.000030, 0.015000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, -2, 0}, 0.182290, 0.000040, 0.080000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, -1, 0}, 0.123830, 0.000470, 0.039000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, 0, 0}, 0.142860, 0.000050, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -5, 0}, 0.100010, 0.000010, 0.067000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -4, 0}, 0.099680, 0.000150, 0.583000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -3, 0}, 0.090140, 0.004290, 0.087000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -3, 2}, 180.077730, 0.000020, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -2, -2}, 0.114890, 0.000080, 0.488000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -2, 0}, 180.128770, 0.012290, 0.040000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -2, 2}, 0.129180, 0.000070, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -1, -2}, 0.123530, 0.000430, 0.089000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -1, 0}, 180.126290, 0.010380, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -1, 2}, 0.121850, 0.000060, 0.015000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 0, -2}, 0.268600, 0.000020, 0.041000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 0, 0}, 180.114990, 0.001410, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 1, 0}, 180.129850, 0.000120, 0.015000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 5, -2, 0}, 0.121980, 0.000020, 0.027000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -4, 0}, 0.088890, 0.000060, 0.043000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -3, 0}, 180.141070, 0.000130, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -2, 0}, 180.128250, 0.000260, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -1, 0}, 180.129650, 0.000120, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, 0, 0}, 180.121850, 0.000030, 0.013000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 8, -3, 0}, 180.121980, 0.000020, 0.016000},
	{{0, 0, 2, 0, -2, 1, 0, 0, -2, 0, 0}, 41.732640, 0.000020, 0.044000},
	{{0, 0, 2, 0, -2, 1, 0, 0, 0, 0, 0}, 33.742770, 0.000030, 0.536000},
	{{0, 0, 2, 0, -2, 1, 0, 0, 2, -3, 0}, 331.132160, 0.000020, 0.076000},
	{{0, 0, 2, 0, -2, 1, 0, 0, 2, -1, 0}, 6.002220, 0.000050, 0.075000},
	{{0, 0, 2, 0, -2, 2, 0, 0, -2, 0, 0}, 283.488980, 0.000050, 0.044000},
	{{0, 0, 2, 0, -2, 2, 0, 0, -2, 1, 0}, 283.491580, 0.000050, 0.104000},
	{{0, 0, 2, 0, -2, 2, 0, 0, 0, -1, 0}, 100.101210, 0.000040, 0.088000},
	{{0, 0, 2, 0, -2, 2, 0, 0, 0, 0, 0}, 282.631020, 0.000090, 0.527000},
	{{0, 0, 2, 0, -2, 2, 0, 0, 0, 1, 0}, 283.141000, 0.000010, 0.066000},
	{{0, 0, 2, 0, -2, 2, 0, 0, 2, -2, 0}, 104.884390, 0.000020, 7.983000},
	{{0, 0, 2, 0, -2, 2, 0, 0, 2, -1, 0}, 280.954320, 0.000240, 0.075000},
	{{0, 0, 2, 0, -2, 3, 0, 0, -2, 0, 0}, 169.176080, 0.000060, 0.044000},
	{{0, 0, 2, 0, -2, 3, 0, 0, -2, 1, 0}, 169.169690, 0.000050, 0.105000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 0, -1, 0}, 351.461290, 0.000040, 0.088000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 0, 0, 0}, 170.302390, 0.000110, 0.517000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 0, 1, 0}, 169.548360, 0.000020, 0.066000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 2, -2, 0}, 348.064030, 0.000020, 6.281000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 2, -1, 0}, 170.933980, 0.000270, 0.075000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 2, 0, 0}, 170.933980, 0.000020, 0.037000},
	{{0, 0, 2, 0, -2, 5, 0, 0, -2, 0, 0}, 106.953160, 0.000030, 0.044000},
	{{0, 0, 2, 0, -2, 5, 0, 0, -2, 1, 0}, 168.165190, 0.000020, 0.105000},
	{{0, 0, 2, 0, -2, 5, 0, 0, 0, 0, 0}, 95.449810, 0.000020, 0.500000},
	{{0, 0, 2, 0, -2, 5, 0, 0, 2, -3, 0}, 140.766100, 0.000030, 0.077000},
	{{0, 0, 2, 0, -2, 5, 0, 0, 2, -1, 0}, 134.076060, 0.000030, 0.074000},
	{{0, 0, 2, 0, -1, -5, 0, 0, -2, -1, 0}, 198.781290, 0.000010, 0.028000},
	{{0, 0, 2, 0, -1, -5, 0, 0, -2, 0, 0}, 198.764250, 0.000130, 0.043000},
	{{0, 0, 2, 0, -1, -5, 0, 0, -2, 1, 0}, 198.763740, 0.000140, 0.103000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, -2, 0}, 198.855170, 0.000020, 0.040000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, -1, 0}, 198.985870, 0.000780, 0.087000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, 0, 0}, 199.277730, 0.000460, 0.573000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, 1, 0}, 199.102710, 0.000060, 0.067000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -3, 0}, 54.525650, 0.000020, 0.075000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -2, 0}, 18.661980, 0.002240, 35.635000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -1, 0}, 18.962500, 0.003620, 0.076000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, 0, 0}, 18.953650, 0.000260, 0.038000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 4, -3, 0}, 15.269330, 0.000050, 0.087000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 4, -2, 0}, 18.717830, 0.000070, 0.040000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 4, -1, 0}, 18.950850, 0.000030, 0.026000},
	{{0, 0, 2, 0, -1, -4, 0, 0, 2, -3, 0}, 196.551830, 0.000020, 0.075000},
	{{0, 0, 2, 0, -1, -4, 0, 0, 2, -2, 0}, 299.693320, 0.000110, 169.910000},
	{{0, 0, 2, 0, -1, -4, 0, 0, 2, -1, 0}, 156.419130, 0.000050, 0.075000},
	{{0, 0, 2, 0, -1, -3, 0, 0, 0, 0, 0}, 137.581760, 0.000010, 0.551000},
	{{0, 0, 2, 0, -1, -3, 0, 0, 2, -3, 0}, 309.045880, 0.000030, 0.076000},
	{{0, 0, 2, 0, -1, -3, 0, 0, 2, -2, 0}, 297.152710, 0.000010, 25.105000},
	{{0, 0, 2, 0, -1, -3, 0, 0, 2, -1, 0}, 252.202370, 0.000010, 0.075000},
	{{0, 0, 2, 0, -1, -2, 0, 0, -2, 0, 0}, 351.918410, 0.000060, 0.044000},
	{{0, 0, 2, 0, -1, -2, 0, 0, -2, 1, 0}, 351.918410, 0.000050, 0.104000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 0, -1, 0}, 169.626630, 0.000080, 0.088000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 0, 0, 0}, 351.039390, 0.000110, 0.541000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 0, 1, 0}, 351.918420, 0.000010, 0.066000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 2, -3, 0}, 146.216990, 0.000010, 0.076000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 2, -2, 0}, 171.273660, 0.000070, 13.554000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 2, -1, 0}, 349.908330, 0.000460, 0.075000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 2, 0, 0}, 349.908490, 0.000030, 0.038000},
	{{0, 0, 2, 0, -1, -1, 0, 0, -2, 0, 0}, 173.334670, 0.000020, 0.044000},
	{{0, 0, 2, 0, -1, -1, 0, 0, 0, 0, 0}, 173.451350, 0.000030, 0.531000},
	{{0, 0, 2, 0, -1, -1, 0, 0, 2, -3, 0}, 358.177820, 0.000020, 0.076000},
	{{0, 0, 2, 0, -1, -1, 0, 0, 2, -2, 0}, 3.177090, 0.000010, 9.283000},
	{{0, 0, 2, 0, -1, -1, 0, 0, 2, -1, 0}, 169.601130, 0.000040, 0.075000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -6, 1, 0}, 261.788350, 0.000020, 0.017000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -6, 2, 0}, 261.985260, 0.000010, 0.022000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -6, 3, 0}, 260.347820, 0.000010, 0.031000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, -1, 0}, 261.374420, 0.000090, 0.016000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 0, 0}, 261.486370, 0.000280, 0.021000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 1, 0}, 262.433060, 0.000630, 0.029000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 2, 0}, 262.777250, 0.000300, 0.048000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -3, 0, 0}, 262.900820, 0.000020, 0.028000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -3, 1, 0}, 86.467740, 0.000020, 0.046000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -2, 0}, 263.933250, 0.000140, 0.020000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -1, 0}, 263.286690, 0.001540, 0.028000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -1, 2}, 84.738500, 0.000030, 0.108000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, -2}, 85.326130, 0.000040, 0.020000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, 0}, 264.378850, 0.016440, 0.044000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, 2}, 264.378940, 0.000140, 0.249000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 1, -2}, 84.993930, 0.000020, 0.027000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 1, 0}, 264.832120, 0.015370, 0.105000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 1, 2}, 84.854610, 0.000030, 0.058000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 2, 0}, 264.947440, 0.000640, 0.271000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 3, 0}, 264.283990, 0.000060, 0.059000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, -2, 0}, 262.502770, 0.000010, 0.027000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, -1, 0}, 257.767510, 0.000060, 0.042000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 0, 0}, 254.072920, 0.000530, 0.096000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 0, 1}, 273.552720, 0.000030, 0.337000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 1, 0}, 244.219010, 0.000030, 0.357000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -3, 0}, 227.575870, 0.000010, 0.026000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -2, 0}, 247.831490, 0.000380, 0.041000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -1, 0}, 245.457490, 0.004560, 0.088000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 0, -2}, 90.374150, 0.000010, 0.040000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 0, 0}, 270.160440, 0.015890, 0.522000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 1, 0}, 271.983720, 0.002510, 0.066000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 2, 0}, 276.512760, 0.000150, 0.035000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 3, 0}, 236.077860, 0.000020, 0.024000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, -2, 0}, 84.369330, 0.000020, 0.082000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, -1, -1}, 257.668530, 0.000030, 0.081000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, -1, 0}, 248.945790, 0.000040, 0.972000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, -1, 1}, 79.552850, 0.000030, 0.069000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, -1}, 257.932500, 0.000280, 1.160000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, 0}, 253.046050, 0.000320, 0.070000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, 1}, 78.794610, 0.000020, 0.036000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 1, -1}, 257.668530, 0.000030, 0.071000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 1, 0}, 257.773260, 0.000050, 0.036000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -3, 0}, 260.510650, 0.000020, 0.076000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -2, 0}, 201.315080, 0.000620, 7.058000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, -2}, 320.375530, 0.000040, 0.074000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, -1}, 79.893040, 0.000030, 39.875000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, 0}, 307.248960, 0.012990, 0.075000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, 2}, 125.669250, 0.000030, 0.025000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 0, -2}, 194.820260, 0.000040, 5.213000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 0, -1}, 80.555490, 0.000040, 0.076000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 0, 0}, 299.596800, 0.000720, 0.038000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 1, -2}, 339.130260, 0.000020, 0.077000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 1, 0}, 282.547310, 0.000050, 0.025000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 3, -1, 0}, 257.772360, 0.000010, 0.039000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 4, -2, 0}, 304.781090, 0.000170, 0.040000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 4, -1, 0}, 305.634160, 0.000110, 0.026000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 4, 0, 0}, 329.375320, 0.000020, 0.019000},
	{{0, 0, 2, 0, -1, 5, 0, 0, 2, -2, 0}, 128.621170, 0.000020, 3.211000},
	{{0, 0, 2, 0, -1, 5, 0, 0, 2, 0, 0}, 128.621170, 0.000020, 0.037000},
	{{0, 0, 2, 0, 0, -7, 0, 0, 2, -2, 0}, 15.198870, 0.000040, 85.805000},
	{{0, 0, 2, 0, 0, -7, 0, 0, 2, -1, 0}, 8.462910, 0.000020, 0.076000},
	{{0, 0, 2, 0, 0, -6, 0, 0, 2, -2, 0}, 8.234460, 0.000020, 44.857000},
	{{0, 0, 2, 0, 0, -6, 0, 0, 2, -1, 0}, 191.285810, 0.000030, 0.075000},
	{{0, 0, 2, 0, 0, -6, 3, 0, 0, 0, 0}, 12.025260, 0.000010, 0.546000},
	{{0, 0, 2, 0, 0, -6, 3, 0, 2, -1, 0}, 7.969070, 0.000030, 0.075000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -4, 1, 0}, 187.841830, 0.000020, 0.029000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, -1, 0}, 187.157080, 0.000050, 0.028000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 0, 0}, 185.899220, 0.000470, 0.044000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 1, 0}, 189.059480, 0.000520, 0.104000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 2, 0}, 189.104140, 0.000010, 0.277000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, -2, 0}, 7.617590, 0.000100, 0.041000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, -1, 0}, 7.373740, 0.001110, 0.088000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, 0, 0}, 187.724800, 0.001080, 0.546000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, 1, 0}, 188.494230, 0.000170, 0.066000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, 2, 0}, 188.794040, 0.000030, 0.035000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -3, 0}, 15.964550, 0.000040, 0.076000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -2, 0}, 7.954740, 0.001490, 17.781000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -1, 0}, 187.648950, 0.006750, 0.075000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, 0, -2}, 8.638990, 0.000010, 3.607000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, 0, 0}, 187.228670, 0.000380, 0.038000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, 1, 0}, 187.665300, 0.000030, 0.025000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, 2, 0}, 8.696290, 0.000010, 0.019000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 4, -3, 0}, 5.145380, 0.000020, 0.087000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 4, -2, 0}, 187.721340, 0.000070, 0.040000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 4, -1, 0}, 187.669970, 0.000060, 0.026000},
	{{0, 0, 2, 0, 0, -4, 0, 0, -2, 0, 0}, 5.373120, 0.000090, 0.044000},
	{{0, 0, 2, 0, 0, -4, 0, 0, -2, 1, 0}, 5.373140, 0.000100, 0.104000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, -2, 0}, 186.885810, 0.000010, 0.041000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, -1, 0}, 186.231490, 0.000130, 0.088000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, 0, 0}, 7.603410, 0.000250, 0.536000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, 1, 0}, 6.056300, 0.000050, 0.066000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, -3, 0}, 268.231340, 0.000010, 0.076000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, -2, 0}, 185.537920, 0.000100, 11.088000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, -1, 0}, 6.184640, 0.000850, 0.075000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, 0, 0}, 6.534570, 0.000040, 0.038000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 4, -2, 0}, 6.919480, 0.000010, 0.040000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -4, 1, 0}, 272.937980, 0.000030, 0.029000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, -1, 0}, 273.046980, 0.000080, 0.028000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 0, 0}, 273.180740, 0.000710, 0.044000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 1, 0}, 272.736080, 0.000710, 0.104000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 2, 0}, 272.720410, 0.000040, 0.272000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, -2, 0}, 93.126690, 0.000040, 0.041000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, -1, 0}, 92.941900, 0.000500, 0.088000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 0, 0}, 273.018020, 0.001500, 0.527000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 1, 0}, 272.833460, 0.000260, 0.066000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 2, 0}, 272.747900, 0.000020, 0.035000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 1, 0, -1}, 294.420200, 0.000020, 1.184000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, -3, 0}, 117.050410, 0.000030, 0.076000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, -2, 0}, 92.754040, 0.000300, 8.056000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, -1, 0}, 272.875590, 0.004570, 0.075000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, 0, -2}, 92.718310, 0.000020, 4.776000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, 0, 0}, 272.951770, 0.000220, 0.038000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 4, -2, 0}, 273.020680, 0.000060, 0.040000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 4, -1, 0}, 272.885700, 0.000040, 0.026000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -4, -1, 0}, 0.216800, 0.000010, 0.016000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -4, 0, 0}, 180.202690, 0.000050, 0.021000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -4, 1, 0}, 180.205070, 0.000080, 0.029000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -4, 2, 0}, 180.212680, 0.000040, 0.048000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, -2, 0}, 180.224540, 0.000030, 0.020000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, -1, 0}, 180.230630, 0.000240, 0.028000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 0, 0}, 180.234050, 0.003580, 0.044000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 0, 2}, 180.232470, 0.000010, 0.248000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 1, 0}, 180.211680, 0.003580, 0.105000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 2, 0}, 180.238340, 0.000160, 0.270000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -1, 0, 0}, 359.920710, 0.000040, 0.096000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -1, 0, 1}, 10.526510, 0.000010, 0.335000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -3, 0}, 0.454130, 0.000020, 0.026000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -2, 0}, 359.851860, 0.000080, 0.041000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -1, 0}, 359.883180, 0.001680, 0.088000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 0, 0}, 180.105310, 0.007310, 0.518000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 1, 0}, 180.095980, 0.001310, 0.066000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 2, 0}, 180.018310, 0.000090, 0.035000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 3, 0}, 0.247970, 0.000010, 0.024000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 1, 0, -1}, 189.781150, 0.000010, 1.139000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 1, 0, 0}, 359.929080, 0.000050, 0.070000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -3, 0}, 173.222450, 0.000030, 0.076000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -2, 0}, 359.986170, 0.000780, 6.326000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, -2}, 180.017870, 0.000080, 0.074000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, -1}, 189.711880, 0.000010, 115.334000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, 0}, 180.033530, 0.018730, 0.075000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, 2}, 0.034300, 0.000040, 0.025000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 0, -2}, 359.891290, 0.000070, 5.700000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 0, 0}, 180.064860, 0.000880, 0.037000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 1, -2}, 180.005550, 0.000040, 0.076000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 1, 0}, 180.005550, 0.000040, 0.025000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, -3, 0}, 357.229570, 0.000010, 0.086000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, -2, 0}, 180.043750, 0.000250, 0.040000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, -1, 0}, 180.039920, 0.000150, 0.026000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, 0, 0}, 180.048660, 0.000020, 0.019000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -4, 0, 0}, 258.563950, 0.000010, 0.021000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -4, 1, 0}, 258.096160, 0.000020, 0.029000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, -1, 0}, 258.378270, 0.000120, 0.028000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 0, 0}, 258.423060, 0.001010, 0.044000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 0, 2}, 258.447740, 0.000010, 0.245000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 1, 0}, 258.458870, 0.000980, 0.105000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 2, 0}, 258.481530, 0.000050, 0.267000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, -1, 0}, 256.501200, 0.000270, 0.089000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 0, 0}, 259.081320, 0.001070, 0.509000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 1, 0}, 259.627420, 0.000150, 0.066000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 1, 0, -1}, 246.322250, 0.000020, 1.096000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, -2, 0}, 254.482820, 0.000020, 5.207000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, -1, 0}, 262.643380, 0.000770, 0.074000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, 0, 0}, 259.251160, 0.000040, 0.037000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 4, -2, 0}, 262.419340, 0.000010, 0.040000},
	{{0, 0, 2, 0, 0, 0, -3, 0, -2, 0, 0}, 353.606840, 0.000030, 0.044000},
	{{0, 0, 2, 0, 0, 0, -3, 0, 0, 0, 0}, 353.699780, 0.000030, 0.509000},
	{{0, 0, 2, 0, 0, 0, -3, 0, 2, -1, 0}, 354.081930, 0.000030, 0.074000},
	{{0, 0, 2, 0, 0, 0, -2, 0, -2, 0, 0}, 178.798450, 0.000090, 0.044000},
	{{0, 0, 2, 0, 0, 0, -2, 0, -2, 1, 0}, 178.798450, 0.000080, 0.105000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 0, -1, 0}, 1.371150, 0.000040, 0.089000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 0, 0, 0}, 179.396040, 0.000150, 0.506000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 0, 1, 0}, 176.847940, 0.000020, 0.066000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 2, -1, 0}, 179.760670, 0.000280, 0.074000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 2, 0, 0}, 359.986920, 0.000020, 0.037000},
	{{0, 0, 2, 0, 0, 0, -1, 0, -2, 0, 0}, 249.047210, 0.000030, 0.044000},
	{{0, 0, 2, 0, 0, 0, -1, 0, 0, 0, 0}, 247.253640, 0.000020, 0.503000},
	{{0, 0, 2, 0, 0, 0, 0, -2, -2, 0, 0}, 180.219050, 0.000030, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, -2, 0, 0, 0}, 180.125200, 0.000050, 0.503000},
	{{0, 0, 2, 0, 0, 0, 0, -2, 2, -1, 0}, 180.018970, 0.000070, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, -1, -2, 0, 0}, 258.845400, 0.000020, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, -1, 0, 0, 0}, 258.679980, 0.000010, 0.502000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -4, 0, 0}, 357.227810, 0.000020, 0.021000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -4, 1, 0}, 0.897750, 0.000020, 0.029000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, -1, 0}, 349.558780, 0.000050, 0.028000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 1.689490, 0.000620, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 1, 0}, 0.945700, 0.000550, 0.105000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 2, 0}, 11.447470, 0.000060, 0.265000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 0, -1}, 11.153410, 0.000050, 0.042000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 0, 0}, 203.562740, 0.000040, 0.096000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 0, 1}, 194.377840, 0.000110, 0.327000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 1, -1}, 10.397260, 0.000010, 0.095000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 356.893610, 0.000140, 0.089000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 20.938600, 0.003160, 0.500000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 20.405050, 0.000350, 0.066000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 2, 0}, 46.074930, 0.000020, 0.035000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, -1, 0}, 204.536690, 0.000010, 0.898000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 0, -1}, 8.091330, 0.000240, 1.057000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0}, 204.624370, 0.000070, 0.070000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 1}, 186.155030, 0.000050, 0.036000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 210.826710, 0.000030, 0.077000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 23.149970, 0.002030, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, -2}, 24.357680, 0.000020, 9.300000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, -1}, 192.712130, 0.000080, 0.075000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 9.805210, 0.000090, 0.037000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 1, 0}, 202.239610, 0.000010, 0.025000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 4, -2, 0}, 20.873490, 0.000030, 0.040000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 4, -1, 0}, 23.052080, 0.000020, 0.026000},
	{{0, 0, 2, 0, 0, 1, 0, 0, -2, 0, 0}, 63.320400, 0.000030, 0.044000},
	{{0, 0, 2, 0, 0, 1, 0, 0, -2, 1, 0}, 63.290340, 0.000010, 0.106000},
	{{0, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0}, 66.742700, 0.000010, 0.492000},
	{{0, 0, 2, 0, 0, 2, 0, 0, 2, -1, 0}, 307.952130, 0.000020, 0.074000},
	{{0, 0, 2, 0, 1, -9, 0, 0, 2, -2, 0}, 86.508070, 0.000010, 210.377000},
	{{0, 0, 2, 0, 1, -5, 0, 0, -2, 0, 0}, 287.028560, 0.000040, 0.044000},
	{{0, 0, 2, 0, 1, -5, 0, 0, -2, 1, 0}, 289.358550, 0.000040, 0.105000},
	{{0, 0, 2, 0, 1, -5, 0, 0, 0, -1, 0}, 250.304440, 0.000010, 0.088000},
	{{0, 0, 2, 0, 1, -5, 0, 0, 0, 0, 0}, 315.213860, 0.000040, 0.522000},
	{{0, 0, 2, 0, 1, -5, 0, 0, 2, -3, 0}, 281.609410, 0.000010, 0.076000},
	{{0, 0, 2, 0, 1, -5, 0, 0, 2, -2, 0}, 7.340850, 0.000020, 7.115000},
	{{0, 0, 2, 0, 1, -5, 0, 0, 2, -1, 0}, 18.630960, 0.000080, 0.075000},
	{{0, 0, 2, 0, 1, -2, 0, 0, -2, 0, 0}, 79.222840, 0.000050, 0.044000},
	{{0, 0, 2, 0, 1, -2, 0, 0, -2, 1, 0}, 79.224220, 0.000040, 0.106000},
	{{0, 0, 2, 0, 1, -2, 0, 0, 0, -1, 0}, 78.832980, 0.000010, 0.089000},
	{{0, 0, 2, 0, 1, -2, 0, 0, 0, 0, 0}, 77.843410, 0.000040, 0.496000},
	{{0, 0, 2, 0, 1, -2, 0, 0, 0, 1, 0}, 78.832980, 0.000010, 0.065000},
	{{0, 0, 2, 0, 1, -2, 0, 0, 2, -3, 0}, 258.430920, 0.000010, 0.077000},
	{{0, 0, 2, 0, 1, -2, 0, 0, 2, -1, 0}, 78.430920, 0.000010, 0.074000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -4, 0, 0}, 323.199600, 0.000010, 0.021000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -4, 2, 0}, 143.032380, 0.000010, 0.048000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -2, -1, 0}, 139.484990, 0.000040, 0.028000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -2, 0, 0}, 139.783650, 0.000250, 0.044000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -2, 1, 0}, 141.848270, 0.000240, 0.106000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -1, 0, -1}, 332.537420, 0.000020, 0.042000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -1, 1, -1}, 152.835980, 0.000010, 0.096000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 0, -1, 0}, 136.659960, 0.000090, 0.090000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 0}, 133.567490, 0.000150, 0.480000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 1, -1, -1}, 332.640340, 0.000030, 0.082000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 1, 0, -1}, 332.973250, 0.000020, 0.970000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 1, 1, -1}, 152.690490, 0.000010, 0.070000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, -1, 0}, 67.111610, 0.000070, 0.074000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, 0, -2}, 166.387040, 0.000020, 43.055000},
	{{0, 0, 2, 0, 1, 2, 0, 0, 2, -3, 0}, 135.697030, 0.000020, 0.078000},
	{{0, 0, 2, 0, 1, 2, 0, 0, 2, -1, 0}, 135.697030, 0.000020, 0.073000},
	{{0, 0, 2, 0, 1, 5, 0, 0, 2, -3, 0}, 110.058140, 0.000020, 0.078000},
	{{0, 0, 2, 0, 1, 5, 0, 0, 2, -2, 0}, 110.448110, 0.000020, 2.083000},
	{{0, 0, 2, 0, 1, 5, 0, 0, 2, -1, 0}, 110.058140, 0.000020, 0.073000},
	{{0, 0, 2, 0, 1, 5, 0, 0, 2, 0, 0}, 110.448110, 0.000020, 0.037000},
	{{0, 0, 2, 0, 2, -10, 0, 0, 2, -3, 0}, 197.615990, 0.000020, 0.076000},
	{{0, 0, 2, 0, 2, -10, 0, 0, 2, -2, 0}, 197.679670, 0.000010, 18.146000},
	{{0, 0, 2, 0, 2, -10, 0, 0, 2, -1, 0}, 17.615990, 0.000020, 0.075000},
	{{0, 0, 2, 0, 2, -8, 0, 0, -2, 0, 0}, 101.769910, 0.000020, 0.044000},
	{{0, 0, 2, 0, 2, -8, 0, 0, 0, 0, 0}, 101.736400, 0.000040, 0.527000},
	{{0, 0, 2, 0, 2, -8, 0, 0, 2, -1, 0}, 101.409280, 0.000070, 0.075000},
	{{0, 0, 2, 0, 2, -7, 0, 0, -2, 0, 0}, 8.273210, 0.000060, 0.044000},
	{{0, 0, 2, 0, 2, -7, 0, 0, -2, 1, 0}, 8.273210, 0.000060, 0.105000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 0, -1, 0}, 188.855310, 0.000040, 0.088000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 0, 0, 0}, 8.291090, 0.000120, 0.518000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 0, 1, 0}, 8.273210, 0.000010, 0.066000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 2, -2, 0}, 188.748770, 0.000020, 6.371000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 2, -1, 0}, 8.735060, 0.000280, 0.075000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 2, 0, 0}, 8.735030, 0.000020, 0.037000},
	{{0, 0, 2, 0, 2, -6, 0, 0, 2, -3, 0}, 268.743310, 0.000010, 0.077000},
	{{0, 0, 2, 0, 2, -6, 0, 0, 2, -1, 0}, 268.743310, 0.000010, 0.074000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -4, 1, 0}, 323.367760, 0.000010, 0.029000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, -1, 0}, 323.317430, 0.000040, 0.028000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 0, 0}, 323.369740, 0.000390, 0.044000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 1, 0}, 323.224040, 0.000400, 0.105000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 2, 0}, 323.362420, 0.000020, 0.265000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 0, -1, 0}, 321.826010, 0.000130, 0.089000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 0, 0, 0}, 322.394710, 0.000390, 0.500000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 0, 1, 0}, 322.715390, 0.000050, 0.066000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 2, -3, 0}, 348.163030, 0.000030, 0.077000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 2, -2, 0}, 323.698840, 0.000010, 4.447000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 2, -1, 0}, 328.818560, 0.000150, 0.074000},
	{{0, 0, 2, 0, 2, 0, 0, 0, -2, 0, 0}, 138.263630, 0.000020, 0.044000},
	{{0, 0, 2, 0, 2, 0, 0, 0, 2, -3, 0}, 128.323620, 0.000030, 0.078000},
	{{0, 0, 2, 0, 2, 0, 0, 0, 2, -1, 0}, 308.323620, 0.000030, 0.073000},
	{{0, 0, 2, 0, 3, -5, 0, 0, 2, -2, 0}, 328.854440, 0.000020, 3.235000},
	{{0, 0, 2, 0, 3, -5, 0, 0, 2, 0, 0}, 328.523290, 0.000030, 0.037000},
	{{0, 0, 2, 0, 3, -2, 0, 0, 2, -3, 0}, 316.218330, 0.000010, 0.078000},
	{{0, 0, 2, 0, 3, -2, 0, 0, 2, -1, 0}, 316.218330, 0.000010, 0.073000},
	{{0, 0, 2, 0, 3, -1, 0, 0, 2, -3, 0}, 126.939630, 0.000020, 0.078000},
	{{0, 0, 2, 0, 3, -1, 0, 0, 2, -1, 0}, 126.939630, 0.000020, 0.073000},
	{{0, 0, 2, 0, 4, -3, 0, 0, 2, -3, 0}, 248.541600, 0.000020, 0.078000},
	{{0, 0, 2, 0, 4, -3, 0, 0, 2, -1, 0}, 248.541600, 0.000020, 0.073000},
	{{0, 0, 2, 0, 4, -3, 0, 0, 2, 0, 0}, 248.541600, 0.000010, 0.037000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, -3, 0}, 127.337480, 0.000020, 0.078000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, -2, 0}, 127.131800, 0.000030, 2.019000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, -1, 0}, 127.337480, 0.000020, 0.073000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, 0, -2}, 307.076760, 0.000010, 6.181000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, 0, 0}, 127.131800, 0.000030, 0.037000},
	{{0, 0, 2, 0, 5, -5, 0, 0, 2, -3, 0}, 264.916990, 0.000020, 0.078000},
	{{0, 0, 2, 0, 5, -5, 0, 0, 2, -2, 0}, 310.681380, 0.000010, 2.093000},
	{{0, 0, 2, 0, 5, -5, 0, 0, 2, -1, 0}, 264.916990, 0.000020, 0.073000},
	{{0, 0, 2, 0, 5, -5, 0, 0, 2, 0, 0}, 310.681380, 0.000010, 0.037000},
	{{0, 0, 2, 1, -1, 0, 0, 0, 0, 0, 0}, 228.600120, 0.000010, 0.409000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0}, 253.110000, 0.000020, 0.395000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, -3, 0}, 283.579090, 0.000010, 0.080000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, -1, 0}, 283.579090, 0.000010, 0.071000},
	{{0, 0, 2, 2, -1, 0, 0, 0, 2, -3, 0}, 102.541360, 0.000010, 0.083000},
	{{0, 0, 2, 2, -1, 0, 0, 0, 2, -1, 0}, 102.541360, 0.000010, 0.069000},
	{{0, 0, 2, 2, -1, 0, 0, 0, 2, 0, 0}, 282.541360, 0.000020, 0.036000},
	{{0, 0, 3, -10, 2, 0, 0, 0, -2, 0, 0}, 22.511410, 0.000010, 0.037000},
	{{0, 0, 3, -10, 2, 0, 0, 0, -2, 2, 0}, 202.511410, 0.000010, 2.672000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 1, 0}, 207.616920, 0.000090, 0.075000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 2, 0}, 26.837880, 0.000100, 89.761000},
	{{0, 0, 3, -9, 0, 0, 0, 0, 0, 1, 0}, 27.616580, 0.000020, 0.087000},
	{{0, 0, 3, -9, 0, 0, 0, 2, -2, 2, 0}, 44.970770, 0.000010, 1002.658000},
	{{0, 0, 3, -9, 0, 0, 1, 0, -2, 2, 0}, 0.074070, 0.000040, 1313.736000},
	{{0, 0, 3, -9, 2, 0, 0, 0, -2, 0, 0}, 51.519600, 0.000030, 0.038000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, -1, 0}, 348.732150, 0.000010, 0.069000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, 0, 0}, 304.592870, 0.000040, 0.798000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, 1, 0}, 348.732150, 0.000010, 0.083000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 2, -1, 0}, 349.663840, 0.000040, 0.098000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 2, 0, 0}, 349.656870, 0.000040, 0.043000},
	{{0, 0, 3, -8, 1, 5, 0, 0, 0, -1, 0}, 21.863940, 0.000010, 0.070000},
	{{0, 0, 3, -8, 1, 5, 0, 0, 0, 0, 0}, 21.825770, 0.000090, 1.001000},
	{{0, 0, 3, -8, 1, 5, 0, 0, 0, 1, 0}, 21.863940, 0.000010, 0.082000},
	{{0, 0, 3, -8, 1, 5, 0, 0, 2, -1, 0}, 22.315940, 0.000070, 0.095000},
	{{0, 0, 3, -8, 1, 5, 0, 0, 2, 0, 0}, 21.999160, 0.000070, 0.042000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -4, 0, 0}, 209.726390, 0.000020, 0.020000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -4, 1, 0}, 209.716540, 0.000040, 0.027000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -4, 2, 0}, 209.716880, 0.000020, 0.042000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, -2, 0}, 209.715560, 0.000020, 0.019000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, -1, 0}, 208.764620, 0.000070, 0.026000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 0, 0}, 209.493560, 0.000530, 0.039000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 0, 2}, 209.717350, 0.000030, 0.903000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 1, 0}, 210.390210, 0.000370, 0.080000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 2, 0}, 32.099180, 0.000030, 1.293000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -1, 0, 0}, 28.939120, 0.000040, 0.075000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, -2, 0}, 38.221200, 0.000030, 0.036000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, -1, 0}, 31.310240, 0.001010, 0.070000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 0, 0}, 29.797470, 0.011210, 0.999000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 1, 0}, 29.217850, 0.003600, 0.082000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 2, 0}, 28.913810, 0.000310, 0.039000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 3, 0}, 27.915750, 0.000010, 0.026000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 1, -2, 0}, 29.906110, 0.000010, 0.066000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -3, 0}, 30.368120, 0.000030, 0.062000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -2, 0}, 30.302480, 0.000380, 0.360000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -1, -2}, 209.746920, 0.000020, 0.061000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -1, 0}, 29.961250, 0.009710, 0.095000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, -2}, 29.744500, 0.000130, 0.322000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, 0}, 29.681060, 0.009050, 0.042000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, 2}, 209.749010, 0.000020, 0.020000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 1, -2}, 209.746440, 0.000010, 0.099000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 1, 0}, 29.464930, 0.000890, 0.027000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 2, 0}, 29.363210, 0.000100, 0.020000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 3, -1, 0}, 209.740230, 0.000010, 0.044000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 3, 0, 0}, 29.740230, 0.000020, 0.028000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, -2, 0}, 30.028310, 0.000190, 0.046000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, -1, 0}, 29.809190, 0.000390, 0.028000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, 0, 0}, 29.654920, 0.000160, 0.021000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, 1, 0}, 29.732290, 0.000040, 0.016000},
	{{0, 0, 3, -8, 5, -5, 0, 0, 2, 0, 0}, 165.952720, 0.000020, 0.042000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 2, -1}, 144.548930, 0.000190, 0.040000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 3, -1}, 144.409860, 0.000230, 0.087000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -2, 0, 0}, 203.691630, 0.000030, 0.039000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 0, -1}, 322.161690, 0.000050, 0.038000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 0, 1}, 322.274950, 0.000040, 3.012000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 1, -1}, 322.162540, 0.000700, 0.075000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, -3}, 328.433700, 0.000010, 0.037000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, -1}, 144.439170, 0.018060, 650.233000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, 1}, 328.433700, 0.000010, 0.037000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 3, -1}, 144.477580, 0.000860, 0.075000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 4, -1}, 144.478140, 0.000060, 0.038000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, -1, 0}, 250.468170, 0.000080, 0.072000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, 0, 0}, 255.387250, 0.000400, 1.385000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, 1, 0}, 251.469780, 0.000080, 0.080000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 0, -1}, 143.176750, 0.000020, 0.563000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 1, -1}, 143.843520, 0.000540, 0.087000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 2, -1}, 144.349120, 0.000230, 0.040000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 3, -1}, 144.394160, 0.000030, 0.026000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, -1, 0}, 351.934880, 0.000090, 0.093000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, 0, 0}, 341.783710, 0.000090, 0.042000},
	{{0, 0, 3, -7, 1, 0, 0, 0, 0, 0, 0}, 92.847460, 0.000010, 1.569000},
	{{0, 0, 3, -7, 2, 0, 0, 0, 0, 0, 0}, 300.596360, 0.000010, 1.808000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -4, 0, 0}, 271.976400, 0.000020, 0.020000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -4, 2, 0}, 273.161720, 0.000020, 0.043000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, -1, 0}, 272.008250, 0.000130, 0.026000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 0, 0}, 271.354340, 0.001130, 0.040000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 0, 2}, 271.746550, 0.000030, 0.522000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 1, 0}, 273.645100, 0.001650, 0.086000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 2, 0}, 280.939730, 0.000040, 0.631000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -1, 0, 0}, 93.238110, 0.000020, 0.080000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -1, 0, 1}, 352.311670, 0.000030, 1.158000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -2, 0}, 268.665880, 0.000200, 0.037000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -1, 0}, 268.916530, 0.003100, 0.074000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -1, 1}, 170.658600, 0.000020, 42.830000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, 0}, 271.342540, 0.016730, 5.260000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 1, 0}, 269.157510, 0.003250, 0.077000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 2, 0}, 269.245340, 0.000220, 0.038000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 3, 0}, 268.534870, 0.000010, 0.025000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 1, -2, 0}, 94.110470, 0.000010, 0.070000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 1, 0, -1}, 353.646890, 0.000030, 0.804000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 1, 0, 0}, 93.028650, 0.000030, 0.082000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -2, 0}, 278.569850, 0.000080, 0.509000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -1, 0}, 275.236880, 0.002340, 0.089000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 0, -2}, 274.745560, 0.000030, 0.435000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 0, 0}, 274.964650, 0.001620, 0.041000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 1, 0}, 273.485710, 0.000170, 0.026000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 4, -2, 0}, 274.533630, 0.000030, 0.044000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 4, -1, 0}, 274.524850, 0.000030, 0.028000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 4, 0, 0}, 274.685770, 0.000020, 0.020000},
	{{0, 0, 3, -6, 0, 2, 0, 0, 0, 0, 0}, 331.076610, 0.000020, 8.183000},
	{{0, 0, 3, -6, 1, 0, 0, 0, -2, 0, 0}, 124.888750, 0.000010, 0.040000},
	{{0, 0, 3, -6, 1, 0, 0, 0, 0, 0, 0}, 126.450610, 0.000090, 9.452000},
	{{0, 0, 3, -6, 1, 0, 0, 0, 2, 0, 0}, 125.450240, 0.000020, 0.041000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -4, 1, 0}, 331.159560, 0.000010, 0.028000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, -1, 0}, 331.159550, 0.000050, 0.026000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 0, 0}, 331.075400, 0.000460, 0.040000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 0, 2}, 331.159560, 0.000010, 0.479000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 1, 0}, 331.363130, 0.000720, 0.087000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 2, 0}, 331.154290, 0.000030, 0.571000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, -2, 0}, 329.911490, 0.000060, 0.038000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, -1, 0}, 329.959500, 0.000920, 0.075000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 0, 0}, 330.474140, 0.004910, 46.520000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 1, 0}, 329.968190, 0.000920, 0.076000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 2, 0}, 329.923020, 0.000060, 0.038000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, -2, 0}, 331.726370, 0.000020, 0.557000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, -1, 0}, 331.440390, 0.000730, 0.087000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, 0, -2}, 331.231320, 0.000010, 0.470000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, 0, 0}, 331.122520, 0.000470, 0.040000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, 1, 0}, 331.218660, 0.000050, 0.026000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 4, -2, 0}, 331.404050, 0.000010, 0.044000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 4, -1, 0}, 331.231320, 0.000020, 0.028000},
	{{0, 0, 3, -6, 3, 0, 0, 0, 0, 0, 0}, 235.663750, 0.000050, 15.922000},
	{{0, 0, 3, -5, -4, 0, 0, 0, -2, 0, 0}, 127.663300, 0.000010, 0.040000},
	{{0, 0, 3, -5, -4, 0, 0, 0, -2, 1, 0}, 127.663300, 0.000020, 0.087000},
	{{0, 0, 3, -5, -4, 0, 0, 0, 0, 0, 0}, 179.452460, 0.000010, 229.298000},
	{{0, 0, 3, -5, -4, 0, 0, 0, 2, -1, 0}, 127.770340, 0.000020, 0.087000},
	{{0, 0, 3, -5, -4, 0, 0, 0, 2, 0, 0}, 127.770340, 0.000010, 0.040000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -4, 0, 0}, 301.538020, 0.000040, 0.020000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -4, 1, 0}, 301.592680, 0.000110, 0.028000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -4, 2, 0}, 301.797530, 0.000060, 0.044000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, -2, 0}, 301.729290, 0.000030, 0.020000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, -1, 0}, 301.396940, 0.000300, 0.027000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, 0}, 301.847890, 0.003410, 0.041000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, 2}, 301.888790, 0.000060, 0.408000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 1, 0}, 301.792700, 0.005100, 0.090000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 2, 0}, 302.048410, 0.000220, 0.473000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 3, 0}, 301.732120, 0.000010, 0.065000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -1, 0, 0}, 121.509260, 0.000110, 0.083000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -1, 0, 1}, 22.822020, 0.000030, 0.717000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -1, 1, 0}, 121.836080, 0.000010, 0.814000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -3, 0}, 299.695050, 0.000010, 0.025000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -2, 0}, 300.210530, 0.000290, 0.038000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -1, 0}, 300.170100, 0.004100, 0.077000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 0, 0}, 300.803870, 0.020090, 2.928000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, -2}, 118.466300, 0.000180, 0.075000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, 0}, 300.068520, 0.003740, 0.074000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 2, -2}, 118.126510, 0.000370, 123.995000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 2, 0}, 299.954490, 0.000240, 0.037000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 3, -2}, 115.269600, 0.000010, 0.075000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 3, 0}, 299.551870, 0.000010, 0.025000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, -1, 0}, 121.182570, 0.000010, 1.833000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, -1, 1}, 203.176170, 0.000030, 0.078000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 0, -1}, 23.012260, 0.000130, 1.404000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 0, 0}, 303.321130, 0.000010, 0.079000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 0, 1}, 203.021770, 0.000020, 0.038000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -2, 0}, 301.957980, 0.000110, 0.698000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -1, 0}, 302.071600, 0.003410, 0.085000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 0, -2}, 301.242540, 0.000050, 0.566000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 0, 0}, 301.136690, 0.001960, 0.040000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 1, -2}, 298.510550, 0.000030, 0.087000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 1, 0}, 301.183860, 0.000200, 0.026000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 2, 0}, 301.382560, 0.000020, 0.019000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 4, -2, 0}, 301.696470, 0.000040, 0.043000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 4, -1, 0}, 301.427430, 0.000070, 0.027000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 4, 0, 0}, 301.625770, 0.000040, 0.020000},
	{{0, 0, 3, -5, 2, 0, 0, 0, 0, 0, 0}, 0.406370, 0.000020, 1.960000},
	{{0, 0, 3, -5, 2, 0, 0, 0, 2, 0, 0}, 0.985150, 0.000010, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, -1, 0}, 330.161110, 0.000030, 0.016000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 0, 0}, 329.009700, 0.000130, 0.021000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 1, 0}, 327.463650, 0.000290, 0.028000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 2, 0}, 328.469940, 0.000180, 0.045000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -3, 1, 0}, 150.321390, 0.000040, 0.044000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, -2, 0}, 328.802240, 0.000090, 0.020000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, -1, 0}, 327.554570, 0.000970, 0.027000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, -1, 2}, 148.614910, 0.000010, 0.097000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, -2}, 148.746510, 0.000030, 0.020000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, 0}, 328.291860, 0.010990, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, 2}, 328.453120, 0.000150, 0.335000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 1, -2}, 148.739090, 0.000030, 0.027000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 1, 0}, 328.675740, 0.014310, 0.094000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 2, 0}, 329.422850, 0.000630, 0.378000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 3, 0}, 328.170780, 0.000040, 0.063000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, -1, 1}, 234.815450, 0.000050, 0.088000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, -1}, 54.526280, 0.000010, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, 0}, 151.032200, 0.002270, 0.087000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, 1}, 54.517510, 0.000060, 0.519000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 1, 0}, 150.817310, 0.000240, 0.568000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 2, 0}, 151.113380, 0.000020, 0.067000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -3, 0}, 330.060330, 0.000040, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -2, 0}, 329.662500, 0.000660, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, -2}, 149.910720, 0.000020, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, 0}, 329.613830, 0.009940, 0.081000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, 2}, 329.935970, 0.000010, 0.069000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 0, -2}, 149.849070, 0.000030, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 0, 0}, 330.087140, 0.046670, 1.145000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 0, 2}, 149.734350, 0.000030, 0.036000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 1, 0}, 330.630190, 0.007890, 0.071000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 1, 2}, 149.910720, 0.000020, 0.024000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 2, 0}, 330.980900, 0.000550, 0.037000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 3, 0}, 331.042820, 0.000040, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -3, 0}, 331.554750, 0.000040, 0.038000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -2, 0}, 331.556490, 0.000610, 0.075000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, -2}, 151.650980, 0.000010, 0.037000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, -1}, 54.795100, 0.000120, 0.074000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 0}, 331.253590, 0.014250, 72.752000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 1}, 54.813580, 0.000220, 0.075000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 2}, 151.650980, 0.000010, 0.037000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, -2}, 331.235610, 0.000020, 0.074000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, -1}, 54.848770, 0.000950, 5.540000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 0}, 331.232930, 0.011260, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 1}, 234.839830, 0.000180, 0.038000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 2}, 151.235530, 0.000020, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, -1}, 54.795100, 0.000120, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, 0}, 331.236870, 0.000760, 0.038000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, 1}, 234.838110, 0.000020, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 2, 0}, 331.235620, 0.000050, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -2, 0}, 315.206990, 0.000040, 1.110000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -1, -2}, 151.340180, 0.000010, 0.069000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -1, 0}, 330.113360, 0.004750, 0.081000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, -2}, 331.233770, 0.000130, 0.810000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, 0}, 331.656670, 0.002600, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 1, -2}, 151.340180, 0.000010, 0.083000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 1, 0}, 332.142630, 0.000290, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 2, 0}, 330.328840, 0.000030, 0.019000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -2, 0}, 331.059310, 0.000190, 0.087000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -1, 0}, 331.237450, 0.000300, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, 0, 0}, 331.237230, 0.000120, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 4, -2, 0}, 322.417230, 0.000070, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 4, -1, 0}, 330.589130, 0.000080, 0.027000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 4, 0, 0}, 335.378030, 0.000030, 0.020000},
	{{0, 0, 3, -4, 1, 0, 0, 0, -2, 0, 0}, 158.531030, 0.000010, 0.042000},
	{{0, 0, 3, -4, 1, 0, 0, 0, 0, 0, 0}, 176.707240, 0.000060, 1.044000},
	{{0, 0, 3, -4, 2, 0, 0, 0, -2, 0, 0}, 236.725690, 0.000030, 0.042000},
	{{0, 0, 3, -4, 2, 0, 0, 0, -2, 1, 0}, 236.725690, 0.000040, 0.096000},
	{{0, 0, 3, -4, 2, 0, 0, 0, 0, -1, 0}, 232.893250, 0.000010, 0.082000},
	{{0, 0, 3, -4, 2, 0, 0, 0, 0, 0, 0}, 222.572210, 0.000080, 0.960000},
	{{0, 0, 3, -4, 2, 0, 0, 0, 0, 1, 0}, 232.893250, 0.000010, 0.070000},
	{{0, 0, 3, -4, 2, 0, 0, 0, 2, 0, 0}, 29.501650, 0.000010, 0.039000},
	{{0, 0, 3, -3, -3, 0, 0, 0, 0, 0, 0}, 307.068080, 0.000010, 0.868000},
	{{0, 0, 3, -3, -2, 0, 0, 0, -2, 0, 0}, 120.842550, 0.000010, 0.043000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -4, 0, 0}, 191.310890, 0.000050, 0.021000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -4, 1, 0}, 190.417200, 0.000100, 0.029000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -4, 2, 0}, 186.919650, 0.000050, 0.046000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, -2, 0}, 187.444620, 0.000040, 0.020000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, -1, 0}, 188.227240, 0.000320, 0.027000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 0, 0}, 187.759650, 0.004050, 0.043000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 0, 2}, 188.061880, 0.000030, 0.285000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 1, 0}, 187.344440, 0.004450, 0.099000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 2, 0}, 187.871780, 0.000200, 0.315000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -1, 0, 0}, 5.857550, 0.000070, 0.091000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -1, 2, 0}, 1.053700, 0.000010, 0.064000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -3, 0}, 182.260090, 0.000010, 0.026000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -2, 0}, 183.051210, 0.000320, 0.040000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -1, 0}, 183.149130, 0.004550, 0.084000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 0, 0}, 182.646150, 0.014540, 0.712000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 1, 0}, 182.417040, 0.002280, 0.068000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 2, 0}, 182.490600, 0.000150, 0.036000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, -2, 0}, 2.657120, 0.000020, 0.079000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, -1, -1}, 279.364980, 0.000010, 0.077000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, -1, 0}, 3.872040, 0.000010, 1.931000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, 0, -1}, 277.642180, 0.000140, 2.848000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, 0, 0}, 8.374930, 0.000040, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, 1, -1}, 279.364980, 0.000010, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -3, 0}, 355.445610, 0.000030, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -2, 0}, 1.110290, 0.000720, 2.710000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -1, 0}, 0.867500, 0.006390, 0.078000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, -2}, 359.110520, 0.000020, 1.423000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, 0}, 1.048730, 0.000620, 0.038000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 1, 0}, 356.667350, 0.000040, 0.025000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 4, -2, 0}, 0.560600, 0.000080, 0.041000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 4, -1, 0}, 0.572100, 0.000080, 0.027000},
	{{0, 0, 3, -3, 2, 0, 0, 0, 2, -3, 0}, 60.843290, 0.000010, 0.074000},
	{{0, 0, 3, -3, 2, 0, 0, 0, 2, -1, 0}, 60.843290, 0.000010, 0.077000},
	{{0, 0, 3, -2, -2, 0, 0, 0, 2, -2, 0}, 257.525700, 0.000030, 166.820000},
	{{0, 0, 3, -2, -2, 0, 0, 0, 2, -1, 0}, 200.057960, 0.000020, 0.075000},
	{{0, 0, 3, -2, -1, 0, 0, 0, 2, -2, 0}, 11.991090, 0.000020, 12.770000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, -1, 0}, 75.937810, 0.000030, 0.016000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, 0, 0}, 257.108520, 0.000110, 0.021000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, 1, 0}, 256.420890, 0.000180, 0.029000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, 2, 0}, 256.528950, 0.000090, 0.048000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -3, 0, 0}, 256.483340, 0.000010, 0.028000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, -2, 0}, 256.864230, 0.000030, 0.020000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, -1, 0}, 256.611740, 0.000390, 0.028000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, 0}, 256.491560, 0.004590, 0.044000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, 2}, 256.844390, 0.000040, 0.247000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 1, 0}, 256.926200, 0.004230, 0.105000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 2, 0}, 256.907420, 0.000190, 0.269000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -1, 0, 0}, 257.315210, 0.000080, 0.096000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -1, 2, 0}, 257.265730, 0.000010, 0.062000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -3, 0}, 77.255930, 0.000010, 0.026000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -2, 0}, 256.078670, 0.000120, 0.041000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -1, 0}, 255.821510, 0.001380, 0.088000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, -1}, 310.844690, 0.000030, 0.087000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, 0}, 254.395930, 0.004590, 0.516000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 1, 0}, 256.023760, 0.000740, 0.066000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 2, 0}, 256.326330, 0.000040, 0.035000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, 0, -1}, 307.662750, 0.000090, 1.133000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, 0, 0}, 257.232860, 0.000070, 0.070000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -3, 0}, 237.151080, 0.000010, 0.076000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -2, 0}, 255.581560, 0.000140, 6.150000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, -1}, 130.336010, 0.000640, 241.391000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, 0}, 259.025320, 0.001960, 0.075000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, -1}, 130.758420, 0.000210, 0.075000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, 0}, 259.569420, 0.000170, 0.037000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 4, -2, 0}, 259.112300, 0.000030, 0.040000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 4, -1, 0}, 258.991520, 0.000020, 0.026000},
	{{0, 0, 3, -2, 2, 0, 0, 0, 2, 0, -2}, 340.271420, 0.000010, 436.527000},
	{{0, 0, 3, -1, -2, 0, 0, 0, 0, 0, 0}, 180.160390, 0.000010, 0.435000},
	{{0, 0, 3, -1, -2, 0, 0, 0, 2, -3, 0}, 1.514090, 0.000010, 0.079000},
	{{0, 0, 3, -1, -2, 0, 0, 0, 2, -1, 0}, 181.514090, 0.000010, 0.073000},
	{{0, 0, 3, -1, 0, 0, 0, 0, -2, 0, 0}, 159.023830, 0.000040, 0.045000},
	{{0, 0, 3, -1, 0, 0, 0, 0, -2, 1, 0}, 158.965420, 0.000020, 0.111000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 0, 0, 0}, 221.082420, 0.000070, 0.405000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 1, 0, -1}, 339.045930, 0.000020, 0.707000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, -1, 0}, 233.530700, 0.000030, 0.072000},
	{{0, 0, 3, 0, -6, 0, 0, 0, -2, 0, 0}, 204.451370, 0.000050, 0.045000},
	{{0, 0, 3, 0, -6, 0, 0, 0, -2, 1, 0}, 204.751110, 0.000020, 0.111000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 0, -1, 0}, 32.370480, 0.000020, 0.093000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 0, 0, 0}, 209.152550, 0.000070, 0.401000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 0, 1, 0}, 208.684070, 0.000010, 0.063000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 2, -1, 0}, 210.639430, 0.000130, 0.072000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 2, 0, 0}, 32.048390, 0.000030, 0.037000},
	{{0, 0, 3, 0, -6, 2, 0, 0, 0, 0, 0}, 185.337870, 0.000010, 0.390000},
	{{0, 0, 3, 0, -6, 2, 0, 0, 2, -3, 0}, 10.494860, 0.000010, 0.080000},
	{{0, 0, 3, 0, -6, 2, 0, 0, 2, -1, 0}, 190.494860, 0.000010, 0.071000},
	{{0, 0, 3, 0, -6, 5, 0, 0, -2, 0, 0}, 32.006370, 0.000020, 0.045000},
	{{0, 0, 3, 0, -6, 5, 0, 0, 0, 0, 0}, 37.131000, 0.000030, 0.375000},
	{{0, 0, 3, 0, -6, 5, 0, 0, 2, -3, 0}, 244.175850, 0.000010, 0.081000},
	{{0, 0, 3, 0, -6, 5, 0, 0, 2, -2, 0}, 69.032900, 0.000020, 1.124000},
	{{0, 0, 3, 0, -6, 5, 0, 0, 2, -1, 0}, 46.736410, 0.000050, 0.071000},
	{{0, 0, 3, 0, -5, 0, 0, 0, -2, -1, 0}, 194.015810, 0.000040, 0.028000},
	{{0, 0, 3, 0, -5, 0, 0, 0, -2, 0, 0}, 193.928810, 0.000260, 0.045000},
	{{0, 0, 3, 0, -5, 0, 0, 0, -2, 1, 0}, 193.838590, 0.000230, 0.112000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 0, -1, 0}, 40.996940, 0.000020, 0.094000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 0, 0, 0}, 198.096690, 0.000440, 0.388000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 0, 1, 0}, 198.638180, 0.000090, 0.063000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 0, 2, 0}, 198.929860, 0.000010, 0.034000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 1, 0, -1}, 290.761280, 0.000020, 0.656000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, -2, 0}, 200.594540, 0.000030, 1.243000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, -1, 0}, 199.525180, 0.001030, 0.071000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, 0, -2}, 200.602440, 0.000040, 2.123000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, 0, 0}, 21.566550, 0.000120, 0.037000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, 1, 0}, 20.642370, 0.000030, 0.025000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 4, -2, 0}, 199.397220, 0.000010, 0.039000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 4, 0, 0}, 200.601300, 0.000020, 0.019000},
	{{0, 0, 3, 0, -5, 2, 0, 0, -2, 0, 0}, 166.257680, 0.000020, 0.045000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 0, 0, 0}, 174.148880, 0.000030, 0.378000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 2, -3, 0}, 1.526600, 0.000010, 0.081000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 2, -2, 0}, 181.251750, 0.000010, 1.146000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 2, -1, 0}, 181.196080, 0.000050, 0.071000},
	{{0, 0, 3, 0, -5, 3, 0, 0, 2, -3, 0}, 59.699350, 0.000010, 0.081000},
	{{0, 0, 3, 0, -5, 3, 0, 0, 2, -2, 0}, 239.699350, 0.000010, 1.103000},
	{{0, 0, 3, 0, -5, 3, 0, 0, 2, -1, 0}, 239.699350, 0.000010, 0.071000},
	{{0, 0, 3, 0, -5, 3, 0, 0, 2, 0, 0}, 59.699350, 0.000010, 0.036000},
	{{0, 0, 3, 0, -5, 5, 0, 0, -2, 0, 0}, 343.079280, 0.000080, 0.045000},
	{{0, 0, 3, 0, -5, 5, 0, 0, -2, 1, 0}, 343.207850, 0.000060, 0.115000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 0, -1, 0}, 261.118230, 0.000020, 0.095000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 0, 0, 0}, 347.118760, 0.000110, 0.364000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 0, 1, 0}, 342.152830, 0.000020, 0.062000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 0, 2, 0}, 348.351450, 0.000010, 0.034000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, -3, 0}, 338.746790, 0.000010, 0.081000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, -1, 0}, 345.494120, 0.000200, 0.070000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, 0, 0}, 168.291840, 0.000060, 0.036000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, 2, 0}, 168.474860, 0.000010, 0.019000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -4, 0, 0}, 182.491770, 0.000030, 0.021000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -4, 1, 0}, 182.546910, 0.000030, 0.030000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -4, 2, 0}, 182.488030, 0.000010, 0.049000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, -1, 0}, 182.365020, 0.000140, 0.028000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 0, 0}, 181.651960, 0.001670, 0.045000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 0, 2}, 182.027300, 0.000010, 0.210000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 1, 0}, 182.403010, 0.001450, 0.113000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 2, 0}, 180.231320, 0.000060, 0.225000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, -2, 0}, 39.144500, 0.000020, 0.042000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, -1, 0}, 48.270730, 0.000300, 0.094000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 0, 0}, 186.610240, 0.002410, 0.376000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 1, 0}, 187.125480, 0.000670, 0.063000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 2, 0}, 192.849730, 0.000030, 0.034000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 1, -3, 0}, 14.469890, 0.000050, 0.040000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 1, -2, 0}, 14.136250, 0.000180, 0.087000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 1, 0, -1}, 280.190940, 0.000060, 0.622000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -3, 0}, 186.923750, 0.000030, 0.081000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -2, 0}, 184.621050, 0.000170, 1.125000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -1, 0}, 189.354570, 0.005930, 0.071000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 0, -2}, 190.429920, 0.000230, 1.801000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 0, 0}, 12.528380, 0.000880, 0.036000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 1, 0}, 10.341070, 0.000090, 0.025000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 2, 0}, 10.226360, 0.000020, 0.019000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -4, 0}, 14.638230, 0.000140, 0.075000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -3, 0}, 14.469890, 0.004520, 569.346000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -2, 0}, 193.700450, 0.000380, 0.075000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -1, 0}, 193.700350, 0.000030, 0.038000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 4, -2, 0}, 188.430300, 0.000090, 0.039000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 4, -1, 0}, 189.805230, 0.000050, 0.026000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 4, 0, 0}, 7.154680, 0.000030, 0.019000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 5, -4, 0}, 14.403800, 0.000070, 0.087000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 5, -3, 0}, 14.469890, 0.000050, 0.040000},
	{{0, 0, 3, 0, -4, 1, 0, 0, 2, -3, 0}, 181.302960, 0.000010, 0.081000},
	{{0, 0, 3, 0, -4, 1, 0, 0, 2, -1, 0}, 1.302960, 0.000010, 0.071000},
	{{0, 0, 3, 0, -4, 2, 0, 0, -2, 0, 0}, 98.240510, 0.000020, 0.045000},
	{{0, 0, 3, 0, -4, 2, 0, 0, 0, -1, 0}, 79.446950, 0.000030, 0.095000},
	{{0, 0, 3, 0, -4, 2, 0, 0, 0, 0, 0}, 113.475900, 0.000020, 0.366000},
	{{0, 0, 3, 0, -4, 2, 0, 0, 2, -3, 0}, 17.869300, 0.000010, 0.081000},
	{{0, 0, 3, 0, -4, 2, 0, 0, 2, -1, 0}, 195.952180, 0.000010, 0.070000},
	{{0, 0, 3, 0, -4, 3, 0, 0, 0, -1, 0}, 134.210380, 0.000040, 0.095000},
	{{0, 0, 3, 0, -4, 3, 0, 0, 2, -1, 0}, 134.211650, 0.000020, 0.070000},
	{{0, 0, 3, 0, -4, 5, 0, 0, -2, 0, 0}, 246.120930, 0.000060, 0.046000},
	{{0, 0, 3, 0, -4, 5, 0, 0, -2, 1, 0}, 246.154730, 0.000040, 0.116000},
	{{0, 0, 3, 0, -4, 5, 0, 0, 0, -1, 0}, 68.277530, 0.000060, 0.096000},
	{{0, 0, 3, 0, -4, 5, 0, 0, 0, 0, 0}, 244.332390, 0.000030, 0.353000},
	{{0, 0, 3, 0, -4, 5, 0, 0, 2, -1, 0}, 68.276580, 0.000030, 0.070000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 0, 0}, 150.032120, 0.000090, 0.021000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 1, 0}, 162.447000, 0.000170, 0.030000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 2, 0}, 165.848140, 0.000060, 0.049000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -3, 0, 0}, 160.870050, 0.000010, 0.029000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, -2, 0}, 153.408020, 0.000060, 0.021000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, -1, 0}, 153.287590, 0.000530, 0.028000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, -2}, 346.342870, 0.000020, 0.020000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, 0}, 163.624000, 0.006550, 0.045000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, 2}, 166.310230, 0.000050, 0.206000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 1, 0}, 165.262670, 0.005560, 0.114000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 2, 0}, 165.278310, 0.000250, 0.221000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 3, 0}, 165.249480, 0.000020, 0.056000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -1, 0, 0}, 347.998960, 0.000090, 0.104000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -2, 0}, 72.305940, 0.000100, 0.042000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -1, 0}, 75.770000, 0.004420, 0.095000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 0, -2}, 351.765350, 0.000010, 0.041000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 0, 0}, 169.783990, 0.008510, 0.364000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 1, -2}, 180.091460, 0.000010, 0.092000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 1, 0}, 175.090600, 0.002460, 0.062000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 2, 0}, 174.693190, 0.000170, 0.034000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 3, 0}, 177.415190, 0.000010, 0.024000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 1, 0, 0}, 355.032840, 0.000080, 0.066000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -3, 0}, 224.055740, 0.000080, 0.081000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -2, 0}, 151.436560, 0.000690, 1.028000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -1, -2}, 179.683940, 0.000030, 0.079000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -1, 0}, 173.718020, 0.021660, 0.070000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -1, 2}, 359.405610, 0.000050, 0.024000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, -2}, 180.508490, 0.000830, 1.564000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, 0}, 5.440540, 0.003680, 0.036000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, 2}, 179.632260, 0.000020, 0.018000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 1, -2}, 358.944070, 0.000020, 0.072000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 1, 0}, 6.324090, 0.000320, 0.025000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 2, 0}, 359.918980, 0.000070, 0.019000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 3, -4, 0}, 180.094710, 0.000010, 0.076000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 3, -2, 0}, 211.419650, 0.000050, 0.075000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 3, -1, 0}, 267.148840, 0.000020, 0.038000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -3, 0}, 78.868590, 0.000030, 0.080000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -2, 0}, 160.785390, 0.000320, 0.039000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -1, -2}, 180.091460, 0.000010, 0.083000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -1, 0}, 146.227670, 0.000110, 0.026000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, 0, 0}, 359.726840, 0.000040, 0.019000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, 2, 0}, 0.035160, 0.000010, 0.013000},
	{{0, 0, 3, 0, -3, 1, 0, 0, 0, -1, 0}, 78.501210, 0.000050, 0.095000},
	{{0, 0, 3, 0, -3, 1, 0, 0, 2, -1, 0}, 78.500730, 0.000030, 0.070000},
	{{0, 0, 3, 0, -2, -5, 0, 0, -2, 0, 0}, 190.404470, 0.000020, 0.045000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 0, 0, 0}, 194.936150, 0.000030, 0.376000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 2, -3, 0}, 21.127470, 0.000020, 0.081000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 2, -2, 0}, 199.605060, 0.000010, 1.127000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 2, -1, 0}, 199.103790, 0.000050, 0.071000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 3, -3, 0}, 18.091920, 0.000180, 1601.744000},
	{{0, 0, 3, 0, -2, -2, 0, 0, 2, -3, 0}, 172.545150, 0.000010, 0.082000},
	{{0, 0, 3, 0, -2, -2, 0, 0, 2, -1, 0}, 352.545150, 0.000010, 0.070000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 0, 0}, 75.883880, 0.000160, 0.021000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 1, 0}, 76.308850, 0.000330, 0.030000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 2, 0}, 75.607610, 0.000100, 0.050000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -3, 0, 0}, 76.287820, 0.000020, 0.029000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -3, 3, 0}, 256.263870, 0.000010, 0.182000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, -3, 0}, 257.332590, 0.000010, 0.016000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, -2, 0}, 75.016970, 0.000050, 0.021000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, -1, 0}, 75.256300, 0.000530, 0.028000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 0, -2}, 255.468460, 0.000020, 0.021000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 0, 0}, 75.716080, 0.008600, 0.046000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 0, 2}, 75.712000, 0.000060, 0.202000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 1, 0}, 75.667540, 0.007020, 0.116000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 2, 0}, 76.743440, 0.000340, 0.217000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 3, 0}, 77.144810, 0.000020, 0.056000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -1, 0, 0}, 254.406820, 0.000060, 0.105000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -3, 0}, 256.447240, 0.000080, 0.027000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -2, 0}, 256.887940, 0.000760, 0.042000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -1, -2}, 77.184900, 0.000020, 0.027000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -1, 0}, 256.833210, 0.008130, 0.096000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 0, 0}, 73.982850, 0.004870, 0.353000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 1, 0}, 73.080450, 0.000950, 0.062000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 2, 0}, 70.454780, 0.000060, 0.034000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 1, -2, -1}, 75.997540, 0.000020, 0.040000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 1, -1, -1}, 77.096000, 0.000120, 0.087000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 1, 0, -1}, 259.428670, 0.000060, 0.563000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -3, 0}, 262.376710, 0.000030, 0.082000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -2, 0}, 259.656680, 0.000600, 0.946000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -1, 0}, 268.938470, 0.004520, 0.070000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, 0, -2}, 316.397430, 0.000040, 1.382000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, 0, 0}, 241.951990, 0.000630, 0.036000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, 1, 0}, 228.283280, 0.000060, 0.024000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -3, -1}, 59.857980, 0.000010, 0.075000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -2, -1}, 75.997540, 0.001610, 277.143000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -2, 0}, 77.204800, 0.000020, 0.074000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, -1}, 257.555590, 0.000420, 0.075000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, 0}, 77.184900, 0.000070, 0.037000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, 0, -1}, 257.286110, 0.000030, 0.038000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, -3, 0}, 77.973720, 0.000010, 0.080000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, -2, 0}, 263.060440, 0.000130, 0.039000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, -1, 0}, 256.842350, 0.000160, 0.026000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, 0, 0}, 263.463360, 0.000030, 0.019000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 5, -3, -1}, 77.271660, 0.000030, 0.087000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 5, -2, -1}, 75.997540, 0.000020, 0.040000},
	{{0, 0, 3, 0, -2, 5, 0, 0, 2, -3, 0}, 308.908940, 0.000010, 0.083000},
	{{0, 0, 3, 0, -2, 5, 0, 0, 2, -1, 0}, 308.908940, 0.000010, 0.069000},
	{{0, 0, 3, 0, -1, -5, 0, 0, -2, 0, 0}, 171.214170, 0.000070, 0.045000},
	{{0, 0, 3, 0, -1, -5, 0, 0, -2, 1, 0}, 173.435750, 0.000050, 0.114000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 0, -1, 0}, 45.114520, 0.000050, 0.095000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 0, 0, 0}, 183.032290, 0.000110, 0.364000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 0, 2, 0}, 188.729790, 0.000010, 0.034000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, -3, 0}, 188.230310, 0.000020, 0.081000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, -1, 0}, 183.065850, 0.000180, 0.070000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, 0, 0}, 8.390220, 0.000060, 0.036000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, 2, 0}, 8.708260, 0.000010, 0.019000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -4, 0, 0}, 166.865670, 0.000030, 0.021000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -4, 1, 0}, 163.240950, 0.000040, 0.030000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, -1, 0}, 164.967720, 0.000120, 0.029000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 0, 0}, 165.059690, 0.001050, 0.046000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 1, 0}, 165.500090, 0.000780, 0.117000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 2, 0}, 166.018480, 0.000040, 0.213000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -1, 0, 0}, 154.836330, 0.000020, 0.106000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 0, -2, 0}, 14.754380, 0.000010, 0.042000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 0, -1, 0}, 143.968420, 0.000150, 0.097000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 0, 0, 0}, 174.406710, 0.000350, 0.343000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 0, 1, 0}, 182.255160, 0.000050, 0.062000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 2, -1, 0}, 53.196640, 0.000030, 0.069000},
	{{0, 0, 3, 0, 0, -5, 0, 0, -2, 0, 0}, 74.805760, 0.000060, 0.046000},
	{{0, 0, 3, 0, 0, -5, 0, 0, -2, 1, 0}, 83.045260, 0.000050, 0.116000},
	{{0, 0, 3, 0, 0, -5, 0, 0, 0, -1, 0}, 264.728440, 0.000060, 0.096000},
	{{0, 0, 3, 0, 0, -5, 0, 0, 0, 0, 0}, 63.978610, 0.000040, 0.353000},
	{{0, 0, 3, 0, 0, -5, 0, 0, 2, -1, 0}, 304.684350, 0.000040, 0.070000},
	{{0, 0, 3, 0, 0, -5, 0, 0, 2, 0, 0}, 185.466610, 0.000020, 0.036000},
	{{0, 0, 3, 0, 0, -5, 0, 0, 3, -2, -1}, 171.663730, 0.000040, 403.851000},
	{{0, 0, 3, 0, 0, -4, 0, 0, -2, 0, 0}, 270.376570, 0.000060, 0.046000},
	{{0, 0, 3, 0, 0, -4, 0, 0, -2, 1, 0}, 270.778350, 0.000020, 0.116000},
	{{0, 0, 3, 0, 0, -4, 0, 0, 0, 0, 0}, 271.394880, 0.000050, 0.349000},
	{{0, 0, 3, 0, 0, -4, 0, 0, 0, 1, 0}, 269.971230, 0.000020, 0.062000},
	{{0, 0, 3, 0, 0, -4, 0, 0, 2, -1, 0}, 272.727680, 0.000120, 0.070000},
	{{0, 0, 3, 0, 0, -4, 0, 0, 2, 0, 0}, 92.727680, 0.000050, 0.036000},
	{{0, 0, 3, 0, 0, -3, 0, 0, -2, -1, 0}, 176.800070, 0.000020, 0.028000},
	{{0, 0, 3, 0, 0, -3, 0, 0, -2, 0, 0}, 176.770920, 0.000200, 0.046000},
	{{0, 0, 3, 0, 0, -3, 0, 0, -2, 1, 0}, 176.627090, 0.000160, 0.117000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 0, -1, 0}, 352.958090, 0.000030, 0.097000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 0, 0, 0}, 177.609600, 0.000210, 0.345000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 0, 1, 0}, 178.072790, 0.000070, 0.062000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, -2, 0}, 180.008730, 0.000020, 0.890000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, -1, 0}, 180.444390, 0.000440, 0.070000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, 0, -2}, 180.008730, 0.000010, 1.265000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, 0, 0}, 0.005600, 0.000090, 0.036000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, 1, 0}, 359.967410, 0.000030, 0.024000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -4, 1, 0}, 76.952170, 0.000010, 0.030000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, -1, 0}, 76.940750, 0.000050, 0.029000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, 0, 0}, 76.947050, 0.000330, 0.046000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, 1, 0}, 76.947570, 0.000260, 0.117000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 0, -2, 0}, 257.105510, 0.000010, 0.042000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 0, -1, 0}, 257.548780, 0.000050, 0.097000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 0, 0, 0}, 76.652100, 0.000220, 0.341000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 0, 1, 0}, 76.653160, 0.000030, 0.062000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 2, -2, 0}, 257.119600, 0.000010, 0.864000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 2, -1, 0}, 257.083690, 0.000070, 0.069000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 2, 0, 0}, 81.300980, 0.000010, 0.036000},
	{{0, 0, 3, 0, 0, -1, 0, 0, -2, 0, 0}, 155.890280, 0.000100, 0.046000},
	{{0, 0, 3, 0, 0, -1, 0, 0, -2, 1, 0}, 155.897120, 0.000060, 0.117000},
	{{0, 0, 3, 0, 0, -1, 0, 0, 0, 0, 0}, 157.567470, 0.000020, 0.337000},
	{{0, 0, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 268.745080, 0.000080, 0.046000},
	{{0, 0, 3, 0, 0, 0, 0, 0, -2, 1, 0}, 290.948610, 0.000040, 0.118000},
	{{0, 0, 3, 0, 0, 0, 0, 0, -1, 0, 1}, 120.820670, 0.000020, 0.247000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 308.363350, 0.000020, 0.098000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 292.649000, 0.000210, 0.333000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 294.452730, 0.000030, 0.062000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 1, 0, -1}, 304.133720, 0.000030, 0.514000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -3, 0}, 216.155440, 0.000030, 0.083000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 39.098360, 0.000030, 0.816000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -1, 0}, 303.942700, 0.000040, 0.069000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 78.126290, 0.000030, 0.036000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 4, 0, 0}, 51.160610, 0.000020, 0.019000},
	{{0, 0, 3, 0, 1, 0, 0, 0, -2, 0, 0}, 38.973240, 0.000020, 0.046000},
	{{0, 0, 3, 0, 1, 0, 0, 0, 2, -3, 0}, 306.867120, 0.000010, 0.084000},
	{{0, 0, 3, 0, 1, 0, 0, 0, 2, -2, 0}, 126.867190, 0.000010, 0.763000},
	{{0, 0, 3, 0, 1, 0, 0, 0, 2, -1, 0}, 126.867120, 0.000010, 0.069000},
	{{0, 0, 3, 0, 1, 0, 0, 0, 2, 0, 0}, 305.385780, 0.000020, 0.036000},
	{{0, 0, 3, 0, 2, -5, 0, 0, -2, 0, 0}, 220.308970, 0.000030, 0.046000},
	{{0, 0, 3, 0, 2, -5, 0, 0, 0, 0, 0}, 219.032880, 0.000010, 0.333000},
	{{0, 0, 3, 0, 2, -5, 0, 0, 2, -3, 0}, 149.142210, 0.000010, 0.083000},
	{{0, 0, 3, 0, 2, -5, 0, 0, 2, -1, 0}, 149.142210, 0.000010, 0.069000},
	{{0, 0, 3, 0, 3, -2, 0, 0, 2, -3, 0}, 307.122430, 0.000010, 0.084000},
	{{0, 0, 3, 0, 3, -2, 0, 0, 2, -2, 0}, 127.122430, 0.000010, 0.709000},
	{{0, 0, 3, 0, 3, -2, 0, 0, 2, -1, 0}, 307.122430, 0.000010, 0.068000},
	{{0, 0, 3, 0, 3, -2, 0, 0, 2, 0, 0}, 127.122430, 0.000010, 0.036000},
	{{0, 0, 3, 0, 4, -5, 0, 0, 2, 0, 0}, 192.610990, 0.000010, 0.036000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, -2, 0}, 168.971080, 0.000020, 0.437000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, 0, 0}, 168.924700, 0.000030, 0.035000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 2, -2, 0}, 184.688200, 0.000010, 0.354000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0}, 184.688200, 0.000010, 0.034000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 1, 0}, 332.227780, 0.000050, 0.075000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 3, 0}, 323.170010, 0.000010, 0.076000},
	{{0, 0, 4, -11, 0, 2, 0, 0, -2, 2, 0}, 356.986630, 0.000010, 151.221000},
	{{0, 0, 4, -11, 1, 0, 0, 0, -2, 1, 0}, 350.562730, 0.000020, 0.075000},
	{{0, 0, 4, -11, 1, 0, 0, 0, -2, 2, 0}, 218.874480, 0.000020, 102.094000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 0, 0, 0}, 259.102510, 0.000010, 0.759000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 2, 0, 0}, 323.073570, 0.000020, 0.043000},
	{{0, 0, 4, -10, 2, 0, 0, 0, -2, 0, 0}, 51.321510, 0.000020, 0.039000},
	{{0, 0, 4, -10, 2, 0, 0, 0, -2, 1, 0}, 51.508670, 0.000010, 0.079000},
	{{0, 0, 4, -10, 2, 0, 0, 0, -2, 2, 0}, 231.241070, 0.000010, 1.598000},
	{{0, 0, 4, -10, 2, 0, 0, 0, -2, 3, 0}, 51.508670, 0.000010, 0.072000},
	{{0, 0, 4, -9, 0, 0, 0, 0, -1, 0, 1}, 293.382400, 0.000020, 3.723000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 0, -1, 0}, 255.111630, 0.000020, 0.071000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 0, 0, 0}, 231.551520, 0.000160, 1.274000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 0, 1, 0}, 271.086250, 0.000030, 0.080000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, -1, 0}, 325.707120, 0.000060, 0.093000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, 0, 0}, 313.113090, 0.000050, 0.042000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, -1, 0}, 242.610290, 0.000030, 0.026000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 0, 0}, 243.311590, 0.000230, 0.040000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 1, 0}, 245.016500, 0.000320, 0.085000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -2, 0}, 240.725820, 0.000050, 0.037000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -1, 0}, 240.023700, 0.000690, 0.074000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 0, 0}, 242.876290, 0.003730, 3.945000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 1, 0}, 240.769220, 0.000740, 0.077000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 2, 0}, 241.240330, 0.000060, 0.038000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 1, 0, -1}, 324.556700, 0.000010, 0.765000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, -2, 0}, 247.122240, 0.000020, 0.493000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, -1, 0}, 248.260640, 0.000530, 0.089000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 0, 0}, 246.518990, 0.000380, 0.041000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 1, 0}, 246.924350, 0.000040, 0.026000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 4, -1, 0}, 246.946650, 0.000010, 0.028000},
	{{0, 0, 4, -8, 1, 0, 0, 0, 0, 0, 0}, 94.085140, 0.000010, 5.911000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -4, 0, 0}, 99.173350, 0.000010, 0.020000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -4, 1, 0}, 279.173350, 0.000030, 0.028000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -4, 2, 0}, 279.173480, 0.000010, 0.044000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, -1, 0}, 279.036660, 0.000070, 0.026000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 0, 0}, 279.046530, 0.000640, 0.040000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 0, 2}, 279.173350, 0.000020, 0.474000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 1, 0}, 279.609170, 0.000990, 0.087000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 2, 0}, 279.173560, 0.000040, 0.564000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, -2, 0}, 276.718150, 0.000080, 0.038000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, -1, 0}, 276.834490, 0.001250, 0.075000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 0, 0}, 278.083710, 0.006500, 1750.265000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 1, 0}, 276.833480, 0.001250, 0.075000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 2, 0}, 276.717630, 0.000080, 0.038000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, -2, 0}, 279.170010, 0.000040, 0.564000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, -1, 0}, 279.605720, 0.000990, 0.087000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, 0, -2}, 279.170210, 0.000020, 0.475000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, 0, 0}, 279.043590, 0.000640, 0.040000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, 1, 0}, 279.033780, 0.000070, 0.026000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 4, -2, 0}, 279.170090, 0.000010, 0.044000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 4, -1, 0}, 279.170210, 0.000030, 0.028000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 4, 0, 0}, 99.170210, 0.000010, 0.020000},
	{{0, 0, 4, -8, 2, 0, 0, 0, -2, 0, 0}, 301.454020, 0.000020, 0.040000},
	{{0, 0, 4, -8, 2, 0, 0, 0, -2, 1, 0}, 301.190910, 0.000010, 0.086000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 0, -1, 0}, 301.514870, 0.000050, 0.075000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 0, 0, 0}, 300.218140, 0.000180, 11.784000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 0, 1, 0}, 301.514870, 0.000050, 0.076000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 2, -1, 0}, 301.532490, 0.000010, 0.088000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 2, 0, 0}, 301.644150, 0.000020, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 0, 0}, 286.779960, 0.000020, 0.013000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 1, 0}, 286.780890, 0.000040, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 2, 0}, 286.782030, 0.000050, 0.021000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 3, 0}, 286.782140, 0.000020, 0.029000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, -1, 0}, 286.545320, 0.000170, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 0, 0}, 286.688320, 0.001060, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 0, 2}, 286.780200, 0.000020, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, -2}, 106.781400, 0.000020, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, 0}, 286.877730, 0.002640, 0.028000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, 2}, 286.779010, 0.000020, 0.107000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 2, 0}, 287.110110, 0.001890, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 3, 0}, 287.695140, 0.000050, 0.103000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, -1, 0}, 286.780510, 0.000030, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 0, 0}, 286.776180, 0.000030, 0.027000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 1, 0}, 106.942860, 0.000170, 0.042000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 2, 0}, 107.298320, 0.000060, 0.094000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -3, 0}, 286.210740, 0.000080, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -2, 0}, 286.200690, 0.000760, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -2, 2}, 106.780880, 0.000010, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, -2}, 106.633830, 0.000060, 0.015000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, 0}, 286.409350, 0.008760, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, 2}, 106.376780, 0.000270, 0.090000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, -2}, 106.709150, 0.000240, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 0}, 286.689570, 0.090020, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 2}, 286.680010, 0.002100, 0.475000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, -2}, 107.078420, 0.000330, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, 0}, 287.112160, 0.139600, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, -2}, 106.783310, 0.000020, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, 0}, 287.815150, 0.004840, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, 2}, 106.781530, 0.000030, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 3, 0}, 288.989690, 0.000220, 0.067000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 4, 0}, 289.774640, 0.000010, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, -1, 0}, 106.193020, 0.000220, 0.039000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 0, 0}, 106.690760, 0.002370, 0.081000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 1, 0}, 107.802520, 0.000210, 1.128000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 2, 0}, 109.473260, 0.000020, 0.071000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -4, 0}, 284.824400, 0.000050, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -3, 0}, 284.937580, 0.000800, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, -2}, 105.027940, 0.000060, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 0}, 284.989300, 0.011620, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 2}, 104.677630, 0.000020, 3.003000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, -2}, 105.240100, 0.000390, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 0}, 284.987760, 0.170830, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 2}, 284.451770, 0.000240, 0.074000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, -2}, 107.223980, 0.000340, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, 0}, 285.987070, 0.901140, 1783.359000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, 2}, 107.226590, 0.000340, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, -2}, 284.427560, 0.000230, 0.074000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, 0}, 284.987670, 0.170820, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, 2}, 105.240740, 0.000390, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, -2}, 104.678250, 0.000020, 2.993000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, 0}, 284.989810, 0.011620, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, 2}, 105.028290, 0.000060, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 3, 0}, 284.938030, 0.000800, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 4, 0}, 284.824790, 0.000050, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, -2, 0}, 109.474860, 0.000020, 0.071000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, -1, 0}, 107.801200, 0.000220, 1.127000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, 0, 0}, 106.690930, 0.002370, 0.081000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, 1, 0}, 106.194180, 0.000220, 0.039000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -4, 0}, 289.773370, 0.000010, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -3, 0}, 288.989830, 0.000220, 0.067000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, -2}, 106.784160, 0.000030, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, 0}, 287.815380, 0.004850, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, 2}, 106.783540, 0.000020, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 0}, 287.113880, 0.139710, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 2}, 107.080170, 0.000330, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, -2}, 286.682610, 0.002100, 0.474000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, 0}, 286.692690, 0.090090, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, 2}, 106.710650, 0.000240, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, -2}, 106.379290, 0.000270, 0.090000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, 0}, 286.410410, 0.008750, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, 2}, 106.635540, 0.000060, 0.015000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 2, -2}, 106.784060, 0.000010, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 2, 0}, 286.202100, 0.000760, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 3, 0}, 286.212960, 0.000080, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, -2, 0}, 107.302150, 0.000060, 0.094000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, -1, 0}, 106.945180, 0.000170, 0.042000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, 0, 0}, 286.787770, 0.000030, 0.027000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, 1, 0}, 286.784460, 0.000030, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -3, 0}, 287.693010, 0.000050, 0.103000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -2, 0}, 287.111860, 0.001890, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, -2}, 286.784820, 0.000020, 0.107000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, 0}, 286.879760, 0.002640, 0.028000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, 2}, 106.783910, 0.000020, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 0, -2}, 286.783910, 0.000020, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 0, 0}, 286.693010, 0.001070, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 1, 0}, 286.548180, 0.000170, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, -3, 0}, 286.783620, 0.000020, 0.029000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, -2, 0}, 286.783740, 0.000050, 0.021000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, -1, 0}, 286.783820, 0.000040, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, 0, 0}, 286.783870, 0.000020, 0.013000},
	{{0, 0, 4, -8, 5, -5, 0, 0, -2, 0, 0}, 61.301250, 0.000070, 0.040000},
	{{0, 0, 4, -8, 5, -5, 0, 0, -2, 1, 0}, 61.301250, 0.000150, 0.087000},
	{{0, 0, 4, -8, 5, -5, 0, 0, 0, -1, 0}, 241.300370, 0.000020, 0.075000},
	{{0, 0, 4, -8, 5, -5, 0, 0, 0, 0, 0}, 241.300810, 0.000010, 590.730000},
	{{0, 0, 4, -8, 5, -5, 0, 0, 0, 1, 0}, 241.301250, 0.000020, 0.075000},
	{{0, 0, 4, -8, 5, -5, 0, 0, 2, -1, 0}, 61.300370, 0.000150, 0.087000},
	{{0, 0, 4, -8, 5, -5, 0, 0, 2, 0, 0}, 61.300370, 0.000070, 0.040000},
	{{0, 0, 4, -7, -2, 0, 0, 0, 0, 0, 0}, 33.696040, 0.000010, 9.124000},
	{{0, 0, 4, -7, -1, 0, 0, 0, 0, 0, 0}, 220.184630, 0.000010, 5.157000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -4, 0, 0}, 272.711250, 0.000030, 0.020000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -4, 1, 0}, 272.522200, 0.000020, 0.028000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -4, 2, 0}, 272.576060, 0.000030, 0.044000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -3, 2, -1}, 41.502240, 0.000010, 0.042000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -3, 3, -1}, 41.474250, 0.000010, 0.095000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, -2, 0}, 272.776720, 0.000020, 0.020000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, -1, 0}, 272.420720, 0.000150, 0.027000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 0, 0}, 273.020890, 0.001700, 0.041000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 0, 2}, 272.828990, 0.000040, 0.419000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 1, 0}, 272.814220, 0.002610, 0.089000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 2, 0}, 272.880770, 0.000100, 0.487000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 0, 0}, 92.309860, 0.000030, 0.083000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 0, 1}, 353.516570, 0.000010, 0.751000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 2, 0}, 92.626870, 0.000010, 0.069000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -2, 0}, 270.563560, 0.000140, 0.038000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -1, 0}, 270.601190, 0.002190, 0.077000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, 0}, 271.446430, 0.010990, 3.594000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 1, 0}, 270.408450, 0.002010, 0.074000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 2, 0}, 270.320880, 0.000130, 0.037000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 3, 0}, 92.532180, 0.000010, 0.025000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 1, -2, 0}, 272.169680, 0.000010, 0.072000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 1, 0, -1}, 353.414150, 0.000070, 1.289000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 1, 0, 0}, 92.169680, 0.000010, 0.079000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -2, 0}, 272.046310, 0.000070, 0.669000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -1, 0}, 272.772060, 0.001890, 0.085000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 0, -2}, 272.169680, 0.000030, 0.547000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 0, 0}, 272.189080, 0.001090, 0.040000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 1, 0}, 271.989860, 0.000130, 0.026000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 4, -2, 0}, 272.340000, 0.000020, 0.043000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 4, 0, 0}, 272.382720, 0.000020, 0.020000},
	{{0, 0, 4, -7, 1, 0, 0, 0, 0, 0, 0}, 318.225230, 0.000010, 2.759000},
	{{0, 0, 4, -7, 2, 0, 0, 0, 0, 0, 0}, 331.253580, 0.000020, 2.238000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -4, 0, 0}, 300.539170, 0.000040, 0.021000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -4, 1, 0}, 300.530060, 0.000080, 0.028000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -4, 2, 0}, 300.412700, 0.000050, 0.045000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, -2, 0}, 300.517290, 0.000030, 0.020000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, -1, 0}, 300.599920, 0.000280, 0.027000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, 0}, 300.389340, 0.003320, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, 2}, 300.458230, 0.000040, 0.343000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 1, 0}, 300.616240, 0.004390, 0.094000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 2, 0}, 300.428640, 0.000200, 0.387000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, -1, 1}, 204.001940, 0.000040, 0.088000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, 0, 0}, 121.586080, 0.000210, 0.087000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, 0, 1}, 23.520220, 0.000040, 0.537000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -2, 0}, 300.900660, 0.000210, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -1, 0}, 300.197980, 0.002960, 0.080000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 0, 0}, 301.217300, 0.014100, 1.235000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 1, 0}, 301.393580, 0.002370, 0.071000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 2, 0}, 301.280650, 0.000150, 0.037000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -2, 0}, 299.731380, 0.000020, 0.075000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -2, 1}, 204.011700, 0.000030, 11.156000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, -1}, 23.990720, 0.000050, 0.074000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, 0}, 301.284500, 0.000230, 12.968000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, 1}, 24.001940, 0.000220, 0.075000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, -1}, 24.021140, 0.000420, 4.101000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, 0}, 302.220850, 0.000610, 0.076000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, 1}, 204.014810, 0.000080, 0.038000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 1, -1}, 23.990720, 0.000050, 0.077000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 1, 0}, 302.241050, 0.000040, 0.038000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -2, 0}, 282.460530, 0.000060, 1.037000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -1, 0}, 296.095650, 0.002090, 0.081000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, -2}, 302.109620, 0.000040, 0.771000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, 0}, 301.061350, 0.000990, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 1, 0}, 301.785170, 0.000130, 0.026000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 4, -3, 0}, 74.818410, 0.000010, 0.095000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 4, -2, 0}, 284.262260, 0.000040, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 4, -1, 0}, 276.318600, 0.000050, 0.027000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 4, 0, 0}, 302.234720, 0.000020, 0.020000},
	{{0, 0, 4, -6, 1, 0, 0, 0, 0, 0, 0}, 150.720780, 0.000020, 1.118000},
	{{0, 0, 4, -6, 1, 0, 0, 0, 2, 0, 0}, 153.571360, 0.000010, 0.039000},
	{{0, 0, 4, -6, 2, 0, 0, 0, -2, 0, 0}, 281.535880, 0.000040, 0.042000},
	{{0, 0, 4, -6, 2, 0, 0, 0, -2, 1, 0}, 289.643520, 0.000040, 0.095000},
	{{0, 0, 4, -6, 2, 0, 0, 0, 0, -1, 0}, 328.674110, 0.000010, 0.081000},
	{{0, 0, 4, -6, 2, 0, 0, 0, 0, 0, 0}, 330.486980, 0.000100, 1.022000},
	{{0, 0, 4, -6, 2, 0, 0, 0, 0, 1, 0}, 328.674110, 0.000010, 0.070000},
	{{0, 0, 4, -6, 2, 0, 0, 0, 2, 0, 0}, 0.579420, 0.000020, 0.039000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -4, 0, 0}, 150.542800, 0.000030, 0.021000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -4, 1, 0}, 155.878210, 0.000070, 0.029000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -4, 2, 0}, 156.158470, 0.000040, 0.046000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, -2, 0}, 156.632470, 0.000020, 0.020000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, -1, 0}, 155.633100, 0.000210, 0.027000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 0, 0}, 156.495040, 0.002530, 0.043000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 0, 2}, 156.600790, 0.000030, 0.290000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 1, 0}, 156.198950, 0.002820, 0.099000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 2, 0}, 156.949850, 0.000120, 0.321000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -1, 0, 0}, 336.161380, 0.000040, 0.091000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -2, 0}, 153.103850, 0.000190, 0.040000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -1, 0}, 153.166020, 0.002920, 0.084000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 0, 0}, 152.760920, 0.009480, 0.745000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 1, 0}, 152.582010, 0.001520, 0.069000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 2, 0}, 152.644660, 0.000100, 0.036000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, -2, 0}, 336.944310, 0.000020, 0.078000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, -1, -1}, 236.077380, 0.000030, 0.077000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, -1, 1}, 56.451250, 0.000020, 0.072000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 0, -1}, 236.087840, 0.000260, 3.475000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 0, 0}, 336.944310, 0.000020, 0.073000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 0, 1}, 56.047270, 0.000030, 0.037000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 1, -1}, 236.077380, 0.000030, 0.074000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -2, 0}, 331.818930, 0.000400, 2.313000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -1, 0}, 331.335000, 0.003820, 0.078000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, -2}, 332.477090, 0.000020, 1.306000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, 0}, 333.254080, 0.000410, 0.038000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 1, 0}, 330.012580, 0.000030, 0.025000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 4, -2, 0}, 331.204600, 0.000050, 0.041000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 4, -1, 0}, 331.418340, 0.000050, 0.027000},
	{{0, 0, 4, -5, 2, 0, 0, 0, 2, 0, 0}, 29.280890, 0.000010, 0.038000},
	{{0, 0, 4, -4, -2, 0, 0, 0, 2, -2, 0}, 304.811260, 0.000010, 14.417000},
	{{0, 0, 4, -4, 0, -3, 0, 0, 2, -1, 0}, 43.451490, 0.000020, 0.075000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -4, 0, 0}, 213.107920, 0.000040, 0.021000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -4, 1, 0}, 211.514170, 0.000040, 0.029000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -4, 2, 0}, 205.210000, 0.000030, 0.047000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, -2, 0}, 205.250960, 0.000010, 0.020000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, -1, 0}, 216.574600, 0.000120, 0.028000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 0, 0}, 206.725570, 0.001750, 0.044000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 0, 2}, 206.271670, 0.000020, 0.251000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 1, 0}, 205.671510, 0.001730, 0.104000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 2, 0}, 207.278780, 0.000070, 0.274000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -1, -1, 0}, 228.316660, 0.000010, 0.042000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -1, 0, 0}, 48.297210, 0.000090, 0.095000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -3, 0}, 2.378780, 0.000020, 0.026000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -2, 0}, 357.277060, 0.000220, 0.041000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -1, 0}, 356.657260, 0.003030, 0.088000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 0, 0}, 191.186990, 0.004040, 0.534000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 1, 0}, 189.865000, 0.000680, 0.066000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 2, 0}, 188.014140, 0.000050, 0.035000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 1, 0, -1}, 278.919830, 0.000070, 1.220000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 1, 0, 0}, 48.298580, 0.000050, 0.070000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -3, 0}, 350.406440, 0.000040, 0.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -2, 0}, 0.336680, 0.002140, 10.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, -2}, 181.447510, 0.000060, 0.074000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, 0}, 181.912760, 0.020080, 0.075000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, 2}, 1.974490, 0.000040, 0.025000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, -2}, 357.846900, 0.000070, 4.269000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, 0}, 182.436990, 0.001040, 0.038000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 1, -2}, 180.642810, 0.000020, 0.077000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 1, 0}, 180.637160, 0.000030, 0.025000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -3, 0}, 2.417530, 0.000040, 0.086000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -2, 0}, 182.148080, 0.000240, 0.040000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -1, 0}, 182.225440, 0.000160, 0.026000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, 0, 0}, 181.820930, 0.000030, 0.019000},
	{{0, 0, 4, -4, 2, 0, 0, 0, 2, -1, 0}, 241.929320, 0.000020, 0.074000},
	{{0, 0, 4, -3, -2, 0, 0, 0, 0, 0, 0}, 151.592580, 0.000010, 0.447000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -4, 0, 0}, 258.788290, 0.000020, 0.021000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -4, 1, 0}, 76.833050, 0.000010, 0.030000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, -1, 0}, 76.467450, 0.000040, 0.028000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, 0, 0}, 76.970830, 0.000370, 0.045000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, 1, 0}, 77.022550, 0.000340, 0.110000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, -1, 0}, 86.806080, 0.000180, 0.092000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 0, 0}, 92.530300, 0.000250, 0.416000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 1, 0}, 70.817560, 0.000040, 0.064000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 1, 0, -1}, 310.019020, 0.000060, 0.740000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, -2, 0}, 73.162550, 0.000010, 1.585000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, -1, 0}, 41.966870, 0.000260, 0.072000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, 0, 0}, 195.290040, 0.000030, 0.037000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, -1, 0}, 154.688540, 0.000030, 0.029000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, 0, 0}, 154.628300, 0.000260, 0.046000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, 1, 0}, 155.375390, 0.000220, 0.117000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, -1, 0}, 154.776040, 0.000050, 0.097000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, 0, 0}, 165.139100, 0.000100, 0.341000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, 1, 0}, 159.508980, 0.000010, 0.062000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, -3, 0}, 186.598200, 0.000010, 0.083000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, -1, 0}, 186.598200, 0.000010, 0.069000},
	{{0, 0, 4, 0, -7, 0, 0, 0, 0, 0, 0}, 209.689240, 0.000010, 0.293000},
	{{0, 0, 4, 0, -7, 0, 0, 0, 2, -1, 0}, 211.318620, 0.000040, 0.067000},
	{{0, 0, 4, 0, -7, 0, 0, 0, 2, 0, 0}, 30.780330, 0.000020, 0.036000},
	{{0, 0, 4, 0, -7, 5, 0, 0, 2, -2, 0}, 17.576510, 0.000010, 0.554000},
	{{0, 0, 4, 0, -7, 5, 0, 0, 2, 0, 0}, 197.576510, 0.000010, 0.035000},
	{{0, 0, 4, 0, -6, 0, 0, 0, -2, 0, 0}, 195.359080, 0.000060, 0.047000},
	{{0, 0, 4, 0, -6, 0, 0, 0, -2, 1, 0}, 195.418810, 0.000030, 0.125000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 0, -1, 0}, 22.901720, 0.000020, 0.102000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 0, 0, 0}, 198.496980, 0.000050, 0.286000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 0, 1, 0}, 198.458220, 0.000020, 0.060000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 2, -2, 0}, 200.624880, 0.000010, 0.581000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 2, -1, 0}, 200.626790, 0.000210, 0.067000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 2, 0, 0}, 20.512360, 0.000090, 0.035000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 2, 1, 0}, 20.595410, 0.000020, 0.024000},
	{{0, 0, 4, 0, -6, 2, 0, 0, 2, -2, 0}, 180.866600, 0.000010, 0.559000},
	{{0, 0, 4, 0, -6, 2, 0, 0, 2, 0, 0}, 0.866600, 0.000010, 0.035000},
	{{0, 0, 4, 0, -6, 5, 0, 0, -2, 0, 0}, 341.141430, 0.000020, 0.047000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 0, 0, 0}, 345.152460, 0.000010, 0.273000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 2, -2, 0}, 348.386640, 0.000020, 0.529000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 2, -1, 0}, 348.189250, 0.000040, 0.066000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 2, 0, 0}, 168.532150, 0.000010, 0.035000},
	{{0, 0, 4, 0, -5, 0, 0, 0, -2, -1, 0}, 183.443290, 0.000030, 0.029000},
	{{0, 0, 4, 0, -5, 0, 0, 0, -2, 0, 0}, 183.374330, 0.000240, 0.047000},
	{{0, 0, 4, 0, -5, 0, 0, 0, -2, 1, 0}, 182.932560, 0.000190, 0.127000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, -1, 0}, 15.462800, 0.000060, 0.103000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, 0, 0}, 186.639340, 0.000190, 0.279000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, 1, 0}, 190.633900, 0.000100, 0.059000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, 2, 0}, 189.968260, 0.000010, 0.033000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 1, 0, -1}, 279.548520, 0.000010, 0.396000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, -2, 0}, 190.308820, 0.000030, 0.554000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, -1, 0}, 190.280790, 0.001030, 0.066000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, 0, -2}, 190.333790, 0.000030, 0.680000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, 0, 0}, 10.322750, 0.000380, 0.035000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, 1, 0}, 10.302750, 0.000070, 0.024000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 4, -2, 0}, 190.194870, 0.000020, 0.038000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 4, -1, 0}, 10.302390, 0.000010, 0.025000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -4, 1, 0}, 166.597430, 0.000030, 0.031000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, -1, 0}, 166.826140, 0.000080, 0.029000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 0, 0}, 164.959940, 0.000760, 0.047000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 1, 0}, 166.037430, 0.000540, 0.128000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 2, 0}, 164.980700, 0.000020, 0.184000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, -2, 0}, 6.579900, 0.000010, 0.044000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, -1, 0}, 355.896550, 0.000200, 0.104000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 0, 0}, 170.234240, 0.000440, 0.273000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 1, 0}, 175.746200, 0.000340, 0.059000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 2, 0}, 178.883340, 0.000020, 0.033000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, -2, 0}, 180.123760, 0.000100, 0.529000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, -1, 0}, 179.869500, 0.003080, 0.066000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 0, -2}, 179.795190, 0.000100, 0.643000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 0, 0}, 0.662100, 0.001250, 0.035000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 1, 0}, 359.635860, 0.000130, 0.024000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 2, 0}, 0.698120, 0.000010, 0.018000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 4, -2, 0}, 179.206800, 0.000050, 0.038000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 4, 0, 0}, 359.382660, 0.000030, 0.019000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 4, 1, 0}, 179.795190, 0.000010, 0.015000},
	{{0, 0, 4, 0, -3, -5, 0, 0, 2, -2, 0}, 198.202500, 0.000010, 0.555000},
	{{0, 0, 4, 0, -3, -5, 0, 0, 2, 0, 0}, 18.202500, 0.000010, 0.035000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -4, 0, 0}, 242.830850, 0.000020, 0.022000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -4, 1, 0}, 63.536770, 0.000030, 0.031000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, -1, 0}, 64.179130, 0.000070, 0.029000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 0, 0}, 63.970470, 0.000690, 0.048000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 1, 0}, 64.008150, 0.000500, 0.129000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 2, 0}, 64.097480, 0.000030, 0.181000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, -3, 0}, 220.114680, 0.000010, 0.028000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, -2, 0}, 265.045030, 0.000020, 0.044000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, -1, 0}, 339.565300, 0.000150, 0.105000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, 0, 0}, 64.175140, 0.000250, 0.267000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, 1, 0}, 63.124640, 0.000060, 0.059000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 1, 0, -1}, 259.109160, 0.000010, 0.371000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, -2, 0}, 5.107370, 0.000010, 0.507000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, -1, 0}, 2.196200, 0.000250, 0.066000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, 0, 0}, 175.370620, 0.000090, 0.035000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, 1, 0}, 204.591450, 0.000020, 0.024000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, -3, 0}, 8.586590, 0.000010, 0.088000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, -2, 0}, 188.585930, 0.000010, 0.530000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, -1, 0}, 188.498140, 0.000040, 0.066000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, 0, 0}, 8.514340, 0.000010, 0.035000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -4, 1, 0}, 331.911630, 0.000030, 0.031000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -4, 3, 0}, 153.916450, 0.000020, 0.170000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, -1, 0}, 331.073510, 0.000060, 0.029000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 0, 0}, 331.491170, 0.000560, 0.048000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 1, 0}, 331.062870, 0.000380, 0.131000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 2, 0}, 331.610480, 0.000020, 0.178000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 0, -2, 0}, 154.138430, 0.000040, 0.044000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 0, -1, 0}, 153.649610, 0.000290, 0.106000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 0, 0, 0}, 329.333880, 0.000100, 0.261000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 2, -3, 0}, 153.640880, 0.000010, 0.089000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 2, -2, 0}, 154.300140, 0.000010, 0.486000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 2, -1, 0}, 156.540690, 0.000040, 0.065000},
	{{0, 0, 4, 0, -2, 5, 0, 0, 2, -3, 0}, 119.423020, 0.000020, 0.091000},
	{{0, 0, 4, 0, -2, 5, 0, 0, 2, -2, 0}, 119.280680, 0.000020, 0.449000},
	{{0, 0, 4, 0, -2, 5, 0, 0, 2, -1, 0}, 119.423020, 0.000020, 0.065000},
	{{0, 0, 4, 0, -1, 0, 0, 0, -2, 0, 0}, 66.118830, 0.000060, 0.048000},
	{{0, 0, 4, 0, -1, 0, 0, 0, -2, 1, 0}, 64.731200, 0.000030, 0.132000},
	{{0, 0, 4, 0, -1, 0, 0, 0, 0, 0, 0}, 73.785190, 0.000010, 0.255000},
	{{0, 0, 4, 0, -1, 0, 0, 0, 2, -1, 0}, 317.912380, 0.000030, 0.065000},
	{{0, 0, 4, 0, -1, 0, 0, 0, 2, 0, 0}, 168.049550, 0.000070, 0.035000},
	{{0, 0, 4, 0, 0, -5, 0, 0, 2, 0, 0}, 92.673420, 0.000010, 0.035000},
	{{0, 0, 4, 0, 0, -4, 0, 0, -2, 0, 0}, 176.171320, 0.000030, 0.048000},
	{{0, 0, 4, 0, 0, -4, 0, 0, 0, 0, 0}, 177.496050, 0.000010, 0.259000},
	{{0, 0, 4, 0, 0, -4, 0, 0, 2, -1, 0}, 179.887210, 0.000050, 0.065000},
	{{0, 0, 4, 0, 0, -4, 0, 0, 2, 0, 0}, 359.887220, 0.000030, 0.035000},
	{{0, 0, 4, 0, 0, -3, 0, 0, -2, 0, 0}, 74.944160, 0.000020, 0.048000},
	{{0, 0, 4, 0, 0, -2, 0, 0, -2, 0, 0}, 333.834220, 0.000030, 0.048000},
	{{0, 0, 4, 0, 0, -2, 0, 0, 0, 0, 0}, 334.426740, 0.000010, 0.254000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0}, 200.824580, 0.000030, 0.250000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -3, 0}, 306.541870, 0.000030, 0.091000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -2, 0}, 128.064720, 0.000040, 0.449000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 0, -2}, 308.223680, 0.000030, 0.528000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 128.143080, 0.000080, 0.035000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 2, 0}, 128.215870, 0.000020, 0.018000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 4, -2, 0}, 308.119290, 0.000010, 0.037000},
	{{0, 0, 4, 0, 1, 0, 0, 0, 2, -1, 0}, 119.690630, 0.000040, 0.064000},
	{{0, 0, 4, 0, 1, 0, 0, 0, 2, 0, 0}, 297.343970, 0.000060, 0.035000},
	{{0, 0, 4, 0, 2, -5, 0, 0, 2, -3, 0}, 318.693330, 0.000020, 0.091000},
	{{0, 0, 4, 0, 2, -5, 0, 0, 2, -2, 0}, 319.514610, 0.000020, 0.449000},
	{{0, 0, 4, 0, 2, -5, 0, 0, 2, -1, 0}, 318.693330, 0.000020, 0.065000},
	{{0, 0, 4, 1, -2, 0, 0, 0, 2, 0, 0}, 98.622100, 0.000020, 0.034000},
	{{0, 0, 4, 1, -1, 0, 0, 0, 2, 0, 0}, 305.301410, 0.000020, 0.034000},
	{{0, 0, 4, 2, -2, 0, 0, 0, 2, 0, 0}, 127.977360, 0.000020, 0.034000},
	{{0, 0, 5, -14, 4, 0, 0, 0, -2, 0, 2}, 258.798600, 0.000020, 855.192000},
	{{0, 0, 5, -12, 0, 0, 0, 0, -2, 1, 0}, 324.394070, 0.000020, 0.078000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 0, 0, 0}, 230.886360, 0.000050, 1.179000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 2, -1, 0}, 305.786460, 0.000050, 0.094000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 2, 0, 0}, 306.926150, 0.000050, 0.042000},
	{{0, 0, 5, -11, 1, 0, 0, 0, 0, 0, 0}, 216.972940, 0.000010, 1.309000},
	{{0, 0, 5, -10, 0, 0, 0, 0, -2, 0, 0}, 212.750520, 0.000060, 0.040000},
	{{0, 0, 5, -10, 0, 0, 0, 0, -2, 1, 0}, 212.493940, 0.000080, 0.085000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, -1, 0}, 212.135220, 0.000170, 0.074000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, 0, 0}, 214.341090, 0.000930, 3.156000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, 1, 0}, 213.378750, 0.000190, 0.077000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 2, -1, 0}, 221.377050, 0.000120, 0.090000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 2, 0, 0}, 219.005560, 0.000100, 0.041000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 2, 1, 0}, 219.673650, 0.000020, 0.027000},
	{{0, 0, 5, -10, 2, 0, 0, 0, 0, 0, 0}, 273.493030, 0.000020, 6.746000},
	{{0, 0, 5, -10, 3, 0, 0, 0, 0, 0, 0}, 39.889250, 0.000030, 15.643000},
	{{0, 0, 5, -9, -2, 0, 0, 0, 0, -1, 0}, 178.693260, 0.000020, 0.076000},
	{{0, 0, 5, -9, -2, 0, 0, 0, 0, 0, 0}, 358.153070, 0.000010, 21.630000},
	{{0, 0, 5, -9, -2, 0, 0, 0, 0, 1, 0}, 178.693260, 0.000020, 0.075000},
	{{0, 0, 5, -9, -1, 0, 0, 0, 0, -1, 0}, 24.300800, 0.000010, 0.076000},
	{{0, 0, 5, -9, -1, 0, 0, 0, 0, 1, 0}, 24.300800, 0.000010, 0.075000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -4, 0, 0}, 243.825920, 0.000020, 0.020000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -4, 2, 0}, 243.703260, 0.000020, 0.044000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, -1, 0}, 243.412530, 0.000100, 0.026000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 0, 0}, 243.749400, 0.000950, 0.041000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 0, 2}, 243.841460, 0.000020, 0.431000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 1, 0}, 244.045760, 0.001460, 0.089000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 2, 0}, 243.870320, 0.000060, 0.503000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -1, 0, 0}, 63.286560, 0.000010, 0.082000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -1, 2, 0}, 63.286560, 0.000010, 0.070000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -2, 0}, 240.437230, 0.000070, 0.038000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -1, 0}, 241.182610, 0.001300, 0.077000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 0, 0}, 242.296690, 0.006760, 4.655000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 1, 0}, 240.955140, 0.001250, 0.074000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 2, 0}, 240.772410, 0.000080, 0.037000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 1, 0, -1}, 324.746710, 0.000020, 1.192000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -2, 0}, 243.012470, 0.000050, 0.641000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -1, 0}, 243.525820, 0.001150, 0.085000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 0, -2}, 243.158860, 0.000020, 0.528000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 0, 0}, 243.136920, 0.000680, 0.040000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 1, 0}, 242.900200, 0.000080, 0.026000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 4, -2, 0}, 243.170540, 0.000010, 0.043000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 4, -1, 0}, 243.213480, 0.000020, 0.027000},
	{{0, 0, 5, -9, 1, 0, 0, 0, 0, 0, 0}, 274.967250, 0.000010, 3.343000},
	{{0, 0, 5, -9, 2, 0, 0, 0, 0, 0, 0}, 302.113840, 0.000010, 2.608000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -4, 0, 0}, 271.978570, 0.000020, 0.021000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -4, 1, 0}, 271.991120, 0.000010, 0.028000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -4, 2, 0}, 272.086640, 0.000020, 0.045000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, -1, 0}, 271.978050, 0.000100, 0.027000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 0, 0}, 271.983800, 0.001100, 0.042000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 0, 2}, 271.974910, 0.000020, 0.350000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 1, 0}, 272.001410, 0.001510, 0.093000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 2, 0}, 271.974500, 0.000050, 0.397000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -1, -1, 1}, 174.296360, 0.000070, 0.087000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -1, 0, 0}, 92.818670, 0.000020, 0.086000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -1, 0, 1}, 354.316480, 0.000010, 0.555000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, -2, 0}, 271.882810, 0.000060, 0.039000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, -1, 0}, 273.524740, 0.000920, 0.080000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 0, 0}, 272.055020, 0.004740, 1.340000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 1, 0}, 271.885870, 0.000800, 0.071000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 2, 0}, 271.854550, 0.000050, 0.037000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -3, 1}, 174.472220, 0.000010, 0.076000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -2, 1}, 174.301570, 0.000220, 38.061000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -1, 0}, 273.151480, 0.000030, 7.118000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -1, 1}, 354.296170, 0.000340, 0.075000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, 0, -1}, 354.309350, 0.000170, 3.255000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, 0, 0}, 272.818660, 0.000120, 0.076000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -2, 0}, 2.250830, 0.000020, 0.973000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -1, 0}, 287.376530, 0.000660, 0.082000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 0, 0}, 276.302140, 0.000350, 0.039000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 1, 0}, 273.051200, 0.000040, 0.026000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 4, -3, 0}, 44.709410, 0.000010, 0.096000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 4, -2, 0}, 44.971800, 0.000040, 0.042000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 4, -1, 0}, 17.579010, 0.000020, 0.027000},
	{{0, 0, 5, -8, 1, 0, 0, 0, 0, 0, 0}, 308.630330, 0.000010, 1.204000},
	{{0, 0, 5, -8, 1, 5, 0, 0, -2, 0, 0}, 174.667660, 0.000070, 0.042000},
	{{0, 0, 5, -8, 1, 5, 0, 0, -2, 1, 0}, 174.785190, 0.000070, 0.095000},
	{{0, 0, 5, -8, 1, 5, 0, 0, 0, -1, 0}, 172.889200, 0.000010, 0.082000},
	{{0, 0, 5, -8, 1, 5, 0, 0, 0, 0, 0}, 172.238960, 0.000100, 0.999000},
	{{0, 0, 5, -8, 1, 5, 0, 0, 0, 1, 0}, 172.889200, 0.000010, 0.070000},
	{{0, 0, 5, -8, 2, 0, 0, 0, 0, 0, 0}, 327.561320, 0.000020, 1.093000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -6, 1, 0}, 184.531210, 0.000010, 0.017000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, -2, 0}, 184.428870, 0.000020, 0.013000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, -1, 0}, 184.151840, 0.000030, 0.016000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 0, 0}, 184.360990, 0.000170, 0.021000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 1, 0}, 184.594330, 0.000400, 0.028000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 2, 0}, 184.950200, 0.000170, 0.046000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -3, 0, 0}, 184.686180, 0.000020, 0.028000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -3, 1, 0}, 4.686180, 0.000010, 0.044000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -3, 3, 0}, 4.686180, 0.000010, 0.273000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, -2, 0}, 184.286170, 0.000110, 0.020000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, -1, 0}, 184.495640, 0.000880, 0.027000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, -1, 2}, 4.969570, 0.000010, 0.099000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, -2}, 5.098620, 0.000020, 0.020000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, 0}, 184.817550, 0.008970, 0.042000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, 2}, 184.773320, 0.000140, 0.322000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 1, 0}, 185.262570, 0.009620, 0.095000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 1, 2}, 4.969570, 0.000010, 0.061000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 2, 0}, 185.807850, 0.000370, 0.361000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 3, 0}, 185.999340, 0.000030, 0.062000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -1, 0, 0}, 9.173820, 0.000040, 0.088000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -1, 1, 0}, 4.568700, 0.000010, 0.530000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -3, 0}, 183.910120, 0.000010, 0.026000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -2, 0}, 184.894080, 0.000310, 0.039000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -1, 0}, 185.635850, 0.003530, 0.082000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 0, 0}, 187.283720, 0.010910, 1.001000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 1, 0}, 191.809400, 0.000970, 0.070000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 2, 0}, 267.965090, 0.000010, 0.036000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 1, 0, 0}, 158.377290, 0.000040, 0.075000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, -2, 0}, 180.860250, 0.000030, 1.291000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, -1, 0}, 0.539340, 0.000400, 0.080000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, 0, -2}, 1.735390, 0.000040, 0.902000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, 0, 0}, 1.025590, 0.000520, 0.039000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, 1, 0}, 1.672630, 0.000040, 0.026000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, 2, 0}, 3.726680, 0.000020, 0.019000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 4, -2, 0}, 3.755940, 0.000020, 0.042000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 4, -1, 0}, 3.315460, 0.000040, 0.027000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 4, 0, 0}, 6.122570, 0.000010, 0.020000},
	{{0, 0, 5, -8, 5, -5, 0, 0, -2, 0, 0}, 319.672780, 0.000020, 0.042000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -4, 0, 0}, 126.482740, 0.000020, 0.021000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -4, 1, 0}, 126.378730, 0.000020, 0.029000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -4, 2, 0}, 126.744980, 0.000020, 0.046000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, -2, 0}, 126.608460, 0.000020, 0.020000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, -1, 0}, 126.358220, 0.000110, 0.027000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 0, 0}, 127.368270, 0.001410, 0.043000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 0, 2}, 126.692050, 0.000020, 0.295000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 1, 0}, 126.213930, 0.001580, 0.098000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 2, 0}, 127.211150, 0.000070, 0.328000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -1, 0, 1}, 206.018990, 0.000010, 0.429000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, -2, 0}, 124.554190, 0.000110, 0.040000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, -1, 0}, 124.125750, 0.001590, 0.083000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 0, 0}, 123.470480, 0.005340, 0.782000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 1, 0}, 123.144340, 0.000860, 0.069000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 2, 0}, 123.268540, 0.000060, 0.036000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, -1, -1}, 204.443140, 0.000030, 0.077000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, -1, 1}, 24.824480, 0.000020, 0.072000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, 0, -1}, 204.459950, 0.000260, 4.456000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, 0, 1}, 24.429660, 0.000030, 0.037000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, 1, -1}, 204.443140, 0.000030, 0.074000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -3, 0}, 298.584750, 0.000010, 0.073000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -2, 0}, 304.136910, 0.000180, 2.017000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -1, 0}, 301.816630, 0.001780, 0.078000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, -2}, 302.450370, 0.000020, 1.206000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, 0}, 302.946650, 0.000190, 0.038000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 1, 0}, 302.792730, 0.000020, 0.025000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 4, -2, 0}, 301.356230, 0.000020, 0.041000},
	{{0, 0, 5, -7, 2, 0, 0, 0, 2, 0, 0}, 0.523970, 0.000010, 0.038000},
	{{0, 0, 5, -7, 3, 0, 0, 0, 2, -1, 0}, 137.114770, 0.000020, 0.077000},
	{{0, 0, 5, -6, -2, 0, 0, 0, 2, -1, 0}, 274.039270, 0.000030, 0.076000},
	{{0, 0, 5, -6, -1, 0, 0, 0, 2, -3, 0}, 268.868650, 0.000010, 0.075000},
	{{0, 0, 5, -6, -1, 0, 0, 0, 2, -2, 0}, 301.350820, 0.000010, 20.650000},
	{{0, 0, 5, -6, -1, 0, 0, 0, 2, -1, 0}, 295.768910, 0.000030, 0.076000},
	{{0, 0, 5, -6, 0, -1, 0, 0, 2, -2, 0}, 269.309430, 0.000060, 518.400000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -4, 1, 0}, 165.921110, 0.000020, 0.029000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, -2, 0}, 330.101950, 0.000010, 0.020000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, -1, 0}, 235.330220, 0.000020, 0.028000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 0, 0}, 169.257840, 0.000730, 0.044000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 1, 0}, 166.768500, 0.000850, 0.103000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 2, 0}, 169.605300, 0.000030, 0.279000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -3, 0}, 331.850170, 0.000060, 0.026000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -2, 0}, 331.453950, 0.000720, 0.040000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -1, -2}, 151.741840, 0.000020, 0.026000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -1, 0}, 331.173730, 0.008380, 0.087000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 0, 0}, 157.540970, 0.001950, 0.553000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 1, 0}, 156.029600, 0.000380, 0.066000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 2, 0}, 154.399150, 0.000030, 0.035000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, -1, 0}, 151.741870, 0.000040, 1.084000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, 0, -1}, 237.308390, 0.000100, 1.323000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, 0, 0}, 149.019460, 0.000020, 0.071000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -4, 0}, 332.793340, 0.000030, 0.038000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -3, 0}, 332.763170, 0.000440, 0.076000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, -2}, 152.054470, 0.000010, 0.037000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, 0}, 331.682910, 0.016820, 27.873000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, 2}, 152.054470, 0.000010, 0.037000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, -2}, 151.705970, 0.000090, 0.074000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, 0}, 151.732400, 0.042820, 0.075000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, 2}, 331.741800, 0.000090, 0.025000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, -2}, 331.559230, 0.000060, 3.360000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, 0}, 151.786040, 0.002630, 0.038000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, 2}, 331.741760, 0.000020, 0.019000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 1, -2}, 151.506080, 0.000010, 0.077000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 1, 0}, 151.705390, 0.000160, 0.025000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 3, -1, 0}, 331.741910, 0.000020, 0.039000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -3, 0}, 331.335610, 0.000280, 0.087000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -2, 0}, 151.791520, 0.000380, 0.040000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -1, 0}, 151.753560, 0.000370, 0.026000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, 0, 0}, 151.731240, 0.000060, 0.019000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 6, -2, 0}, 151.753460, 0.000010, 0.020000},
	{{0, 0, 5, -6, 1, 0, 0, 0, 0, 0, 0}, 5.387130, 0.000010, 0.528000},
	{{0, 0, 5, -6, 2, 0, 0, 0, 2, -2, 0}, 209.029690, 0.000020, 4.890000},
	{{0, 0, 5, -5, -1, 0, 0, 0, -2, 0, 0}, 327.438670, 0.000010, 0.044000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, -1, 0}, 137.149400, 0.000040, 0.028000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 0, 0}, 133.486800, 0.000240, 0.045000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 1, 0}, 136.285950, 0.000210, 0.109000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -2, 0}, 4.137940, 0.000020, 0.041000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -1, 0}, 19.191380, 0.000280, 0.092000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 0, 0}, 173.743430, 0.001280, 0.427000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 1, 0}, 175.787560, 0.000220, 0.064000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 2, 0}, 171.963340, 0.000020, 0.035000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 1, 0, -1}, 282.354700, 0.000040, 0.777000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -2, 0}, 179.241880, 0.000050, 1.762000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -1, 0}, 179.307380, 0.002610, 0.072000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 0, -2}, 180.703950, 0.000180, 4.273000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 0, 0}, 2.360530, 0.000200, 0.037000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 1, 0}, 0.381970, 0.000050, 0.025000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 4, -2, 0}, 179.526800, 0.000040, 0.040000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 4, -1, 0}, 178.074520, 0.000010, 0.026000},
	{{0, 0, 5, -5, 2, 0, 0, 0, 0, 0, 0}, 57.369180, 0.000010, 0.398000},
	{{0, 0, 5, -4, -2, 0, 0, 0, -2, 0, 0}, 149.142990, 0.000010, 0.045000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, -1, 0}, 86.586570, 0.000020, 0.028000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, 0, 0}, 88.535380, 0.000170, 0.046000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, 1, 0}, 87.049420, 0.000130, 0.116000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, -2, 0}, 255.580310, 0.000010, 0.042000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, -1, 0}, 249.708830, 0.000160, 0.096000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, 0, 0}, 86.605890, 0.000080, 0.348000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, 1, 0}, 67.961590, 0.000040, 0.062000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 1, 0, -1}, 309.950160, 0.000040, 0.550000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, -1, 0}, 358.543160, 0.000130, 0.070000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, 0, 0}, 206.476430, 0.000050, 0.036000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 3, -1, -1}, 309.940120, 0.000030, 0.075000},
	{{0, 0, 5, -3, -1, 0, 0, 0, 0, 0, 0}, 197.928090, 0.000010, 0.301000},
	{{0, 0, 5, -3, 0, 0, 0, 0, -2, 0, 0}, 327.618370, 0.000030, 0.047000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 0, 0, 0}, 315.909090, 0.000010, 0.294000},
	{{0, 0, 5, -2, 0, 0, 0, 0, -2, 0, 0}, 50.801350, 0.000020, 0.048000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 2, -2, 0}, 266.385150, 0.000020, 0.462000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 2, 0, 0}, 266.385150, 0.000020, 0.035000},
	{{0, 0, 5, 0, -8, 0, 0, 0, 2, 0, 0}, 30.778390, 0.000010, 0.034000},
	{{0, 0, 5, 0, -7, 0, 0, 0, -2, 0, 0}, 195.146960, 0.000020, 0.049000},
	{{0, 0, 5, 0, -7, 0, 0, 0, 2, -1, 0}, 200.507100, 0.000050, 0.063000},
	{{0, 0, 5, 0, -7, 0, 0, 0, 2, 0, 0}, 20.507100, 0.000050, 0.034000},
	{{0, 0, 5, 0, -7, 5, 0, 0, 2, -2, 0}, 347.689890, 0.000010, 0.356000},
	{{0, 0, 5, 0, -7, 5, 0, 0, 2, 0, 0}, 167.689890, 0.000010, 0.034000},
	{{0, 0, 5, 0, -6, 0, 0, 0, -2, 0, 0}, 182.564870, 0.000050, 0.049000},
	{{0, 0, 5, 0, -6, 0, 0, 0, -2, 1, 0}, 182.661730, 0.000020, 0.143000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 0, -1, 0}, 10.051680, 0.000020, 0.114000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 0, 0, 0}, 180.197340, 0.000010, 0.223000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 0, 1, 0}, 190.051690, 0.000010, 0.056000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, -2, 0}, 190.051680, 0.000010, 0.368000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, -1, 0}, 190.051680, 0.000210, 0.063000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, 0, 0}, 9.873380, 0.000120, 0.034000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, 1, 0}, 10.051680, 0.000030, 0.024000},
	{{0, 0, 5, 0, -5, 0, 0, 0, -2, 0, 0}, 165.090180, 0.000140, 0.050000},
	{{0, 0, 5, 0, -5, 0, 0, 0, -2, 1, 0}, 164.999570, 0.000060, 0.145000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 0, -1, 0}, 20.460820, 0.000020, 0.115000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 0, 0, 0}, 139.955990, 0.000020, 0.218000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 0, 1, 0}, 174.425760, 0.000050, 0.056000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, -2, 0}, 181.761360, 0.000010, 0.357000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, -1, 0}, 178.997640, 0.000500, 0.062000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, 0, -2}, 179.142820, 0.000020, 0.405000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, 0, 0}, 359.315340, 0.000320, 0.034000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, 1, 0}, 359.105170, 0.000060, 0.023000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 4, -1, 0}, 359.142810, 0.000030, 0.025000},
	{{0, 0, 5, 0, -4, 0, 0, 0, -2, 0, 0}, 62.822660, 0.000110, 0.050000},
	{{0, 0, 5, 0, -4, 0, 0, 0, -2, 1, 0}, 62.950720, 0.000070, 0.147000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 0, -1, 0}, 246.258000, 0.000020, 0.116000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 0, 0, 0}, 65.413920, 0.000020, 0.214000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 0, 1, 0}, 58.176900, 0.000010, 0.056000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 2, -1, 0}, 18.497930, 0.000060, 0.062000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 2, 0, 0}, 195.994020, 0.000060, 0.034000},
	{{0, 0, 5, 0, -3, -5, 0, 0, 2, -2, 0}, 187.923290, 0.000010, 0.357000},
	{{0, 0, 5, 0, -3, -5, 0, 0, 2, 0, 0}, 7.923290, 0.000010, 0.034000},
	{{0, 0, 5, 0, -3, 0, 0, 0, -2, 0, 0}, 319.220200, 0.000060, 0.050000},
	{{0, 0, 5, 0, -3, 0, 0, 0, -2, 1, 0}, 315.209420, 0.000030, 0.148000},
	{{0, 0, 5, 0, -3, 0, 0, 0, 0, 0, 0}, 316.156380, 0.000010, 0.211000},
	{{0, 0, 5, 0, -3, 5, 0, 0, 2, 0, 0}, 298.875750, 0.000010, 0.034000},
	{{0, 0, 5, 0, -2, 0, 0, 0, -2, 0, 0}, 228.398410, 0.000040, 0.050000},
	{{0, 0, 5, 0, -2, 0, 0, 0, -2, 1, 0}, 227.717960, 0.000010, 0.150000},
	{{0, 0, 5, 0, -2, 0, 0, 0, 2, -1, 0}, 248.043160, 0.000020, 0.061000},
	{{0, 0, 5, 0, -2, 0, 0, 0, 2, 0, 0}, 250.556120, 0.000050, 0.034000},
	{{0, 0, 5, 0, -1, 0, 0, 0, 0, -1, 0}, 309.530500, 0.000010, 0.120000},
	{{0, 0, 5, 0, -1, 0, 0, 0, 0, 1, 0}, 309.530500, 0.000010, 0.055000},
	{{0, 0, 5, 0, -1, 0, 0, 0, 2, -3, 0}, 130.411710, 0.000010, 0.099000},
	{{0, 0, 5, 0, -1, 0, 0, 0, 2, -2, 0}, 309.975450, 0.000040, 0.318000},
	{{0, 0, 5, 0, -1, 0, 0, 0, 2, 0, 0}, 311.029690, 0.000040, 0.034000},
	{{0, 0, 5, 0, 0, 0, 0, 0, -2, 0, 0}, 302.153280, 0.000020, 0.051000},
	{{0, 0, 5, 0, 0, 0, 0, 0, -2, 2, 0}, 302.153280, 0.000020, 0.148000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, -2, 0}, 158.018720, 0.000010, 0.046000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 14.867130, 0.000040, 0.200000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 2, 0}, 37.365810, 0.000010, 0.032000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, -2, 0}, 197.950440, 0.000030, 0.310000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 4, 0, 0}, 215.587290, 0.000030, 0.018000},
	{{0, 0, 5, 0, 1, -5, 0, 0, 2, 0, 0}, 138.279890, 0.000010, 0.034000},
	{{0, 0, 6, -16, 4, 5, 0, 0, 0, 0, 0}, 98.554290, 0.000030, 0.500000},
	{{0, 0, 6, -16, 4, 5, 0, 0, 2, -1, 0}, 98.554290, 0.000060, 0.105000},
	{{0, 0, 6, -16, 4, 5, 0, 0, 2, 0, 0}, 98.554290, 0.000070, 0.044000},
	{{0, 0, 6, -15, 0, 0, 0, 0, 2, 0, 0}, 0.785290, 0.000020, 0.044000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, -1, 0}, 274.742570, 0.000010, 0.071000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, 0, 0}, 270.377970, 0.000060, 1.097000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, 1, 0}, 274.742570, 0.000010, 0.081000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 2, -1, 0}, 283.392190, 0.000060, 0.095000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 2, 0, 0}, 283.392190, 0.000050, 0.042000},
	{{0, 0, 6, -12, 0, 0, 0, 0, -2, 0, 0}, 182.304840, 0.000010, 0.040000},
	{{0, 0, 6, -12, 0, 0, 0, 0, -2, 1, 0}, 182.307470, 0.000020, 0.084000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, -1, 0}, 184.201910, 0.000050, 0.073000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 0, 0}, 186.110800, 0.000280, 2.630000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 1, 0}, 184.201910, 0.000050, 0.078000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 2, -1, 0}, 193.940160, 0.000030, 0.090000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 2, 0, 0}, 193.940160, 0.000030, 0.041000},
	{{0, 0, 6, -12, 2, 0, 0, 0, 0, -1, 0}, 229.812700, 0.000010, 0.074000},
	{{0, 0, 6, -12, 2, 0, 0, 0, 0, 1, 0}, 229.812700, 0.000010, 0.077000},
	{{0, 0, 6, -12, 3, 0, 0, 0, 0, 0, 0}, 46.098290, 0.000050, 7.856000},
	{{0, 0, 6, -11, -2, 0, 0, 0, 0, -1, 0}, 332.617700, 0.000010, 0.075000},
	{{0, 0, 6, -11, -2, 0, 0, 0, 0, 0, 0}, 150.582950, 0.000010, 58.360000},
	{{0, 0, 6, -11, -2, 0, 0, 0, 0, 1, 0}, 332.617700, 0.000010, 0.076000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -4, 1, 0}, 214.834150, 0.000010, 0.028000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -4, 2, 0}, 214.852460, 0.000010, 0.044000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, -1, 0}, 214.837660, 0.000070, 0.026000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 0, 0}, 214.720720, 0.000640, 0.041000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 0, 2}, 214.852330, 0.000010, 0.443000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 1, 0}, 215.260000, 0.000990, 0.088000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 2, 0}, 214.882080, 0.000040, 0.519000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -2, 0}, 212.793780, 0.000060, 0.038000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -1, 0}, 211.861890, 0.000960, 0.076000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 0, 0}, 213.130320, 0.005060, 6.602000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 1, 0}, 211.636000, 0.000920, 0.075000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 2, 0}, 211.023570, 0.000050, 0.038000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 1, 0, -1}, 295.649390, 0.000010, 1.108000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, -2, 0}, 214.112020, 0.000030, 0.616000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, -1, 0}, 214.682750, 0.000820, 0.086000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 0, -2}, 214.228940, 0.000010, 0.511000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 0, 0}, 214.167910, 0.000500, 0.040000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 1, 0}, 214.293150, 0.000050, 0.026000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 4, -2, 0}, 214.270820, 0.000010, 0.043000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 4, -1, 0}, 214.269880, 0.000020, 0.027000},
	{{0, 0, 6, -11, 3, 0, 0, 0, 0, 0, 0}, 78.422780, 0.000020, 2.473000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -4, 1, 0}, 243.254770, 0.000010, 0.028000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, -1, 0}, 243.253970, 0.000040, 0.027000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 0, 0}, 243.248410, 0.000390, 0.042000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 1, 0}, 243.329550, 0.000540, 0.093000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 2, 0}, 243.255750, 0.000030, 0.407000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -1, -1, 1}, 324.932160, 0.000020, 0.087000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, -2, 0}, 240.919730, 0.000010, 0.039000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, -1, 0}, 242.380460, 0.000330, 0.080000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 0, 0}, 242.972770, 0.001750, 1.464000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 1, 0}, 242.327380, 0.000270, 0.072000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 2, 0}, 242.372400, 0.000020, 0.037000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 1, -2, 1}, 144.936790, 0.000060, 26.959000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 1, -1, 1}, 144.932160, 0.000110, 0.076000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 1, 0, -1}, 324.929410, 0.000070, 2.698000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 1, 0, 0}, 241.120260, 0.000020, 0.077000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, -1, 0}, 248.551390, 0.000310, 0.082000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, 0, 0}, 243.967200, 0.000170, 0.039000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, 1, 0}, 244.038230, 0.000010, 0.026000},
	{{0, 0, 6, -10, 2, 0, 0, 0, 0, 0, 0}, 122.961450, 0.000010, 1.174000},
	{{0, 0, 6, -10, 3, 0, 0, 0, -2, 0, 0}, 107.856470, 0.000010, 0.042000},
	{{0, 0, 6, -10, 3, 0, 0, 0, 0, 0, 0}, 108.284420, 0.000060, 1.068000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -4, 1, 0}, 97.487600, 0.000030, 0.029000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, -1, 0}, 97.420200, 0.000080, 0.027000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 0, 0}, 98.092050, 0.000780, 0.043000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 0, 2}, 97.555500, 0.000010, 0.301000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 1, 0}, 97.217960, 0.000910, 0.097000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 2, 0}, 96.954900, 0.000050, 0.335000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, -2, 0}, 94.971170, 0.000040, 0.040000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, -1, 0}, 95.275860, 0.000870, 0.083000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 0, 0}, 94.528280, 0.002970, 0.823000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 1, 0}, 94.544970, 0.000490, 0.069000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 2, 0}, 94.359620, 0.000030, 0.036000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, -2, 0}, 271.779860, 0.000010, 0.077000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, -1, -1}, 174.342050, 0.000030, 0.076000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 0, -1}, 174.365430, 0.000210, 6.208000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 0, 0}, 91.779860, 0.000010, 0.074000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 0, 1}, 354.335380, 0.000020, 0.037000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 1, -2}, 94.315680, 0.000040, 176.039000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 1, -1}, 174.342050, 0.000030, 0.075000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -2, 0}, 274.276760, 0.000060, 1.788000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -1, 0}, 272.606790, 0.000760, 0.079000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, 0, 0}, 275.107540, 0.000060, 0.039000},
	{{0, 0, 6, -8, -2, 0, 0, 0, 0, 0, 0}, 244.028910, 0.000010, 0.634000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -4, 1, 0}, 132.651660, 0.000010, 0.029000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, -1, 0}, 126.490480, 0.000100, 0.028000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 0, 0}, 131.573550, 0.000500, 0.043000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 1, 0}, 133.357120, 0.000390, 0.103000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 2, 0}, 137.244510, 0.000020, 0.284000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -2, 0}, 122.709870, 0.000210, 0.040000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -1, 0}, 122.629300, 0.006640, 0.087000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 0, 0}, 124.517600, 0.002060, 0.573000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 1, 0}, 125.543600, 0.000310, 0.067000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 2, 0}, 127.041140, 0.000020, 0.035000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 1, -1, 0}, 302.336450, 0.000030, 1.163000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 1, 0, -1}, 205.294510, 0.000090, 1.444000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 1, 0, 0}, 122.240970, 0.000020, 0.071000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -4, 0}, 301.503960, 0.000050, 0.038000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -3, 0}, 301.491630, 0.000670, 0.075000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, -2}, 122.337810, 0.000020, 0.037000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, 0}, 302.356460, 0.020230, 36.376000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, 2}, 122.337810, 0.000020, 0.037000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, -2}, 302.336250, 0.000060, 0.073000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, 0}, 302.343460, 0.033170, 0.076000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, 2}, 122.336330, 0.000060, 0.025000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, -2}, 302.504800, 0.000030, 2.770000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, 0}, 302.301810, 0.002430, 0.038000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 1, 0}, 302.368760, 0.000180, 0.025000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -3, 0}, 302.729960, 0.000310, 0.087000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -2, 0}, 302.355240, 0.000660, 0.040000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -1, 0}, 302.347020, 0.000340, 0.026000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, 0, 0}, 302.256410, 0.000030, 0.020000},
	{{0, 0, 6, -8, 0, 1, 0, 0, 2, -2, 0}, 164.892080, 0.000020, 154.875000},
	{{0, 0, 6, -8, 1, 0, 0, 0, 0, 0, 0}, 356.855370, 0.000010, 0.546000},
	{{0, 0, 6, -8, 1, 0, 0, 0, 2, -1, 0}, 288.176580, 0.000030, 0.075000},
	{{0, 0, 6, -8, 2, 0, 0, 0, 2, 0, 0}, 180.286710, 0.000010, 0.038000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -4, 1, 0}, 82.368490, 0.000030, 0.029000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, -1, 0}, 82.673420, 0.000060, 0.028000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 0, 0}, 82.380890, 0.000540, 0.044000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 1, 0}, 82.823720, 0.000460, 0.105000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 2, 0}, 82.647690, 0.000020, 0.265000},
	{{0, 0, 6, -8, 3, 0, 0, 0, 0, -1, 0}, 84.182990, 0.000110, 0.089000},
	{{0, 0, 6, -8, 3, 0, 0, 0, 0, 0, 0}, 84.496910, 0.000240, 0.500000},
	{{0, 0, 6, -8, 3, 0, 0, 0, 2, -3, 0}, 112.220200, 0.000010, 0.077000},
	{{0, 0, 6, -7, -6, 0, 0, 0, 2, -2, 0}, 194.085650, 0.000020, 612.237000},
	{{0, 0, 6, -7, -2, 0, 0, 0, 2, -1, -2}, 272.419060, 0.000020, 0.075000},
	{{0, 0, 6, -7, -2, 0, 0, 0, 2, 0, -2}, 274.942530, 0.000100, 483.014000},
	{{0, 0, 6, -7, -2, 0, 0, 0, 2, 1, -2}, 272.419060, 0.000020, 0.075000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, -1, 0}, 121.145590, 0.000030, 0.028000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 0, 0}, 115.838560, 0.000180, 0.045000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 1, 0}, 120.293110, 0.000170, 0.109000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, -2, 0}, 333.394890, 0.000020, 0.041000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, -1, 0}, 340.225830, 0.000300, 0.091000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 0, 0}, 146.138230, 0.001030, 0.439000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 1, 0}, 146.484060, 0.000210, 0.064000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 2, 0}, 145.725930, 0.000020, 0.035000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 1, 0, -1}, 239.707070, 0.000060, 0.817000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -3, 0}, 154.814160, 0.000020, 0.078000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -2, 0}, 151.127200, 0.000030, 1.983000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -1, -2}, 151.534370, 0.000010, 0.076000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -1, 0}, 150.756920, 0.002640, 0.073000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, -2}, 151.534370, 0.000250, 5.859000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, 0}, 332.791250, 0.000170, 0.037000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 1, -2}, 151.534370, 0.000010, 0.074000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 1, 0}, 331.351030, 0.000050, 0.025000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 4, -2, 0}, 150.731030, 0.000040, 0.040000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, -1, 0}, 149.656970, 0.000020, 0.028000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 0, 0}, 150.743810, 0.000120, 0.046000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 1, 0}, 136.401120, 0.000070, 0.115000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -2, 0}, 249.708530, 0.000030, 0.042000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -1, 0}, 231.979040, 0.000360, 0.096000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, 0, 0}, 179.268550, 0.000630, 0.356000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, 1, 0}, 173.098750, 0.000110, 0.062000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 1, 0, -1}, 283.256030, 0.000030, 0.569000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -2, 0}, 202.112200, 0.000060, 0.965000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -1, 0}, 187.682710, 0.001190, 0.070000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 0, -2}, 180.609290, 0.000040, 1.424000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 0, 0}, 353.500090, 0.000160, 0.036000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 1, 0}, 0.545970, 0.000040, 0.025000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 3, -2, -1}, 103.246380, 0.000040, 55.903000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 3, -1, -1}, 103.220610, 0.000050, 0.076000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 4, -2, 0}, 179.881160, 0.000020, 0.039000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 4, -1, 0}, 0.507110, 0.000010, 0.026000},
	{{0, 0, 6, -5, 0, 0, 0, 0, -2, 0, 0}, 41.159040, 0.000050, 0.047000},
	{{0, 0, 6, -5, 0, 0, 0, 0, -2, 1, 0}, 41.008930, 0.000020, 0.123000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 0, -1, 0}, 236.592170, 0.000040, 0.101000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 0, 0, 0}, 53.390520, 0.000020, 0.299000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 0, 1, 0}, 34.114170, 0.000020, 0.060000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 1, 0, -1}, 309.731760, 0.000020, 0.437000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, -1, 0}, 30.133990, 0.000140, 0.067000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, 0, 0}, 208.652930, 0.000060, 0.036000},
	{{0, 0, 6, -4, 0, 0, 0, 0, -2, 0, 0}, 327.931940, 0.000020, 0.048000},
	{{0, 0, 6, 0, -8, 0, 0, 0, 2, -1, 0}, 200.248110, 0.000020, 0.059000},
	{{0, 0, 6, 0, -8, 0, 0, 0, 2, 0, 0}, 20.248110, 0.000020, 0.033000},
	{{0, 0, 6, 0, -7, 0, 0, 0, 0, 0, 0}, 10.051800, 0.000010, 0.185000},
	{{0, 0, 6, 0, -7, 0, 0, 0, 2, -1, 0}, 189.584550, 0.000040, 0.059000},
	{{0, 0, 6, 0, -7, 0, 0, 0, 2, 0, 0}, 9.584550, 0.000040, 0.033000},
	{{0, 0, 6, 0, -6, 0, 0, 0, -2, 0, 0}, 162.225890, 0.000020, 0.052000},
	{{0, 0, 6, 0, -6, 0, 0, 0, 0, 0, 0}, 5.275560, 0.000020, 0.182000},
	{{0, 0, 6, 0, -6, 0, 0, 0, 2, -1, 0}, 178.117150, 0.000100, 0.059000},
	{{0, 0, 6, 0, -6, 0, 0, 0, 2, 0, 0}, 358.117140, 0.000090, 0.033000},
	{{0, 0, 6, 0, -6, 0, 0, 0, 2, 1, 0}, 358.117140, 0.000010, 0.023000},
	{{0, 0, 6, 0, -5, 0, 0, 0, -2, 0, 0}, 59.893670, 0.000030, 0.052000},
	{{0, 0, 6, 0, -5, 0, 0, 0, 2, -1, 0}, 23.284720, 0.000020, 0.059000},
	{{0, 0, 6, 0, -5, 0, 0, 0, 2, 0, 0}, 203.285340, 0.000020, 0.033000},
	{{0, 0, 6, 0, -2, 0, 0, 0, 0, 0, 0}, 308.357190, 0.000010, 0.171000},
	{{0, 0, 6, 0, -2, 0, 0, 0, 0, 2, 0}, 308.357190, 0.000010, 0.031000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 2, -2, 0}, 322.325270, 0.000010, 0.237000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 2, -1, 0}, 326.762030, 0.000020, 0.057000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 0}, 322.325270, 0.000010, 0.033000},
	{{0, 0, 7, -17, 0, -2, 0, 0, -2, 0, 2}, 356.309150, 0.000040, 997.332000},
	{{0, 0, 7, -16, 4, 5, 0, 0, -2, -1, 0}, 175.617360, 0.000020, 0.026000},
	{{0, 0, 7, -16, 4, 5, 0, 0, -2, 0, 0}, 175.617360, 0.000020, 0.039000},
	{{0, 0, 7, -16, 4, 5, 0, 0, -2, 1, 0}, 175.617360, 0.000070, 0.080000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, -1, 0}, 355.617360, 0.000200, 0.070000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 0, 0}, 355.617360, 0.001200, 1.000000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 1, 0}, 355.617360, 0.000270, 0.082000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, -2, 0}, 355.617360, 0.000060, 0.360000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, -1, 0}, 355.617360, 0.001150, 0.095000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, 0, -2}, 355.617360, 0.000010, 0.322000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, 0, 0}, 355.617360, 0.000870, 0.042000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, 1, 0}, 355.617360, 0.000110, 0.027000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 4, -1, 0}, 355.617360, 0.000040, 0.028000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 4, 0, 0}, 355.617360, 0.000020, 0.021000},
	{{0, 0, 7, -15, 0, 0, 0, 0, -2, 1, 0}, 78.451200, 0.000030, 0.080000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, -1, 0}, 251.870760, 0.000010, 0.070000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, 0, 0}, 256.029940, 0.000300, 1.025000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, 1, 0}, 254.796160, 0.000110, 0.081000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, -1, 0}, 258.304740, 0.000280, 0.095000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, 0, 0}, 257.804200, 0.000240, 0.042000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, 1, 0}, 258.030640, 0.000030, 0.027000},
	{{0, 0, 7, -14, 0, 0, 0, 0, 0, 0, 0}, 158.050110, 0.000060, 2.254000},
	{{0, 0, 7, -14, 1, 0, 0, 0, 0, 0, 0}, 186.561470, 0.000020, 2.783000},
	{{0, 0, 7, -14, 3, 0, 0, 0, 0, 0, 0}, 17.050750, 0.000010, 5.245000},
	{{0, 0, 7, -13, -1, 0, 0, 0, -2, 0, 0}, 116.214640, 0.000060, 0.040000},
	{{0, 0, 7, -13, -1, 0, 0, 0, -2, 1, 0}, 116.678610, 0.000070, 0.087000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 0, -1, 0}, 115.106570, 0.000130, 0.075000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 0, 0, 0}, 117.137090, 0.000550, 263.130000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 0, 1, 0}, 115.106570, 0.000130, 0.075000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 2, -1, 0}, 116.672200, 0.000070, 0.087000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 2, 0, 0}, 116.207350, 0.000050, 0.040000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -4, 1, 0}, 185.846090, 0.000030, 0.028000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -4, 2, 0}, 185.861430, 0.000010, 0.044000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, -1, 0}, 185.846060, 0.000060, 0.026000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 0, 0}, 185.692150, 0.000630, 0.041000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 0, 2}, 185.846110, 0.000010, 0.455000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 1, 0}, 186.335820, 0.000980, 0.088000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 2, 0}, 185.875330, 0.000040, 0.537000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, -2, 0}, 182.600340, 0.000070, 0.038000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, -1, 0}, 182.805500, 0.001070, 0.076000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, -2}, 4.193600, 0.000010, 0.037000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, 0}, 184.173280, 0.005580, 11.350000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, 2}, 4.193600, 0.000010, 0.037000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 1, 0}, 182.662240, 0.001050, 0.075000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 2, 0}, 182.511790, 0.000070, 0.038000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -2, 0}, 185.345710, 0.000040, 0.593000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -1, 0}, 185.802090, 0.000870, 0.086000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 0, -2}, 185.385940, 0.000010, 0.495000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 0, 0}, 185.245650, 0.000550, 0.040000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 1, 0}, 185.400370, 0.000050, 0.026000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 4, -1, 0}, 185.385940, 0.000020, 0.028000},
	{{0, 0, 7, -13, 1, 0, 0, 0, 0, 0, 0}, 220.097640, 0.000010, 5.800000},
	{{0, 0, 7, -13, 3, 0, 0, 0, 0, 0, 0}, 49.525840, 0.000020, 2.932000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, -1, 0}, 214.455680, 0.000020, 0.027000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, 0, 0}, 214.418700, 0.000120, 0.041000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, 1, 0}, 214.487870, 0.000200, 0.092000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, -1, 0}, 213.567220, 0.000120, 0.079000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, 0, 0}, 213.581120, 0.000660, 1.613000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, 1, 0}, 213.547720, 0.000100, 0.072000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 1, 0, -1}, 295.835790, 0.000020, 2.304000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 2, -1, 0}, 215.067120, 0.000140, 0.083000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 2, 0, 0}, 214.812660, 0.000080, 0.039000},
	{{0, 0, 7, -12, 3, 0, 0, 0, 0, 0, 0}, 78.434430, 0.000030, 1.146000},
	{{0, 0, 7, -11, -2, 0, 0, 0, 0, 0, 0}, 184.739430, 0.000010, 1.017000},
	{{0, 0, 7, -11, -1, 0, 0, 0, 1, 0, -1}, 266.121830, 0.000010, 74.609000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -4, 1, 0}, 68.976530, 0.000020, 0.029000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, -1, 0}, 68.948930, 0.000050, 0.027000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 0, 0}, 68.892400, 0.000470, 0.042000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 1, 0}, 68.617060, 0.000560, 0.097000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 2, 0}, 68.933200, 0.000030, 0.342000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, -2, 0}, 66.107390, 0.000020, 0.039000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, -1, 0}, 66.439550, 0.000490, 0.083000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 0, 0}, 66.058730, 0.001790, 0.868000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 1, 0}, 65.844820, 0.000300, 0.069000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 2, 0}, 66.742950, 0.000020, 0.036000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, -1, -1}, 144.337650, 0.000020, 0.076000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 0, -1}, 144.609550, 0.000170, 10.235000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 0, 1}, 324.577250, 0.000020, 0.037000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 1, -1}, 144.337650, 0.000020, 0.075000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, -2, 0}, 247.547970, 0.000030, 1.606000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, -1, 0}, 245.096400, 0.000290, 0.079000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, 0, 0}, 248.949810, 0.000020, 0.039000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, -1, 0}, 101.110830, 0.000020, 0.028000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, 0, 0}, 101.357310, 0.000160, 0.043000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, 1, 0}, 102.118600, 0.000160, 0.102000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, -2, 0}, 93.000240, 0.000050, 0.040000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, -1, 0}, 93.774350, 0.001180, 0.086000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 0, 0}, 95.107400, 0.000800, 0.594000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 1, 0}, 96.159720, 0.000130, 0.067000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 1, 0, -1}, 175.378100, 0.000070, 1.589000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -3, 0}, 273.494400, 0.000040, 0.075000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -2, 0}, 273.329500, 0.001110, 11.006000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -1, 0}, 273.152240, 0.005070, 0.076000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 0, -2}, 273.470810, 0.000020, 2.356000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 0, 0}, 273.145830, 0.000430, 0.038000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 1, 0}, 273.246100, 0.000040, 0.025000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 4, -3, 0}, 273.242070, 0.000020, 0.088000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 4, -2, 0}, 273.159970, 0.000080, 0.041000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 4, -1, 0}, 273.126640, 0.000050, 0.026000},
	{{0, 0, 7, -10, 1, 0, 0, 0, 2, -2, 0}, 124.265950, 0.000230, 152.550000},
	{{0, 0, 7, -10, 1, 0, 0, 0, 2, -1, 0}, 142.654340, 0.000080, 0.075000},
	{{0, 0, 7, -10, 2, 0, 0, 0, 2, -2, 0}, 331.202980, 0.000010, 12.862000},
	{{0, 0, 7, -10, 2, 0, 0, 0, 2, 0, 0}, 151.202980, 0.000010, 0.038000},
	{{0, 0, 7, -9, -2, 0, 0, 0, 0, 0, 0}, 221.758630, 0.000010, 0.489000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, -2, 0}, 88.837850, 0.000010, 0.020000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, 0, 0}, 92.450580, 0.000110, 0.044000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, 1, 0}, 85.131680, 0.000090, 0.108000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, -2, 0}, 303.815960, 0.000020, 0.041000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, -1, 0}, 306.957280, 0.000220, 0.091000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 0, 0}, 116.850780, 0.000590, 0.452000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 1, 0}, 114.650080, 0.000120, 0.065000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 2, 0}, 119.413810, 0.000020, 0.035000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 1, 0, -1}, 206.606470, 0.000050, 0.861000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -2, 0}, 122.383970, 0.000020, 2.269000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -1, -2}, 122.490520, 0.000020, 0.076000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -1, 0}, 121.763700, 0.001860, 0.073000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, -2}, 122.490520, 0.000300, 9.319000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, 0}, 303.461460, 0.000110, 0.037000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 1, -2}, 122.490520, 0.000020, 0.075000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 1, 0}, 302.350660, 0.000030, 0.025000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 4, -2, 0}, 121.641160, 0.000030, 0.040000},
	{{0, 0, 7, -9, 2, 0, 0, 0, 2, -2, 0}, 180.075260, 0.000010, 1.641000},
	{{0, 0, 7, -9, 2, 0, 0, 0, 2, 0, 0}, 180.075260, 0.000010, 0.037000},
	{{0, 0, 7, -8, -2, 0, 0, 0, 0, 0, 0}, 273.107080, 0.000010, 0.388000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, -1, 0}, 135.903540, 0.000020, 0.028000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 0, 0}, 136.551360, 0.000100, 0.045000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 1, 0}, 129.532960, 0.000070, 0.114000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, -2, 0}, 350.890780, 0.000010, 0.042000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, -1, 0}, 10.717960, 0.000340, 0.095000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, 0, 0}, 147.416460, 0.000550, 0.364000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, 1, 0}, 148.589670, 0.000130, 0.062000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, 2, 0}, 149.455250, 0.000010, 0.034000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 1, 0, -1}, 241.335820, 0.000030, 0.591000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, -2, 0}, 106.345330, 0.000020, 1.028000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, -1, 0}, 144.770640, 0.001030, 0.070000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 0, -2}, 151.328080, 0.000040, 1.565000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 0, 0}, 336.191070, 0.000200, 0.036000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 1, 0}, 331.410520, 0.000040, 0.025000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 4, -2, 0}, 151.212840, 0.000020, 0.039000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 4, -1, 0}, 331.434840, 0.000010, 0.026000},
	{{0, 0, 7, -8, 3, 0, 0, 0, -2, 0, 0}, 339.862510, 0.000030, 0.046000},
	{{0, 0, 7, -8, 3, 0, 0, 0, -2, 1, 0}, 339.847810, 0.000010, 0.118000},
	{{0, 0, 7, -8, 3, 0, 0, 0, 3, -1, -2}, 338.095330, 0.000020, 204.109000},
	{{0, 0, 7, -7, 0, 0, 0, 0, -2, 0, 0}, 167.718510, 0.000060, 0.047000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, -1, 0}, 292.335790, 0.000020, 0.100000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 0, 0}, 178.639390, 0.000320, 0.305000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 1, 0}, 176.360740, 0.000060, 0.060000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 1, 0, -1}, 283.884450, 0.000020, 0.450000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -2, 0}, 180.407390, 0.000020, 0.665000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -1, 0}, 181.252120, 0.000500, 0.068000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 0, -2}, 180.417640, 0.000020, 0.854000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 0, 0}, 0.854090, 0.000130, 0.036000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 1, 0}, 0.410490, 0.000030, 0.024000},
	{{0, 0, 7, -6, -2, 0, 0, 0, 0, 0, 0}, 330.614250, 0.000020, 0.275000},
	{{0, 0, 7, -6, 0, 0, 0, 0, -2, 0, 0}, 43.289490, 0.000030, 0.048000},
	{{0, 0, 7, -6, 0, 0, 0, 0, -2, 1, 0}, 35.619370, 0.000010, 0.130000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 0, -1, 0}, 181.782580, 0.000020, 0.106000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 0, 0, 0}, 40.162000, 0.000020, 0.262000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 0, 1, 0}, 29.834860, 0.000010, 0.059000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 1, 0, -1}, 309.352160, 0.000010, 0.363000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, -1, 0}, 29.845160, 0.000100, 0.065000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, 0, 0}, 209.850720, 0.000060, 0.035000},
	{{0, 0, 7, 0, -8, 0, 0, 0, 2, 0, 0}, 8.931100, 0.000020, 0.032000},
	{{0, 0, 7, 0, -7, 0, 0, 0, 2, -1, 0}, 176.698420, 0.000030, 0.056000},
	{{0, 0, 7, 0, -7, 0, 0, 0, 2, 0, 0}, 356.698420, 0.000030, 0.032000},
	{{0, 0, 8, -19, 0, 0, 0, 0, -2, 0, 2}, 202.696180, 0.000030, 180.816000},
	{{0, 0, 8, -19, 0, 3, 0, 0, 2, 0, 0}, 277.161150, 0.000030, 0.044000},
	{{0, 0, 8, -17, 0, 0, 0, 0, -1, 0, 1}, 175.194400, 0.000050, 66.080000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 0, -1, 0}, 234.308320, 0.000010, 0.070000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 0, 0, 0}, 234.342770, 0.000060, 0.963000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 0, 1, 0}, 234.308320, 0.000010, 0.082000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 2, -1, 0}, 232.434730, 0.000050, 0.096000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 2, 0, 0}, 232.434730, 0.000040, 0.042000},
	{{0, 0, 8, -16, 0, 0, 0, 0, 0, 0, 0}, 121.394900, 0.000020, 1.973000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, -1, 0}, 252.680440, 0.000020, 0.016000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 0, 0}, 252.680440, 0.000110, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 1, 0}, 252.680440, 0.000290, 0.028000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 2, 0}, 252.680440, 0.000200, 0.044000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -3, 0, 0}, 252.680440, 0.000020, 0.027000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -3, 3, 0}, 72.680440, 0.000010, 0.376000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -2, 0}, 252.680440, 0.000070, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -1, 0}, 252.680440, 0.000680, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -1, 2}, 72.680440, 0.000010, 0.090000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 0, -2}, 72.680440, 0.000020, 0.019000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 0, 0}, 252.680440, 0.008650, 0.040000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 0, 2}, 252.680440, 0.000210, 0.474000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 1, -2}, 72.680440, 0.000030, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 1, 0}, 252.680440, 0.017090, 0.087000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 2, 0}, 252.680440, 0.000830, 0.564000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 3, 0}, 252.680440, 0.000060, 0.067000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -1, -1, 0}, 72.680440, 0.000020, 0.039000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -1, 0, 0}, 72.680440, 0.000230, 0.081000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -1, 1, 0}, 72.680440, 0.000050, 1.127000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -3, 0}, 72.680440, 0.000020, 0.025000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -2, 0}, 72.680440, 0.000150, 0.038000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -1, 0}, 72.680440, 0.001990, 0.075000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 0, 0}, 72.680440, 0.001880, 94316.280000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 1, 0}, 72.680440, 0.001990, 0.075000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 2, 0}, 72.680440, 0.000150, 0.038000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 3, 0}, 72.680440, 0.000020, 0.025000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 1, -1, 0}, 72.680440, 0.000050, 1.127000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 1, 0, 0}, 72.680440, 0.000230, 0.081000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 1, 1, 0}, 72.680440, 0.000020, 0.039000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -3, 0}, 252.680440, 0.000060, 0.067000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -2, 0}, 252.680440, 0.000830, 0.564000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -1, 0}, 252.680440, 0.017090, 0.087000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -1, 2}, 72.680440, 0.000030, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 0, -2}, 252.680440, 0.000210, 0.474000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 0, 0}, 252.680440, 0.008650, 0.040000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 0, 2}, 72.680440, 0.000020, 0.019000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 1, -2}, 72.680440, 0.000010, 0.090000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 1, 0}, 252.680440, 0.000680, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 2, 0}, 252.680440, 0.000070, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 3, -3, 0}, 72.680440, 0.000010, 0.376000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 3, 0, 0}, 252.680440, 0.000020, 0.027000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, -2, 0}, 252.680440, 0.000200, 0.044000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, -1, 0}, 252.680440, 0.000290, 0.028000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, 0, 0}, 252.680440, 0.000110, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, 1, 0}, 252.680440, 0.000020, 0.016000},
	{{0, 0, 8, -16, 6, 0, 0, 0, -2, 0, 0}, 261.024760, 0.000070, 0.040000},
	{{0, 0, 8, -16, 6, 0, 0, 0, -2, 1, 0}, 261.024760, 0.000120, 0.087000},
	{{0, 0, 8, -16, 6, 0, 0, 0, 0, 1, 0}, 81.024760, 0.000020, 0.075000},
	{{0, 0, 8, -16, 6, 0, 0, 0, 2, -1, 0}, 261.024760, 0.000120, 0.087000},
	{{0, 0, 8, -16, 6, 0, 0, 0, 2, 0, 0}, 261.024760, 0.000070, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -4, 0, 0}, 156.840070, 0.000030, 0.020000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -4, 1, 0}, 156.841570, 0.000080, 0.028000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -4, 2, 0}, 157.633710, 0.000040, 0.044000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, -2, 0}, 156.834210, 0.000030, 0.020000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, -1, 0}, 156.211530, 0.000260, 0.026000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, 0}, 156.708470, 0.002680, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, 2}, 156.807770, 0.000050, 0.469000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 1, 0}, 157.360800, 0.004140, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 2, 0}, 158.413430, 0.000160, 0.556000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 3, 0}, 156.845410, 0.000010, 0.066000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -1, 0, 0}, 336.592250, 0.000100, 0.081000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -1, 1, 0}, 336.807770, 0.000010, 1.097000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -3, 0}, 152.805150, 0.000020, 0.025000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -2, 0}, 153.807530, 0.000350, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, -2}, 334.483960, 0.000020, 0.025000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, 0}, 153.770740, 0.005030, 0.076000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, -2}, 336.818950, 0.000010, 0.037000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, 0}, 155.309140, 0.026110, 40.427000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, 2}, 336.818950, 0.000010, 0.037000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, 0}, 153.729870, 0.005010, 0.075000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, 2}, 334.483960, 0.000020, 0.025000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 2, 0}, 153.752760, 0.000340, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 3, 0}, 152.764630, 0.000020, 0.025000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 1, -1, 0}, 336.645840, 0.000010, 1.160000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 1, 0, 0}, 336.620540, 0.000070, 0.081000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -3, 0}, 156.637250, 0.000010, 0.067000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -2, 0}, 158.197090, 0.000150, 0.572000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -1, 0}, 157.222110, 0.003980, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, -2}, 156.645840, 0.000060, 0.480000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, 0}, 156.539150, 0.002570, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 1, 0}, 156.060700, 0.000250, 0.026000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 2, 0}, 156.672280, 0.000030, 0.020000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 4, -2, 0}, 157.368880, 0.000050, 0.044000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 4, -1, 0}, 156.692690, 0.000070, 0.028000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 4, 0, 0}, 156.676820, 0.000030, 0.020000},
	{{0, 0, 8, -15, 2, 0, 0, 0, 0, -1, 0}, 18.953480, 0.000010, 0.077000},
	{{0, 0, 8, -15, 2, 0, 0, 0, 0, 1, 0}, 18.953480, 0.000010, 0.074000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 0, 0}, 185.614220, 0.000060, 0.041000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 1, 0}, 185.614290, 0.000090, 0.092000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, -1, 0}, 182.672800, 0.000050, 0.079000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 0, 0}, 184.334930, 0.000290, 1.797000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 1, 0}, 182.672800, 0.000050, 0.072000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 2, -1, 0}, 184.995050, 0.000070, 0.083000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 2, 0, 0}, 186.159950, 0.000040, 0.040000},
	{{0, 0, 8, -14, 3, 0, 0, 0, 0, 0, 0}, 49.413480, 0.000010, 1.236000},
	{{0, 0, 8, -13, 0, -1, 0, 0, 1, -1, -1}, 140.831400, 0.000020, 0.075000},
	{{0, 0, 8, -13, 0, -1, 0, 0, 1, 0, -1}, 173.131690, 0.000310, 2556.886000},
	{{0, 0, 8, -13, 0, -1, 0, 0, 1, 1, -1}, 140.831400, 0.000020, 0.075000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -4, 1, 0}, 41.718310, 0.000010, 0.028000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, -1, 0}, 41.681190, 0.000040, 0.027000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 0, 0}, 41.593140, 0.000350, 0.042000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 1, 0}, 41.867030, 0.000430, 0.096000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 2, 0}, 41.782550, 0.000020, 0.349000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, -2, 0}, 38.300270, 0.000010, 0.039000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, -1, 0}, 38.596600, 0.000320, 0.082000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, 0, 0}, 37.649220, 0.001310, 0.919000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, 1, 0}, 37.190690, 0.000200, 0.070000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 1, -1, -1}, 112.411750, 0.000020, 0.076000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 1, 0, -1}, 113.542440, 0.000180, 29.122000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 1, 1, -1}, 112.411750, 0.000020, 0.075000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 2, -1, 0}, 216.296570, 0.000090, 0.080000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 2, 0, 0}, 37.635770, 0.000020, 0.039000},
	{{0, 0, 8, -12, 0, 0, 0, 0, -2, 0, 0}, 70.665490, 0.000080, 0.043000},
	{{0, 0, 8, -12, 0, 0, 0, 0, -2, 1, 0}, 71.228570, 0.000080, 0.101000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, -2, 0}, 64.232460, 0.000020, 0.040000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, -1, 0}, 64.802090, 0.000360, 0.086000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, 0, 0}, 65.759560, 0.000360, 0.617000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, 1, 0}, 66.935730, 0.000080, 0.067000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 1, 0, -1}, 145.719110, 0.000040, 1.767000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -2, 0}, 244.823650, 0.000210, 6.484000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -1, 0}, 244.220440, 0.001420, 0.076000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, 0, 0}, 244.303650, 0.000150, 0.038000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 4, -2, 0}, 244.133690, 0.000020, 0.041000},
	{{0, 0, 8, -12, 2, 0, 0, 0, 2, -2, 0}, 314.299130, 0.000040, 69.540000},
	{{0, 0, 8, -12, 2, 0, 0, 0, 2, -1, 0}, 129.289690, 0.000070, 0.075000},
	{{0, 0, 8, -11, -2, 0, 0, 0, 0, 0, 0}, 231.572640, 0.000010, 0.504000},
	{{0, 0, 8, -11, 0, 0, 0, 0, -2, 0, 0}, 52.262740, 0.000060, 0.044000},
	{{0, 0, 8, -11, 0, 0, 0, 0, -2, 1, 0}, 41.954140, 0.000040, 0.107000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, -2, 0}, 272.438080, 0.000020, 0.041000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, -1, 0}, 275.933300, 0.000170, 0.090000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, 0, 0}, 86.948180, 0.000290, 0.465000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, 1, 0}, 84.662700, 0.000060, 0.065000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 1, 0, -1}, 175.955740, 0.000040, 0.911000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, -2}, 93.559820, 0.000070, 0.076000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, 0}, 92.898230, 0.001160, 0.073000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, -2}, 93.468440, 0.000650, 22.758000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, 0}, 274.115890, 0.000100, 0.037000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 1, -2}, 93.559820, 0.000070, 0.075000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 1, 0}, 273.453930, 0.000010, 0.025000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 4, -2, 0}, 92.737550, 0.000020, 0.040000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 0, 0}, 110.651260, 0.000070, 0.045000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 1, 0}, 103.425460, 0.000040, 0.114000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, -2, 0}, 302.195890, 0.000010, 0.042000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, -1, 0}, 323.650730, 0.000100, 0.095000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, 0, 0}, 120.120380, 0.000340, 0.373000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, 1, 0}, 119.814660, 0.000070, 0.063000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 1, 0, -1}, 207.572640, 0.000030, 0.614000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -2, 0}, 118.519360, 0.000020, 1.100000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -1, 0}, 121.122530, 0.000780, 0.071000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, -2}, 122.442120, 0.000030, 1.737000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, 0}, 302.480860, 0.000110, 0.036000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 1, 0}, 302.420190, 0.000030, 0.025000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 3, -3, 0}, 302.780380, 0.000020, 45.185000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 3, -2, 0}, 122.780390, 0.000030, 0.075000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 4, -2, 0}, 122.338160, 0.000010, 0.039000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 4, 0, 0}, 122.441430, 0.000020, 0.019000},
	{{0, 0, 8, -9, 0, 0, 0, 0, -2, 0, 0}, 145.268430, 0.000060, 0.046000},
	{{0, 0, 8, -9, 0, 0, 0, 0, -2, 1, 0}, 144.667240, 0.000020, 0.121000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, -1, 0}, 293.124050, 0.000020, 0.100000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, 0, 0}, 149.559150, 0.000320, 0.311000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, 1, 0}, 148.510520, 0.000060, 0.061000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 1, 0, -1}, 242.902200, 0.000020, 0.463000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -2, 0}, 151.382450, 0.000020, 0.694000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -1, 0}, 151.403690, 0.000590, 0.068000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, -2}, 151.383420, 0.000020, 0.903000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, 0}, 330.971770, 0.000160, 0.036000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 1, 0}, 331.209110, 0.000030, 0.024000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 4, -2, 0}, 149.934220, 0.000010, 0.038000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 4, -1, 0}, 331.372640, 0.000010, 0.025000},
	{{0, 0, 8, -8, 0, 0, 0, 0, -2, 0, 0}, 159.669330, 0.000020, 0.048000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, -1, 0}, 359.630610, 0.000030, 0.105000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, 0, 0}, 177.893540, 0.000170, 0.267000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, 1, 0}, 180.054460, 0.000010, 0.059000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 1, 0, -1}, 284.293740, 0.000010, 0.371000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -2, 0}, 180.061320, 0.000010, 0.507000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -1, 0}, 179.800850, 0.000250, 0.066000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, 0, 0}, 0.100570, 0.000110, 0.035000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, 1, 0}, 0.063000, 0.000030, 0.024000},
	{{0, 0, 8, -7, -2, 0, 0, 0, 0, 0, 0}, 330.151480, 0.000010, 0.243000},
	{{0, 0, 8, -7, 0, 0, 0, 0, -2, 0, 0}, 45.814310, 0.000010, 0.049000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 0, 0, 0}, 48.985820, 0.000020, 0.234000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 0, 1, 0}, 30.569510, 0.000010, 0.057000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, -1, 0}, 30.577760, 0.000070, 0.063000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, 0, 0}, 210.582590, 0.000050, 0.034000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, -2, 0}, 174.224320, 0.000010, 0.036000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, -1, 0}, 174.224090, 0.000030, 0.070000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, 0, 0}, 174.224170, 0.000230, 1.000000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, 1, 0}, 174.224120, 0.000050, 0.082000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 2, -1, 0}, 174.224220, 0.000240, 0.095000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 2, 0, 0}, 174.224210, 0.000190, 0.042000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 2, 1, 0}, 174.224220, 0.000020, 0.027000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -4, 1, 0}, 127.720040, 0.000010, 0.028000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, -1, 0}, 127.720030, 0.000040, 0.026000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 0, 0}, 127.558730, 0.000380, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 1, 0}, 128.207850, 0.000580, 0.087000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 2, 0}, 127.697300, 0.000020, 0.576000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -2, 0}, 125.285460, 0.000060, 0.038000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -1, 0}, 125.086550, 0.000770, 0.075000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 0, 0}, 126.491160, 0.004070, 25.886000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 1, 0}, 125.174050, 0.000780, 0.076000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 2, 0}, 125.288420, 0.000060, 0.038000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -2, 0}, 128.054470, 0.000030, 0.552000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -1, 0}, 128.562030, 0.000610, 0.087000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 0, 0}, 127.864860, 0.000400, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 1, 0}, 128.034770, 0.000040, 0.026000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 4, -1, 0}, 128.034770, 0.000010, 0.028000},
	{{0, 0, 9, -17, 1, 0, 0, 0, 0, 0, 0}, 173.431370, 0.000010, 21.895000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 0, 0}, 156.749710, 0.000030, 0.041000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 1, 0}, 156.749820, 0.000020, 0.091000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, -1, 0}, 156.615560, 0.000020, 0.078000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, 0, 0}, 154.688330, 0.000120, 2.028000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, 1, 0}, 156.615560, 0.000020, 0.073000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 2, -1, 0}, 155.263050, 0.000020, 0.084000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 2, 0, 0}, 156.375650, 0.000020, 0.040000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -4, 0, 0}, 149.743510, 0.000030, 0.021000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -4, 1, 0}, 149.743510, 0.000030, 0.028000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -4, 2, 0}, 149.743510, 0.000020, 0.046000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, -1, 0}, 149.743510, 0.000100, 0.027000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 0, 0}, 149.743510, 0.000870, 0.042000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 0, 2}, 149.743510, 0.000010, 0.322000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 1, 0}, 149.743510, 0.001140, 0.095000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 2, 0}, 149.743510, 0.000060, 0.360000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, -1, 0}, 149.743510, 0.000250, 0.082000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 0, 0}, 149.743510, 0.001210, 1.000000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 1, 0}, 149.743510, 0.000200, 0.070000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 2, -2, 0}, 149.743510, 0.000010, 1.292000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 2, -1, 0}, 329.743510, 0.000060, 0.080000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 2, 0, 0}, 329.743510, 0.000040, 0.039000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 2, 1, 0}, 329.743510, 0.000020, 0.026000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -4, 1, 0}, 21.756480, 0.000020, 0.028000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, -1, 0}, 21.459060, 0.000070, 0.027000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 0, 0}, 23.476730, 0.000670, 0.042000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 1, 0}, 21.628200, 0.000810, 0.096000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 2, 0}, 22.441090, 0.000040, 0.357000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, -2, 0}, 13.576750, 0.000020, 0.039000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, -1, 0}, 15.102610, 0.000520, 0.082000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 0, 0}, 12.348440, 0.002090, 0.976000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 1, 0}, 9.714220, 0.000310, 0.070000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 2, 0}, 9.094270, 0.000010, 0.036000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, -1, -1}, 268.080740, 0.000020, 0.075000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, -1}, 267.801350, 0.000170, 34.449000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, 0}, 191.628140, 0.000040, 0.075000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, 1}, 267.678280, 0.000040, 0.037000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 1, -1}, 268.080740, 0.000020, 0.076000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 2, -1, 0}, 334.767440, 0.000020, 0.080000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 2, 0, 0}, 355.087010, 0.000040, 0.039000},
	{{0, 0, 9, -14, 0, 0, 0, 0, -2, 0, 0}, 40.526230, 0.000040, 0.043000},
	{{0, 0, 9, -14, 0, 0, 0, 0, -2, 1, 0}, 40.526170, 0.000040, 0.101000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 0, -1, 0}, 36.377370, 0.000120, 0.085000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 0, 0, 0}, 37.324080, 0.000140, 0.643000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 0, 1, 0}, 37.695410, 0.000030, 0.068000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 1, 0, -1}, 116.339530, 0.000020, 1.989000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, -2, 0}, 215.103410, 0.000050, 4.596000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, -1, 0}, 215.879510, 0.000440, 0.077000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, 0, 0}, 215.713850, 0.000060, 0.038000},
	{{0, 0, 9, -13, 0, 0, 0, 0, -2, 0, 0}, 359.049740, 0.000030, 0.044000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, -1, 0}, 245.572160, 0.000120, 0.090000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 0, -2}, 64.772510, 0.000010, 0.040000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 0, 0}, 53.917190, 0.000120, 0.479000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 1, -2}, 244.545920, 0.000020, 0.087000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 1, 0}, 57.269650, 0.000030, 0.065000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 1, 0, -1}, 146.118040, 0.000020, 0.967000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -2, -2}, 64.618930, 0.000010, 0.038000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, -2}, 64.656350, 0.000210, 0.075000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, 0}, 63.899220, 0.000680, 0.074000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, -2}, 64.772510, 0.000950, 51.478000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, 0}, 64.205040, 0.000070, 0.037000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 1, -2}, 64.656350, 0.000210, 0.076000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 2, -2}, 64.618930, 0.000010, 0.038000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 4, -1, -2}, 244.545920, 0.000020, 0.087000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 4, 0, -2}, 64.772510, 0.000010, 0.040000},
	{{0, 0, 9, -12, 0, 0, 0, 0, -2, 0, 0}, 81.844700, 0.000040, 0.045000},
	{{0, 0, 9, -12, 0, 0, 0, 0, -2, 1, 0}, 81.741870, 0.000010, 0.113000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, -1, 0}, 273.471420, 0.000070, 0.094000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, 0, 0}, 91.277580, 0.000190, 0.382000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, 1, 0}, 93.325870, 0.000030, 0.063000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 1, 0, -1}, 176.572510, 0.000020, 0.639000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -2, 0}, 93.417660, 0.000010, 1.182000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -1, 0}, 93.426750, 0.000480, 0.071000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 0, -2}, 93.432570, 0.000020, 1.952000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 0, 0}, 273.417990, 0.000070, 0.037000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 1, 0}, 273.425670, 0.000010, 0.025000},
	{{0, 0, 9, -12, 2, 0, 0, 0, 2, -3, 0}, 150.929730, 0.000010, 0.082000},
	{{0, 0, 9, -12, 2, 0, 0, 0, 2, -1, 0}, 330.929730, 0.000010, 0.070000},
	{{0, 0, 9, -11, -2, 0, 0, 0, 0, 0, 0}, 231.910890, 0.000010, 0.335000},
	{{0, 0, 9, -11, 0, 0, 0, 0, -2, 0, 0}, 118.450550, 0.000050, 0.046000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, -1, 0}, 303.694180, 0.000040, 0.099000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, 0, 0}, 120.643490, 0.000220, 0.317000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, 1, 0}, 121.214910, 0.000040, 0.061000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 1, 0, -1}, 208.566070, 0.000020, 0.477000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, -2, 0}, 122.379130, 0.000020, 0.726000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, -1, 0}, 122.376790, 0.000440, 0.068000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 0, -2}, 122.379700, 0.000010, 0.958000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 0, 0}, 301.613360, 0.000110, 0.036000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 1, 0}, 302.134870, 0.000020, 0.024000},
	{{0, 0, 9, -10, -2, 0, 0, 0, 0, 0, 0}, 272.360200, 0.000010, 0.285000},
	{{0, 0, 9, -10, 0, 0, 0, 0, -2, 0, 0}, 144.465670, 0.000050, 0.047000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, -1, 0}, 334.889690, 0.000010, 0.104000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, 0, 0}, 149.732930, 0.000180, 0.272000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, 1, 0}, 147.491300, 0.000030, 0.059000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 1, 0, -1}, 244.373260, 0.000010, 0.380000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -2, 0}, 151.223520, 0.000020, 0.524000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -1, 0}, 151.204940, 0.000340, 0.066000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, 0, -2}, 151.226850, 0.000010, 0.635000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, 0, 0}, 332.743770, 0.000130, 0.035000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, 1, 0}, 331.684310, 0.000030, 0.024000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 4, 0, 0}, 151.226770, 0.000020, 0.019000},
	{{0, 0, 9, -9, -2, 0, 0, 0, 0, 0, 0}, 301.218410, 0.000010, 0.247000},
	{{0, 0, 9, -9, -1, 0, 0, 0, 0, 0, 0}, 146.965480, 0.000010, 0.242000},
	{{0, 0, 9, -9, 0, 0, 0, 0, -2, 0, 0}, 154.121750, 0.000020, 0.049000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 0, -1, 0}, 359.465520, 0.000010, 0.111000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 0, 0, 0}, 175.656250, 0.000080, 0.237000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 2, -1, 0}, 179.469940, 0.000120, 0.064000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 2, 0, 0}, 359.468270, 0.000080, 0.035000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 2, 1, -4}, 186.670870, 0.000020, 0.087000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 4, -1, -4}, 4.410560, 0.000080, 0.075000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 4, 0, -4}, 192.804770, 0.000530, 4535.679000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 4, 1, -4}, 4.410560, 0.000080, 0.075000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 6, -1, -4}, 186.670870, 0.000020, 0.087000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 2, -1, 0}, 31.026460, 0.000050, 0.062000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 2, 0, 0}, 211.030810, 0.000040, 0.034000},
	{{0, 0, 9, -7, 0, 0, 0, 0, 2, 0, 0}, 59.719030, 0.000010, 0.033000},
	{{0, 0, 10, -21, 2, 0, 0, 0, 0, 0, 0}, 230.142170, 0.000010, 1.003000},
	{{0, 0, 10, -21, 2, 0, 0, 0, 2, 0, 0}, 230.964600, 0.000010, 0.042000},
	{{0, 0, 10, -19, 0, 0, 0, 0, -2, 0, 0}, 98.562020, 0.000020, 0.040000},
	{{0, 0, 10, -19, 0, 0, 0, 0, -2, 1, 0}, 98.562090, 0.000030, 0.086000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, -1, 0}, 98.307970, 0.000040, 0.075000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, 0, 0}, 98.020060, 0.000230, 9.804000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, 1, 0}, 98.307970, 0.000040, 0.076000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 2, -1, 0}, 99.591750, 0.000030, 0.088000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 2, 0, 0}, 99.591750, 0.000020, 0.041000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -4, 0, 0}, 71.287350, 0.000030, 0.020000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -4, 1, 0}, 71.287350, 0.000060, 0.028000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -4, 2, 0}, 71.287350, 0.000050, 0.044000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, -2, 0}, 71.287350, 0.000020, 0.020000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, -1, 0}, 71.287350, 0.000130, 0.026000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 0, 0}, 71.287350, 0.001730, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 0, 2}, 71.287350, 0.000050, 0.475000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 1, 0}, 71.287350, 0.003400, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 2, 0}, 71.287360, 0.000160, 0.564000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -1, 0, 0}, 251.287390, 0.000060, 0.081000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, -2, 0}, 251.287250, 0.000030, 0.038000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, -1, 0}, 251.287240, 0.000390, 0.075000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, 0, 0}, 251.287310, 0.000380, 6408.190000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, 1, 0}, 251.287380, 0.000390, 0.075000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, 2, 0}, 251.287370, 0.000030, 0.038000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 1, 0, 0}, 251.287230, 0.000060, 0.081000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -2, 0}, 71.287270, 0.000160, 0.564000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -1, 0}, 71.287270, 0.003400, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 0, -2}, 71.287270, 0.000050, 0.474000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 0, 0}, 71.287270, 0.001730, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 1, 0}, 71.287270, 0.000130, 0.026000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 2, 0}, 71.287270, 0.000020, 0.020000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 4, -2, 0}, 71.287270, 0.000050, 0.044000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 4, -1, 0}, 71.287270, 0.000060, 0.028000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 4, 0, 0}, 71.287270, 0.000030, 0.020000},
	{{0, 0, 10, -19, 1, 0, 0, 0, 0, 0, 0}, 288.816620, 0.000010, 56.510000},
	{{0, 0, 10, -18, 0, 0, 0, 0, -2, 0, 0}, 127.806310, 0.000010, 0.041000},
	{{0, 0, 10, -18, 0, 0, 0, 0, 0, 0, 0}, 125.557480, 0.000060, 2.327000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, -1, 0}, 142.200720, 0.000020, 0.027000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 0, 0}, 142.200680, 0.000100, 0.042000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 1, 0}, 141.242430, 0.000120, 0.095000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, -1, 0}, 150.066010, 0.000110, 0.081000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, 0, 0}, 152.285270, 0.000480, 1.040000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, 1, 0}, 152.905870, 0.000080, 0.070000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 1, 0, -1}, 238.099910, 0.000030, 10.823000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 2, -3, 0}, 151.682120, 0.000010, 0.071000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 2, -1, 0}, 163.229640, 0.000030, 0.080000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 2, 0, 0}, 160.544410, 0.000020, 0.039000},
	{{0, 0, 10, -16, 0, 0, 0, 0, -2, 0, 0}, 10.770680, 0.000020, 0.043000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 0, -1, 0}, 6.627900, 0.000030, 0.085000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 0, 0, 0}, 8.225040, 0.000070, 0.670000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 1, 0, -1}, 78.894070, 0.000010, 2.276000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 2, -2, 0}, 183.711440, 0.000010, 3.559000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 2, -1, 0}, 186.627900, 0.000140, 0.077000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 2, 0, 0}, 186.624230, 0.000010, 0.038000},
	{{0, 0, 10, -16, 4, 5, 0, 0, -2, 0, 0}, 46.806580, 0.000080, 0.044000},
	{{0, 0, 10, -16, 4, 5, 0, 0, -2, 1, 0}, 46.806580, 0.000060, 0.105000},
	{{0, 0, 10, -16, 4, 5, 0, 0, 0, 0, 0}, 46.806580, 0.000030, 0.500000},
	{{0, 0, 10, -15, -3, 0, 0, 0, 2, -2, 0}, 166.867520, 0.000020, 455.769000},
	{{0, 0, 10, -15, -3, 0, 0, 0, 2, -1, 0}, 193.065350, 0.000030, 0.075000},
	{{0, 0, 10, -15, 0, 0, 0, 0, -2, 0, 0}, 289.187320, 0.000060, 0.044000},
	{{0, 0, 10, -15, 0, 0, 0, 0, -2, 1, 0}, 289.143050, 0.000050, 0.106000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 0, -1, 0}, 221.177290, 0.000070, 0.089000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 0, 0, 0}, 348.422670, 0.000050, 0.494000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 0, 1, 0}, 343.885180, 0.000010, 0.065000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 1, 0, -1}, 116.631750, 0.000010, 1.030000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -1, 0}, 32.268850, 0.000380, 0.074000},
	{{0, 0, 10, -15, 1, 0, 0, 0, 2, -1, -2}, 248.472260, 0.000040, 0.075000},
	{{0, 0, 10, -15, 1, 0, 0, 0, 2, 0, -2}, 245.970580, 0.000210, 662.430000},
	{{0, 0, 10, -15, 1, 0, 0, 0, 2, 1, -2}, 248.472260, 0.000040, 0.075000},
	{{0, 0, 10, -14, 0, 0, 0, 0, -2, 0, 0}, 53.317920, 0.000020, 0.045000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 0, -1, 0}, 244.427440, 0.000040, 0.093000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 0, 0, 0}, 62.755760, 0.000080, 0.391000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 0, 1, 0}, 64.471720, 0.000020, 0.063000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 1, 0, -1}, 146.546040, 0.000010, 0.666000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, -2, 0}, 64.458280, 0.000010, 1.278000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, -1, 0}, 64.443710, 0.000260, 0.071000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, 0, -2}, 64.439250, 0.000010, 2.228000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, 0, 0}, 244.438220, 0.000040, 0.037000},
	{{0, 0, 10, -13, 0, 0, 0, 0, -2, 0, 0}, 91.534310, 0.000020, 0.046000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 0, -1, 0}, 273.450320, 0.000030, 0.098000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 0, 0, 0}, 92.530910, 0.000110, 0.324000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 0, 1, 0}, 93.274980, 0.000020, 0.061000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 1, 0, -1}, 177.215920, 0.000010, 0.492000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, -2, 0}, 93.383240, 0.000010, 0.761000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, -1, 0}, 93.375400, 0.000290, 0.069000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, 0, 0}, 273.368400, 0.000080, 0.036000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, 1, 0}, 273.375800, 0.000010, 0.024000},
	{{0, 0, 10, -12, 0, 0, 0, 0, -2, 0, 0}, 119.034090, 0.000030, 0.047000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 0, -1, 0}, 303.356120, 0.000030, 0.104000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 0, 0, 0}, 120.374400, 0.000140, 0.276000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 0, 1, 0}, 121.964090, 0.000020, 0.059000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 1, 0, -1}, 209.571100, 0.000010, 0.390000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, -2, 0}, 122.278970, 0.000020, 0.542000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, -1, 0}, 122.729650, 0.000270, 0.066000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, 0, 0}, 302.231050, 0.000100, 0.035000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, 1, 0}, 302.279290, 0.000030, 0.024000},
	{{0, 0, 10, -11, -2, 0, 0, 0, 0, 0, 0}, 272.092630, 0.000020, 0.251000},
	{{0, 0, 10, -11, -1, 0, 0, 0, 0, 0, 0}, 118.344550, 0.000010, 0.246000},
	{{0, 0, 10, -11, 0, 0, 0, 0, -2, 0, 0}, 139.446200, 0.000020, 0.049000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 0, -1, 0}, 333.318140, 0.000020, 0.110000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 0, 0, 0}, 148.867520, 0.000110, 0.241000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 0, 1, 0}, 150.454390, 0.000020, 0.057000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -2, 0}, 150.995620, 0.000010, 0.421000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -1, 0}, 151.832320, 0.000210, 0.064000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, 0, 0}, 330.927890, 0.000090, 0.035000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, 1, 0}, 330.996280, 0.000030, 0.024000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 0, -1, 0}, 178.489450, 0.000010, 0.117000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 0, 0, 0}, 175.367270, 0.000030, 0.214000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 0, 1, 0}, 178.489450, 0.000010, 0.056000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 2, -1, 0}, 178.485730, 0.000060, 0.062000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 2, 0, 0}, 358.483400, 0.000050, 0.034000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 2, -1, 0}, 31.271440, 0.000040, 0.060000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 2, 0, 0}, 211.275460, 0.000030, 0.033000},
	{{0, 0, 11, -21, 0, 0, 0, 0, 0, -1, 1}, 8.026770, 0.000010, 720.555000},
	{{0, 0, 11, -21, 0, 0, 0, 0, 0, 0, 0}, 66.343130, 0.000030, 6.047000},
	{{0, 0, 11, -21, 2, 0, 0, 0, -2, 0, 0}, 128.136410, 0.000110, 0.040000},
	{{0, 0, 11, -21, 2, 0, 0, 0, -2, 1, 0}, 129.487100, 0.000160, 0.087000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, -2, 0}, 122.890950, 0.000010, 0.038000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, -1, 0}, 123.520870, 0.000240, 0.075000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, 0, 0}, 126.340250, 0.001180, 308.674000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, 1, 0}, 123.511840, 0.000240, 0.075000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, 2, 0}, 122.892600, 0.000010, 0.038000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 2, -1, 0}, 129.455630, 0.000160, 0.087000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 2, 0, 0}, 128.107540, 0.000110, 0.040000},
	{{0, 0, 11, -20, 0, 0, 0, 0, 0, 0, 0}, 97.367710, 0.000030, 2.730000},
	{{0, 0, 11, -19, 0, 0, 0, 0, -2, 0, 0}, 123.836800, 0.000020, 0.042000},
	{{0, 0, 11, -19, 0, 0, 0, 0, -2, 1, 0}, 123.836840, 0.000020, 0.094000},
	{{0, 0, 11, -19, 0, 0, 0, 0, 0, 0, 0}, 126.925810, 0.000080, 1.114000},
	{{0, 0, 11, -19, 0, 0, 0, 0, 1, -1, 0}, 129.033480, 0.000040, 90.987000},
	{{0, 0, 11, -19, 0, 3, 0, 0, -2, -1, 0}, 328.350410, 0.000030, 0.027000},
	{{0, 0, 11, -19, 0, 3, 0, 0, -2, 0, 0}, 328.350410, 0.000170, 0.042000},
	{{0, 0, 11, -19, 0, 3, 0, 0, -2, 1, 0}, 328.350410, 0.000230, 0.095000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, -1, 0}, 328.350490, 0.000060, 0.082000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, 0, 0}, 328.350450, 0.000240, 1.000000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, 1, 0}, 328.350520, 0.000030, 0.070000},
	{{0, 0, 11, -18, 0, 0, 0, 0, -2, 0, 0}, 341.283030, 0.000020, 0.043000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 0, 0, 0}, 339.517540, 0.000030, 0.699000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 2, -1, 0}, 157.703990, 0.000050, 0.077000},
	{{0, 0, 11, -17, 0, 0, 0, 0, -2, 0, 0}, 30.040530, 0.000020, 0.044000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 0, -1, 0}, 186.349270, 0.000050, 0.089000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 0, 0, 0}, 19.239340, 0.000040, 0.510000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 2, -1, 0}, 6.349250, 0.000230, 0.074000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 2, 0, 0}, 186.561330, 0.000020, 0.037000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 0, -1, 0}, 215.407560, 0.000020, 0.093000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 0, 0, 0}, 33.998890, 0.000040, 0.401000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 0, 1, 0}, 35.599920, 0.000010, 0.063000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, -1, 0}, 35.474110, 0.000130, 0.072000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, 0, 0}, 215.468330, 0.000040, 0.037000},
	{{0, 0, 11, -15, 0, 0, 0, 0, -2, 0, 0}, 77.659650, 0.000020, 0.046000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 0, -1, 0}, 244.392630, 0.000020, 0.098000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 0, 0, 0}, 66.627620, 0.000050, 0.331000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 0, 1, 0}, 64.399070, 0.000020, 0.061000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 2, -1, 0}, 63.835040, 0.000150, 0.069000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 2, 0, 0}, 244.391980, 0.000050, 0.036000},
	{{0, 0, 11, -14, 0, 0, 0, 0, -2, 0, 0}, 84.187390, 0.000030, 0.047000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 0, -1, 0}, 273.416440, 0.000020, 0.103000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 0, 0, 0}, 91.677830, 0.000070, 0.281000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 0, 1, 0}, 86.373420, 0.000010, 0.059000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 1, 0, -1}, 177.878980, 0.000010, 0.400000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, -1, 0}, 93.298280, 0.000180, 0.066000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, 0, 0}, 273.293810, 0.000090, 0.035000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 4, -4, 0}, 273.309150, 0.000010, 119.249000},
	{{0, 0, 11, -13, 0, 0, 0, 0, -2, 0, 0}, 114.900800, 0.000030, 0.048000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 0, -1, 0}, 302.135830, 0.000020, 0.109000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 0, 0, 0}, 120.060660, 0.000090, 0.245000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 0, 1, 0}, 122.135370, 0.000010, 0.058000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, -2, 0}, 122.136160, 0.000010, 0.432000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, -1, 0}, 122.136530, 0.000170, 0.064000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, 0, 0}, 302.173380, 0.000080, 0.035000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, 1, 0}, 302.136510, 0.000020, 0.024000},
	{{0, 0, 11, -12, 0, 0, 0, 0, -2, 0, 0}, 139.863820, 0.000020, 0.050000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 0, -1, 0}, 316.565130, 0.000010, 0.116000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 0, 0, 0}, 147.874370, 0.000060, 0.216000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, -1, 0}, 150.678740, 0.000120, 0.062000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, 0, 0}, 330.678100, 0.000090, 0.034000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, 1, 0}, 330.678680, 0.000020, 0.023000},
	{{0, 0, 11, -11, 0, 0, 0, 0, 0, 0, 0}, 168.799780, 0.000010, 0.194000},
	{{0, 0, 11, -11, 0, 0, 0, 0, 2, -1, 0}, 176.748770, 0.000030, 0.060000},
	{{0, 0, 11, -11, 0, 0, 0, 0, 2, 0, 0}, 356.746890, 0.000040, 0.033000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, -1, 0}, 29.144030, 0.000030, 0.058000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, 0, 0}, 211.352200, 0.000040, 0.033000},
	{{0, 0, 12, -22, 0, 0, 0, 0, 0, 0, 0}, 68.378070, 0.000020, 3.301000},
	{{0, 0, 12, -21, 0, 0, 0, 0, 0, 0, 0}, 98.112810, 0.000020, 1.198000},
	{{0, 0, 12, -21, 2, 0, 0, 0, -2, 0, 0}, 12.624880, 0.000020, 0.042000},
	{{0, 0, 12, -21, 2, 0, 0, 0, 0, 0, 0}, 357.919700, 0.000020, 0.997000},
	{{0, 0, 12, -20, 0, 0, 0, 0, 0, 0, 0}, 310.073910, 0.000010, 0.732000},
	{{0, 0, 12, -20, 0, 0, 0, 0, 2, -1, 0}, 124.833640, 0.000020, 0.078000},
	{{0, 0, 12, -19, 0, 0, 0, 0, 0, -1, 0}, 157.624060, 0.000030, 0.088000},
	{{0, 0, 12, -19, 0, 0, 0, 0, 2, -2, 0}, 157.584960, 0.000010, 8.066000},
	{{0, 0, 12, -19, 0, 0, 0, 0, 2, -1, 0}, 337.624060, 0.000150, 0.075000},
	{{0, 0, 12, -19, 0, 3, 0, 0, -2, 0, 0}, 225.413470, 0.000010, 0.044000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 0, 0, 0}, 7.768900, 0.000010, 0.412000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, -1, 0}, 5.687770, 0.000080, 0.072000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, 0, 0}, 186.497310, 0.000020, 0.037000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 0, 0, 0}, 39.460900, 0.000020, 0.338000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 0, 1, 0}, 31.916380, 0.000010, 0.062000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, -1, 0}, 35.424000, 0.000080, 0.069000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, 0, 0}, 215.419170, 0.000040, 0.036000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 0, -1, 0}, 244.351720, 0.000010, 0.102000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 0, 0, 0}, 63.687560, 0.000030, 0.286000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 0, 1, 0}, 64.314690, 0.000010, 0.060000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, -1, 0}, 64.330770, 0.000100, 0.067000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, 0, 0}, 244.326810, 0.000050, 0.035000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 0, -1, 0}, 273.359120, 0.000010, 0.108000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 0, 0, 0}, 91.609280, 0.000030, 0.248000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 0, 1, 0}, 84.075590, 0.000010, 0.058000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, -1, 0}, 93.192580, 0.000120, 0.064000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, 0, 0}, 274.505990, 0.000070, 0.035000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 0, -1, 0}, 301.945640, 0.000010, 0.115000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 0, 0, 0}, 119.892930, 0.000050, 0.219000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, -1, 0}, 121.946570, 0.000110, 0.062000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, 0, 0}, 301.946240, 0.000090, 0.034000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, 1, 0}, 301.946540, 0.000020, 0.024000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 0, 0, 0}, 145.862040, 0.000020, 0.197000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 2, -1, 0}, 150.253830, 0.000080, 0.060000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 2, 0, 0}, 330.253030, 0.000070, 0.034000},
	{{0, 0, 12, -12, 0, 0, 0, 0, 2, 0, 0}, 353.138410, 0.000020, 0.033000},
	{{0, 0, 12, -11, 0, 0, 0, 0, 2, -1, 0}, 31.327310, 0.000020, 0.057000},
	{{0, 0, 12, -11, 0, 0, 0, 0, 2, 0, 0}, 211.279230, 0.000030, 0.032000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 0, -1, 0}, 128.263630, 0.000030, 0.088000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 2, -2, 0}, 128.673240, 0.000030, 16.498000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 2, -1, 0}, 308.263670, 0.000130, 0.075000},
	{{0, 0, 13, -20, 0, 0, 0, 0, 2, -1, 0}, 336.061230, 0.000040, 0.072000},
	{{0, 0, 13, -20, 0, 0, 0, 0, 2, 0, 0}, 157.524950, 0.000020, 0.037000},
	{{0, 0, 13, -19, 0, 0, 0, 0, 2, -1, 0}, 6.457320, 0.000050, 0.070000},
	{{0, 0, 13, -19, 0, 0, 0, 0, 2, 0, 0}, 186.437850, 0.000020, 0.036000},
	{{0, 0, 13, -18, 0, 0, 0, 0, 0, 0, 0}, 35.524890, 0.000010, 0.292000},
	{{0, 0, 13, -18, 0, 0, 0, 0, 2, -1, 0}, 35.363420, 0.000060, 0.067000},
	{{0, 0, 13, -18, 0, 0, 0, 0, 2, 0, 0}, 215.359170, 0.000030, 0.036000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 0, 0, 0}, 63.314070, 0.000020, 0.252000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 0, 1, 0}, 64.213900, 0.000010, 0.058000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 2, -1, 0}, 64.245120, 0.000070, 0.065000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 2, 0, 0}, 244.241350, 0.000040, 0.035000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 0, 0, 0}, 91.079860, 0.000020, 0.223000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 0, 1, 0}, 106.642650, 0.000020, 0.056000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 2, -1, 0}, 93.068960, 0.000080, 0.063000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 2, 0, 0}, 273.068750, 0.000060, 0.034000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 0, 0, 0}, 118.464350, 0.000020, 0.199000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, -1, 0}, 121.703740, 0.000080, 0.061000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, 0, 0}, 301.703350, 0.000060, 0.034000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 0, 0, 0}, 144.202600, 0.000010, 0.180000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 2, -1, 0}, 149.691650, 0.000040, 0.059000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 2, 0, 0}, 329.690710, 0.000040, 0.033000},
	{{0, 0, 13, -12, 0, 0, 0, 0, 2, -1, 0}, 31.052550, 0.000020, 0.055000},
	{{0, 0, 13, -12, 0, 0, 0, 0, 2, 0, 0}, 211.053760, 0.000020, 0.032000},
	{{0, 0, 13, -11, 0, 0, 0, 0, 2, 0, 0}, 63.905120, 0.000020, 0.031000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 0, -3, 0}, 98.664130, 0.000010, 0.026000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 0, -2, 0}, 98.627040, 0.000070, 0.040000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 0, -1, 0}, 278.672990, 0.000150, 0.087000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 0, 0, 0}, 278.669720, 0.000020, 0.565000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -4, 0}, 97.859320, 0.000020, 0.038000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -3, 0}, 97.857760, 0.000250, 0.075000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, -2}, 278.664130, 0.000020, 0.037000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, 0}, 98.664130, 0.008000, 362.998000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, 2}, 278.664130, 0.000020, 0.037000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -1, 0}, 98.668190, 0.001620, 0.075000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, 0, 0}, 98.668150, 0.000110, 0.038000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 4, -3, 0}, 98.986980, 0.000130, 0.087000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 4, -2, 0}, 98.689060, 0.000110, 0.040000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 4, -1, 0}, 98.664130, 0.000010, 0.026000},
	{{0, 0, 14, -23, 4, 0, 0, 0, 2, 0, -2}, 70.284120, 0.000070, 1053.903000},
	{{0, 0, 14, -22, 0, 0, 0, 0, 2, -1, 0}, 306.348880, 0.000020, 0.073000},
	{{0, 0, 14, -21, 0, 0, 0, 0, 2, -1, 0}, 337.499060, 0.000020, 0.070000},
	{{0, 0, 14, -21, 0, 0, 0, 0, 2, 0, 0}, 157.470370, 0.000020, 0.036000},
	{{0, 0, 14, -21, 0, 0, 0, 0, 3, -2, -1}, 238.328400, 0.000020, 146.030000},
	{{0, 0, 14, -20, 0, 0, 0, 0, 2, -1, 0}, 6.396970, 0.000030, 0.067000},
	{{0, 0, 14, -20, 0, 0, 0, 0, 2, 0, 0}, 186.381920, 0.000020, 0.036000},
	{{0, 0, 14, -19, 0, 0, 0, 0, 0, 0, 0}, 35.227750, 0.000020, 0.257000},
	{{0, 0, 14, -19, 0, 0, 0, 0, 2, -1, 0}, 35.288470, 0.000040, 0.065000},
	{{0, 0, 14, -19, 0, 0, 0, 0, 2, 0, 0}, 215.284860, 0.000030, 0.035000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 0, 0, 0}, 62.863140, 0.000010, 0.226000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 2, -1, 0}, 66.102690, 0.000050, 0.063000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 2, 0, 0}, 245.761300, 0.000050, 0.034000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 0, -1, 0}, 92.899130, 0.000010, 0.121000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 0, 0, 0}, 90.424940, 0.000010, 0.202000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 0, 1, 0}, 92.899130, 0.000010, 0.055000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 2, -1, 0}, 92.898780, 0.000050, 0.061000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 2, 0, 0}, 272.898550, 0.000050, 0.034000},
	{{0, 0, 14, -16, 0, 0, 0, 0, 0, 0, 0}, 117.408030, 0.000010, 0.182000},
	{{0, 0, 14, -16, 0, 0, 0, 0, 2, -1, 0}, 121.400800, 0.000040, 0.059000},
	{{0, 0, 14, -16, 0, 0, 0, 0, 2, 0, 0}, 301.400360, 0.000050, 0.033000},
	{{0, 0, 14, -15, 0, 0, 0, 0, 2, -1, 0}, 149.661420, 0.000020, 0.057000},
	{{0, 0, 14, -15, 0, 0, 0, 0, 2, 0, 0}, 328.944800, 0.000040, 0.033000},
	{{0, 0, 14, -13, 0, 0, 0, 0, 2, 0, 0}, 210.660320, 0.000010, 0.031000},
	{{0, 0, 15, -25, 0, 0, 0, 0, 2, -1, 0}, 67.303160, 0.000020, 0.076000},
	{{0, 0, 15, -22, 0, 0, 0, 0, 2, 0, 0}, 157.412960, 0.000020, 0.036000},
	{{0, 0, 15, -21, 0, 0, 0, 0, 2, -1, 0}, 6.315680, 0.000020, 0.065000},
	{{0, 0, 15, -21, 0, 0, 0, 0, 2, 0, 0}, 186.315650, 0.000020, 0.035000},
	{{0, 0, 15, -20, 0, 0, 0, 0, 2, -1, 0}, 35.193630, 0.000030, 0.063000},
	{{0, 0, 15, -20, 0, 0, 0, 0, 2, 0, 0}, 215.193860, 0.000030, 0.034000},
	{{0, 0, 15, -19, 0, 0, 0, 0, 2, -1, 0}, 64.010400, 0.000030, 0.061000},
	{{0, 0, 15, -19, 0, 0, 0, 0, 2, 0, 0}, 244.010320, 0.000040, 0.034000},
	{{0, 0, 15, -18, 0, 0, 0, 0, 2, -1, 0}, 92.690900, 0.000040, 0.059000},
	{{0, 0, 15, -18, 0, 0, 0, 0, 2, 0, 0}, 272.690760, 0.000050, 0.033000},
	{{0, 0, 15, -17, 0, 0, 0, 0, 2, -1, 0}, 121.028300, 0.000030, 0.057000},
	{{0, 0, 15, -17, 0, 0, 0, 0, 2, 0, 0}, 301.027790, 0.000030, 0.033000},
	{{0, 0, 15, -16, 0, 0, 0, 0, 2, -1, 0}, 147.937130, 0.000020, 0.056000},
	{{0, 0, 15, -16, 0, 0, 0, 0, 2, 0, 0}, 327.936620, 0.000030, 0.032000},
	{{0, 0, 15, -14, 0, 0, 0, 0, 2, 0, 0}, 206.560970, 0.000010, 0.031000},
	{{0, 0, 16, -23, 0, 0, 0, 0, 2, 0, 0}, 157.348970, 0.000020, 0.035000},
	{{0, 0, 16, -22, 0, 0, 0, 0, 2, -1, 0}, 6.236630, 0.000020, 0.063000},
	{{0, 0, 16, -22, 0, 0, 0, 0, 2, 0, 0}, 186.236600, 0.000010, 0.034000},
	{{0, 0, 16, -21, 0, 0, 0, 0, 2, -1, 0}, 35.085580, 0.000030, 0.061000},
	{{0, 0, 16, -21, 0, 0, 0, 0, 2, 0, 0}, 215.085530, 0.000020, 0.034000},
	{{0, 0, 16, -20, 0, 0, 0, 0, 2, -1, 0}, 63.851120, 0.000030, 0.059000},
	{{0, 0, 16, -20, 0, 0, 0, 0, 2, 0, 0}, 243.851700, 0.000040, 0.033000},
	{{0, 0, 16, -19, 0, 0, 0, 0, 0, 0, 0}, 92.441580, 0.000020, 0.170000},
	{{0, 0, 16, -19, 0, 0, 0, 0, 2, -1, 0}, 92.440130, 0.000030, 0.058000},
	{{0, 0, 16, -19, 0, 0, 0, 0, 2, 0, 0}, 272.441410, 0.000040, 0.033000},
	{{0, 0, 16, -18, 0, 0, 0, 0, 2, -1, 0}, 120.569530, 0.000020, 0.056000},
	{{0, 0, 16, -18, 0, 0, 0, 0, 2, 0, 0}, 300.573190, 0.000040, 0.032000},
	{{0, 0, 16, -17, 0, 0, 0, 0, 2, 0, 0}, 326.527400, 0.000020, 0.032000},
	{{0, 0, 16, -15, 0, 0, 0, 0, 2, 0, 0}, 209.206690, 0.000020, 0.031000},
	{{0, 0, 16, -5, -1, 0, 0, 0, 0, -1, 0}, 272.097580, 0.000020, 658.208000},
	{{0, 0, 17, -32, 0, 0, 0, 0, 0, 0, 0}, 282.422850, 0.000040, 71.966000},
	{{0, 0, 17, -30, 0, 0, 0, 0, 1, 0, -1}, 243.793780, 0.000030, 232.951000},
	{{0, 0, 17, -28, 0, 0, 0, 0, 2, 0, -2}, 221.726260, 0.000050, 188.324000},
	{{0, 0, 17, -24, 0, 0, 0, 0, 2, 0, 0}, 157.275780, 0.000020, 0.035000},
	{{0, 0, 17, -23, 0, 0, 0, 0, 2, 0, 0}, 186.142220, 0.000020, 0.034000},
	{{0, 0, 17, -22, 0, 0, 0, 0, 2, -1, 0}, 34.956590, 0.000020, 0.060000},
	{{0, 0, 17, -22, 0, 0, 0, 0, 2, 0, 0}, 214.956540, 0.000020, 0.033000},
	{{0, 0, 17, -21, 0, 0, 0, 0, 2, -1, 0}, 63.663190, 0.000020, 0.058000},
	{{0, 0, 17, -21, 0, 0, 0, 0, 2, 0, 0}, 243.663920, 0.000030, 0.033000},
	{{0, 0, 17, -20, 0, 0, 0, 0, 2, -1, 0}, 92.146200, 0.000030, 0.056000},
	{{0, 0, 17, -20, 0, 0, 0, 0, 2, 0, 0}, 272.146080, 0.000030, 0.032000},
	{{0, 0, 17, -19, 0, 0, 0, 0, 2, -1, 0}, 120.018850, 0.000020, 0.054000},
	{{0, 0, 17, -19, 0, 0, 0, 0, 2, 0, 0}, 300.018610, 0.000020, 0.032000},
	{{0, 0, 17, -18, 0, 0, 0, 0, 2, 0, 0}, 327.217100, 0.000010, 0.031000},
	{{0, 0, 18, -24, 0, 0, 0, 0, 2, 0, 0}, 186.032300, 0.000010, 0.033000},
	{{0, 0, 18, -23, 0, 0, 0, 0, 2, -1, 0}, 34.805440, 0.000020, 0.058000},
	{{0, 0, 18, -23, 0, 0, 0, 0, 2, 0, 0}, 214.805390, 0.000020, 0.033000},
	{{0, 0, 18, -22, 0, 0, 0, 0, 2, -1, 0}, 63.444740, 0.000020, 0.056000},
	{{0, 0, 18, -22, 0, 0, 0, 0, 2, 0, 0}, 243.444650, 0.000020, 0.032000},
	{{0, 0, 18, -21, 0, 0, 0, 0, 2, 0, 0}, 271.799150, 0.000020, 0.032000},
	{{0, 0, 18, -20, 0, 0, 0, 0, 2, 0, 0}, 299.339570, 0.000020, 0.031000},
	{{0, 0, 19, -25, 0, 0, 0, 0, 2, 0, 0}, 185.904880, 0.000010, 0.033000},
	{{0, 0, 19, -24, 0, 0, 0, 0, 2, 0, 0}, 214.630550, 0.000010, 0.032000},
	{{0, 0, 19, -23, 0, 0, 0, 0, 2, 0, 0}, 243.191220, 0.000020, 0.032000},
	{{0, 0, 19, -22, 0, 0, 0, 0, 2, 0, 0}, 271.393540, 0.000020, 0.031000},
	{{0, 0, 19, -21, 0, 0, 0, 0, 2, 0, 0}, 298.499920, 0.000010, 0.031000},
	{{0, 0, 19, -17, -3, 0, 0, 0, -4, 3, 0}, 255.593860, 0.000030, 1361.910000},
	{{0, 0, 20, -26, 0, 0, 0, 0, 2, 0, 0}, 185.759720, 0.000020, 0.032000},
	{{0, 0, 20, -25, 0, 0, 0, 0, 2, 0, 0}, 214.430430, 0.000010, 0.032000},
	{{0, 0, 20, -24, 0, 0, 0, 0, 2, 0, 0}, 242.900490, 0.000010, 0.031000},
	{{0, 0, 20, -23, 0, 0, 0, 0, 2, 0, 0}, 270.914980, 0.000020, 0.031000},
	{{0, 0, 20, -18, 0, 0, 0, 0, -3, 1, 1}, 140.454600, 0.000160, 584.305000},
	{{0, 0, 20, -16, 0, 0, -1, 0, -2, 1, 0}, 105.223220, 0.000020, 1701.651000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -4, 1, 0}, 327.067010, 0.000020, 0.040000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -4, 2, 0}, 327.067010, 0.000020, 0.087000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 0, 0}, 327.021070, 0.000070, 0.076000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 1, 0}, 327.067010, 0.001480, 88.385000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 2, 0}, 327.104610, 0.000090, 0.075000},
	{{0, 0, 20, -16, 0, 0, 0, 0, 0, 0, 0}, 327.067010, 0.000020, 0.087000},
	{{0, 0, 20, -16, 0, 0, 0, 0, 0, 1, 0}, 327.067010, 0.000020, 0.040000},
	{{0, 0, 20, -13, 2, 0, 0, 0, 0, -1, 0}, 59.402550, 0.000020, 1043.255000},
	{{0, 0, 21, -26, 0, 0, 0, 0, 2, 0, 0}, 214.201770, 0.000010, 0.031000},
	{{0, 0, 21, -25, 0, 0, 0, 0, 2, 0, 0}, 242.566050, 0.000010, 0.031000},
	{{0, 0, 21, -24, 0, 0, 0, 0, 2, 0, 0}, 270.360930, 0.000010, 0.030000},
	{{0, 0, 21, -18, 0, 0, 0, 0, -2, 1, 0}, 15.764310, 0.000140, 19.211000},
	{{0, 0, 22, -19, -5, 0, 0, 0, -2, 1, 0}, 87.782730, 0.000010, 190.106000},
	{{0, 0, 23, -21, -4, 0, 0, 0, -2, 1, 0}, 326.309020, 0.000010, 63.795000},
	{{0, 0, 23, -20, 0, 0, 0, 0, -1, 0, 0}, 100.984870, 0.000090, 411.317000},
	{{0, 0, 23, -20, 2, 0, 0, 0, -1, 1, -1}, 258.278900, 0.000080, 1726.003000},
	{{0, 0, 26, -27, -2, 0, 0, 0, -2, 0, 0}, 268.214230, 0.000010, 0.075000},
	{{0, 0, 26, -27, -2, 0, 0, 0, -2, 1, 0}, 356.237470, 0.000010, 171.793000},
	{{0, 0, 26, -27, -2, 0, 0, 0, -2, 2, 0}, 268.214230, 0.000010, 0.075000},
	{{0, 0, 26, -27, -1, 0, 0, 0, -2, 1, 0}, 103.459620, 0.000010, 12.742000},
	{{0, 0, 26, -27, 0, 0, 0, 0, -2, 1, 0}, 336.957000, 0.000010, 6.143000},
	{{0, 0, 26, -24, 0, 0, 0, 0, 0, -1, 0}, 278.293820, 0.000040, 61.818000},
	{{0, 0, 26, -22, 0, 0, 0, 0, 1, -1, -1}, 229.823820, 0.000070, 152.117000},
	{{0, 0, 27, -29, 0, 0, 0, 0, -2, 1, 0}, 53.215640, 0.000020, 10.059000},
	{{0, 0, 28, -31, 0, 0, -3, 0, -2, 1, 0}, 34.454280, 0.000130, 2901.861000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 0, 0}, 29.610850, 0.000020, 0.076000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 1, 0}, 28.796190, 0.000460, 27.739000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 2, 0}, 28.363350, 0.000030, 0.075000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 0, 0}, 305.758940, 0.000030, 0.075000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 1, 0}, 305.758940, 0.000500, 36.607000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 2, 0}, 305.758940, 0.000030, 0.076000},
	{{0, 0, 29, -32, -6, 0, 0, 0, -2, 1, 0}, 125.457040, 0.000030, 685.011000},
	{{0, 0, 29, -31, 0, 0, 0, 0, -1, 1, -1}, 211.610910, 0.000020, 56.451000},
	{{0, 0, 29, -29, -4, 0, 0, 0, 0, -1, 0}, 52.728770, 0.000010, 84.635000},
	{{0, 0, 29, -29, 0, 0, 0, 0, 0, 1, -2}, 336.968190, 0.000010, 123.278000},
	{{0, 0, 30, -35, 0, 0, 0, 0, -2, 1, 0}, 250.325360, 0.000040, 11.027000},
	{{0, 0, 30, -35, 2, 0, 0, 0, -2, 1, 0}, 79.509160, 0.000020, 12.833000},
	{{0, 0, 30, -33, -3, 0, 0, 0, -1, -1, 1}, 125.604110, 0.000140, 2071.859000},
	{{0, 0, 30, -33, -1, 0, 0, 0, -1, 0, 0}, 242.865470, 0.000030, 730.361000},
	{{0, 0, 31, -37, 0, 0, 0, 0, -2, 1, 0}, 179.398090, 0.000020, 6.491000},
	{{0, 0, 31, -37, 2, 0, 0, 0, -2, 1, 0}, 92.983040, 0.000010, 68.710000},
	{{0, 0, 31, -34, 0, 0, 0, 0, 0, -3, 2}, 244.981070, 0.000040, 2022.190000},
	{{0, 0, 32, -39, 2, 0, 0, 0, -2, 1, 0}, 22.697200, 0.000010, 20.486000},
	{{0, 0, 32, -39, 3, 0, 0, 0, -2, 1, 0}, 352.818730, 0.000010, 28.177000},
	{{0, 0, 32, -35, 0, -4, 0, 0, 0, -1, 0}, 284.843820, 0.000050, 2015.126000},
	{{0, 0, 33, -41, 3, 0, 0, 0, -2, 1, 0}, 339.586410, 0.000010, 35.871000},
	{{0, 0, 33, -40, -3, 0, 0, 0, -2, 1, 0}, 88.940430, 0.000040, 494.910000},
	{{0, 0, 33, -37, -1, 0, 0, 0, 0, -1, 0}, 6.721210, 0.000010, 80.800000},
	{{0, 0, 34, -43, 0, 0, 0, 0, -2, -1, 2}, 271.072560, 0.000010, 93.931000},
	{{0, 0, 34, -43, 4, 0, 0, 0, -2, 1, 0}, 261.073700, 0.000020, 144.041000},
	{{0, 0, 34, -42, -2, 0, 0, 0, -2, 1, 0}, 69.864080, 0.000010, 52.868000},
	{{0, 0, 34, -41, 0, 0, 0, 0, -1, -1, 1}, 33.747560, 0.000170, 958.407000},
	{{0, 0, 34, -41, 2, 0, 0, 0, -1, -1, 0}, 210.399780, 0.000010, 0.075000},
	{{0, 0, 34, -41, 2, 0, 0, 0, -1, 0, 0}, 210.399780, 0.000200, 1236.942000},
	{{0, 0, 34, -41, 2, 0, 0, 0, -1, 1, 0}, 210.399780, 0.000010, 0.075000},
	{{0, 0, 34, -39, 0, 0, 0, 0, 0, -1, 0}, 30.962160, 0.000180, 116.831000},
	{{0, 0, 34, -37, 0, 0, 0, 0, 1, -1, -1}, 182.371160, 0.000020, 55.060000},
	{{0, 0, 35, -44, -2, 0, 0, 0, -2, 1, 0}, 25.913010, 0.000020, 22.496000},
	{{0, 0, 35, -44, -1, 0, 0, 0, -2, 1, 0}, 263.244900, 0.000020, 25.094000},
	{{0, 0, 35, -41, 0, 0, 0, 0, 0, -1, 0}, 352.961370, 0.000010, 18.245000},
	{{0, 0, 36, -46, -1, 0, 0, 0, -2, 1, 0}, 221.494450, 0.000010, 42.523000},
	{{0, 0, 36, -44, 0, -2, 0, 0, -1, 1, -1}, 149.082470, 0.000010, 401.021000},
	{{0, 0, 37, -48, 0, 0, 0, 0, -2, 0, 0}, 222.481130, 0.000030, 0.075000},
	{{0, 0, 37, -48, 0, 0, 0, 0, -2, 1, 0}, 251.778490, 0.000160, 387.400000},
	{{0, 0, 37, -48, 0, 0, 0, 0, -2, 2, 0}, 233.589430, 0.000010, 0.075000},
	{{0, 0, 37, -46, 0, 0, 0, 0, -1, 1, -1}, 2.116910, 0.000080, 142.421000},
	{{0, 0, 37, -45, 2, 0, 0, 0, 0, -1, 0}, 356.177140, 0.000030, 77.298000},
	{{0, 0, 38, -47, 3, 0, 0, 0, 0, -1, 0}, 297.284480, 0.000010, 125.022000},
	{{0, 0, 40, -53, -4, 0, 0, 0, -2, 1, 0}, 270.348710, 0.000010, 561.851000},
	{{0, 0, 40, -50, -2, 0, 0, 0, 0, -1, 0}, 352.606790, 0.000010, 116.607000},
	{{0, 0, 40, -48, -2, 0, 0, 0, 1, -1, -1}, 189.706380, 0.000030, 973.771000},
	{{0, 0, 40, -48, 0, 0, 0, 0, 1, 0, -2}, 301.001920, 0.000020, 347.370000},
	{{0, 0, 41, -56, 3, 0, 0, 0, -2, 1, 0}, 126.318940, 0.000010, 318.264000},
	{{0, 0, 42, -54, 0, -1, 0, 0, 0, -2, 0}, 311.880460, 0.000010, 0.075000},
	{{0, 0, 42, -54, 0, -1, 0, 0, 0, -1, 0}, 311.880460, 0.000210, 1533.043000},
	{{0, 0, 42, -54, 0, -1, 0, 0, 0, 0, 0}, 311.880460, 0.000010, 0.075000},
	{{0, 0, 43, -55, -2, 0, 0, 0, 0, 1, -2}, 312.303430, 0.000010, 1957.040000},
	{{0, 0, 43, -52, 0, 0, 0, 0, 2, -1, -2}, 273.606640, 0.000010, 92.025000},
	{{0, 0, 44, -61, -1, 0, 0, 0, -2, 1, 0}, 31.136630, 0.000070, 820.282000},
	{{0, 0, 44, -56, 1, 0, 0, 0, 1, -1, -1}, 297.365360, 0.000130, 2145.021000},
	{{0, 0, 45, -63, 0, 0, 0, 0, -2, 1, 0}, 178.897290, 0.000010, 45.137000},
	{{0, 0, 48, -69, 2, 0, 0, 0, -2, 1, 0}, 11.692270, 0.000050, 1518.942000},
	{{0, 0, 48, -67, 0, 0, 0, 0, -1, 0, 0}, 335.322190, 0.000080, 118.917000},
	{{0, 1, -42, 51, 0, 0, 0, 0, 0, 1, 0}, 279.858780, 0.000010, 353.939000},
	{{0, 1, -37, 45, 0, 0, 0, 0, 2, -1, 0}, 92.724440, 0.000020, 30.256000},
	{{0, 1, -36, 43, 0, 0, 0, 0, 2, -1, 0}, 63.397270, 0.000010, 32.986000},
	{{0, 1, -11, 0, 0, 0, 0, 0, 4, -1, -2}, 154.757860, 0.000050, 3701.205000},
	{{0, 1, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 289.629150, 0.000010, 0.030000},
	{{0, 1, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 289.629150, 0.000010, 0.152000},
	{{0, 1, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 120.654750, 0.000020, 0.056000},
	{{0, 1, -8, 0, 2, 0, 0, 0, -2, 0, 0}, 322.501920, 0.000010, 0.032000},
	{{0, 1, -8, 0, 2, 0, 0, 0, -2, 2, 0}, 142.501920, 0.000010, 0.226000},
	{{0, 1, -8, 10, 0, 0, 0, 0, -1, 0, 1}, 214.606960, 0.000020, 258.482000},
	{{0, 1, -8, 12, 0, 0, 0, 0, -2, 0, 0}, 145.524670, 0.000060, 0.040000},
	{{0, 1, -8, 12, 0, 0, 0, 0, -2, 1, 0}, 145.642400, 0.000080, 0.087000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 0, -1, 0}, 144.847680, 0.000110, 0.075000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 0, 0, 0}, 144.552960, 0.000510, 174.398000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 0, 1, 0}, 144.847680, 0.000110, 0.075000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 2, -1, 0}, 145.643470, 0.000080, 0.087000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 2, 0, 0}, 145.524770, 0.000060, 0.040000},
	{{0, 1, -8, 13, 0, 0, 0, 0, 0, 0, 0}, 354.258300, 0.000010, 1.861000},
	{{0, 1, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 211.177390, 0.000010, 0.023000},
	{{0, 1, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 217.879080, 0.000030, 0.033000},
	{{0, 1, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 214.005510, 0.000020, 0.059000},
	{{0, 1, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 218.683070, 0.000010, 0.278000},
	{{0, 1, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 36.871420, 0.000010, 0.104000},
	{{0, 1, -7, 0, 2, 0, 0, 0, -2, 0, 0}, 231.686650, 0.000050, 0.033000},
	{{0, 1, -7, 0, 2, 0, 0, 0, -2, 1, 0}, 231.641160, 0.000020, 0.060000},
	{{0, 1, -7, 0, 2, 0, 0, 0, 0, -2, 0}, 231.642620, 0.000010, 0.032000},
	{{0, 1, -7, 0, 2, 0, 0, 0, 0, 0, 0}, 231.642620, 0.000010, 0.192000},
	{{0, 1, -7, 2, 0, 0, 0, 0, -2, 0, 0}, 231.908460, 0.000020, 0.034000},
	{{0, 1, -7, 2, 0, 0, 0, 0, -2, 1, 0}, 51.694520, 0.000020, 0.063000},
	{{0, 1, -7, 2, 0, 0, 0, 0, -2, 2, 0}, 231.908460, 0.000020, 0.394000},
	{{0, 1, -7, 2, 0, 0, 0, 0, -2, 3, 0}, 51.694520, 0.000020, 0.093000},
	{{0, 1, -7, 11, 0, 0, 0, 0, 0, 0, 0}, 325.289390, 0.000010, 2.110000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 324.100090, 0.000020, 0.024000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 346.164700, 0.000050, 0.385000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 142.693450, 0.000010, 0.032000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 144.100090, 0.000030, 0.057000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 152.432530, 0.000050, 0.229000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 331.401070, 0.000030, 0.141000},
	{{0, 1, -6, 0, 1, 0, 0, 0, -2, 0, 0}, 52.691110, 0.000010, 0.034000},
	{{0, 1, -6, 0, 1, 0, 0, 0, -2, 1, 0}, 50.469310, 0.000010, 0.063000},
	{{0, 1, -6, 0, 1, 0, 0, 0, 0, -1, 0}, 230.469310, 0.000010, 0.057000},
	{{0, 1, -6, 0, 1, 0, 0, 0, 0, 1, 0}, 230.469310, 0.000010, 0.112000},
	{{0, 1, -6, 0, 2, 0, 0, 0, -2, 0, 0}, 291.824360, 0.000050, 0.035000},
	{{0, 1, -6, 0, 2, 0, 0, 0, -2, 1, 0}, 291.956650, 0.000010, 0.064000},
	{{0, 1, -6, 0, 2, 0, 0, 0, -2, 3, 0}, 291.956650, 0.000010, 0.092000},
	{{0, 1, -6, 2, 0, 0, 0, 0, -2, 0, 0}, 272.305790, 0.000030, 0.036000},
	{{0, 1, -6, 2, 0, 0, 0, 0, -2, 2, 0}, 273.613580, 0.000020, 0.651000},
	{{0, 1, -6, 3, 0, 0, 0, 0, -2, 0, 0}, 288.628100, 0.000010, 0.036000},
	{{0, 1, -6, 3, 0, 0, 0, 0, -2, 1, 0}, 108.628100, 0.000020, 0.070000},
	{{0, 1, -6, 3, 0, 0, 0, 0, -2, 2, 0}, 288.628100, 0.000010, 0.995000},
	{{0, 1, -6, 3, 0, 0, 0, 0, -2, 3, 0}, 108.628100, 0.000020, 0.082000},
	{{0, 1, -6, 6, 0, 0, 0, 0, 0, 0, 0}, 209.498560, 0.000010, 0.844000},
	{{0, 1, -6, 8, 0, 0, 0, 0, 0, 0, 0}, 271.980850, 0.000010, 8.264000},
	{{0, 1, -5, 0, -1, 0, 0, 0, -2, 0, 0}, 58.491550, 0.000020, 0.035000},
	{{0, 1, -5, 0, -1, 0, 0, 0, -2, 2, 0}, 65.673590, 0.000010, 0.594000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 231.780360, 0.000020, 0.019000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -4, 3, 0}, 51.841840, 0.000030, 0.076000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, -2, 0}, 51.779160, 0.000010, 0.018000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 53.783870, 0.000050, 0.036000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 231.149370, 0.000020, 0.067000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 232.024080, 0.000040, 0.086000},
	{{0, 1, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 51.676570, 0.000010, 0.033000},
	{{0, 1, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 323.652360, 0.000040, 0.296000},
	{{0, 1, -5, 0, 1, 0, 0, 0, -2, 0, 0}, 308.771670, 0.000030, 0.036000},
	{{0, 1, -5, 0, 1, 0, 0, 0, -2, 1, 0}, 161.348070, 0.000030, 0.068000},
	{{0, 1, -5, 0, 1, 0, 0, 0, -2, 2, 0}, 221.257000, 0.000010, 0.660000},
	{{0, 1, -5, 2, 0, 0, 0, 0, 0, 0, 0}, 172.334420, 0.000010, 0.433000},
	{{0, 1, -5, 3, 0, 0, 0, 0, -4, 3, 0}, 181.638610, 0.000010, 0.087000},
	{{0, 1, -5, 3, 0, 0, 0, 0, -2, 1, 0}, 354.319410, 0.000090, 0.075000},
	{{0, 1, -5, 3, 0, 0, 0, 0, -2, 2, 0}, 133.113570, 0.000070, 184.957000},
	{{0, 1, -5, 3, 0, 0, 0, 0, -2, 3, 0}, 13.995360, 0.000050, 0.075000},
	{{0, 1, -5, 3, 0, 0, 0, 0, 0, 1, 0}, 181.638610, 0.000010, 0.087000},
	{{0, 1, -5, 5, 0, 0, 0, 0, -1, 2, -1}, 330.723020, 0.000020, 238.317000},
	{{0, 1, -5, 5, 0, 0, 0, 0, 0, 0, 0}, 73.005070, 0.000010, 1.397000},
	{{0, 1, -5, 6, 0, 0, 0, 0, 0, 0, 0}, 260.624700, 0.000010, 5.424000},
	{{0, 1, -5, 8, -3, 0, 0, 0, 0, 0, 0}, 71.948840, 0.000010, 1.597000},
	{{0, 1, -4, -2, 0, 0, 0, 0, -2, 0, 0}, 11.070710, 0.000030, 0.035000},
	{{0, 1, -4, -2, 0, 0, 0, 0, -2, 2, 0}, 11.027630, 0.000020, 0.601000},
	{{0, 1, -4, 0, -1, 0, 0, 0, -2, 0, 0}, 54.541870, 0.000060, 0.037000},
	{{0, 1, -4, 0, -1, 0, 0, 0, -2, 1, 0}, 62.346100, 0.000100, 0.072000},
	{{0, 1, -4, 0, -1, 0, 0, 0, -2, 3, 0}, 329.757320, 0.000010, 0.080000},
	{{0, 1, -4, 0, -1, 0, 0, 0, 0, 1, 0}, 242.346630, 0.000020, 0.093000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -4, 0, 0}, 128.843430, 0.000020, 0.019000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -4, 2, 0}, 128.843430, 0.000020, 0.039000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 107.915540, 0.000060, 0.037000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 241.968970, 0.000070, 0.072000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 149.718420, 0.000030, 1.665000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 358.564160, 0.000030, 0.079000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 118.180290, 0.000020, 0.068000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 237.233920, 0.000040, 0.757000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 241.770890, 0.000030, 0.064000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 245.668950, 0.000280, 0.421000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 251.054140, 0.000040, 0.092000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 60.723920, 0.000030, 0.292000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 243.907610, 0.000050, 0.110000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 242.991290, 0.000070, 0.045000},
	{{0, 1, -4, 0, 1, 0, 0, 0, -2, 1, 0}, 308.669530, 0.000030, 0.073000},
	{{0, 1, -4, 0, 2, 0, 0, 0, 2, -2, 0}, 90.680120, 0.000020, 0.251000},
	{{0, 1, -4, 0, 2, 0, 0, 0, 2, 0, 0}, 270.680120, 0.000020, 0.044000},
	{{0, 1, -4, 0, 3, 0, 0, 0, -2, 0, 2}, 357.639600, 0.000030, 71.265000},
	{{0, 1, -4, 0, 3, 0, 0, 0, 0, 0, 0}, 346.287920, 0.000010, 0.471000},
	{{0, 1, -4, 1, 0, 0, 0, 0, -2, 1, 0}, 297.130220, 0.000030, 0.075000},
	{{0, 1, -4, 2, 0, 0, 0, 0, 0, 0, 0}, 272.790170, 0.000020, 0.763000},
	{{0, 1, -4, 3, 0, 0, 0, 0, 0, 0, 0}, 353.423900, 0.000020, 1.283000},
	{{0, 1, -4, 4, 0, 0, 0, 0, 0, -1, 0}, 29.736640, 0.000030, 0.074000},
	{{0, 1, -4, 4, 0, 0, 0, 0, 0, 0, 0}, 216.784070, 0.000020, 4.037000},
	{{0, 1, -4, 4, 0, 0, 0, 0, 0, 1, 0}, 29.736640, 0.000030, 0.077000},
	{{0, 1, -4, 4, 0, 0, 0, 0, 2, -2, 0}, 29.598910, 0.000010, 0.495000},
	{{0, 1, -4, 4, 0, 0, 0, 0, 2, 0, 0}, 29.598910, 0.000010, 0.041000},
	{{0, 1, -3, -1, 0, 0, 0, 0, -2, 1, 0}, 270.419080, 0.000020, 0.075000},
	{{0, 1, -3, 0, -2, 0, 0, 0, -2, 0, 0}, 51.582620, 0.000030, 0.038000},
	{{0, 1, -3, 0, -2, 0, 0, 0, -2, 1, 0}, 230.083320, 0.000060, 0.077000},
	{{0, 1, -3, 0, -2, 0, 0, 0, -2, 3, 0}, 54.616140, 0.000010, 0.074000},
	{{0, 1, -3, 0, -1, 0, 0, 0, -2, 1, 0}, 304.097190, 0.000020, 0.077000},
	{{0, 1, -3, 0, -1, 0, 0, 0, -2, 3, 0}, 23.009020, 0.000010, 0.074000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -4, 2, 0}, 342.312710, 0.000020, 0.041000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -3, 0, 1}, 165.306240, 0.000010, 0.040000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -3, 1, 1}, 348.375690, 0.000010, 0.085000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 334.362940, 0.000020, 0.025000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 322.877610, 0.000080, 0.038000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 338.122800, 0.001090, 0.078000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 336.137760, 0.000100, 2.503000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 355.675550, 0.000050, 0.073000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, -2, 3}, 348.330660, 0.000020, 78.110000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 166.465330, 0.000180, 0.074000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 340.670740, 0.000130, 0.037000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 336.251510, 0.000160, 0.073000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 165.270380, 0.001000, 3.118000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, -1}, 346.532730, 0.000060, 0.072000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, 0}, 336.225750, 0.000020, 2.051000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 166.465330, 0.000180, 0.077000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 137.500800, 0.000030, 0.036000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 157.335610, 0.000430, 0.068000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 157.204140, 0.003790, 0.728000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 163.802840, 0.000820, 0.084000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 161.219700, 0.000050, 0.040000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 346.687120, 0.000010, 0.064000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 346.592980, 0.000230, 0.412000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 337.687030, 0.000030, 0.091000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 167.894770, 0.000090, 0.041000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 346.687120, 0.000010, 0.092000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 167.870360, 0.000040, 0.318000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 154.131720, 0.000210, 0.099000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 160.390550, 0.000230, 0.043000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 157.819320, 0.000020, 0.027000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 167.382080, 0.000020, 0.021000},
	{{0, 1, -3, 0, 1, 0, 0, 0, -2, 1, 0}, 266.873160, 0.000010, 0.078000},
	{{0, 1, -3, 0, 1, 0, 0, 0, -2, 3, 0}, 86.873160, 0.000010, 0.073000},
	{{0, 1, -3, 0, 1, 0, 0, 0, 0, 0, 0}, 271.771670, 0.000010, 0.775000},
	{{0, 1, -3, 0, 1, 0, 0, 0, 2, -2, 0}, 89.356280, 0.000030, 0.326000},
	{{0, 1, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 89.208310, 0.000020, 0.043000},
	{{0, 1, -3, 0, 2, 0, 0, 0, -2, 0, 0}, 179.907000, 0.000030, 0.039000},
	{{0, 1, -3, 0, 2, 0, 0, 0, -2, 1, 0}, 178.665270, 0.000050, 0.079000},
	{{0, 1, -3, 0, 2, 0, 0, 0, 0, -2, 0}, 180.435000, 0.000010, 0.036000},
	{{0, 1, -3, 0, 2, 0, 0, 0, 0, 0, 0}, 180.874440, 0.000060, 0.829000},
	{{0, 1, -3, 0, 2, 0, 0, 0, 2, -1, 0}, 179.866580, 0.000030, 0.097000},
	{{0, 1, -3, 0, 2, 0, 0, 0, 2, 0, 0}, 180.255440, 0.000010, 0.042000},
	{{0, 1, -3, 0, 2, 0, 0, 0, 2, 2, 0}, 179.894910, 0.000010, 0.020000},
	{{0, 1, -3, 0, 3, 0, 0, 0, 2, 0, 0}, 170.906800, 0.000040, 0.042000},
	{{0, 1, -3, 1, 0, 0, 0, 0, 0, 0, 0}, 163.751810, 0.000020, 1.187000},
	{{0, 1, -3, 2, 0, 0, 0, 0, -2, 2, 0}, 179.213420, 0.000010, 0.684000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 0, -1, 0}, 357.730090, 0.000020, 0.074000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 0, 1, 0}, 357.730090, 0.000020, 0.077000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 2, -3, 0}, 0.206490, 0.000030, 0.065000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 2, -2, 0}, 179.458710, 0.000020, 0.480000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 2, -1, 0}, 0.206490, 0.000030, 0.090000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 2, 0, 0}, 179.913930, 0.000040, 0.041000},
	{{0, 1, -3, 3, 0, 0, 0, 0, 0, 0, 0}, 36.959770, 0.000050, 4.534000},
	{{0, 1, -3, 6, 0, 0, 0, 0, 2, -3, 0}, 103.216120, 0.000020, 0.076000},
	{{0, 1, -3, 6, 0, 0, 0, 0, 2, -1, 0}, 103.216120, 0.000020, 0.075000},
	{{0, 1, -2, -3, 0, 0, 0, 0, -2, 1, 0}, 11.747990, 0.000010, 0.074000},
	{{0, 1, -2, -3, 0, 0, 0, 0, -2, 3, 0}, 110.501700, 0.000010, 0.077000},
	{{0, 1, -2, 0, -1, 0, 0, 0, -2, 1, 0}, 204.026560, 0.000020, 0.084000},
	{{0, 1, -2, 0, -1, 0, 0, 0, -2, 3, 0}, 24.026560, 0.000020, 0.069000},
	{{0, 1, -2, 0, -1, 0, 0, 0, 2, -2, 0}, 279.594300, 0.000010, 0.448000},
	{{0, 1, -2, 0, -1, 0, 0, 0, 2, 0, 0}, 99.594300, 0.000010, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -4, 0, 0}, 147.421740, 0.000020, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -4, 1, 0}, 121.746220, 0.000050, 0.027000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -4, 2, 0}, 209.203390, 0.000010, 0.043000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -3, 0, 1}, 256.663700, 0.000010, 0.042000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -3, 1, 1}, 32.932280, 0.000020, 0.093000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -3, 2, -1}, 76.622580, 0.000010, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 101.828110, 0.000020, 0.019000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 114.285120, 0.000260, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, -1, 2}, 117.637520, 0.000020, 0.087000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 121.838230, 0.001760, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 76.620690, 0.000100, 0.086000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 2}, 117.863220, 0.000060, 0.577000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 210.077550, 0.001230, 0.084000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 269.499470, 0.000210, 0.715000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 3, 0}, 276.270820, 0.000060, 0.068000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -2, 1}, 256.658630, 0.000020, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, -1}, 84.290290, 0.000040, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, 0}, 88.451180, 0.000020, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, 1}, 256.647520, 0.000440, 0.080000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 76.605260, 0.000380, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 88.332290, 0.000320, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 256.710040, 0.001650, 1.472000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 76.981800, 0.000870, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, 0}, 91.659320, 0.000070, 1.951000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, 1}, 256.638830, 0.000310, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, -1}, 76.632070, 0.000080, 2.892000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, 1}, 256.660810, 0.000020, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -3, 0}, 107.205070, 0.000040, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 105.567380, 0.000670, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -2, 2}, 295.422690, 0.000040, 24.413000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, -2}, 286.229440, 0.000030, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 106.025720, 0.009130, 0.073000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 1}, 256.587150, 0.000080, 4.814000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 2}, 299.022920, 0.000070, 0.076000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, -2}, 282.167080, 0.000010, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 76.332230, 0.000150, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 103.715670, 0.044780, 2.670000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 256.614460, 0.000340, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 2}, 282.167080, 0.000010, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, -2}, 108.919750, 0.000010, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, -1}, 76.628310, 0.000020, 1.848000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 106.632340, 0.008520, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 1}, 256.614460, 0.000020, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 2}, 286.229440, 0.000030, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 106.005550, 0.000540, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 3, 0}, 106.830910, 0.000040, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -2, -1}, 256.649540, 0.000010, 0.036000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -2, 1}, 76.672330, 0.000040, 0.913000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 256.681720, 0.000240, 0.068000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 272.599610, 0.000030, 0.793000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 76.816260, 0.000570, 0.082000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 256.717430, 0.002180, 0.700000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 280.642840, 0.000420, 0.083000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 78.670420, 0.000500, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 256.534620, 0.000460, 0.085000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 1, 1}, 78.199810, 0.000040, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 2, -1}, 256.636350, 0.000020, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 285.997860, 0.000010, 0.065000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 225.600850, 0.000110, 0.465000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 228.433420, 0.001860, 0.090000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, -2}, 211.101220, 0.000010, 0.403000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 236.846420, 0.001370, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 217.538580, 0.000080, 0.027000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 2, 0}, 259.635580, 0.000030, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 248.744260, 0.000020, 0.044000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, -1, 0}, 263.069730, 0.000040, 0.028000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, 0, 0}, 219.571300, 0.000010, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, 1, 0}, 87.841080, 0.000020, 0.016000},
	{{0, 1, -2, 0, 0, 1, 0, 0, 0, -2, 2}, 359.794770, 0.000010, 142.558000},
	{{0, 1, -2, 0, 0, 1, 0, 0, 0, 0, 0}, 0.038810, 0.000010, 2.937000},
	{{0, 1, -2, 0, 1, 0, 0, 0, -2, 0, 0}, 173.288440, 0.000060, 0.040000},
	{{0, 1, -2, 0, 1, 0, 0, 0, -2, 1, 0}, 177.970830, 0.000180, 0.085000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 0, -1, 0}, 356.284300, 0.000030, 0.074000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 0, 0, 0}, 1.635360, 0.000080, 3.446000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 0, 1, 0}, 357.500310, 0.000080, 0.077000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 2, -2, 0}, 1.625930, 0.000010, 0.484000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 2, -1, 0}, 358.690080, 0.000020, 0.089000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 2, 0, 0}, 177.529070, 0.000030, 0.041000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 2, 2, 0}, 178.721600, 0.000010, 0.020000},
	{{0, 1, -2, 0, 2, 0, 0, 0, -2, 0, 0}, 235.698430, 0.000010, 0.040000},
	{{0, 1, -2, 0, 2, 0, 0, 0, -2, 1, 0}, 240.845910, 0.000020, 0.086000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 0, -1, 0}, 60.845910, 0.000080, 0.074000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 0, 0, 0}, 212.098900, 0.000020, 4.858000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 0, 1, 0}, 60.845910, 0.000080, 0.077000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 2, -2, 0}, 83.016090, 0.000020, 0.505000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 2, -1, 0}, 240.845910, 0.000020, 0.089000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 2, 0, 0}, 83.016090, 0.000020, 0.041000},
	{{0, 1, -2, 0, 3, 0, 0, 0, 0, 0, 0}, 221.825580, 0.000010, 8.226000},
	{{0, 1, -2, 0, 4, 0, 0, 0, 0, 0, 0}, 241.063070, 0.000020, 26.839000},
	{{0, 1, -2, 1, 0, 0, 0, 0, 0, -1, 0}, 168.887430, 0.000020, 0.076000},
	{{0, 1, -2, 1, 0, 0, 0, 0, 0, 0, 0}, 316.817060, 0.000010, 6.361000},
	{{0, 1, -2, 1, 0, 0, 0, 0, 0, 1, 0}, 168.887430, 0.000020, 0.075000},
	{{0, 1, -2, 2, 0, 0, 0, 0, -2, 0, 0}, 220.796430, 0.000020, 0.042000},
	{{0, 1, -2, 2, 0, 0, 0, 0, -2, 1, 0}, 220.718720, 0.000010, 0.093000},
	{{0, 1, -2, 2, 0, 0, 0, 0, -2, 2, 0}, 220.941540, 0.000030, 0.406000},
	{{0, 1, -2, 2, 0, 0, 0, 0, -2, 3, 0}, 220.718720, 0.000010, 0.064000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 0, -1, 0}, 222.501390, 0.000020, 0.080000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 0, 0, 0}, 280.741610, 0.000010, 1.452000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 0, 1, 0}, 222.501390, 0.000020, 0.072000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, -3, 0}, 44.755520, 0.000040, 0.070000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, -2, 0}, 44.755530, 0.000030, 0.922000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, -1, 0}, 44.755520, 0.000040, 0.082000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, 0, 0}, 45.437620, 0.000020, 0.039000},
	{{0, 1, -2, 3, 0, 0, 0, 0, -2, 0, 0}, 236.435730, 0.000020, 0.043000},
	{{0, 1, -2, 3, 0, 0, 0, 0, -2, 2, 0}, 236.435730, 0.000020, 0.334000},
	{{0, 1, -2, 3, 0, 0, 0, 0, 2, -3, 0}, 236.451620, 0.000030, 0.072000},
	{{0, 1, -2, 3, 0, 0, 0, 0, 2, -2, 0}, 236.880380, 0.000020, 1.807000},
	{{0, 1, -2, 3, 0, 0, 0, 0, 2, -1, 0}, 236.451620, 0.000030, 0.079000},
	{{0, 1, -2, 3, 0, 0, 0, 0, 2, 0, 0}, 236.880380, 0.000020, 0.039000},
	{{0, 1, -2, 4, 0, 0, 0, 0, 2, -3, 0}, 268.583280, 0.000030, 0.075000},
	{{0, 1, -2, 4, 0, 0, 0, 0, 2, -2, 0}, 97.555560, 0.000010, 45.963000},
	{{0, 1, -2, 4, 0, 0, 0, 0, 2, -1, 0}, 217.111180, 0.000030, 0.076000},
	{{0, 1, -1, -5, 0, 0, 0, 0, -2, 1, 0}, 24.066860, 0.000020, 0.074000},
	{{0, 1, -1, -2, 0, 0, 0, 0, 0, 0, 0}, 120.667430, 0.000010, 2.284000},
	{{0, 1, -1, 0, -2, 0, 0, 0, -2, 0, 0}, 24.956620, 0.000020, 0.041000},
	{{0, 1, -1, 0, -2, 0, 0, 0, -2, 2, 0}, 204.956620, 0.000020, 0.448000},
	{{0, 1, -1, 0, -2, 0, 0, 0, 0, 0, 0}, 6.133700, 0.000010, 2.189000},
	{{0, 1, -1, 0, -1, 0, 0, 0, -2, 0, 0}, 211.704000, 0.000060, 0.041000},
	{{0, 1, -1, 0, -1, 0, 0, 0, -2, 2, 0}, 91.855860, 0.000020, 0.432000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 0, 0, 0}, 72.786570, 0.000020, 1.848000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, -3, 0}, 193.925940, 0.000010, 0.069000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, -2, 0}, 193.925940, 0.000010, 0.811000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, -1, 0}, 193.925900, 0.000040, 0.083000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, 0, 0}, 191.710940, 0.000070, 0.040000},
	{{0, 1, -1, 0, 0, -1, 0, 0, 0, 0, 0}, 88.271430, 0.000010, 1.690000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -6, 0, 0}, 179.987110, 0.000020, 0.014000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -6, 1, 0}, 179.983480, 0.000050, 0.017000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -6, 2, 0}, 179.983270, 0.000060, 0.021000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -6, 3, 0}, 179.771060, 0.000020, 0.030000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, -2, 0}, 180.000840, 0.000010, 0.013000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, -1, 0}, 179.990480, 0.000200, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 179.992910, 0.001130, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 0, 2}, 179.968450, 0.000010, 0.045000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 1, -2}, 359.982720, 0.000020, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 1, 0}, 179.992510, 0.002660, 0.028000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 2, 0}, 179.967310, 0.001750, 0.045000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 3, 0}, 180.357600, 0.000060, 0.110000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, -1, 0}, 179.971910, 0.000030, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 0, 0}, 179.813950, 0.000020, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 1, 0}, 359.991470, 0.000230, 0.043000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 2, 0}, 0.060950, 0.000040, 0.100000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 3, 0}, 359.988090, 0.000010, 0.304000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -3, 0}, 180.003860, 0.000090, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -2, 0}, 180.012870, 0.000840, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -1, -2}, 359.984290, 0.000040, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 179.989740, 0.009390, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -1, 2}, 359.990450, 0.000230, 0.095000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, -2}, 359.986620, 0.000250, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 179.981520, 0.099220, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 2}, 179.984190, 0.001640, 0.366000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, -2}, 359.982690, 0.000310, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 179.984360, 0.131220, 0.092000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 2, -2}, 359.977770, 0.000030, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 179.988180, 0.004970, 0.417000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 179.948370, 0.000170, 0.064000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 4, 0}, 179.919900, 0.000010, 0.035000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, -1, 0}, 0.005880, 0.000470, 0.040000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, -1, 1}, 50.920300, 0.000030, 0.086000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 220.632960, 0.000010, 0.040000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 0.007560, 0.006660, 0.085000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 149.121310, 0.000020, 0.596000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 1, 0}, 0.001660, 0.000770, 0.661000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 2, -1}, 220.632960, 0.000010, 0.743000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 2, 0}, 359.105050, 0.000020, 0.068000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -4, 0}, 180.012820, 0.000050, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -3, 0}, 180.010410, 0.000720, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -2, -2}, 0.010370, 0.000050, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -2, 0}, 180.009070, 0.010190, 0.039000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -2, 2}, 0.013310, 0.000010, 1.043000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, -2}, 0.007960, 0.000370, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 180.008880, 0.153500, 0.079000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 2}, 180.046500, 0.000190, 0.070000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, -2}, 359.995720, 0.000230, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 180.009880, 0.821550, 1.599000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 2}, 0.010390, 0.000500, 0.036000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, -2}, 180.205080, 0.000120, 0.077000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 180.015110, 0.127220, 0.072000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, 2}, 0.013330, 0.000310, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 2, -2}, 359.880230, 0.000030, 3.425000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 2, 0}, 180.016020, 0.008850, 0.037000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 2, 2}, 0.011820, 0.000060, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 3, 0}, 180.017770, 0.000620, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 4, 0}, 180.019340, 0.000040, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -2, 0}, 180.102480, 0.000250, 0.074000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -2, 1}, 247.054340, 0.000030, 10.557000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 31.604140, 0.000030, 0.073000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, 0}, 180.012890, 0.002920, 3.824000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, 1}, 230.920290, 0.000130, 0.076000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, -2}, 180.020540, 0.000030, 0.072000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 24.501420, 0.000250, 2.335000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 180.020100, 0.012180, 0.077000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 189.749040, 0.000040, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 2}, 0.021500, 0.000020, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, -1}, 31.604140, 0.000030, 0.078000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, 0}, 180.021590, 0.000750, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 2, 0}, 179.965110, 0.000050, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -4, 0}, 359.715140, 0.000010, 0.036000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 359.995550, 0.001760, 0.871000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, -2}, 0.165060, 0.000020, 0.068000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 179.879730, 0.012920, 0.083000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, 2}, 359.953740, 0.000030, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, -2}, 180.020670, 0.000890, 0.675000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 180.014640, 0.022010, 0.039000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, 2}, 359.887840, 0.000020, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 1, -2}, 0.082470, 0.000080, 0.085000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 1, 0}, 179.998900, 0.002860, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 2, 0}, 180.086000, 0.000280, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 3, 0}, 180.065020, 0.000030, 0.015000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 3, -2, 0}, 179.854850, 0.000030, 0.089000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 3, -1, 0}, 180.018300, 0.000170, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 3, 0, 0}, 180.018630, 0.000120, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 3, 2, 0}, 180.039140, 0.000020, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -3, 0}, 0.337750, 0.000060, 0.097000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -2, 0}, 179.806870, 0.000190, 0.042000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -1, -2}, 180.029830, 0.000020, 0.100000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -1, 0}, 179.978890, 0.000510, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, 0, 0}, 179.995460, 0.000220, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, 1, 0}, 179.997140, 0.000040, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 5, -2, 0}, 180.019610, 0.000010, 0.028000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 6, -1, 0}, 0.026870, 0.000030, 0.016000},
	{{0, 1, -1, 0, 0, 1, 0, 0, 0, 0, 0}, 85.913320, 0.000020, 1.516000},
	{{0, 1, -1, 0, 1, 0, 0, 0, -2, 0, 0}, 344.898430, 0.000040, 0.042000},
	{{0, 1, -1, 0, 1, 0, 0, 0, -2, 1, 0}, 169.063610, 0.000010, 0.093000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 0, -1, 0}, 349.063610, 0.000070, 0.080000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 0, 0, 0}, 295.597370, 0.000010, 1.409000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 0, 1, 0}, 349.063610, 0.000070, 0.072000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 1, -2, 1}, 105.146230, 0.000020, 95.933000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 1, -1, 1}, 91.854730, 0.000090, 0.075000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 2, -3, 0}, 314.474970, 0.000020, 0.070000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 2, -2, 0}, 314.420200, 0.000020, 0.940000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 2, -1, 0}, 315.095990, 0.000040, 0.082000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 2, 0, 0}, 330.477100, 0.000070, 0.039000},
	{{0, 1, -1, 0, 2, 0, 0, 0, 0, 0, 0}, 74.451500, 0.000010, 1.259000},
	{{0, 1, -1, 0, 2, 0, 0, 0, 1, 0, -1}, 354.963230, 0.000010, 3.852000},
	{{0, 1, -1, 2, 0, 0, 0, 0, 2, -3, 0}, 211.598560, 0.000020, 0.075000},
	{{0, 1, -1, 2, 0, 0, 0, 0, 2, -1, 0}, 231.876200, 0.000060, 0.076000},
	{{0, 1, 0, -7, 0, 0, 0, 0, -2, 0, 2}, 176.646400, 0.000010, 88.775000},
	{{0, 1, 0, -6, 0, 0, 0, 0, -2, 1, 0}, 206.527040, 0.000030, 0.077000},
	{{0, 1, 0, -3, 0, 0, 0, 0, 0, -1, 0}, 0.655870, 0.000020, 0.076000},
	{{0, 1, 0, -3, 0, 0, 0, 0, 0, 0, 0}, 324.217070, 0.000030, 32.819000},
	{{0, 1, 0, -3, 0, 0, 0, 0, 0, 1, 0}, 0.655870, 0.000020, 0.075000},
	{{0, 1, 0, -2, 0, 0, 0, 0, -2, 2, 0}, 321.255310, 0.000020, 0.428000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 0, -1, 0}, 321.562240, 0.000030, 0.079000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 0, 1, 0}, 321.562240, 0.000030, 0.072000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 2, -3, 0}, 139.617500, 0.000040, 0.069000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 2, -2, 0}, 140.140830, 0.000020, 0.825000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 2, -1, 0}, 139.617500, 0.000040, 0.083000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 2, 0, 0}, 140.140830, 0.000020, 0.040000},
	{{0, 1, 0, 0, -3, 0, 0, 0, 0, 0, 0}, 316.078240, 0.000010, 0.729000},
	{{0, 1, 0, 0, -2, 0, 0, 0, -2, 0, 0}, 303.461540, 0.000060, 0.043000},
	{{0, 1, 0, 0, -2, 0, 0, 0, 2, -3, 0}, 140.803770, 0.000020, 0.074000},
	{{0, 1, 0, 0, -2, 0, 0, 0, 2, -2, 0}, 308.549500, 0.000010, 3.154000},
	{{0, 1, 0, 0, -2, 0, 0, 0, 2, -1, 0}, 320.803770, 0.000020, 0.077000},
	{{0, 1, 0, 0, -2, 0, 0, 0, 2, 0, 0}, 128.549500, 0.000010, 0.038000},
	{{0, 1, 0, 0, -1, 0, 0, 0, -2, 0, 0}, 180.153330, 0.000040, 0.043000},
	{{0, 1, 0, 0, -1, 0, 0, 0, -2, 1, 0}, 0.990830, 0.000030, 0.101000},
	{{0, 1, 0, 0, -1, 0, 0, 0, -2, 2, 0}, 178.692080, 0.000010, 0.302000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, -2, 0}, 180.990830, 0.000030, 0.040000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, -1, 0}, 0.454200, 0.000040, 0.085000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0}, 4.897740, 0.000040, 0.649000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, 1, 0}, 0.454200, 0.000040, 0.068000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, -3, 0}, 3.603980, 0.000030, 0.074000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, -2, 0}, 4.073730, 0.000020, 4.296000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, -1, 0}, 183.603980, 0.000030, 0.077000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, 0, 0}, 3.494270, 0.000070, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, -2, 0}, 76.973300, 0.000010, 0.013000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, -1, 0}, 77.861140, 0.000030, 0.016000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 0, 0}, 78.477250, 0.000240, 0.021000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 1, 0}, 77.300980, 0.000400, 0.029000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 2, 0}, 77.863180, 0.000160, 0.047000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 0, 0}, 76.363280, 0.000020, 0.028000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 0, 1}, 103.360930, 0.000020, 0.045000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 1, -1}, 103.337320, 0.000010, 0.028000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 1, 1}, 103.338330, 0.000010, 0.114000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 3, 0}, 256.363280, 0.000010, 0.233000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -2, 0}, 76.878970, 0.000110, 0.020000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -1, 0}, 77.144900, 0.000930, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -1, 2}, 256.126260, 0.000010, 0.105000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, -2}, 257.036540, 0.000020, 0.020000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 77.055400, 0.009420, 0.043000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 2}, 76.648420, 0.000100, 0.268000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 76.964720, 0.008730, 0.101000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 1, 2}, 256.126260, 0.000010, 0.059000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 74.649920, 0.000330, 0.294000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 3, 0}, 85.014460, 0.000070, 0.060000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 4, 0}, 80.289380, 0.000010, 0.033000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -1, -1}, 103.340530, 0.000070, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -1, 1}, 283.795160, 0.000090, 0.095000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, -1}, 103.307560, 0.000770, 0.041000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 258.053410, 0.000220, 0.093000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 1}, 283.339260, 0.001980, 0.373000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 1, -1}, 102.525400, 0.000450, 0.092000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 1, 1}, 283.343990, 0.000220, 0.063000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 2, -1}, 99.182760, 0.000010, 0.426000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 2, 1}, 283.338600, 0.000010, 0.034000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -3, 0}, 84.441250, 0.000030, 0.026000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -2, 0}, 80.775780, 0.000490, 0.040000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 81.703430, 0.006540, 0.086000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1}, 282.866590, 0.000120, 0.085000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 82.232990, 0.014570, 0.615000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 103.337450, 0.000050, 0.066000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 81.229070, 0.001910, 0.067000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 83.187980, 0.000110, 0.036000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, -1}, 103.335150, 0.000090, 0.039000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 263.742640, 0.000010, 0.080000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, 1}, 283.476060, 0.000030, 1.105000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, -1}, 103.333580, 0.001410, 0.079000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 270.377040, 0.000030, 1.354000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 1}, 283.337330, 0.000880, 0.071000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, -3}, 283.331000, 0.000010, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 103.333710, 0.008940, 1.749000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 271.092500, 0.000170, 0.071000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 283.332670, 0.001140, 0.036000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 1, -1}, 103.383660, 0.001260, 0.072000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1}, 283.333650, 0.000120, 0.025000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 2, -1}, 103.335030, 0.000090, 0.037000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 269.578780, 0.000040, 0.075000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -3, 1}, 282.434380, 0.000030, 54.757000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 265.802800, 0.001950, 6.734000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -2, 1}, 103.341660, 0.000030, 0.075000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, -1}, 103.331160, 0.000040, 3.172000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 270.206610, 0.008210, 0.076000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 103.337480, 0.000200, 0.077000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 275.311560, 0.000620, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 271.842060, 0.000050, 0.025000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, -2, -1}, 283.335860, 0.000020, 0.832000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, -1, -1}, 283.327130, 0.000180, 0.083000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, -1, 1}, 283.331110, 0.000020, 0.026000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, 0, -1}, 103.336750, 0.000080, 0.040000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, 1, -1}, 103.333810, 0.000010, 0.026000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 4, -3, 0}, 265.517950, 0.000030, 0.088000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 4, -2, 0}, 273.653290, 0.000090, 0.041000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 4, -1, 0}, 270.792780, 0.000070, 0.026000},
	{{0, 1, 0, 0, 1, 0, 0, 0, -2, 0, 0}, 80.433150, 0.000010, 0.043000},
	{{0, 1, 0, 0, 1, 0, 0, 0, -2, 2, 0}, 260.433150, 0.000010, 0.287000},
	{{0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0}, 94.520450, 0.000010, 0.585000},
	{{0, 1, 0, 0, 1, 0, 0, 0, 2, -3, 0}, 285.809370, 0.000020, 0.075000},
	{{0, 1, 0, 0, 1, 0, 0, 0, 2, -2, 0}, 264.994700, 0.000020, 15.579000},
	{{0, 1, 0, 0, 1, 0, 0, 0, 2, -1, 0}, 302.409220, 0.000060, 0.076000},
	{{0, 1, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 151.683450, 0.000010, 0.038000},
	{{0, 1, 0, 0, 2, 0, 0, 0, 2, -3, 0}, 149.992340, 0.000040, 0.076000},
	{{0, 1, 0, 0, 2, 0, 0, 0, 2, -2, 0}, 342.798250, 0.000020, 49.716000},
	{{0, 1, 0, 0, 2, 0, 0, 0, 2, -1, 0}, 111.602870, 0.000030, 0.075000},
	{{0, 1, 1, -5, 0, 0, 0, 0, 0, 0, 0}, 100.470260, 0.000020, 30.398000},
	{{0, 1, 1, -3, 0, 0, 0, 0, 1, 0, -1}, 242.602960, 0.000010, 42.928000},
	{{0, 1, 1, -2, 0, 0, 0, 0, -2, 0, 0}, 180.131170, 0.000030, 0.043000},
	{{0, 1, 1, -2, 0, 0, 0, 0, -2, 1, 0}, 0.051720, 0.000030, 0.101000},
	{{0, 1, 1, -2, 0, 0, 0, 0, -2, 3, 0}, 0.051720, 0.000010, 0.060000},
	{{0, 1, 1, -2, 0, 0, 0, 0, 0, -1, 0}, 0.051720, 0.000010, 0.086000},
	{{0, 1, 1, -2, 0, 0, 0, 0, 0, 0, 0}, 232.002120, 0.000010, 0.640000},
	{{0, 1, 1, -2, 0, 0, 0, 0, 0, 1, 0}, 0.051720, 0.000010, 0.067000},
	{{0, 1, 1, -2, 0, 0, 0, 0, 2, -3, 0}, 183.774560, 0.000010, 0.074000},
	{{0, 1, 1, -2, 0, 0, 0, 0, 2, -1, 0}, 183.774560, 0.000010, 0.077000},
	{{0, 1, 1, -1, 0, 0, 0, 0, 2, 0, -2}, 37.481810, 0.000020, 73.036000},
	{{0, 1, 1, 0, -4, 0, 0, 0, 0, 0, 0}, 199.688870, 0.000010, 0.437000},
	{{0, 1, 1, 0, -3, 0, 0, 0, -2, 0, 0}, 191.537010, 0.000040, 0.045000},
	{{0, 1, 1, 0, -3, 0, 0, 0, -2, 2, 0}, 9.149970, 0.000010, 0.241000},
	{{0, 1, 1, 0, -2, 0, 0, 0, -2, 1, 0}, 180.043130, 0.000090, 0.111000},
	{{0, 1, 1, 0, -2, 0, 0, 0, -2, 3, 0}, 0.147690, 0.000010, 0.057000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 0, -1, 0}, 180.062920, 0.000020, 0.093000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 0, 0, 0}, 180.762110, 0.000050, 0.407000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 0, 1, 0}, 180.062920, 0.000020, 0.064000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 2, -3, 0}, 0.341140, 0.000010, 0.080000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 2, -1, 0}, 180.142290, 0.000050, 0.072000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 2, 0, 0}, 0.093840, 0.000020, 0.037000},
	{{0, 1, 1, 0, -1, 0, 0, 0, -2, 0, 0}, 90.652940, 0.000030, 0.045000},
	{{0, 1, 1, 0, -1, 0, 0, 0, -2, 2, 0}, 90.652940, 0.000030, 0.232000},
	{{0, 1, 1, 0, -1, 0, 0, 0, 0, -2, 0}, 345.847560, 0.000030, 0.042000},
	{{0, 1, 1, 0, -1, 0, 0, 0, 0, 0, 0}, 189.161970, 0.000030, 0.394000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -4, 0, 0}, 96.294410, 0.000010, 0.021000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -4, 1, 0}, 348.797850, 0.000040, 0.030000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, -1, 0}, 351.830350, 0.000090, 0.028000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 355.715680, 0.000870, 0.045000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 357.265650, 0.000670, 0.113000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 2.000130, 0.000060, 0.227000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, -1}, 9.967780, 0.000040, 0.043000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 204.517260, 0.000050, 0.103000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, 1}, 190.206050, 0.000110, 0.272000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 1, -1}, 9.967770, 0.000010, 0.101000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, -2, 0}, 17.241820, 0.000020, 0.042000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 7.131550, 0.000410, 0.094000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 22.283190, 0.002730, 0.381000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 24.154930, 0.000270, 0.063000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 18.782920, 0.000030, 0.034000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 12.684820, 0.000160, 0.636000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 205.152820, 0.000050, 0.067000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 1}, 191.705080, 0.000030, 0.035000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 280.061380, 0.000020, 0.081000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 13.604080, 0.000020, 1.174000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 21.706670, 0.000660, 0.071000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, 0, -2}, 26.744140, 0.000010, 1.931000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 222.691930, 0.000040, 0.037000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 3, -2, 0}, 23.894200, 0.000020, 0.076000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 4, -2, 0}, 30.281790, 0.000010, 0.039000},
	{{0, 1, 1, 0, 2, 0, 0, 0, 2, -2, 0}, 308.159280, 0.000010, 0.980000},
	{{0, 1, 1, 0, 2, 0, 0, 0, 2, -1, 0}, 308.159280, 0.000030, 0.070000},
	{{0, 1, 1, 0, 2, 0, 0, 0, 2, 0, 0}, 128.159280, 0.000010, 0.036000},
	{{0, 1, 2, -6, 0, 0, 0, 0, 0, 0, 0}, 273.782650, 0.000010, 2.297000},
	{{0, 1, 2, -4, 0, 0, 0, 0, -2, 0, 0}, 330.647020, 0.000010, 0.043000},
	{{0, 1, 2, -4, 0, 0, 0, 0, -2, 2, 0}, 330.647020, 0.000010, 0.306000},
	{{0, 1, 2, -3, 0, 0, 0, 0, 2, -1, 0}, 266.522140, 0.000020, 0.074000},
	{{0, 1, 2, 0, -3, 0, 0, 0, 0, 0, 0}, 241.272780, 0.000010, 0.297000},
	{{0, 1, 2, 0, -2, 0, 0, 0, -2, 0, 0}, 269.307710, 0.000020, 0.047000},
	{{0, 1, 2, 0, -2, 0, 0, 0, -2, 2, 0}, 89.307710, 0.000020, 0.191000},
	{{0, 1, 2, 0, -2, 0, 0, 0, 0, 0, 0}, 90.174110, 0.000010, 0.289000},
	{{0, 1, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 275.678630, 0.000090, 0.047000},
	{{0, 1, 2, 0, 0, 0, 0, 0, -2, 1, 0}, 282.047490, 0.000040, 0.127000},
	{{0, 1, 2, 0, 0, 0, 0, 0, -1, 0, 1}, 122.286300, 0.000020, 0.214000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 305.597080, 0.000030, 0.104000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 293.108730, 0.000200, 0.276000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 291.985870, 0.000020, 0.059000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 1, 0, -1}, 305.432530, 0.000020, 0.389000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 219.459180, 0.000030, 0.088000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 45.060260, 0.000040, 0.540000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 271.033080, 0.000030, 0.066000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 72.878440, 0.000040, 0.035000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 1, 0}, 55.710890, 0.000010, 0.024000},
	{{0, 1, 2, 0, 1, 0, 0, 0, 0, 0, 0}, 128.859340, 0.000020, 0.270000},
	{{0, 1, 2, 0, 1, 0, 0, 0, 2, -2, 0}, 126.895960, 0.000010, 0.517000},
	{{0, 1, 2, 0, 1, 0, 0, 0, 2, -1, 0}, 135.602730, 0.000010, 0.066000},
	{{0, 1, 2, 0, 1, 0, 0, 0, 2, 0, 0}, 308.444160, 0.000120, 0.035000},
	{{0, 1, 2, 3, 0, 0, 0, 0, 2, -2, 0}, 184.688010, 0.000010, 0.290000},
	{{0, 1, 2, 3, 0, 0, 0, 0, 2, 0, 0}, 184.688010, 0.000010, 0.033000},
	{{0, 1, 3, -8, 0, 0, 0, 0, 0, 0, 0}, 245.047220, 0.000010, 2.688000},
	{{0, 1, 3, -8, 3, 0, 0, 0, 0, 0, 0}, 108.118160, 0.000010, 1.600000},
	{{0, 1, 3, -5, 0, 0, 0, 0, 0, 0, 0}, 150.614760, 0.000010, 0.508000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, -3, 0}, 320.599810, 0.000030, 0.095000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, -2, 0}, 309.072810, 0.000050, 0.361000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, -1, 0}, 320.599810, 0.000030, 0.062000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, 0, 0}, 300.079990, 0.000050, 0.034000},
	{{0, 1, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 89.463910, 0.000020, 0.050000},
	{{0, 1, 3, 0, 0, 0, 0, 0, -2, 2, 0}, 131.906710, 0.000010, 0.156000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 128.213120, 0.000020, 0.116000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 208.258080, 0.000030, 0.216000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 128.213120, 0.000020, 0.056000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 1, 0, 0}, 128.215030, 0.000020, 0.059000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 128.141340, 0.000030, 0.351000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, -1, 0}, 306.652290, 0.000020, 0.062000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, 0, -2}, 308.215030, 0.000030, 0.397000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 129.298930, 0.000040, 0.034000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, 2, 0}, 128.213110, 0.000020, 0.018000},
	{{0, 1, 3, 0, 1, 0, 0, 0, 2, -2, 0}, 114.559330, 0.000010, 0.341000},
	{{0, 1, 3, 0, 1, 0, 0, 0, 2, 0, 0}, 294.559330, 0.000010, 0.034000},
	{{0, 1, 4, -7, 0, 0, 0, 0, 2, -1, 0}, 303.842430, 0.000020, 0.075000},
	{{0, 1, 4, -2, 0, 0, 0, 0, 2, -2, 0}, 266.385690, 0.000020, 0.359000},
	{{0, 1, 4, -2, 0, 0, 0, 0, 2, 0, 0}, 266.385690, 0.000020, 0.034000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 0, 0, 0}, 309.244820, 0.000030, 0.180000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, -3, 0}, 309.247320, 0.000030, 0.105000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, -2, 0}, 128.783300, 0.000020, 0.265000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, -1, 0}, 309.247320, 0.000030, 0.059000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, 0, 0}, 128.908370, 0.000030, 0.033000},
	{{0, 1, 4, 0, 0, 0, 0, 0, -2, 0, 0}, 302.148150, 0.000020, 0.052000},
	{{0, 1, 4, 0, 0, 0, 0, 0, -2, 2, 0}, 302.148150, 0.000020, 0.135000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 0, -2, 0}, 122.083190, 0.000010, 0.048000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0}, 302.083190, 0.000010, 0.178000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, -3, 0}, 37.362690, 0.000030, 0.106000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, -2, 0}, 207.603970, 0.000050, 0.260000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, -1, 0}, 59.942990, 0.000010, 0.058000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 343.286910, 0.000020, 0.033000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 1, 0}, 34.495600, 0.000010, 0.023000},
	{{0, 1, 5, -9, 0, 0, 0, 0, 2, -1, 0}, 268.472900, 0.000030, 0.075000},
	{{0, 1, 5, -2, 0, 0, 0, 0, 2, -3, 0}, 128.304010, 0.000010, 0.106000},
	{{0, 1, 5, -2, 0, 0, 0, 0, 2, -2, 0}, 128.184570, 0.000020, 0.264000},
	{{0, 1, 5, -2, 0, 0, 0, 0, 2, -1, 0}, 128.304010, 0.000010, 0.059000},
	{{0, 1, 5, -2, 0, 0, 0, 0, 2, 0, 0}, 130.343360, 0.000040, 0.033000},
	{{0, 1, 5, 0, -3, 0, 0, 0, 2, 0, 0}, 138.992520, 0.000020, 0.032000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 0, 0, 0}, 128.315210, 0.000010, 0.155000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 0, 2, 0}, 308.315210, 0.000010, 0.030000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 2, -3, 0}, 308.357600, 0.000020, 0.117000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 2, -2, 0}, 308.314570, 0.000020, 0.214000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 2, -1, 0}, 128.357600, 0.000020, 0.056000},
	{{0, 1, 5, 0, -1, 0, 0, 0, 2, -2, 0}, 38.698840, 0.000010, 0.210000},
	{{0, 1, 5, 0, -1, 0, 0, 0, 2, 0, 0}, 38.698840, 0.000010, 0.032000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 0, -1, 0}, 152.012520, 0.000010, 0.151000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 0, 1, 0}, 152.012520, 0.000010, 0.050000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 2, 2, 0}, 152.012520, 0.000020, 0.017000},
	{{0, 1, 6, -11, 0, 0, 0, 0, 2, -3, 0}, 142.279770, 0.000020, 0.075000},
	{{0, 1, 6, -11, 0, 0, 0, 0, 2, -2, 0}, 67.731130, 0.000100, 335.665000},
	{{0, 1, 6, -11, 0, 0, 0, 0, 2, -1, 0}, 142.279770, 0.000020, 0.075000},
	{{0, 1, 6, 0, 0, 0, 0, 0, 2, 0, 0}, 239.442580, 0.000030, 0.031000},
	{{0, 1, 9, -20, 0, 0, 0, 0, 0, 0, 0}, 248.078080, 0.000010, 122.527000},
	{{0, 1, 29, -36, 0, 0, 0, 0, -2, 1, 0}, 10.307510, 0.000010, 317.190000},
	{{0, 1, 37, -51, 0, 0, 0, 0, -2, 1, 0}, 155.607010, 0.000020, 35.857000},
	{{0, 1, 43, -59, 0, 0, 0, 0, 0, -2, 0}, 97.328560, 0.000010, 0.075000},
	{{0, 1, 43, -59, 0, 0, 0, 0, 0, -1, 0}, 97.328560, 0.000240, 2513.483000},
	{{0, 1, 43, -59, 0, 0, 0, 0, 0, 0, 0}, 97.328560, 0.000010, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -4, 1, 0}, 295.930280, 0.000010, 0.026000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -4, 2, 0}, 295.930280, 0.000090, 0.040000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -4, 3, 0}, 290.962450, 0.000150, 0.087000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 0, 0}, 301.493730, 0.000010, 0.038000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 1, 0}, 290.921120, 0.000280, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 2, -2}, 115.930280, 0.000020, 0.037000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 2, 0}, 295.930280, 0.008080, 3054.914000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 2, 2}, 115.930280, 0.000020, 0.037000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 3, 0}, 321.439840, 0.000150, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 4, 0}, 301.493730, 0.000010, 0.038000},
	{{0, 2, -13, 15, 0, 0, 0, 0, 0, 1, 0}, 298.251980, 0.000120, 0.087000},
	{{0, 2, -13, 15, 0, 0, 0, 0, 0, 2, 0}, 295.930280, 0.000090, 0.040000},
	{{0, 2, -13, 15, 0, 0, 0, 0, 0, 3, 0}, 295.930280, 0.000010, 0.026000},
	{{0, 2, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 289.624680, 0.000010, 0.031000},
	{{0, 2, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 289.624680, 0.000010, 0.167000},
	{{0, 2, -10, 11, 0, 0, 0, 0, 0, 0, 0}, 87.154110, 0.000010, 1.111000},
	{{0, 2, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 121.158150, 0.000020, 0.058000},
	{{0, 2, -9, 0, 2, 0, 0, 0, -2, 0, 0}, 322.551820, 0.000020, 0.033000},
	{{0, 2, -9, 8, 0, 0, 0, 0, 0, 0, 0}, 46.496700, 0.000010, 0.669000},
	{{0, 2, -9, 11, 0, 0, 0, 0, 0, 0, 0}, 341.363430, 0.000010, 10.043000},
	{{0, 2, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 213.239190, 0.000010, 0.023000},
	{{0, 2, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 213.239190, 0.000010, 0.062000},
	{{0, 2, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 200.155880, 0.000010, 0.211000},
	{{0, 2, -8, 0, 2, 0, 0, 0, -2, 0, 0}, 231.681770, 0.000040, 0.034000},
	{{0, 2, -8, 0, 2, 0, 0, 0, -2, 1, 0}, 231.637150, 0.000020, 0.062000},
	{{0, 2, -8, 0, 2, 0, 0, 0, 0, 0, 0}, 231.641330, 0.000020, 0.218000},
	{{0, 2, -8, 0, 3, 0, 0, 0, -2, 0, 0}, 221.890060, 0.000010, 0.034000},
	{{0, 2, -8, 0, 3, 0, 0, 0, -2, 2, 0}, 221.890060, 0.000010, 0.367000},
	{{0, 2, -8, 2, 0, 0, 0, 0, -2, 0, 0}, 231.908270, 0.000020, 0.035000},
	{{0, 2, -8, 2, 0, 0, 0, 0, -2, 1, 0}, 51.778350, 0.000030, 0.066000},
	{{0, 2, -8, 2, 0, 0, 0, 0, -2, 2, 0}, 231.908270, 0.000020, 0.523000},
	{{0, 2, -8, 2, 0, 0, 0, 0, -2, 3, 0}, 51.778350, 0.000030, 0.088000},
	{{0, 2, -8, 5, 0, 0, 0, 0, -2, 0, 2}, 322.264410, 0.000010, 58.829000},
	{{0, 2, -8, 6, 0, 0, 0, 0, 0, 0, 0}, 0.269230, 0.000010, 0.642000},
	{{0, 2, -8, 7, 0, 0, 0, 0, 0, 0, 0}, 17.336840, 0.000020, 0.974000},
	{{0, 2, -8, 7, 0, 0, 0, 0, 2, 0, 0}, 2.164350, 0.000020, 0.042000},
	{{0, 2, -8, 9, 0, 0, 0, 0, -2, 0, 0}, 263.805250, 0.000020, 0.040000},
	{{0, 2, -8, 9, 0, 0, 0, 0, -2, 1, 0}, 263.805250, 0.000020, 0.087000},
	{{0, 2, -8, 9, 0, 0, 0, 0, 0, -1, 0}, 261.442650, 0.000040, 0.076000},
	{{0, 2, -8, 9, 0, 0, 0, 0, 0, 0, 0}, 263.805250, 0.000170, 27.621000},
	{{0, 2, -8, 9, 0, 0, 0, 0, 0, 1, 0}, 261.442650, 0.000040, 0.075000},
	{{0, 2, -8, 9, 0, 0, 0, 0, 2, -1, 0}, 263.805250, 0.000020, 0.087000},
	{{0, 2, -8, 9, 0, 0, 0, 0, 2, 0, 0}, 263.805250, 0.000020, 0.040000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 324.014960, 0.000020, 0.024000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 138.460320, 0.000040, 0.035000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 132.056830, 0.000040, 0.066000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 344.659270, 0.000020, 0.506000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 152.594400, 0.000050, 0.089000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 142.755710, 0.000010, 0.033000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 157.112470, 0.000050, 0.267000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 114.128740, 0.000020, 0.044000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 329.124960, 0.000050, 0.129000},
	{{0, 2, -7, 0, 1, 0, 0, 0, -2, 2, 0}, 51.208170, 0.000020, 0.529000},
	{{0, 2, -7, 0, 1, 0, 0, 0, -2, 3, 0}, 231.208180, 0.000010, 0.088000},
	{{0, 2, -7, 0, 1, 0, 0, 0, 0, -1, 0}, 230.468020, 0.000020, 0.059000},
	{{0, 2, -7, 0, 1, 0, 0, 0, 0, 1, 0}, 230.468020, 0.000020, 0.104000},
	{{0, 2, -7, 0, 2, 0, 0, 0, -2, 0, 0}, 291.822750, 0.000050, 0.035000},
	{{0, 2, -7, 2, 0, 0, 0, 0, -2, 0, 0}, 261.981030, 0.000010, 0.036000},
	{{0, 2, -7, 3, 0, 0, 0, 0, -2, 0, 0}, 288.626810, 0.000010, 0.037000},
	{{0, 2, -7, 3, 0, 0, 0, 0, -2, 0, 2}, 288.972600, 0.000040, 21.566000},
	{{0, 2, -7, 3, 0, 0, 0, 0, -2, 2, 0}, 288.626810, 0.000010, 2.632000},
	{{0, 2, -7, 6, 0, 0, 0, 0, 0, 0, 0}, 8.619850, 0.000010, 1.789000},
	{{0, 2, -7, 7, 0, 0, 0, 0, -2, 0, 0}, 234.685960, 0.000060, 0.040000},
	{{0, 2, -7, 7, 0, 0, 0, 0, -2, 1, 0}, 234.097210, 0.000080, 0.087000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 0, -1, 0}, 237.694090, 0.000090, 0.075000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 0, 0, 0}, 235.317610, 0.000530, 36.814000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 0, 1, 0}, 237.666830, 0.000090, 0.076000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 2, -1, 0}, 234.011320, 0.000090, 0.087000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 2, 0, 0}, 234.595030, 0.000060, 0.040000},
	{{0, 2, -6, 0, -1, 0, 0, 0, -2, 0, 0}, 58.435990, 0.000020, 0.036000},
	{{0, 2, -6, 0, -1, 0, 0, 0, -2, 1, 0}, 65.743870, 0.000010, 0.070000},
	{{0, 2, -6, 0, -1, 0, 0, 0, -2, 2, 0}, 65.743870, 0.000010, 0.944000},
	{{0, 2, -6, 0, -1, 0, 0, 0, -2, 3, 0}, 245.743870, 0.000010, 0.082000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 231.785210, 0.000020, 0.019000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -4, 3, 0}, 64.640680, 0.000010, 0.080000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -3, 2, 0}, 231.785210, 0.000010, 0.075000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -3, 4, 0}, 231.785210, 0.000010, 0.076000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 52.502170, 0.000100, 0.036000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 276.422560, 0.000030, 0.070000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 51.905650, 0.000070, 1.026000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 237.353910, 0.000080, 0.081000},
	{{0, 2, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 51.908290, 0.000010, 0.062000},
	{{0, 2, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 324.576320, 0.000050, 0.364000},
	{{0, 2, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 31.255670, 0.000040, 0.095000},
	{{0, 2, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 214.434700, 0.000020, 0.045000},
	{{0, 2, -6, 0, 1, 0, 0, 0, -2, 0, 0}, 324.960300, 0.000030, 0.036000},
	{{0, 2, -6, 0, 1, 0, 0, 0, -2, 2, 0}, 220.950940, 0.000010, 1.123000},
	{{0, 2, -6, 2, 0, 0, 0, 0, -2, 1, 0}, 213.892080, 0.000020, 0.076000},
	{{0, 2, -6, 2, 0, 0, 0, 0, -2, 2, 0}, 4.225950, 0.000010, 11.308000},
	{{0, 2, -6, 2, 0, 0, 0, 0, -2, 3, 0}, 213.892080, 0.000020, 0.075000},
	{{0, 2, -6, 3, 0, 0, 0, 0, 0, 0, 0}, 318.905820, 0.000020, 0.867000},
	{{0, 2, -6, 5, 0, 0, 0, 0, -2, 0, 0}, 208.894210, 0.000020, 0.040000},
	{{0, 2, -6, 5, 0, 0, 0, 0, 0, 0, 0}, 222.985490, 0.000080, 11.046000},
	{{0, 2, -6, 5, 0, 0, 0, 0, 2, 0, 0}, 208.894210, 0.000010, 0.041000},
	{{0, 2, -6, 6, 0, 0, 0, 0, 0, 0, 0}, 56.338190, 0.000020, 2.267000},
	{{0, 2, -6, 8, -3, 0, 0, 0, -2, 0, 0}, 252.168810, 0.000020, 0.043000},
	{{0, 2, -6, 8, -3, 0, 0, 0, 0, 0, 0}, 251.997270, 0.000030, 0.799000},
	{{0, 2, -5, -3, 0, 0, 0, 0, -2, 0, 0}, 355.312640, 0.000010, 0.036000},
	{{0, 2, -5, -3, 0, 0, 0, 0, -2, 1, 0}, 175.312640, 0.000010, 0.067000},
	{{0, 2, -5, -3, 0, 0, 0, 0, -2, 2, 0}, 355.312640, 0.000010, 0.637000},
	{{0, 2, -5, -3, 0, 0, 0, 0, -2, 3, 0}, 175.312640, 0.000010, 0.086000},
	{{0, 2, -5, -2, 0, 0, 0, 0, -2, 0, 0}, 11.108360, 0.000030, 0.036000},
	{{0, 2, -5, -2, 0, 0, 0, 0, -2, 2, 0}, 11.024870, 0.000020, 0.963000},
	{{0, 2, -5, 0, -2, 0, 0, 0, -2, 1, 0}, 341.494810, 0.000070, 0.075000},
	{{0, 2, -5, 0, -1, 0, 0, 0, -2, 0, 0}, 235.789120, 0.000010, 0.038000},
	{{0, 2, -5, 0, -1, 0, 0, 0, -2, 1, 0}, 151.729350, 0.000040, 0.075000},
	{{0, 2, -5, 0, 0, -1, 0, 0, -2, 1, 0}, 233.891100, 0.000030, 0.075000},
	{{0, 2, -5, 0, 0, -1, 0, 0, -2, 2, 0}, 63.365830, 0.000020, 112.558000},
	{{0, 2, -5, 0, 0, 0, -2, 0, -2, 1, 0}, 338.080500, 0.000040, 0.075000},
	{{0, 2, -5, 0, 0, 0, -2, 0, -2, 2, 0}, 175.299490, 0.000110, 793.895000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 116.997220, 0.000020, 0.020000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 67.668580, 0.000020, 0.026000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 68.108320, 0.000040, 0.040000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, -2, 0}, 133.865770, 0.000010, 0.019000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 79.937040, 0.000170, 0.038000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 67.610400, 0.002000, 0.076000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 69.088970, 0.001330, 39.899000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 54.541150, 0.000120, 0.075000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 238.622270, 0.000070, 1.438000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 241.177390, 0.000040, 0.067000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 238.873860, 0.000370, 0.572000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 244.149030, 0.000420, 0.087000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 62.241390, 0.000040, 0.357000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 131.451830, 0.000130, 0.103000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 146.961170, 0.000140, 0.044000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 129.727600, 0.000020, 0.028000},
	{{0, 2, -5, 0, 0, 1, 0, 0, -2, 1, 0}, 48.700030, 0.000030, 0.076000},
	{{0, 2, -5, 0, 1, 0, 0, 0, -2, 1, 0}, 60.006450, 0.000050, 0.076000},
	{{0, 2, -5, 0, 1, 0, 0, 0, -2, 2, 0}, 230.590940, 0.000010, 9.144000},
	{{0, 2, -5, 0, 1, 0, 0, 0, -2, 3, 0}, 121.487780, 0.000010, 0.075000},
	{{0, 2, -5, 0, 2, 0, 0, 0, -2, 1, 0}, 270.714560, 0.000020, 0.077000},
	{{0, 2, -5, 2, 0, 0, 0, 0, 0, 0, 0}, 286.812650, 0.000010, 1.459000},
	{{0, 2, -5, 3, 0, 0, 0, 0, 0, 0, 0}, 187.799060, 0.000050, 6.498000},
	{{0, 2, -5, 4, 0, 0, 0, 0, 0, -1, 0}, 209.597610, 0.000020, 0.078000},
	{{0, 2, -5, 4, 0, 0, 0, 0, 0, 1, 0}, 209.597610, 0.000020, 0.073000},
	{{0, 2, -5, 4, 0, 0, 0, 0, 2, -2, 0}, 29.597610, 0.000010, 0.716000},
	{{0, 2, -5, 4, 0, 0, 0, 0, 2, 0, 0}, 29.597610, 0.000010, 0.040000},
	{{0, 2, -5, 5, 0, 0, 0, 0, 0, 0, 0}, 57.524260, 0.000020, 1.100000},
	{{0, 2, -5, 6, 0, 0, 0, 0, 0, 0, 0}, 86.339470, 0.000010, 0.694000},
	{{0, 2, -4, -2, 0, 0, 0, 0, -2, 1, 0}, 307.206580, 0.000020, 0.075000},
	{{0, 2, -4, -2, 0, 0, 0, 0, -2, 2, 0}, 109.868890, 0.000020, 26.107000},
	{{0, 2, -4, -2, 0, 0, 0, 0, -2, 3, 0}, 307.206580, 0.000020, 0.076000},
	{{0, 2, -4, 0, -2, 0, 0, 0, -2, 0, 0}, 51.841370, 0.000020, 0.039000},
	{{0, 2, -4, 0, -2, 0, 0, 0, -2, 1, 0}, 51.841370, 0.000030, 0.081000},
	{{0, 2, -4, 0, -1, 0, 0, 0, 0, 0, 0}, 237.298180, 0.000010, 1.200000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -4, 0, 0}, 355.591920, 0.000010, 0.020000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -4, 1, 0}, 194.257850, 0.000020, 0.027000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 186.326040, 0.000030, 0.026000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 195.598470, 0.000270, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 0, 2}, 193.070080, 0.000020, 0.736000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 325.831010, 0.000330, 0.082000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 349.183190, 0.000040, 0.976000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 187.504470, 0.000020, 0.070000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 158.339370, 0.000040, 0.038000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 350.498900, 0.000040, 0.077000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 293.488410, 0.000020, 0.038000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 157.370630, 0.000530, 0.076000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 359.767090, 0.000070, 3.281000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 352.646150, 0.000560, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, 0}, 155.689340, 0.000150, 7.244000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 350.498900, 0.000040, 0.074000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 2, -1}, 172.553350, 0.000310, 34.842000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 2, 0}, 182.475600, 0.000020, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 3, -1}, 172.502490, 0.000010, 0.076000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 166.441880, 0.000080, 0.037000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 152.778660, 0.000780, 0.071000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 129.371640, 0.004130, 1.335000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 101.161670, 0.000600, 0.080000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 88.760600, 0.000040, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 337.822410, 0.000010, 0.611000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 169.607750, 0.000050, 0.085000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 349.879070, 0.000180, 0.555000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 334.765510, 0.000170, 0.086000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 169.762570, 0.000050, 0.040000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 173.009660, 0.000120, 0.087000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 28.319430, 0.000090, 0.396000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 19.213720, 0.002590, 0.093000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, -2}, 18.116400, 0.000040, 0.350000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 19.008720, 0.002260, 0.042000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 16.500780, 0.000240, 0.027000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 19.142950, 0.000020, 0.020000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 4, -2, 0}, 16.619750, 0.000050, 0.045000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 21.331650, 0.000070, 0.028000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 65.872770, 0.000020, 0.021000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 4, 1, 0}, 191.389510, 0.000010, 0.016000},
	{{0, 2, -4, 0, 1, 0, 0, 0, 0, 0, 0}, 251.130380, 0.000030, 1.505000},
	{{0, 2, -4, 0, 1, 0, 0, 0, 2, 0, 0}, 89.354580, 0.000050, 0.042000},
	{{0, 2, -4, 0, 2, 0, 0, 0, -2, 0, 0}, 179.906810, 0.000030, 0.039000},
	{{0, 2, -4, 0, 2, 0, 0, 0, -2, 1, 0}, 179.906810, 0.000020, 0.083000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 0, -2, 0}, 180.433710, 0.000010, 0.037000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 0, -1, 0}, 179.826510, 0.000020, 0.072000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 0, 0, 0}, 181.319430, 0.000130, 1.723000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 0, 1, 0}, 179.826510, 0.000020, 0.079000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 0, 2, 0}, 180.272600, 0.000010, 0.039000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 2, -1, 0}, 179.849360, 0.000030, 0.092000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 2, 0, 0}, 179.849360, 0.000030, 0.041000},
	{{0, 2, -4, 0, 3, 0, 0, 0, 0, 0, 0}, 174.936350, 0.000020, 2.016000},
	{{0, 2, -4, 1, 0, 0, 0, 0, 0, 0, 0}, 276.844930, 0.000030, 4.603000},
	{{0, 2, -4, 2, 0, 0, 0, 0, -2, 0, 0}, 358.684060, 0.000030, 0.041000},
	{{0, 2, -4, 2, 0, 0, 0, 0, -2, 2, 0}, 356.716620, 0.000010, 0.479000},
	{{0, 2, -4, 2, 0, 0, 0, 0, 0, -1, 0}, 359.103990, 0.000040, 0.077000},
	{{0, 2, -4, 2, 0, 0, 0, 0, 0, 0, 0}, 1.203600, 0.000090, 3.181000},
	{{0, 2, -4, 2, 0, 0, 0, 0, 0, 1, 0}, 359.103990, 0.000040, 0.074000},
	{{0, 2, -4, 2, 0, 0, 0, 0, 2, -2, 0}, 179.456590, 0.000010, 0.685000},
	{{0, 2, -4, 2, 0, 0, 0, 0, 2, 0, 0}, 179.917060, 0.000040, 0.040000},
	{{0, 2, -4, 4, 0, 0, 0, 0, -2, 0, 0}, 57.975690, 0.000010, 0.043000},
	{{0, 2, -4, 4, 0, 0, 0, 0, -2, 2, 0}, 57.975690, 0.000010, 0.317000},
	{{0, 2, -4, 4, 0, 0, 0, 0, 2, -3, 0}, 61.473550, 0.000030, 0.073000},
	{{0, 2, -4, 4, 0, 0, 0, 0, 2, -1, 0}, 61.473550, 0.000030, 0.078000},
	{{0, 2, -3, -4, 0, 0, 0, 0, -2, 1, 0}, 253.088800, 0.000020, 0.075000},
	{{0, 2, -3, -4, 0, 0, 0, 0, -2, 3, 0}, 253.088800, 0.000020, 0.076000},
	{{0, 2, -3, -1, 0, 0, 0, 0, 0, 0, 0}, 286.822920, 0.000010, 3.563000},
	{{0, 2, -3, 0, -3, 0, 0, 0, -2, 0, 0}, 300.944780, 0.000020, 0.040000},
	{{0, 2, -3, 0, -3, 0, 0, 0, -2, 1, 0}, 318.416510, 0.000030, 0.087000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 0, -1, 0}, 231.886550, 0.000040, 0.075000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 0, 0, 0}, 4.963850, 0.000030, 535.690000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 0, 1, 0}, 231.886550, 0.000040, 0.075000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 2, -1, 0}, 318.423740, 0.000030, 0.087000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 2, 0, 0}, 300.919860, 0.000020, 0.040000},
	{{0, 2, -3, 0, -2, 0, 0, 0, 0, 0, 0}, 101.064350, 0.000020, 12.131000},
	{{0, 2, -3, 0, -1, 0, 0, 0, 0, -1, 0}, 301.029220, 0.000030, 0.076000},
	{{0, 2, -3, 0, -1, 0, 0, 0, 0, 0, 0}, 120.079860, 0.000030, 5.997000},
	{{0, 2, -3, 0, -1, 0, 0, 0, 0, 1, 0}, 301.029220, 0.000030, 0.075000},
	{{0, 2, -3, 0, 0, -1, 0, 0, 0, 0, 0}, 356.198400, 0.000010, 4.606000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -6, 1, 0}, 272.100540, 0.000020, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -6, 2, 0}, 271.165870, 0.000030, 0.021000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, -1, 0}, 270.613270, 0.000070, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 271.973850, 0.000530, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 271.617430, 0.001210, 0.028000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 1, 2}, 271.553650, 0.000020, 0.110000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 2, 0}, 271.603140, 0.000820, 0.044000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 3, 0}, 271.135610, 0.000020, 0.106000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, -1, 0}, 271.765330, 0.000010, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 0, 1}, 256.630850, 0.000010, 0.043000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 1, 0}, 90.862460, 0.000050, 0.042000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 1, 1}, 20.608200, 0.000020, 0.098000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -3, 0}, 271.208960, 0.000020, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -2, -2}, 91.816240, 0.000010, 0.013000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -2, 0}, 271.140150, 0.000330, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, -2}, 91.042910, 0.000020, 0.015000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 271.161020, 0.003950, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, 2}, 90.987290, 0.000090, 0.092000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, -2}, 90.574760, 0.000080, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 271.380940, 0.042140, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 256.577670, 0.000030, 0.090000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 2}, 271.584330, 0.000820, 0.424000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, -2}, 91.415250, 0.000140, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, -1}, 257.324780, 0.000010, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 271.566250, 0.061880, 0.089000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 2}, 270.931530, 0.000030, 0.064000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 271.644860, 0.002320, 0.494000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 271.829290, 0.000150, 0.065000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -2, 1}, 256.610860, 0.000020, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -1, -1}, 112.473710, 0.000010, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 90.646960, 0.000150, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 256.624610, 0.000380, 0.084000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 76.780700, 0.000120, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 90.628550, 0.001480, 0.083000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 256.869390, 0.000670, 0.766000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, -1}, 77.865330, 0.000290, 0.081000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, 0}, 91.721010, 0.000170, 0.879000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 256.877020, 0.000130, 0.069000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 2, -1}, 76.640160, 0.000030, 1.030000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 2, 0}, 91.242770, 0.000030, 0.069000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -4, 0}, 267.795380, 0.000010, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 268.023000, 0.000270, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -2, -2}, 89.057040, 0.000030, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 268.688920, 0.004080, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, -2}, 89.161740, 0.000160, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 257.339270, 0.000060, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 268.696480, 0.060300, 0.077000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 76.364310, 0.000020, 2.394000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 2}, 269.828810, 0.000070, 0.072000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 91.748620, 0.000150, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 257.323450, 0.000890, 0.076000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 269.953930, 0.343550, 3.983000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 76.577670, 0.000160, 0.073000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 2}, 90.693800, 0.000210, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, -2}, 262.046510, 0.000120, 0.075000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 256.565240, 0.000330, 11.864000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 268.568750, 0.055400, 0.074000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 2}, 88.793910, 0.000120, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, -2}, 79.077920, 0.000010, 12.126000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, -1}, 257.259060, 0.000020, 0.075000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 268.571880, 0.003780, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, 2}, 89.077110, 0.000030, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 3, 0}, 268.714980, 0.000250, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 4, 0}, 267.530980, 0.000010, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, -1}, 256.579240, 0.000030, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, 1}, 76.595940, 0.000080, 2.131000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 256.576480, 0.000450, 0.071000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 266.530070, 0.000060, 1.572000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 76.653230, 0.001180, 0.078000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 256.564540, 0.003970, 1.246000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 119.922420, 0.000080, 0.079000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 77.129050, 0.000830, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 256.481230, 0.000560, 0.080000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 87.545290, 0.000020, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 1, 1}, 76.992480, 0.000070, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 2, -1}, 256.578750, 0.000030, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 2, 0}, 270.517200, 0.000010, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 271.300190, 0.000040, 0.068000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 272.137490, 0.001060, 0.657000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -2, 2}, 90.667800, 0.000010, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 271.018200, 0.034510, 0.085000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, 2}, 91.215510, 0.000070, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 269.815140, 0.000580, 0.539000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 77.464820, 0.000220, 0.086000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 269.986470, 0.021720, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, 2}, 90.326060, 0.000050, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, -2}, 90.238460, 0.000070, 0.088000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, -1}, 77.324780, 0.000010, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 269.383620, 0.002130, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 269.711750, 0.000210, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, -3, -1}, 76.636050, 0.000020, 0.063000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, -2, 1}, 69.652210, 0.000010, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, -1, 0}, 90.146570, 0.000020, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, 0, -1}, 256.643680, 0.000010, 0.042000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, 0, 0}, 270.041780, 0.000030, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -3, 0}, 273.674810, 0.000010, 0.100000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -2, 0}, 268.558720, 0.000370, 0.043000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -1, -2}, 270.409410, 0.000010, 0.104000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 268.275150, 0.000570, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 0, -2}, 270.517200, 0.000030, 0.044000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 267.538740, 0.000220, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 1, 0}, 271.365020, 0.000050, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 5, -2, 0}, 270.146580, 0.000010, 0.028000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 6, -2, 0}, 275.208950, 0.000010, 0.021000},
	{{0, 2, -3, 0, 0, 1, 0, 0, 0, -1, 0}, 179.783680, 0.000010, 0.077000},
	{{0, 2, -3, 0, 0, 1, 0, 0, 0, 0, 0}, 359.739860, 0.000010, 3.509000},
	{{0, 2, -3, 0, 0, 1, 0, 0, 0, 1, 0}, 179.783680, 0.000010, 0.074000},
	{{0, 2, -3, 0, 0, 2, 0, 0, 0, 0, 0}, 93.561810, 0.000010, 3.135000},
	{{0, 2, -3, 0, 1, 0, 0, 0, -2, 0, 0}, 175.482050, 0.000090, 0.041000},
	{{0, 2, -3, 0, 1, 0, 0, 0, -2, 1, 0}, 3.029820, 0.000050, 0.090000},
	{{0, 2, -3, 0, 1, 0, 0, 0, -2, 2, 0}, 358.646630, 0.000010, 0.474000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 0, 0}, 359.255510, 0.000280, 2.982000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 1, -2}, 181.356040, 0.000030, 0.075000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 2, -2}, 134.651510, 0.000090, 544.385000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 2, 0}, 178.717380, 0.000020, 0.037000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 2, -1, 0}, 358.560510, 0.000030, 0.085000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 177.271930, 0.000010, 0.040000},
	{{0, 2, -3, 0, 2, 0, 0, 0, -2, 0, 0}, 51.451150, 0.000030, 0.041000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 0, 0, 0}, 55.782230, 0.000050, 2.383000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 2, -2, 0}, 60.194910, 0.000030, 0.738000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 2, -1, 0}, 60.309830, 0.000060, 0.084000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 2, 0, 0}, 60.194910, 0.000030, 0.040000},
	{{0, 2, -3, 0, 3, 0, 0, 0, 0, 0, 0}, 65.492880, 0.000020, 1.984000},
	{{0, 2, -3, 1, 0, 0, 0, 0, 0, 0, 0}, 359.269140, 0.000020, 1.278000},
	{{0, 2, -3, 2, 0, 0, 0, 0, -2, 0, 0}, 40.174710, 0.000010, 0.043000},
	{{0, 2, -3, 2, 0, 0, 0, 0, -2, 1, 0}, 40.510860, 0.000010, 0.098000},
	{{0, 2, -3, 2, 0, 0, 0, 0, -2, 2, 0}, 40.236630, 0.000030, 0.324000},
	{{0, 2, -3, 2, 0, 0, 0, 0, -2, 3, 0}, 40.510860, 0.000010, 0.061000},
	{{0, 2, -3, 2, 0, 0, 0, 0, 0, 0, 0}, 256.271720, 0.000020, 0.761000},
	{{0, 2, -3, 2, 0, 0, 0, 0, 2, -2, 0}, 44.719050, 0.000030, 2.176000},
	{{0, 2, -3, 2, 0, 0, 0, 0, 2, 0, 0}, 45.367310, 0.000020, 0.038000},
	{{0, 2, -3, 3, 0, 0, 0, 0, 2, -3, 0}, 237.604050, 0.000030, 0.076000},
	{{0, 2, -3, 3, 0, 0, 0, 0, 2, -2, 0}, 236.879090, 0.000010, 13.873000},
	{{0, 2, -3, 3, 0, 0, 0, 0, 2, -1, 0}, 231.221380, 0.000050, 0.075000},
	{{0, 2, -3, 3, 0, 0, 0, 0, 2, 0, 0}, 236.879090, 0.000010, 0.038000},
	{{0, 2, -2, -2, 0, 0, 0, 0, 0, -1, 0}, 47.368060, 0.000010, 0.077000},
	{{0, 2, -2, -2, 0, 0, 0, 0, 0, 0, 0}, 151.689150, 0.000010, 5.328000},
	{{0, 2, -2, -2, 0, 0, 0, 0, 0, 1, 0}, 47.368060, 0.000010, 0.074000},
	{{0, 2, -2, -1, 0, 0, 0, 0, 1, -3, 1}, 166.282350, 0.000010, 0.075000},
	{{0, 2, -2, -1, 0, 0, 0, 0, 1, -2, 1}, 166.282350, 0.000270, 1124.126000},
	{{0, 2, -2, -1, 0, 0, 0, 0, 1, -1, 1}, 166.282350, 0.000010, 0.075000},
	{{0, 2, -2, 0, -2, 0, 0, 0, -2, 0, 0}, 205.439510, 0.000010, 0.042000},
	{{0, 2, -2, 0, -2, 0, 0, 0, 0, 0, 0}, 341.340300, 0.000010, 0.924000},
	{{0, 2, -2, 0, -2, 0, 0, 0, 1, 0, -1}, 175.320190, 0.000010, 34.878000},
	{{0, 2, -2, 0, -1, 0, 0, 0, -2, 0, 0}, 224.931970, 0.000090, 0.042000},
	{{0, 2, -2, 0, -1, 0, 0, 0, -2, 1, 0}, 12.460780, 0.000030, 0.097000},
	{{0, 2, -2, 0, -1, 0, 0, 0, -2, 2, 0}, 9.796770, 0.000040, 0.340000},
	{{0, 2, -2, 0, -1, 0, 0, 0, -2, 3, 0}, 192.042370, 0.000020, 0.062000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 0, -2, 0}, 193.056320, 0.000010, 0.039000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 0, -1, 0}, 11.569310, 0.000010, 0.083000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 0, 0, 0}, 86.450170, 0.000020, 0.857000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 0, 1, 0}, 11.569310, 0.000010, 0.069000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 1, 0, -1}, 76.961450, 0.000020, 8.852000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 2, -2, 0}, 193.996210, 0.000010, 1.647000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 2, -1, 0}, 192.205450, 0.000050, 0.079000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 2, 0, 0}, 191.765440, 0.000060, 0.039000},
	{{0, 2, -2, 0, 0, -1, 0, 0, 0, 0, 0}, 270.412060, 0.000010, 0.822000},
	{{0, 2, -2, 0, 0, -1, 0, 0, 2, -1, 0}, 92.482940, 0.000030, 0.079000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -6, 0, 0}, 359.927160, 0.000030, 0.014000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -6, 1, 0}, 0.439300, 0.000030, 0.017000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -6, 2, 0}, 0.540230, 0.000070, 0.022000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -6, 3, 0}, 0.367630, 0.000020, 0.030000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -5, 2, 0}, 180.403730, 0.000010, 0.029000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, -2, 0}, 359.900940, 0.000030, 0.013000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, -1, 0}, 359.430530, 0.000200, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, -1, 2}, 0.308380, 0.000010, 0.029000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 0, -2}, 180.323430, 0.000010, 0.013000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 0, 0}, 0.707390, 0.001480, 0.021000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 0, 2}, 0.281340, 0.000050, 0.047000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 1, -2}, 180.304970, 0.000010, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 1, 0}, 0.582060, 0.003460, 0.029000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 1, 2}, 0.368110, 0.000020, 0.123000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 2, 0}, 0.490960, 0.002130, 0.046000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 3, 0}, 0.480420, 0.000050, 0.118000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, -1, 0}, 0.434440, 0.000040, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, 0, 0}, 1.209650, 0.000040, 0.028000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, 1, 0}, 180.305910, 0.000220, 0.044000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, 2, 0}, 180.433210, 0.000080, 0.107000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -3, 0}, 0.290290, 0.000080, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 0.284590, 0.000840, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -2, 2}, 180.324760, 0.000010, 0.043000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -1, -2}, 180.292380, 0.000070, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 0.446800, 0.011200, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -1, 2}, 180.300060, 0.000240, 0.101000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, -2}, 180.302780, 0.000320, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 0.366590, 0.134320, 0.043000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 2}, 0.350100, 0.001540, 0.298000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, -2}, 180.304590, 0.000370, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 0.311770, 0.160900, 0.098000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, 2}, 180.291560, 0.000080, 0.060000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, -2}, 180.299000, 0.000030, 0.042000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 0.227640, 0.007040, 0.331000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, 2}, 180.283260, 0.000030, 0.033000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 3, 0}, 0.232370, 0.000540, 0.061000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 4, 0}, 0.221170, 0.000050, 0.034000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, -2, 0}, 180.607660, 0.000020, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, -1, 0}, 180.119850, 0.000220, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, -1, 1}, 185.454640, 0.000030, 0.091000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 188.365370, 0.000110, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 180.064280, 0.002760, 0.090000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 3.668320, 0.000200, 0.434000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 11.977360, 0.000030, 0.089000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 1, 0}, 180.103360, 0.000290, 0.468000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 2, 0}, 179.933860, 0.000030, 0.065000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -3, 0}, 0.296780, 0.000250, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, -2}, 180.234180, 0.000030, 0.019000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 0.486000, 0.003760, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, -2}, 180.354760, 0.000130, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 0.398520, 0.056350, 0.083000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, 2}, 180.339850, 0.000090, 0.067000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, -2}, 359.053210, 0.000030, 0.039000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 0.204480, 0.301550, 0.799000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 2}, 180.186610, 0.000140, 0.036000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 1, -2}, 358.826260, 0.000040, 0.081000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 0.156810, 0.050710, 0.069000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 1, 2}, 180.214080, 0.000140, 0.024000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 0.077100, 0.003530, 0.036000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 2, 2}, 180.192590, 0.000020, 0.018000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 3, -2}, 179.741520, 0.000020, 0.071000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 3, 0}, 0.227090, 0.000230, 0.024000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -2, -1}, 187.482860, 0.000040, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, -2}, 359.989470, 0.000020, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 187.482860, 0.000520, 0.077000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 0.067300, 0.000280, 2.747000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 5.543640, 0.000190, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, -2}, 359.988720, 0.000360, 0.076000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 185.612330, 0.003340, 5.069000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 0.059690, 0.002020, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 5.871580, 0.000360, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -2}, 359.971780, 0.000270, 32.762000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 187.482860, 0.000520, 0.074000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, 0}, 359.850650, 0.000090, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, 1}, 5.894570, 0.000040, 0.025000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 2, -2}, 0.011470, 0.000040, 0.075000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 2, -1}, 187.482860, 0.000040, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -4, 0}, 0.735610, 0.000030, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 0.880370, 0.000360, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, -2}, 179.873970, 0.000020, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 359.828620, 0.005590, 1.912000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, 2}, 180.112980, 0.000020, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, -2}, 0.075430, 0.000120, 0.071000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 359.997620, 0.135930, 0.079000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, 2}, 180.014410, 0.000290, 0.025000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, -2}, 359.992900, 0.002230, 1.168000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 359.986670, 0.035530, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, 2}, 180.084150, 0.000130, 0.019000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 1, -2}, 179.868820, 0.000110, 0.081000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 0.008620, 0.003250, 0.025000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 1, 2}, 180.082300, 0.000010, 0.015000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 2, -2}, 179.976570, 0.000020, 0.039000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 2, 0}, 0.128320, 0.000310, 0.019000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 3, 0}, 0.061980, 0.000020, 0.015000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, -2, 0}, 180.031520, 0.000040, 0.084000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, -1, -1}, 11.977360, 0.000030, 0.086000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, -1, 0}, 180.032730, 0.000060, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, 0, -2}, 179.989470, 0.000070, 0.087000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, 0, -1}, 185.391250, 0.000020, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, 0, 0}, 0.006270, 0.000040, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -3, 0}, 358.608560, 0.000050, 0.091000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 0.058940, 0.001810, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -1, -2}, 359.893290, 0.000020, 0.094000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -1, 0}, 0.016080, 0.001720, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, 0, 0}, 359.999540, 0.000490, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, 1, 0}, 0.055590, 0.000070, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 5, -3, 0}, 359.994370, 0.000010, 0.043000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 6, -3, 0}, 0.046850, 0.000020, 0.028000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 6, -2, 0}, 0.041200, 0.000040, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 6, -1, 0}, 0.010760, 0.000050, 0.016000},
	{{0, 2, -2, 0, 0, 1, 0, 0, 2, -1, 0}, 87.677540, 0.000030, 0.078000},
	{{0, 2, -2, 0, 1, 0, 0, 0, -2, 0, 0}, 346.480100, 0.000060, 0.043000},
	{{0, 2, -2, 0, 1, 0, 0, 0, -2, 1, 0}, 171.904570, 0.000040, 0.099000},
	{{0, 2, -2, 0, 1, 0, 0, 0, -2, 3, 0}, 352.220660, 0.000030, 0.061000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 0, 0, 0}, 212.183120, 0.000020, 0.749000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 2, -2, 0}, 349.581330, 0.000010, 2.280000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 2, -1, 0}, 336.378060, 0.000070, 0.078000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 2, 0, 0}, 316.887510, 0.000050, 0.038000},
	{{0, 2, -2, 0, 2, 0, 0, 0, 0, 0, 0}, 7.310720, 0.000010, 0.704000},
	{{0, 2, -2, 1, 0, 0, 0, 0, 2, -3, 0}, 226.019310, 0.000020, 0.075000},
	{{0, 2, -2, 1, 0, 0, 0, 0, 2, -2, 0}, 358.897530, 0.000030, 114.769000},
	{{0, 2, -2, 1, 0, 0, 0, 0, 2, -1, 0}, 226.019310, 0.000020, 0.075000},
	{{0, 2, -1, -4, 0, 0, 0, 0, 0, 0, 0}, 161.416330, 0.000010, 8.045000},
	{{0, 2, -1, -3, 0, 0, 0, 0, -2, 0, 0}, 303.120270, 0.000020, 0.042000},
	{{0, 2, -1, -3, 0, 0, 0, 0, -2, 2, 0}, 303.120270, 0.000020, 0.412000},
	{{0, 2, -1, -3, 0, 0, 0, 0, 0, -1, 0}, 303.120270, 0.000010, 0.079000},
	{{0, 2, -1, -3, 0, 0, 0, 0, 0, 1, 0}, 303.120270, 0.000010, 0.072000},
	{{0, 2, -1, -3, 0, 0, 0, 0, 2, -3, 0}, 303.564920, 0.000020, 0.070000},
	{{0, 2, -1, -3, 0, 0, 0, 0, 2, -2, 0}, 303.564920, 0.000020, 0.894000},
	{{0, 2, -1, -3, 0, 0, 0, 0, 2, -1, 0}, 303.564920, 0.000020, 0.082000},
	{{0, 2, -1, -3, 0, 0, 0, 0, 2, 0, 0}, 303.564920, 0.000020, 0.039000},
	{{0, 2, -1, -2, 0, 0, 0, 0, -2, 0, 0}, 127.733290, 0.000030, 0.042000},
	{{0, 2, -1, -2, 0, 0, 0, 0, -2, 2, 0}, 135.098890, 0.000040, 0.338000},
	{{0, 2, -1, -2, 0, 0, 0, 0, 0, 0, 0}, 355.008340, 0.000010, 0.842000},
	{{0, 2, -1, -2, 0, 0, 0, 0, 2, -2, 0}, 139.612800, 0.000030, 1.706000},
	{{0, 2, -1, -2, 0, 0, 0, 0, 2, 0, 0}, 139.690310, 0.000020, 0.039000},
	{{0, 2, -1, -1, 0, 0, 0, 0, 2, -3, 0}, 93.391660, 0.000010, 0.075000},
	{{0, 2, -1, -1, 0, 0, 0, 0, 2, -1, 0}, 273.391660, 0.000010, 0.076000},
	{{0, 2, -1, 0, -3, 0, 0, 0, 0, 0, 0}, 129.634780, 0.000010, 0.500000},
	{{0, 2, -1, 0, -2, 0, 0, 0, -2, 0, 0}, 116.198930, 0.000060, 0.044000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 0, 0, 0}, 292.329480, 0.000040, 0.480000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 2, -3, 0}, 321.186150, 0.000020, 0.077000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 2, -1, 0}, 141.439730, 0.000050, 0.074000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 2, 0, -2}, 170.199840, 0.000040, 39.852000},
	{{0, 2, -1, 0, -1, 0, 0, 0, -2, 0, 0}, 2.536580, 0.000030, 0.044000},
	{{0, 2, -1, 0, -1, 0, 0, 0, -2, 1, 0}, 181.350980, 0.000100, 0.107000},
	{{0, 2, -1, 0, -1, 0, 0, 0, -2, 2, 0}, 178.732040, 0.000010, 0.254000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 0, -2, 0}, 185.135210, 0.000010, 0.041000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 0, 0, 0}, 176.705310, 0.000060, 0.462000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 0, 1, 0}, 181.468640, 0.000040, 0.065000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, -2, 0}, 182.478680, 0.000020, 2.546000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, -1, 0}, 177.548320, 0.000160, 0.073000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, 0, -2}, 183.040030, 0.000050, 16.889000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, 0, 0}, 4.042200, 0.000090, 0.037000},
	{{0, 2, -1, 0, 0, -1, 0, 0, -2, 0, 0}, 180.215670, 0.000010, 0.044000},
	{{0, 2, -1, 0, 0, -1, 0, 0, -2, 2, 0}, 0.215670, 0.000010, 0.251000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -6, 1, 0}, 257.359260, 0.000010, 0.017000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, -1, 0}, 257.079480, 0.000060, 0.017000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 256.119090, 0.000190, 0.021000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 1, 0}, 257.067240, 0.000500, 0.029000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 2, 0}, 256.519300, 0.000230, 0.048000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 3, 0}, 249.927830, 0.000010, 0.134000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 0, 0}, 257.533160, 0.000020, 0.029000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 0, 1}, 103.126760, 0.000020, 0.047000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 1, -1}, 103.228160, 0.000010, 0.029000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 1, 0}, 76.664890, 0.000020, 0.046000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 1, 1}, 103.298200, 0.000010, 0.122000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -2, 0}, 257.148300, 0.000110, 0.020000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 257.054770, 0.001200, 0.028000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -1, 2}, 77.386360, 0.000020, 0.112000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, -2}, 77.017520, 0.000030, 0.020000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 257.092350, 0.013450, 0.044000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 2}, 257.570550, 0.000100, 0.229000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, -2}, 77.117500, 0.000010, 0.028000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 257.140130, 0.012030, 0.108000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, 2}, 77.257410, 0.000030, 0.057000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 258.447660, 0.000540, 0.248000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 254.192940, 0.000030, 0.058000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, -1, -1}, 103.206450, 0.000040, 0.027000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, -1, 1}, 283.566450, 0.000100, 0.100000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 103.223770, 0.000550, 0.042000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 283.220030, 0.001320, 0.303000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, -1}, 101.848420, 0.000330, 0.097000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, 0}, 77.330030, 0.000010, 0.319000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, 1}, 283.212350, 0.000130, 0.060000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -2, 0}, 256.629160, 0.000190, 0.041000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 257.055100, 0.002620, 0.091000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, -2}, 77.268350, 0.000010, 0.041000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, -1}, 283.330200, 0.000010, 0.090000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 252.157700, 0.008730, 0.444000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, 1}, 103.329450, 0.000030, 0.064000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 253.845660, 0.001470, 0.064000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 2, 0}, 253.196340, 0.000100, 0.035000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -2, -1}, 103.288960, 0.000040, 0.040000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -2, 1}, 283.316930, 0.000020, 0.653000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 103.292620, 0.000730, 0.083000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, 0}, 77.212890, 0.000010, 0.733000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, 1}, 283.294450, 0.000490, 0.068000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 103.304000, 0.004420, 0.835000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 276.744600, 0.000050, 0.068000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 283.296100, 0.000490, 0.036000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 1, -1}, 103.457920, 0.000560, 0.069000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 1, 1}, 283.304650, 0.000050, 0.024000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 2, -1}, 103.358380, 0.000030, 0.036000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 261.491900, 0.000070, 0.078000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 256.298790, 0.000150, 2.096000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -1, -1}, 286.586740, 0.000030, 3.223000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 243.585890, 0.002000, 0.073000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, -2}, 246.096590, 0.000200, 6.968000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 283.337960, 0.000240, 0.074000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 71.021650, 0.000130, 0.037000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, -2, -1}, 283.311340, 0.000030, 1.734000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, -1, -1}, 283.326790, 0.000230, 0.079000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, 0, -1}, 103.303630, 0.000050, 0.039000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 4, -2, 0}, 205.667460, 0.000010, 0.040000},
	{{0, 2, -1, 0, 1, 0, 0, 0, 2, -3, 0}, 75.750720, 0.000010, 0.079000},
	{{0, 2, -1, 0, 1, 0, 0, 0, 2, -1, 0}, 255.750720, 0.000010, 0.072000},
	{{0, 2, 0, -6, 0, 0, 0, 0, 0, 0, 0}, 68.540100, 0.000020, 16.410000},
	{{0, 2, 0, -5, 0, 0, 0, 0, 0, 0, 0}, 110.674640, 0.000010, 1.687000},
	{{0, 2, 0, -3, 0, 0, 0, 0, 2, -3, 0}, 231.641300, 0.000020, 0.075000},
	{{0, 2, 0, -3, 0, 0, 0, 0, 2, -2, 0}, 151.779090, 0.000020, 8.473000},
	{{0, 2, 0, -3, 0, 0, 0, 0, 2, -1, 0}, 254.837560, 0.000040, 0.076000},
	{{0, 2, 0, -2, 0, 0, 0, 0, -2, 0, 0}, 359.780270, 0.000030, 0.044000},
	{{0, 2, 0, -2, 0, 0, 0, 0, -2, 1, 0}, 179.894190, 0.000030, 0.108000},
	{{0, 2, 0, -2, 0, 0, 0, 0, -2, 3, 0}, 179.894190, 0.000020, 0.058000},
	{{0, 2, 0, -2, 0, 0, 0, 0, 0, -2, 0}, 179.894190, 0.000010, 0.041000},
	{{0, 2, 0, -2, 0, 0, 0, 0, 0, -1, 0}, 179.894190, 0.000010, 0.090000},
	{{0, 2, 0, -2, 0, 0, 0, 0, 0, 0, 0}, 179.894190, 0.000010, 0.457000},
	{{0, 2, 0, -2, 0, 0, 0, 0, 0, 1, 0}, 179.894190, 0.000010, 0.065000},
	{{0, 2, 0, -2, 0, 0, 0, 0, 2, -3, 0}, 167.160480, 0.000010, 0.078000},
	{{0, 2, 0, -2, 0, 0, 0, 0, 2, -1, 0}, 167.160480, 0.000010, 0.073000},
	{{0, 2, 0, 0, -3, 0, 0, 0, -2, 0, 0}, 8.937600, 0.000040, 0.046000},
	{{0, 2, 0, 0, -3, 0, 0, 0, -2, 2, 0}, 9.133430, 0.000010, 0.210000},
	{{0, 2, 0, 0, -3, 0, 0, 0, 0, 0, 0}, 190.886330, 0.000010, 0.334000},
	{{0, 2, 0, 0, -2, 0, 0, 0, -2, 0, 0}, 179.954000, 0.000020, 0.046000},
	{{0, 2, 0, 0, -2, 0, 0, 0, -2, 1, 0}, 0.116390, 0.000110, 0.119000},
	{{0, 2, 0, 0, -2, 0, 0, 0, -2, 2, 0}, 0.307150, 0.000010, 0.206000},
	{{0, 2, 0, 0, -2, 0, 0, 0, -2, 3, 0}, 0.063450, 0.000020, 0.055000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 0, -2, 0}, 0.061780, 0.000020, 0.043000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 0, -1, 0}, 0.105740, 0.000010, 0.098000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 0, 0, 0}, 0.009060, 0.000090, 0.324000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 0, 1, 0}, 0.105740, 0.000010, 0.061000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 2, -3, 0}, 0.093650, 0.000010, 0.084000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 2, -2, 0}, 180.056240, 0.000020, 0.764000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 2, -1, 0}, 180.093650, 0.000010, 0.069000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 2, 0, 0}, 0.093650, 0.000010, 0.036000},
	{{0, 2, 0, 0, -1, 0, 0, 0, -2, 0, 0}, 90.689730, 0.000020, 0.046000},
	{{0, 2, 0, 0, -1, 0, 0, 0, -2, 2, 0}, 90.569560, 0.000030, 0.202000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -4, 0, 0}, 3.406890, 0.000010, 0.022000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -4, 1, 0}, 124.842870, 0.000020, 0.030000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, -1, 0}, 140.707890, 0.000090, 0.029000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 126.544300, 0.000670, 0.047000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 126.237580, 0.000490, 0.121000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 67.417300, 0.000020, 0.199000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -1, 0, -1}, 9.197110, 0.000030, 0.044000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 204.976580, 0.000040, 0.110000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -1, 0, 1}, 190.306290, 0.000060, 0.232000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -1, 1, -1}, 9.197110, 0.000010, 0.108000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, -2, 0}, 23.304620, 0.000020, 0.043000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 43.603430, 0.000200, 0.100000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 31.139410, 0.002040, 0.308000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 30.175020, 0.000210, 0.061000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 110.153530, 0.000010, 0.034000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 13.529170, 0.000090, 0.455000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 205.528840, 0.000030, 0.064000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 118.527800, 0.000020, 0.085000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 3.411740, 0.000010, 0.677000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 29.102680, 0.000390, 0.068000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 205.173070, 0.000080, 0.036000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 208.639980, 0.000010, 0.024000},
	{{0, 2, 0, 0, 2, 0, 0, 0, 2, -2, 0}, 308.159090, 0.000010, 0.608000},
	{{0, 2, 0, 0, 2, 0, 0, 0, 2, 0, 0}, 128.556610, 0.000020, 0.036000},
	{{0, 2, 1, -8, 0, 0, 0, 0, -2, 0, 0}, 19.932670, 0.000050, 0.040000},
	{{0, 2, 1, -8, 0, 0, 0, 0, -2, 1, 0}, 19.932670, 0.000090, 0.087000},
	{{0, 2, 1, -8, 0, 0, 0, 0, 0, -1, 0}, 24.299530, 0.000020, 0.075000},
	{{0, 2, 1, -8, 0, 0, 0, 0, 0, 0, 0}, 0.533090, 0.000120, 411.948000},
	{{0, 2, 1, -8, 0, 0, 0, 0, 0, 1, 0}, 24.299530, 0.000020, 0.075000},
	{{0, 2, 1, -8, 0, 0, 0, 0, 2, -1, 0}, 20.002150, 0.000090, 0.087000},
	{{0, 2, 1, -8, 0, 0, 0, 0, 2, 0, 0}, 20.002150, 0.000050, 0.040000},
	{{0, 2, 1, -5, 0, 0, 0, 0, 0, 0, 0}, 120.844940, 0.000020, 0.628000},
	{{0, 2, 1, -5, 0, 0, 0, 0, 2, -3, 0}, 121.538240, 0.000010, 0.074000},
	{{0, 2, 1, -5, 0, 0, 0, 0, 2, -1, 0}, 121.538240, 0.000010, 0.076000},
	{{0, 2, 1, -4, 0, 0, 0, 0, -2, 0, 0}, 150.582570, 0.000010, 0.044000},
	{{0, 2, 1, -4, 0, 0, 0, 0, -2, 2, 0}, 150.401740, 0.000020, 0.257000},
	{{0, 2, 1, 0, -2, 0, 0, 0, -2, 0, 0}, 269.208180, 0.000020, 0.048000},
	{{0, 2, 1, 0, -2, 0, 0, 0, -2, 2, 0}, 89.208180, 0.000020, 0.171000},
	{{0, 2, 1, 0, -1, 0, 0, 0, 0, 0, 0}, 18.297310, 0.000010, 0.240000},
	{{0, 2, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 334.013960, 0.000060, 0.049000},
	{{0, 2, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 341.303690, 0.000030, 0.138000},
	{{0, 2, 1, 0, 0, 0, 0, 0, -1, 0, 1}, 123.547570, 0.000020, 0.189000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 288.812410, 0.000040, 0.111000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 295.541790, 0.000130, 0.235000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 288.181730, 0.000020, 0.057000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 306.204540, 0.000020, 0.313000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 274.631270, 0.000030, 0.064000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 113.346980, 0.000020, 0.034000},
	{{0, 2, 1, 0, 1, 0, 0, 0, 2, -3, 0}, 128.364040, 0.000040, 0.094000},
	{{0, 2, 1, 0, 1, 0, 0, 0, 2, -2, 0}, 126.860500, 0.000010, 0.390000},
	{{0, 2, 1, 0, 1, 0, 0, 0, 2, -1, 0}, 304.484710, 0.000020, 0.063000},
	{{0, 2, 1, 0, 1, 0, 0, 0, 2, 0, 0}, 128.236770, 0.000070, 0.034000},
	{{0, 2, 1, 2, 0, 0, 0, 0, 2, 0, 0}, 168.895380, 0.000010, 0.033000},
	{{0, 2, 2, -10, 0, 0, 0, 0, 0, 0, 0}, 65.153930, 0.000010, 15.199000},
	{{0, 2, 2, -8, 0, 0, 0, 0, 0, 0, 0}, 60.622840, 0.000020, 1.002000},
	{{0, 2, 2, -8, 3, 0, 0, 0, -2, 0, 0}, 288.338520, 0.000020, 0.043000},
	{{0, 2, 2, -8, 3, 0, 0, 0, 0, 0, 0}, 288.166520, 0.000030, 0.800000},
	{{0, 2, 2, -7, 0, 0, 0, 0, 0, 0, 0}, 92.673900, 0.000010, 0.654000},
	{{0, 2, 2, 0, -4, 0, 0, 0, 0, 0, 0}, 174.029420, 0.000010, 0.204000},
	{{0, 2, 2, 0, -2, 0, 0, 0, 2, -2, 0}, 335.389470, 0.000010, 0.302000},
	{{0, 2, 2, 0, -2, 0, 0, 0, 2, 0, 0}, 335.389470, 0.000010, 0.034000},
	{{0, 2, 2, 0, -1, 0, 0, 0, 2, -3, 0}, 141.308600, 0.000020, 0.101000},
	{{0, 2, 2, 0, -1, 0, 0, 0, 2, -2, 0}, 220.486470, 0.000010, 0.295000},
	{{0, 2, 2, 0, -1, 0, 0, 0, 2, -1, 0}, 141.308600, 0.000020, 0.060000},
	{{0, 2, 2, 0, -1, 0, 0, 0, 2, 0, 0}, 155.317460, 0.000060, 0.033000},
	{{0, 2, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 131.037270, 0.000020, 0.051000},
	{{0, 2, 2, 0, 0, 0, 0, 0, -2, 1, 0}, 308.243910, 0.000010, 0.160000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 128.243910, 0.000060, 0.125000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 221.306900, 0.000030, 0.190000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 128.243910, 0.000040, 0.054000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, 2, 0}, 307.238950, 0.000020, 0.031000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 126.070980, 0.000060, 0.288000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 127.608220, 0.000040, 0.060000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 127.479030, 0.000110, 0.033000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 1, 0}, 128.299550, 0.000020, 0.023000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 2, 0}, 128.243910, 0.000060, 0.018000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 4, -2, 0}, 306.070980, 0.000010, 0.035000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 4, -1, 0}, 128.200130, 0.000010, 0.024000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 4, 0, 0}, 308.243910, 0.000010, 0.018000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 4, 1, 0}, 308.200130, 0.000010, 0.015000},
	{{0, 2, 2, 0, 1, 0, 0, 0, 2, 0, 0}, 300.376620, 0.000040, 0.033000},
	{{0, 2, 3, -3, 0, 0, 0, 0, 2, -2, 0}, 251.372550, 0.000010, 0.347000},
	{{0, 2, 3, -3, 0, 0, 0, 0, 2, 0, 0}, 251.372550, 0.000010, 0.034000},
	{{0, 2, 3, -2, 0, 0, 0, 0, 2, -2, 0}, 84.581080, 0.000020, 0.293000},
	{{0, 2, 3, -2, 0, 0, 0, 0, 2, 0, 0}, 84.581080, 0.000020, 0.033000},
	{{0, 2, 3, 0, -2, 0, 0, 0, 2, 0, 0}, 40.271820, 0.000010, 0.032000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 0, -1, 0}, 309.480820, 0.000020, 0.141000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 0, 0, 0}, 129.531340, 0.000030, 0.162000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 2, -2, 0}, 128.783110, 0.000020, 0.228000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 2, -1, 0}, 129.486890, 0.000090, 0.057000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 2, 0, 0}, 129.480820, 0.000050, 0.032000},
	{{0, 2, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 302.097990, 0.000030, 0.054000},
	{{0, 2, 3, 0, 0, 0, 0, 0, -2, 2, 0}, 302.096650, 0.000040, 0.125000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, -2, 0}, 122.071280, 0.000010, 0.049000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 209.692250, 0.000030, 0.143000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 17.798550, 0.000020, 0.160000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 209.692250, 0.000030, 0.051000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, 2, 0}, 25.103370, 0.000020, 0.031000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 193.383440, 0.000010, 0.032000},
	{{0, 2, 4, -2, 0, 0, 0, 0, 2, -3, 0}, 308.146470, 0.000010, 0.113000},
	{{0, 2, 4, -2, 0, 0, 0, 0, 2, -2, 0}, 308.229660, 0.000050, 0.227000},
	{{0, 2, 4, -2, 0, 0, 0, 0, 2, -1, 0}, 308.178090, 0.000020, 0.057000},
	{{0, 2, 4, -2, 0, 0, 0, 0, 2, 0, 0}, 308.205450, 0.000060, 0.032000},
	{{0, 2, 4, 0, -3, 0, 0, 0, 2, 0, 0}, 318.109300, 0.000030, 0.032000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 0, 0, 0}, 308.379640, 0.000020, 0.141000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, -3, 0}, 128.358030, 0.000020, 0.126000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, -2, 0}, 308.314380, 0.000020, 0.188000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, -1, 0}, 128.358030, 0.000020, 0.054000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, 0, 0}, 308.331810, 0.000060, 0.031000},
	{{0, 2, 4, 0, -1, 0, 0, 0, 2, 0, 0}, 38.644900, 0.000020, 0.031000},
	{{0, 2, 4, 0, 0, 0, 0, 0, 0, -1, 0}, 123.910390, 0.000020, 0.167000},
	{{0, 2, 4, 0, 0, 0, 0, 0, 2, -2, 0}, 324.393070, 0.000010, 0.183000},
	{{0, 2, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 160.470210, 0.000010, 0.031000},
	{{0, 2, 5, 0, 0, 0, 0, 0, 2, 0, 0}, 239.015200, 0.000020, 0.030000},
	{{0, 2, 18, -19, 0, 0, 0, 0, -2, -1, 2}, 261.062860, 0.000010, 1216.760000},
	{{0, 2, 21, -26, 0, 0, 0, 0, -3, 1, 1}, 187.912310, 0.000060, 1396.538000},
	{{0, 2, 21, -24, 0, 0, 0, 0, -2, 1, 0}, 205.945380, 0.000010, 112.528000},
	{{0, 2, 27, -28, 0, 0, 0, 0, 2, -1, -2}, 220.771430, 0.000070, 1662.840000},
	{{0, 2, 38, -56, 0, 0, 0, 0, -2, 1, 0}, 77.242430, 0.000020, 199.649000},
	{{0, 3, -15, 23, 0, 0, 0, 0, 2, 0, -2}, 135.343940, 0.000010, 449.647000},
	{{0, 3, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 289.614000, 0.000010, 0.031000},
	{{0, 3, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 121.851740, 0.000020, 0.060000},
	{{0, 3, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 121.851740, 0.000020, 0.101000},
	{{0, 3, -10, 0, 2, 0, 0, 0, -2, 0, 0}, 322.611070, 0.000020, 0.034000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 215.252550, 0.000010, 0.024000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 38.891780, 0.000020, 0.035000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 230.838740, 0.000020, 0.092000},
	{{0, 3, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 246.963050, 0.000020, 0.243000},
	{{0, 3, -9, 0, 1, 0, 0, 0, -2, 1, 0}, 321.437760, 0.000010, 0.064000},
	{{0, 3, -9, 0, 1, 0, 0, 0, -2, 3, 0}, 141.437760, 0.000010, 0.091000},
	{{0, 3, -9, 0, 2, 0, 0, 0, -2, 0, 0}, 231.670570, 0.000030, 0.035000},
	{{0, 3, -9, 0, 2, 0, 0, 0, -2, 1, 0}, 231.599650, 0.000020, 0.065000},
	{{0, 3, -9, 0, 2, 0, 0, 0, -2, 3, 0}, 231.599650, 0.000020, 0.090000},
	{{0, 3, -9, 0, 2, 0, 0, 0, 0, 0, 0}, 231.638570, 0.000020, 0.253000},
	{{0, 3, -9, 0, 3, 0, 0, 0, -2, 0, 0}, 221.887300, 0.000010, 0.035000},
	{{0, 3, -9, 0, 3, 0, 0, 0, -2, 2, 0}, 221.887300, 0.000010, 0.477000},
	{{0, 3, -9, 2, 0, 0, 0, 0, -2, 0, 0}, 231.906970, 0.000020, 0.036000},
	{{0, 3, -9, 2, 0, 0, 0, 0, -2, 1, 0}, 51.906970, 0.000020, 0.069000},
	{{0, 3, -9, 2, 0, 0, 0, 0, -2, 2, 0}, 231.906970, 0.000020, 0.778000},
	{{0, 3, -9, 2, 0, 0, 0, 0, -2, 3, 0}, 51.906970, 0.000020, 0.084000},
	{{0, 3, -9, 4, 0, 0, 0, 0, -2, 1, 0}, 115.331700, 0.000010, 0.074000},
	{{0, 3, -9, 4, 0, 0, 0, 0, -2, 3, 0}, 115.331700, 0.000010, 0.077000},
	{{0, 3, -9, 4, 0, 0, 0, 0, 0, 0, 0}, 351.358350, 0.000010, 0.501000},
	{{0, 3, -9, 4, 0, 0, 0, 0, 2, 0, 0}, 352.373950, 0.000020, 0.044000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 323.997490, 0.000040, 0.024000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 164.959160, 0.000020, 0.036000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 69.792960, 0.000010, 0.068000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 315.505870, 0.000030, 0.741000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 135.667700, 0.000030, 0.084000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 142.817210, 0.000010, 0.034000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 322.817210, 0.000010, 0.061000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 149.076850, 0.000030, 0.320000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 322.817210, 0.000010, 0.099000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 332.321870, 0.000030, 0.120000},
	{{0, 3, -8, 0, 1, 0, 0, 0, -2, -2, 0}, 50.465260, 0.000010, 0.018000},
	{{0, 3, -8, 0, 1, 0, 0, 0, -2, 2, 0}, 51.201830, 0.000020, 0.790000},
	{{0, 3, -8, 0, 1, 0, 0, 0, -2, 3, 0}, 231.201840, 0.000020, 0.083000},
	{{0, 3, -8, 0, 2, 0, 0, 0, -2, 0, 0}, 291.819400, 0.000040, 0.036000},
	{{0, 3, -8, 0, 2, 0, 0, 0, -2, 1, 0}, 111.892110, 0.000050, 0.069000},
	{{0, 3, -8, 0, 2, 0, 0, 0, -2, 3, 0}, 292.298370, 0.000010, 0.083000},
	{{0, 3, -8, 2, 0, 0, 0, 0, -2, 1, 0}, 244.907510, 0.000010, 0.074000},
	{{0, 3, -8, 2, 0, 0, 0, 0, -2, 3, 0}, 244.907510, 0.000010, 0.077000},
	{{0, 3, -8, 3, 0, 0, 0, 0, -2, 0, 0}, 288.624050, 0.000010, 0.038000},
	{{0, 3, -8, 3, 0, 0, 0, 0, -2, 2, 0}, 288.624050, 0.000010, 4.071000},
	{{0, 3, -8, 4, 0, 0, 0, 0, -2, 1, 0}, 69.349420, 0.000030, 0.080000},
	{{0, 3, -8, 4, 0, 0, 0, 0, -2, 2, 0}, 250.765750, 0.000010, 1.286000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 0, -1, 0}, 241.084230, 0.000020, 0.070000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 0, 0, 0}, 248.242620, 0.000400, 1.003000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 0, 1, 0}, 249.198980, 0.000150, 0.082000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, -2, 0}, 249.843050, 0.000010, 0.361000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, -1, 0}, 249.648000, 0.000360, 0.095000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, 0, 0}, 249.987700, 0.000300, 0.042000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, 1, 0}, 249.776440, 0.000030, 0.027000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 4, 0, 0}, 70.009900, 0.000020, 0.021000},
	{{0, 3, -8, 5, 0, 0, 0, 0, 0, 0, 0}, 312.587990, 0.000010, 2.151000},
	{{0, 3, -8, 6, 0, 0, 0, 0, 0, 0, 0}, 210.606930, 0.000050, 14.998000},
	{{0, 3, -8, 8, -3, 0, 0, 0, 0, 0, 0}, 163.062660, 0.000010, 1.140000},
	{{0, 3, -7, 0, -1, 0, 0, 0, -2, 0, 0}, 58.378200, 0.000020, 0.037000},
	{{0, 3, -7, 0, -1, 0, 0, 0, -2, 0, 2}, 61.590350, 0.000030, 9.980000},
	{{0, 3, -7, 0, -1, 0, 0, 0, -2, 1, 0}, 267.246770, 0.000080, 0.073000},
	{{0, 3, -7, 0, -1, 0, 0, 0, -2, 2, 0}, 65.793190, 0.000010, 2.306000},
	{{0, 3, -7, 0, 0, -1, 0, 0, -2, 0, 2}, 324.227910, 0.000010, 20.062000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -4, 0, 0}, 231.788510, 0.000020, 0.019000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, -1, 2}, 50.727770, 0.000030, 0.075000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 52.815970, 0.000070, 0.037000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 0, 2}, 295.919980, 0.000030, 62.897000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 297.142080, 0.000030, 0.074000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 1, 2}, 50.727770, 0.000030, 0.076000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 51.912230, 0.000030, 2.862000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 267.977560, 0.000020, 0.077000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 208.100990, 0.000020, 0.065000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, -1, 2}, 51.788510, 0.000020, 0.087000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 256.420790, 0.000060, 0.471000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 208.100990, 0.000020, 0.090000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 190.934300, 0.000090, 0.107000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 191.809620, 0.000100, 0.044000},
	{{0, 3, -7, 0, 0, 0, 1, 0, -2, 0, 2}, 238.391430, 0.000010, 250.179000},
	{{0, 3, -7, 0, 0, 1, 0, 0, -2, 0, 2}, 319.485020, 0.000010, 55.406000},
	{{0, 3, -7, 0, 0, 1, 0, 0, -2, 1, 0}, 139.426660, 0.000030, 0.074000},
	{{0, 3, -7, 0, 0, 1, 0, 0, -2, 3, 0}, 319.426660, 0.000030, 0.077000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 0, 0}, 0.688130, 0.000020, 0.037000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 0, 2}, 180.688130, 0.000020, 14.619000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 1, 0}, 2.619490, 0.000030, 0.074000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 2, 0}, 70.924360, 0.000020, 3.772000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 3, 0}, 2.619490, 0.000030, 0.077000},
	{{0, 3, -7, 0, 4, 0, 0, 0, -2, 1, 0}, 4.214650, 0.000030, 0.075000},
	{{0, 3, -7, 0, 4, 0, 0, 0, -2, 2, 0}, 163.492620, 0.000010, 81.999000},
	{{0, 3, -7, 2, 0, 0, 0, 0, -2, 1, 0}, 24.871980, 0.000010, 0.080000},
	{{0, 3, -7, 2, 0, 0, 0, 0, -2, 3, 0}, 24.871980, 0.000010, 0.072000},
	{{0, 3, -7, 2, 0, 0, 0, 0, -1, 0, 1}, 357.911810, 0.000060, 158.825000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -4, 0, 0}, 147.640870, 0.000040, 0.020000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -4, 1, 0}, 147.533480, 0.000100, 0.028000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -4, 2, 0}, 147.197880, 0.000060, 0.044000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, -2, 0}, 147.640860, 0.000030, 0.020000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, -1, 0}, 147.975310, 0.000320, 0.026000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 0, 0}, 147.705860, 0.003380, 0.040000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 0, 2}, 147.640850, 0.000070, 0.474000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 1, 0}, 147.321070, 0.005340, 0.087000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 2, 0}, 146.761820, 0.000200, 0.563000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -1, 0, 0}, 327.705700, 0.000100, 0.081000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -1, 1, 0}, 327.640850, 0.000010, 1.123000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -3, 0}, 150.312540, 0.000020, 0.025000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -2, 0}, 149.412330, 0.000400, 0.038000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -1, -2}, 328.880000, 0.000020, 0.025000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -1, 0}, 149.428430, 0.005880, 0.075000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 0, -2}, 327.002330, 0.000010, 0.037000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 0, 0}, 148.231030, 0.032450, 302.434000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 0, 2}, 327.002330, 0.000010, 0.037000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 1, 0}, 149.431920, 0.005880, 0.075000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 1, 2}, 328.880000, 0.000020, 0.025000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 2, 0}, 149.416840, 0.000400, 0.038000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 3, 0}, 149.554410, 0.000030, 0.025000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 1, -1, 0}, 327.650370, 0.000010, 1.132000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 1, 0, 0}, 327.702000, 0.000100, 0.081000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, -2, 0}, 146.778480, 0.000200, 0.565000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, -1, 0}, 147.330550, 0.005310, 0.087000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 0, -2}, 147.650360, 0.000070, 0.475000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 0, 0}, 147.714850, 0.003360, 0.040000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 1, 0}, 147.984100, 0.000320, 0.026000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 2, 0}, 147.650350, 0.000030, 0.020000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 4, -2, 0}, 147.205130, 0.000060, 0.044000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 4, -1, 0}, 147.533780, 0.000090, 0.028000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 4, 0, 0}, 147.650340, 0.000040, 0.020000},
	{{0, 3, -7, 5, 0, 0, 0, 0, 0, 0, 0}, 256.552570, 0.000010, 1.869000},
	{{0, 3, -7, 6, 0, 0, 0, 0, 1, 0, -1}, 333.730170, 0.000020, 77.464000},
	{{0, 3, -7, 7, 0, 0, 0, 0, 0, 0, 0}, 267.322700, 0.000010, 0.626000},
	{{0, 3, -7, 7, 0, 0, 0, 0, 2, -3, 0}, 86.413570, 0.000010, 0.074000},
	{{0, 3, -7, 7, 0, 0, 0, 0, 2, -1, 0}, 86.413570, 0.000010, 0.076000},
	{{0, 3, -6, -3, 0, 0, 0, 0, -2, 0, 0}, 355.312450, 0.000010, 0.036000},
	{{0, 3, -6, -3, 0, 0, 0, 0, -2, 1, 0}, 175.312450, 0.000020, 0.070000},
	{{0, 3, -6, -3, 0, 0, 0, 0, -2, 2, 0}, 355.312450, 0.000010, 1.059000},
	{{0, 3, -6, -3, 0, 0, 0, 0, -2, 3, 0}, 175.312450, 0.000020, 0.081000},
	{{0, 3, -6, -2, 0, 0, 0, 0, -2, 0, 0}, 11.105590, 0.000030, 0.037000},
	{{0, 3, -6, -2, 0, 0, 0, 0, -2, 1, 0}, 10.668730, 0.000010, 0.073000},
	{{0, 3, -6, -2, 0, 0, 0, 0, -2, 2, 0}, 11.020410, 0.000020, 2.423000},
	{{0, 3, -6, -2, 0, 0, 0, 0, -2, 3, 0}, 10.668730, 0.000010, 0.078000},
	{{0, 3, -6, -1, 0, 0, 0, 0, -2, 1, 0}, 51.972110, 0.000020, 0.076000},
	{{0, 3, -6, -1, 0, 0, 0, 0, -2, 3, 0}, 51.972110, 0.000020, 0.075000},
	{{0, 3, -6, 0, -2, 0, 0, 0, -2, 1, 0}, 6.888820, 0.000040, 0.078000},
	{{0, 3, -6, 0, -2, 0, 0, 0, -2, 3, 0}, 180.286690, 0.000020, 0.073000},
	{{0, 3, -6, 0, -1, 0, 0, 0, -4, 3, 0}, 55.933510, 0.000010, 0.092000},
	{{0, 3, -6, 0, -1, 0, 0, 0, -2, 0, 0}, 235.751350, 0.000010, 0.039000},
	{{0, 3, -6, 0, -1, 0, 0, 0, -2, 1, 0}, 236.770360, 0.000090, 0.079000},
	{{0, 3, -6, 0, -1, 0, 0, 0, -2, 3, 0}, 232.450910, 0.000020, 0.072000},
	{{0, 3, -6, 0, -1, 0, 0, 0, 0, -1, 0}, 235.751350, 0.000010, 0.069000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 120.176130, 0.000020, 0.020000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -3, 0, 1}, 238.814340, 0.000020, 0.040000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -3, 1, 1}, 59.666100, 0.000030, 0.087000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 267.618110, 0.000020, 0.026000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 253.046350, 0.000050, 0.039000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 241.556420, 0.000020, 0.079000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 163.815610, 0.000040, 0.072000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -2, 1}, 239.280170, 0.000020, 0.038000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, -1}, 59.012150, 0.000020, 0.025000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, 1}, 239.134920, 0.000350, 0.075000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 59.012150, 0.000180, 0.037000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 23.166380, 0.000030, 0.074000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 238.814340, 0.001990, 14.355000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, -1}, 58.692810, 0.000040, 0.073000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 239.134920, 0.000350, 0.076000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 2, 0}, 84.686310, 0.000010, 0.077000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 2, 1}, 239.280170, 0.000020, 0.038000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 286.949140, 0.000010, 0.036000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 100.865360, 0.000150, 0.070000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 97.281470, 0.001290, 0.890000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 90.847100, 0.000430, 0.082000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 87.296350, 0.000010, 0.039000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 59.666100, 0.000030, 0.088000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 60.153020, 0.000090, 0.459000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 254.276810, 0.000020, 0.041000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 90.599360, 0.000080, 0.345000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 90.556010, 0.001530, 0.097000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 0, -2}, 88.766010, 0.000020, 0.310000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 90.345320, 0.001350, 0.042000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 89.441390, 0.000160, 0.027000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 4, -2, 0}, 89.753890, 0.000030, 0.046000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 90.212400, 0.000030, 0.028000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 89.566660, 0.000040, 0.021000},
	{{0, 3, -6, 0, 0, 2, 0, 0, -1, -1, 1}, 74.168120, 0.000010, 0.075000},
	{{0, 3, -6, 0, 0, 2, 0, 0, -1, 0, 1}, 95.036960, 0.000020, 565.470000},
	{{0, 3, -6, 0, 0, 2, 0, 0, -1, 1, 1}, 74.168120, 0.000010, 0.075000},
	{{0, 3, -6, 0, 1, 0, 0, 0, -1, 0, 1}, 154.832840, 0.000020, 68.309000},
	{{0, 3, -6, 0, 1, 0, 0, 0, 0, 0, 0}, 185.366920, 0.000020, 0.962000},
	{{0, 3, -6, 0, 1, 0, 0, 0, 2, 0, 0}, 185.700810, 0.000030, 0.042000},
	{{0, 3, -6, 0, 2, 0, 0, 0, -1, 0, 1}, 83.521060, 0.000010, 10.107000},
	{{0, 3, -6, 0, 2, 0, 0, 0, 0, 0, 0}, 69.299600, 0.000020, 1.047000},
	{{0, 3, -6, 0, 2, 0, 0, 0, 2, -1, 0}, 288.724230, 0.000040, 0.095000},
	{{0, 3, -6, 0, 2, 0, 0, 0, 2, 0, 0}, 288.724230, 0.000030, 0.042000},
	{{0, 3, -6, 0, 3, 0, 0, 0, 0, 0, 0}, 59.300600, 0.000020, 1.149000},
	{{0, 3, -6, 2, 0, 0, 0, 0, -2, 0, 0}, 94.491960, 0.000020, 0.040000},
	{{0, 3, -6, 2, 0, 0, 0, 0, -2, 1, 0}, 94.491960, 0.000030, 0.087000},
	{{0, 3, -6, 2, 0, 0, 0, 0, 0, -1, 0}, 90.971820, 0.000010, 0.075000},
	{{0, 3, -6, 2, 0, 0, 0, 0, 0, 0, 0}, 93.475690, 0.000170, 16.650000},
	{{0, 3, -6, 2, 0, 0, 0, 0, 0, 1, 0}, 90.971820, 0.000010, 0.076000},
	{{0, 3, -6, 2, 0, 0, 0, 0, 2, -1, 0}, 94.686740, 0.000030, 0.088000},
	{{0, 3, -6, 2, 0, 0, 0, 0, 2, 0, 0}, 94.686740, 0.000020, 0.041000},
	{{0, 3, -6, 3, 0, 0, 0, 0, 0, 0, 0}, 153.865590, 0.000020, 2.120000},
	{{0, 3, -6, 4, 0, 0, 0, 0, -2, -1, 0}, 50.457050, 0.000030, 0.027000},
	{{0, 3, -6, 4, 0, 0, 0, 0, -2, 0, 0}, 49.068050, 0.000220, 0.042000},
	{{0, 3, -6, 4, 0, 0, 0, 0, -2, 1, 0}, 50.361290, 0.000260, 0.095000},
	{{0, 3, -6, 4, 0, 0, 0, 0, 0, -1, 0}, 62.227520, 0.000050, 0.082000},
	{{0, 3, -6, 4, 0, 0, 0, 0, 0, 0, 0}, 117.975700, 0.000090, 0.997000},
	{{0, 3, -6, 4, 0, 0, 0, 0, 0, 1, 0}, 208.240520, 0.000030, 0.070000},
	{{0, 3, -6, 4, 0, 0, 0, 0, 2, -1, 0}, 224.713840, 0.000020, 0.080000},
	{{0, 3, -6, 4, 0, 0, 0, 0, 2, 0, 0}, 219.828330, 0.000030, 0.039000},
	{{0, 3, -5, -3, 0, 0, 0, 0, -2, 1, 0}, 98.356780, 0.000040, 0.076000},
	{{0, 3, -5, -3, 0, 0, 0, 0, -2, 2, 0}, 46.820850, 0.000050, 18.007000},
	{{0, 3, -5, -3, 0, 0, 0, 0, -2, 3, 0}, 98.356780, 0.000040, 0.075000},
	{{0, 3, -5, 0, -2, 0, 0, 0, -2, 0, 0}, 51.840070, 0.000020, 0.040000},
	{{0, 3, -5, 0, -2, 0, 0, 0, 0, -1, 0}, 231.840070, 0.000020, 0.074000},
	{{0, 3, -5, 0, -2, 0, 0, 0, 0, 1, 0}, 231.840070, 0.000020, 0.077000},
	{{0, 3, -5, 0, -1, 0, 0, 0, 0, -2, 0}, 216.781440, 0.000010, 0.037000},
	{{0, 3, -5, 0, -1, 0, 0, 0, 0, 0, 0}, 101.045650, 0.000030, 4.814000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, -1, 0}, 344.133310, 0.000020, 0.016000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 345.566580, 0.000150, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 344.079990, 0.000340, 0.028000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 346.990990, 0.000250, 0.043000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -3, 0, 0}, 342.276670, 0.000020, 0.027000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -3, 1, 0}, 166.642200, 0.000010, 0.042000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -2, 0}, 344.359600, 0.000110, 0.019000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 342.997220, 0.000980, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -1, 2}, 178.384650, 0.000020, 0.089000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, -2}, 165.302740, 0.000020, 0.019000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 344.004270, 0.010700, 0.040000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 348.409330, 0.000040, 0.087000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 2}, 344.161170, 0.000270, 0.504000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, -2}, 165.191970, 0.000040, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 345.882830, 0.019170, 0.086000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 347.120770, 0.000790, 0.606000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 345.686710, 0.000060, 0.067000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, -1, 0}, 165.933510, 0.000020, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 0, -1}, 169.847830, 0.000030, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 155.008230, 0.000280, 0.080000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 350.650740, 0.000130, 1.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 1, -1}, 166.275930, 0.000030, 0.079000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 1, 0}, 162.656380, 0.000050, 1.310000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -3, 0}, 337.631230, 0.000060, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 338.457330, 0.000980, 0.038000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, -2}, 160.825850, 0.000040, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 338.067200, 0.014230, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 1}, 349.987960, 0.000070, 23.081000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 2}, 339.466650, 0.000030, 0.074000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, -2}, 169.205300, 0.000070, 0.037000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 168.576980, 0.000040, 0.074000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 344.529950, 0.082770, 8.102000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 168.409320, 0.000190, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 2}, 170.501490, 0.000040, 0.037000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, -2}, 339.466650, 0.000030, 0.073000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 338.663730, 0.014980, 0.076000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, 2}, 160.825850, 0.000040, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 338.057980, 0.001000, 0.038000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 3, 0}, 335.773100, 0.000060, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, -2, 0}, 188.076190, 0.000020, 0.070000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 344.999500, 0.000030, 0.069000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 101.289640, 0.000020, 0.990000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 167.364930, 0.000080, 0.081000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 347.196770, 0.000330, 0.849000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 46.475180, 0.000220, 0.082000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 167.035100, 0.000080, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 344.999500, 0.000030, 0.083000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 26.347520, 0.000040, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -3, 0}, 348.751470, 0.000060, 0.066000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 346.855230, 0.000950, 0.527000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 346.950200, 0.022990, 0.088000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, 2}, 166.135310, 0.000050, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, -2}, 346.485120, 0.000300, 0.448000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 346.498740, 0.014240, 0.041000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, 2}, 166.270700, 0.000030, 0.019000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 1, -2}, 166.126860, 0.000030, 0.091000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 346.151730, 0.001300, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 345.370250, 0.000110, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 3, -2, 0}, 13.575670, 0.000070, 0.096000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 3, -1, 0}, 17.447510, 0.000110, 0.042000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 3, 0, 0}, 6.306780, 0.000070, 0.027000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 349.962900, 0.000330, 0.044000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, -1, 0}, 348.482910, 0.000430, 0.028000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, 0, -2}, 346.315530, 0.000020, 0.044000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 343.792600, 0.000130, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, 1, 0}, 345.734060, 0.000030, 0.016000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 6, -1, 0}, 345.809080, 0.000010, 0.016000},
	{{0, 3, -5, 0, 0, 2, 0, 0, -2, 0, 0}, 178.794260, 0.000020, 0.040000},
	{{0, 3, -5, 0, 0, 2, 0, 0, 0, -1, 0}, 179.673780, 0.000040, 0.075000},
	{{0, 3, -5, 0, 0, 2, 0, 0, 0, 0, 0}, 178.710010, 0.000130, 18.007000},
	{{0, 3, -5, 0, 0, 2, 0, 0, 0, 1, 0}, 179.673780, 0.000040, 0.076000},
	{{0, 3, -5, 0, 0, 2, 0, 0, 2, 0, 0}, 178.813450, 0.000020, 0.041000},
	{{0, 3, -5, 0, 0, 3, 0, 0, -2, 0, 0}, 87.116050, 0.000020, 0.040000},
	{{0, 3, -5, 0, 0, 3, 0, 0, -2, 1, 0}, 87.116050, 0.000030, 0.087000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 0, -1, 0}, 87.325830, 0.000040, 0.075000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 0, 0, 0}, 87.279080, 0.000170, 46.327000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 0, 1, 0}, 87.325830, 0.000040, 0.076000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 2, -1, 0}, 87.124200, 0.000030, 0.087000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 2, 0, 0}, 87.124200, 0.000020, 0.040000},
	{{0, 3, -5, 0, 1, 0, 0, 0, -2, 0, 0}, 82.289550, 0.000100, 0.040000},
	{{0, 3, -5, 0, 1, 0, 0, 0, -2, 1, 0}, 82.276180, 0.000170, 0.087000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, -2, 0}, 83.051960, 0.000010, 0.038000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, -1, 0}, 82.294250, 0.000210, 0.075000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, 0, 0}, 80.274110, 0.000980, 25.559000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, 1, 0}, 82.461970, 0.000230, 0.076000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, 2, 0}, 83.045010, 0.000010, 0.038000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 2, -3, 0}, 89.658430, 0.000010, 0.066000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 2, -1, 0}, 83.141990, 0.000200, 0.087000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 2, 0, 0}, 84.601150, 0.000160, 0.040000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 2, 1, 0}, 83.993790, 0.000020, 0.026000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -4, 1, 0}, 178.988190, 0.000020, 0.028000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, -1, 0}, 178.998400, 0.000060, 0.026000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 0, 0}, 179.002600, 0.000600, 0.040000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 0, 2}, 178.971040, 0.000010, 0.465000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 1, 0}, 178.641990, 0.000890, 0.087000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 2, 0}, 178.971330, 0.000040, 0.550000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, -2, 0}, 180.229230, 0.000080, 0.038000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, -1, 0}, 180.300210, 0.001060, 0.076000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 0, -2}, 358.910000, 0.000010, 0.037000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 0, 0}, 178.909090, 0.006120, 22.135000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 0, 2}, 358.910000, 0.000010, 0.037000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 1, 0}, 180.317110, 0.001050, 0.075000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 2, 0}, 180.193490, 0.000080, 0.038000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, -2, 0}, 175.360590, 0.000010, 0.578000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, -1, 0}, 178.610600, 0.000830, 0.087000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, 0, -2}, 178.966470, 0.000010, 0.485000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, 0, 0}, 178.924700, 0.000510, 0.040000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, 1, 0}, 178.942440, 0.000050, 0.026000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 4, -1, 0}, 178.966470, 0.000020, 0.028000},
	{{0, 3, -5, 0, 3, 0, 0, 0, -2, 0, 0}, 170.283520, 0.000020, 0.041000},
	{{0, 3, -5, 0, 3, 0, 0, 0, -2, 1, 0}, 170.283520, 0.000020, 0.088000},
	{{0, 3, -5, 0, 3, 0, 0, 0, 0, -1, 0}, 169.268440, 0.000020, 0.076000},
	{{0, 3, -5, 0, 3, 0, 0, 0, 0, 0, 0}, 167.787790, 0.000170, 7.723000},
	{{0, 3, -5, 0, 3, 0, 0, 0, 0, 1, 0}, 169.268440, 0.000020, 0.075000},
	{{0, 3, -5, 0, 3, 0, 0, 0, 2, -1, 0}, 170.199410, 0.000040, 0.086000},
	{{0, 3, -5, 0, 3, 0, 0, 0, 2, 0, 0}, 170.272900, 0.000020, 0.040000},
	{{0, 3, -5, 0, 4, 0, 0, 0, 0, 0, 0}, 158.733950, 0.000030, 4.678000},
	{{0, 3, -5, 2, 0, 0, 0, 0, -2, 0, 0}, 359.160630, 0.000030, 0.042000},
	{{0, 3, -5, 2, 0, 0, 0, 0, 0, -1, 0}, 180.822890, 0.000020, 0.081000},
	{{0, 3, -5, 2, 0, 0, 0, 0, 0, 0, 0}, 359.798920, 0.000100, 1.064000},
	{{0, 3, -5, 2, 0, 0, 0, 0, 0, 1, 0}, 180.822890, 0.000020, 0.070000},
	{{0, 3, -5, 2, 0, 0, 0, 0, 2, -3, 0}, 179.455740, 0.000020, 0.071000},
	{{0, 3, -5, 2, 0, 0, 0, 0, 2, -1, 0}, 179.455740, 0.000020, 0.081000},
	{{0, 3, -5, 2, 0, 0, 0, 0, 2, 0, 0}, 181.826200, 0.000020, 0.039000},
	{{0, 3, -5, 3, 0, 0, 0, 0, 2, -3, 0}, 210.033510, 0.000010, 0.074000},
	{{0, 3, -5, 3, 0, 0, 0, 0, 2, -1, 0}, 210.033510, 0.000010, 0.077000},
	{{0, 3, -5, 4, 0, 0, 0, 0, -2, 0, 0}, 312.527750, 0.000020, 0.044000},
	{{0, 3, -4, -5, 0, 0, 0, 0, -2, 2, 0}, 110.879660, 0.000020, 127.646000},
	{{0, 3, -4, -3, 0, 0, 0, 0, -1, 2, -1}, 120.960530, 0.000010, 565.421000},
	{{0, 3, -4, -2, 0, 0, 0, 0, 0, 0, 0}, 302.190300, 0.000010, 5.353000},
	{{0, 3, -4, -1, 0, 0, 0, 0, 0, 0, 0}, 171.624400, 0.000020, 2.900000},
	{{0, 3, -4, 0, -1, 0, 0, 0, 2, -3, 0}, 279.703460, 0.000010, 0.070000},
	{{0, 3, -4, 0, -1, 0, 0, 0, 2, -1, 0}, 99.703460, 0.000010, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -6, 1, 0}, 271.188260, 0.000020, 0.017000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -6, 2, 0}, 270.658980, 0.000010, 0.021000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, -1, 0}, 271.266390, 0.000080, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 0, 0}, 269.884910, 0.000440, 0.021000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 0, 2}, 270.626350, 0.000020, 0.046000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 1, 0}, 270.038380, 0.001000, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 1, 2}, 270.584730, 0.000010, 0.118000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 2, 0}, 270.033760, 0.000620, 0.045000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 3, 0}, 270.354520, 0.000020, 0.113000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 0, 0}, 90.319310, 0.000070, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 0, 1}, 76.621370, 0.000020, 0.044000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 1, 0}, 90.342840, 0.000190, 0.044000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 1, 1}, 76.584280, 0.000010, 0.105000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -3, 0}, 270.590410, 0.000020, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -2, 0}, 270.632880, 0.000260, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, -2}, 90.607920, 0.000020, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 270.403070, 0.003340, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, 2}, 90.595770, 0.000060, 0.097000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, -2}, 90.609120, 0.000060, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 270.557410, 0.036680, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 2}, 270.594670, 0.000480, 0.335000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, -2}, 90.626780, 0.000120, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 270.606420, 0.046620, 0.094000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, 2}, 270.715640, 0.000020, 0.062000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 270.793740, 0.001980, 0.377000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 270.727820, 0.000110, 0.063000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -2, 0}, 270.192540, 0.000080, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 270.265610, 0.000310, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 76.455650, 0.000150, 0.088000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 2}, 270.341110, 0.000020, 0.477000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, -2}, 270.282160, 0.000020, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 256.588200, 0.000300, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 90.349690, 0.011970, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 76.599680, 0.001020, 0.518000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 256.622260, 0.000280, 0.086000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, 0}, 90.335330, 0.001250, 0.567000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 76.628220, 0.000100, 0.066000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 2, -1}, 256.584180, 0.000020, 0.626000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 2, 0}, 90.282870, 0.000110, 0.067000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -3, 0}, 271.427490, 0.000190, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 271.347480, 0.002650, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, -2}, 90.866380, 0.000090, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 271.173910, 0.039450, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 2}, 272.815900, 0.000020, 0.069000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, -2}, 91.091010, 0.000040, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 256.483460, 0.000070, 0.080000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 270.993160, 0.175110, 1.141000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 76.311810, 0.000040, 0.070000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 2}, 90.870850, 0.000130, 0.036000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, -1}, 260.385880, 0.000020, 1.409000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 271.086660, 0.029110, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 2}, 90.928580, 0.000080, 0.024000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 271.119700, 0.002020, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 3, 0}, 271.056750, 0.000130, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -5, 0}, 90.310130, 0.000010, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -4, 0}, 269.952810, 0.000020, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -3, -2}, 270.310130, 0.000010, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -3, 0}, 269.902850, 0.000280, 0.038000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, -2}, 90.161060, 0.000020, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 269.895230, 0.004050, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 1}, 92.563330, 0.000030, 6.397000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, -2}, 90.354850, 0.000080, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 77.795710, 0.000050, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 270.342920, 0.103860, 95.796000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 255.847850, 0.000140, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 2}, 90.354850, 0.000080, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -2}, 270.287940, 0.000120, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 256.477500, 0.002970, 5.644000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 270.286040, 0.065140, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 77.233880, 0.000470, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 2}, 90.292180, 0.000140, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 77.288800, 0.000080, 0.076000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 270.289590, 0.004430, 0.038000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, 1}, 76.222510, 0.000040, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, 2}, 90.310130, 0.000010, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 2, 0}, 270.287580, 0.000310, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 3, 0}, 270.310130, 0.000010, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 166.941470, 0.000040, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 80.456050, 0.000420, 1.114000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, -2}, 91.782700, 0.000020, 0.069000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, -1}, 81.612660, 0.000010, 0.940000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 282.081850, 0.004310, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, -2}, 271.827250, 0.000220, 0.812000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 76.528310, 0.000060, 0.082000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 272.396620, 0.004620, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 1, -2}, 91.782700, 0.000020, 0.083000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 271.751140, 0.000560, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 270.767290, 0.000080, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -3, 0}, 271.332320, 0.000030, 0.560000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -2, 0}, 270.568250, 0.001490, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, -2}, 270.341110, 0.000020, 0.472000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 256.694330, 0.000070, 0.088000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, 0}, 270.332060, 0.001990, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 0, -1}, 256.645160, 0.000020, 0.041000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 0, 0}, 270.297500, 0.000700, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 1, 0}, 270.293100, 0.000090, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -3, 0}, 93.384560, 0.000060, 0.094000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -2, 0}, 282.789720, 0.000370, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 281.151150, 0.000520, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 274.755620, 0.000080, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, 1, 0}, 91.695370, 0.000030, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 5, -3, 0}, 270.565240, 0.000020, 0.044000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 5, -2, 0}, 270.401290, 0.000040, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 5, -1, 0}, 270.327250, 0.000030, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 6, -3, 0}, 282.988630, 0.000010, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 6, -2, 0}, 283.100520, 0.000020, 0.021000},
	{{0, 3, -4, 0, 1, 0, 0, 0, -2, 0, 0}, 203.349150, 0.000020, 0.042000},
	{{0, 3, -4, 0, 1, 0, 0, 0, -2, 1, 0}, 354.524430, 0.000110, 0.095000},
	{{0, 3, -4, 0, 1, 0, 0, 0, -2, 2, 0}, 83.095880, 0.000010, 0.366000},
	{{0, 3, -4, 0, 1, 0, 0, 0, -2, 3, 0}, 355.984420, 0.000010, 0.063000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, -1, 0}, 342.334300, 0.000010, 0.081000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, 0, 0}, 356.762130, 0.000440, 1.041000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, 1, 0}, 342.334300, 0.000010, 0.070000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, 2, 0}, 178.688720, 0.000030, 0.036000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 2, -2, 0}, 178.165900, 0.000010, 1.230000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 2, -1, 0}, 327.785410, 0.000040, 0.080000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 2, 0, 0}, 178.165850, 0.000010, 0.039000},
	{{0, 3, -4, 0, 2, 0, 0, 0, -2, 0, 0}, 83.490650, 0.000040, 0.042000},
	{{0, 3, -4, 0, 2, 0, 0, 0, -2, 1, 0}, 83.490650, 0.000050, 0.096000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 0, -1, 0}, 240.204880, 0.000010, 0.082000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 0, 0, 0}, 107.387480, 0.000040, 0.957000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 0, 1, 0}, 240.204880, 0.000010, 0.070000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 1, -1, -1}, 230.961690, 0.000020, 0.075000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 1, 0, -1}, 112.122420, 0.000060, 116.455000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 1, 1, -1}, 230.961690, 0.000020, 0.075000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 2, -3, 0}, 60.691540, 0.000010, 0.072000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 2, -2, 0}, 60.552030, 0.000010, 1.372000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 2, -1, 0}, 88.413150, 0.000030, 0.080000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 2, 0, 0}, 60.272590, 0.000040, 0.039000},
	{{0, 3, -4, 1, 0, 0, 0, 0, 2, -3, 0}, 359.527870, 0.000010, 0.073000},
	{{0, 3, -4, 1, 0, 0, 0, 0, 2, -1, 0}, 359.527870, 0.000010, 0.078000},
	{{0, 3, -4, 2, 0, 0, 0, 0, 2, -3, 0}, 111.430750, 0.000020, 0.076000},
	{{0, 3, -4, 2, 0, 0, 0, 0, 2, -1, 0}, 111.430750, 0.000020, 0.075000},
	{{0, 3, -4, 3, 0, 0, 0, 0, 2, -3, 0}, 51.716420, 0.000010, 0.080000},
	{{0, 3, -4, 3, 0, 0, 0, 0, 2, -2, 0}, 236.876330, 0.000010, 1.434000},
	{{0, 3, -4, 3, 0, 0, 0, 0, 2, -1, 0}, 51.716420, 0.000010, 0.072000},
	{{0, 3, -4, 3, 0, 0, 0, 0, 2, 0, 0}, 236.876330, 0.000010, 0.037000},
	{{0, 3, -3, -2, 0, 0, 0, 0, 0, 0, 0}, 33.603230, 0.000010, 1.230000},
	{{0, 3, -3, 0, -2, 0, 0, 0, -2, 0, 0}, 205.439320, 0.000010, 0.043000},
	{{0, 3, -3, 0, -2, 0, 0, 0, 0, 0, 0}, 340.447980, 0.000010, 0.586000},
	{{0, 3, -3, 0, -2, 0, 0, 0, 2, -2, 0}, 14.763280, 0.000010, 15.139000},
	{{0, 3, -3, 0, -2, 0, 0, 0, 2, -1, 0}, 30.309520, 0.000030, 0.076000},
	{{0, 3, -3, 0, -1, 0, 0, 0, -4, 2, 0}, 50.938530, 0.000010, 0.047000},
	{{0, 3, -3, 0, -1, 0, 0, 0, -2, 0, 0}, 206.569850, 0.000080, 0.044000},
	{{0, 3, -3, 0, -1, 0, 0, 0, -2, 1, 0}, 13.056130, 0.000030, 0.103000},
	{{0, 3, -3, 0, -1, 0, 0, 0, -2, 2, 0}, 272.295120, 0.000030, 0.280000},
	{{0, 3, -3, 0, -1, 0, 0, 0, -2, 3, 0}, 13.056130, 0.000020, 0.059000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 0, -2, 0}, 193.056130, 0.000010, 0.040000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 0, -1, 0}, 86.963480, 0.000010, 0.087000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 0, 0, 0}, 46.310700, 0.000030, 0.558000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -3, 0}, 283.220410, 0.000020, 0.076000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -2, 0}, 214.120940, 0.000060, 54.802000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -1, 0}, 262.565530, 0.000080, 0.075000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, 0, 0}, 191.810540, 0.000050, 0.038000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 4, -3, 0}, 86.963480, 0.000010, 0.087000},
	{{0, 3, -3, 0, 0, -3, 0, 0, 2, -3, 0}, 116.871520, 0.000050, 0.075000},
	{{0, 3, -3, 0, 0, -3, 0, 0, 2, -2, 0}, 122.063660, 0.000700, 1412.983000},
	{{0, 3, -3, 0, 0, -3, 0, 0, 2, -1, 0}, 116.871520, 0.000050, 0.075000},
	{{0, 3, -3, 0, 0, -1, 0, 0, 2, -3, 0}, 93.217480, 0.000010, 0.076000},
	{{0, 3, -3, 0, 0, -1, 0, 0, 2, -2, 0}, 272.899560, 0.000010, 14.577000},
	{{0, 3, -3, 0, 0, -1, 0, 0, 2, -1, 0}, 92.790850, 0.000070, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -6, 1, 0}, 4.004480, 0.000010, 0.017000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, -1, 0}, 356.957140, 0.000030, 0.016000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 7.106320, 0.000140, 0.021000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 0, 2}, 2.087240, 0.000020, 0.048000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 4.923480, 0.000340, 0.029000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 2, 0}, 5.257030, 0.000170, 0.047000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 3, 0}, 179.595560, 0.000010, 0.128000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -3, 1, 0}, 182.969740, 0.000020, 0.046000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -2, 0}, 0.523950, 0.000240, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 1.881090, 0.002150, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -1, 2}, 182.039870, 0.000030, 0.108000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, -2}, 182.650120, 0.000030, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 2.821740, 0.015020, 0.044000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, 2}, 3.198270, 0.000110, 0.251000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, -2}, 182.692240, 0.000010, 0.027000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 2.665940, 0.014870, 0.104000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, 2}, 182.364400, 0.000030, 0.058000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 1.644130, 0.000820, 0.274000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 1.012690, 0.000130, 0.059000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, -2, 0}, 177.138300, 0.000030, 0.027000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 176.842720, 0.000170, 0.042000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 178.578430, 0.000030, 0.042000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 340.393920, 0.000330, 0.095000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 354.245770, 0.000130, 0.341000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 1, -1}, 0.334640, 0.000010, 0.094000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 1, 0}, 359.436670, 0.000060, 0.362000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -4, 0}, 0.097270, 0.000040, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 0.143690, 0.000630, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, -2}, 179.986280, 0.000050, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 0.139990, 0.008840, 0.041000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, -2}, 180.110740, 0.000250, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 0.120460, 0.125370, 0.088000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, 2}, 179.637380, 0.000040, 0.065000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 359.763600, 0.000070, 0.040000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 11.319030, 0.000030, 0.087000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 179.099750, 0.043400, 0.533000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, 2}, 358.641400, 0.000030, 0.035000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, -2}, 0.122110, 0.000200, 0.085000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 179.181270, 0.007370, 0.066000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, 2}, 358.880140, 0.000030, 0.024000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 2, -2}, 359.526470, 0.000020, 0.648000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 179.874510, 0.000540, 0.035000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 3, 0}, 179.611270, 0.000050, 0.024000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -2, 0}, 174.998520, 0.000060, 0.082000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 182.090300, 0.000090, 0.080000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 183.043550, 0.000190, 1.011000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 6.592030, 0.000060, 0.069000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, -2}, 0.011780, 0.000030, 0.079000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 184.509640, 0.000710, 1.215000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 358.282580, 0.002260, 0.070000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 4.698410, 0.000060, 0.036000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 182.090300, 0.000090, 0.071000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 356.871020, 0.000160, 0.036000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -4, 0}, 3.938140, 0.000070, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -3, -2}, 180.584200, 0.000010, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 3.139590, 0.001220, 0.076000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, -2}, 180.368270, 0.000130, 0.037000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 0.041670, 0.071990, 9.751000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, -2}, 179.993990, 0.001870, 0.074000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, -1}, 192.877030, 0.000040, 15.575000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 179.981440, 0.643710, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 2}, 359.979180, 0.001280, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 0.033940, 0.003050, 4.330000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 191.318990, 0.000150, 0.076000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 179.942770, 0.030300, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, 2}, 359.963690, 0.000180, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, -2}, 180.015030, 0.000720, 0.077000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 179.843750, 0.002070, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, 2}, 359.980760, 0.000030, 0.015000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 2, -2}, 180.014600, 0.000050, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 179.820110, 0.000080, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, -2, 0}, 181.488580, 0.000020, 0.080000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, -1, 0}, 359.021320, 0.000280, 0.039000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, 0, 0}, 0.025060, 0.000080, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, 1, 0}, 0.060440, 0.000010, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -4, 0}, 358.636270, 0.000050, 0.598000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -3, 0}, 359.536430, 0.001330, 0.086000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -2, -2}, 0.008470, 0.000040, 0.499000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -2, 0}, 179.978590, 0.007650, 0.040000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -2, 2}, 359.984580, 0.000050, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -1, -2}, 359.998180, 0.000350, 0.089000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 179.968910, 0.005770, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -1, 2}, 359.981680, 0.000030, 0.015000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, 0, -2}, 359.860650, 0.000010, 0.041000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 179.984280, 0.000710, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, 1, 0}, 179.913680, 0.000040, 0.015000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 5, -2, 0}, 359.988180, 0.000010, 0.027000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -4, 0}, 359.433510, 0.000020, 0.043000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -3, 0}, 180.223830, 0.000090, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -2, 0}, 179.982320, 0.000160, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -1, 0}, 179.964430, 0.000060, 0.016000},
	{{0, 3, -3, 0, 0, 1, 0, 0, 2, -3, 0}, 87.684060, 0.000010, 0.076000},
	{{0, 3, -3, 0, 0, 1, 0, 0, 2, -2, 0}, 87.674780, 0.000010, 7.326000},
	{{0, 3, -3, 0, 0, 1, 0, 0, 2, -1, 0}, 87.689010, 0.000040, 0.075000},
	{{0, 3, -3, 0, 1, 0, 0, 0, -2, 0, 0}, 328.016110, 0.000070, 0.044000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 0, -1, 0}, 171.265450, 0.000010, 0.089000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 0, 0, 0}, 187.958840, 0.000050, 0.510000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 0, 1, 0}, 171.265450, 0.000010, 0.066000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, -2, 0}, 37.405540, 0.000010, 5.352000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, -1, 0}, 202.713940, 0.000040, 0.074000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 332.059200, 0.000040, 0.037000},
	{{0, 3, -3, 0, 2, 0, 0, 0, 2, -3, 0}, 327.041260, 0.000010, 0.077000},
	{{0, 3, -3, 0, 2, 0, 0, 0, 2, -1, 0}, 183.886430, 0.000030, 0.074000},
	{{0, 3, -2, -3, 0, 0, 0, 0, 2, -3, 0}, 303.513440, 0.000030, 0.073000},
	{{0, 3, -2, -3, 0, 0, 0, 0, 2, -2, 0}, 303.564730, 0.000010, 2.030000},
	{{0, 3, -2, -3, 0, 0, 0, 0, 2, -1, 0}, 303.513440, 0.000030, 0.078000},
	{{0, 3, -2, -3, 0, 0, 0, 0, 2, 0, 0}, 303.564730, 0.000010, 0.038000},
	{{0, 3, -2, -2, 0, 0, 0, 0, 0, 0, 0}, 102.186070, 0.000010, 0.552000},
	{{0, 3, -2, -2, 0, 0, 0, 0, 2, -2, 0}, 125.990300, 0.000010, 25.521000},
	{{0, 3, -2, -2, 0, 0, 0, 0, 2, -1, 0}, 156.776260, 0.000020, 0.075000},
	{{0, 3, -2, -2, 0, 0, 0, 0, 2, 0, 0}, 139.681990, 0.000020, 0.038000},
	{{0, 3, -2, 0, -2, 0, 0, 0, -2, 0, 0}, 89.596780, 0.000020, 0.045000},
	{{0, 3, -2, 0, -2, 0, 0, 0, -2, 1, 0}, 119.791530, 0.000010, 0.114000},
	{{0, 3, -2, 0, -2, 0, 0, 0, -2, 2, 0}, 269.596780, 0.000020, 0.223000},
	{{0, 3, -2, 0, -2, 0, 0, 0, 2, -3, 0}, 308.545450, 0.000010, 0.081000},
	{{0, 3, -2, 0, -2, 0, 0, 0, 2, -1, 0}, 308.545450, 0.000010, 0.070000},
	{{0, 3, -2, 0, -1, 0, 0, 0, -2, 0, 0}, 2.310980, 0.000010, 0.046000},
	{{0, 3, -2, 0, -1, 0, 0, 0, -2, 2, 0}, 1.488920, 0.000030, 0.219000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 0, -2, 0}, 184.996260, 0.000010, 0.042000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 0, -1, 0}, 4.785240, 0.000020, 0.096000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 0, 0, 0}, 179.612560, 0.000010, 0.358000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 2, -1, 0}, 184.785240, 0.000100, 0.070000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 2, 0, 0}, 4.004420, 0.000080, 0.036000},
	{{0, 3, -2, 0, 0, -1, 0, 0, -2, 0, 0}, 180.215480, 0.000010, 0.046000},
	{{0, 3, -2, 0, 0, -1, 0, 0, -2, 2, 0}, 0.215480, 0.000010, 0.217000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -4, 0, 0}, 256.564430, 0.000030, 0.021000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -4, 1, 0}, 254.918020, 0.000020, 0.030000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -3, 0, 1}, 103.182240, 0.000020, 0.048000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -3, 1, 1}, 103.315860, 0.000020, 0.132000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 257.126180, 0.000020, 0.021000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 256.959670, 0.000290, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 256.612570, 0.001610, 0.046000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 2}, 258.141150, 0.000010, 0.201000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 257.166010, 0.001350, 0.116000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 255.301530, 0.000060, 0.215000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, -1, -1}, 103.141260, 0.000020, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, -1, 1}, 283.563470, 0.000090, 0.107000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 103.164440, 0.000420, 0.044000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 255.812150, 0.000030, 0.105000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 283.156560, 0.000870, 0.254000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 103.315880, 0.000220, 0.104000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 1, 1}, 283.230550, 0.000080, 0.058000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -3, 0}, 256.884510, 0.000030, 0.027000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 256.858650, 0.000470, 0.042000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 256.689040, 0.005940, 0.096000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 282.774280, 0.000040, 0.095000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 191.121530, 0.000410, 0.348000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 103.322820, 0.000030, 0.061000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 131.123660, 0.000050, 0.062000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 78.941950, 0.000010, 0.034000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -2, 1}, 283.323710, 0.000010, 0.464000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 283.115920, 0.000050, 0.087000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 283.306350, 0.000260, 0.065000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 103.310100, 0.002740, 0.549000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 273.386520, 0.000030, 0.066000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 283.298390, 0.000250, 0.035000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 103.309500, 0.000330, 0.066000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 1, 1}, 283.299500, 0.000030, 0.024000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 2, -1}, 103.307790, 0.000030, 0.035000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 86.727800, 0.000040, 0.082000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 257.245980, 0.000460, 0.907000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 256.217780, 0.003650, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, -2}, 256.541110, 0.000060, 1.300000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 283.341090, 0.000080, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 257.548610, 0.000140, 0.036000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -2, -1}, 283.273930, 0.000430, 20.498000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -2, 0}, 77.049350, 0.000020, 0.074000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -1, -1}, 103.287460, 0.002390, 0.075000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -1, 0}, 77.044010, 0.000040, 0.037000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, 0, -1}, 103.293230, 0.000200, 0.038000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 4, -3, 0}, 262.281630, 0.000020, 0.079000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 256.375800, 0.000100, 0.039000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 4, -1, 0}, 257.352890, 0.000080, 0.026000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 5, -2, -1}, 103.287310, 0.000030, 0.040000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 5, -1, -1}, 103.287420, 0.000020, 0.026000},
	{{0, 3, -1, -6, 0, 0, 0, 0, 0, 0, 0}, 80.321980, 0.000010, 1.457000},
	{{0, 3, -1, -4, 0, 0, 0, 0, 2, -3, 0}, 146.946790, 0.000020, 0.075000},
	{{0, 3, -1, -4, 0, 0, 0, 0, 2, -2, 0}, 301.816640, 0.000030, 41.349000},
	{{0, 3, -1, -3, 0, 0, 0, 0, 0, 0, 0}, 310.377250, 0.000010, 0.438000},
	{{0, 3, -1, -2, 0, 0, 0, 0, -2, 0, 0}, 0.495020, 0.000030, 0.046000},
	{{0, 3, -1, -2, 0, 0, 0, 0, -2, 1, 0}, 179.894000, 0.000010, 0.115000},
	{{0, 3, -1, -2, 0, 0, 0, 0, -2, 2, 0}, 0.495020, 0.000030, 0.218000},
	{{0, 3, -1, -2, 0, 0, 0, 0, -2, 3, 0}, 179.894000, 0.000010, 0.056000},
	{{0, 3, -1, -2, 0, 0, 0, 0, 0, -2, 0}, 179.894000, 0.000010, 0.042000},
	{{0, 3, -1, -2, 0, 0, 0, 0, 0, 0, 0}, 179.894000, 0.000010, 0.355000},
	{{0, 3, -1, 0, -2, 0, 0, 0, -2, -2, 0}, 180.105550, 0.000010, 0.021000},
	{{0, 3, -1, 0, -2, 0, 0, 0, -2, 1, 0}, 180.024490, 0.000010, 0.129000},
	{{0, 3, -1, 0, -2, 0, 0, 0, -2, 2, 0}, 0.310880, 0.000010, 0.182000},
	{{0, 3, -1, 0, -2, 0, 0, 0, 0, -2, 0}, 359.989550, 0.000030, 0.044000},
	{{0, 3, -1, 0, -2, 0, 0, 0, 0, -1, 0}, 0.105550, 0.000010, 0.105000},
	{{0, 3, -1, 0, -2, 0, 0, 0, 0, 0, 0}, 359.989550, 0.000030, 0.270000},
	{{0, 3, -1, 0, -2, 0, 0, 0, 0, 1, 0}, 0.105550, 0.000010, 0.059000},
	{{0, 3, -1, 0, -1, 0, 0, 0, -2, 0, 0}, 90.497840, 0.000020, 0.048000},
	{{0, 3, -1, 0, -1, 0, 0, 0, -2, 2, 0}, 90.407490, 0.000030, 0.180000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 39.255490, 0.000030, 0.029000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 43.920930, 0.000330, 0.048000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 42.141670, 0.000220, 0.131000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 13.049370, 0.000010, 0.177000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 8.197710, 0.000020, 0.046000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 205.309300, 0.000040, 0.118000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 189.955910, 0.000040, 0.203000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 87.782670, 0.000200, 0.107000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 26.195700, 0.001800, 0.258000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 23.698840, 0.000170, 0.058000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 180.350510, 0.000020, 0.096000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 13.278120, 0.000050, 0.354000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 208.717220, 0.000020, 0.062000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 182.615790, 0.000010, 0.034000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 165.635740, 0.000030, 0.090000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 26.295830, 0.000020, 0.476000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 35.472280, 0.000280, 0.065000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 200.506650, 0.000090, 0.035000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, 1, 0}, 203.807260, 0.000010, 0.024000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 4, -2, -2}, 246.513210, 0.000070, 200.852000},
	{{0, 3, 0, -8, 3, 0, 0, 0, 0, 0, 0}, 199.229090, 0.000010, 1.142000},
	{{0, 3, 0, -5, 0, 0, 0, 0, 0, 0, 0}, 120.467180, 0.000010, 0.451000},
	{{0, 3, 0, 0, -2, 0, 0, 0, -2, 0, 0}, 269.026510, 0.000020, 0.050000},
	{{0, 3, 0, 0, -2, 0, 0, 0, -2, 2, 0}, 89.026510, 0.000020, 0.154000},
	{{0, 3, 0, 0, -1, 0, 0, 0, 0, 0, 0}, 19.876910, 0.000010, 0.209000},
	{{0, 3, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 293.597090, 0.000060, 0.050000},
	{{0, 3, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 289.943030, 0.000030, 0.151000},
	{{0, 3, 0, 0, 0, 0, 0, 0, -1, 0, 1}, 124.547830, 0.000010, 0.169000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 287.505480, 0.000020, 0.119000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 291.787580, 0.000100, 0.205000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 292.042930, 0.000010, 0.055000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 307.113120, 0.000020, 0.262000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 218.638570, 0.000020, 0.098000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 218.638570, 0.000020, 0.061000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 192.368510, 0.000020, 0.034000},
	{{0, 3, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 131.165290, 0.000060, 0.034000},
	{{0, 3, 1, 0, -1, 0, 0, 0, 2, -2, 0}, 147.832890, 0.000010, 0.249000},
	{{0, 3, 1, 0, -1, 0, 0, 0, 2, -1, 0}, 141.308410, 0.000030, 0.058000},
	{{0, 3, 1, 0, -1, 0, 0, 0, 2, 0, 0}, 154.352320, 0.000030, 0.033000},
	{{0, 3, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 308.175220, 0.000020, 0.178000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 308.326870, 0.000020, 0.136000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 206.450840, 0.000020, 0.170000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 308.326870, 0.000020, 0.052000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 126.206600, 0.000050, 0.244000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 127.737790, 0.000060, 0.033000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, 1, 0}, 308.232310, 0.000020, 0.023000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, 2, 0}, 128.211620, 0.000020, 0.018000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 4, -2, 0}, 306.206600, 0.000010, 0.035000},
	{{0, 3, 1, 0, 1, 0, 0, 0, 2, -2, 0}, 114.915050, 0.000010, 0.239000},
	{{0, 3, 1, 0, 1, 0, 0, 0, 2, -1, 0}, 299.517730, 0.000030, 0.057000},
	{{0, 3, 1, 0, 1, 0, 0, 0, 2, 0, 0}, 294.915050, 0.000010, 0.033000},
	{{0, 3, 2, -9, 0, 0, 0, 0, 2, 0, -2}, 243.478240, 0.000010, 62.037000},
	{{0, 3, 2, -3, 0, 0, 0, 0, 2, -2, 0}, 251.372360, 0.000010, 0.285000},
	{{0, 3, 2, -3, 0, 0, 0, 0, 2, 0, 0}, 251.372360, 0.000010, 0.033000},
	{{0, 3, 2, 0, -1, 0, 0, 0, 2, 0, 0}, 309.711090, 0.000020, 0.032000},
	{{0, 3, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 302.082390, 0.000040, 0.056000},
	{{0, 3, 2, 0, 0, 0, 0, 0, -2, 2, 0}, 302.080980, 0.000050, 0.116000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 41.794370, 0.000030, 0.145000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 211.833560, 0.000020, 0.032000},
	{{0, 3, 3, -2, 0, 0, 0, 0, 2, -3, 0}, 308.146280, 0.000010, 0.122000},
	{{0, 3, 3, -2, 0, 0, 0, 0, 2, -2, 0}, 308.090900, 0.000010, 0.198000},
	{{0, 3, 3, -2, 0, 0, 0, 0, 2, -1, 0}, 308.146280, 0.000010, 0.055000},
	{{0, 3, 3, -2, 0, 0, 0, 0, 2, 0, 0}, 308.090900, 0.000010, 0.032000},
	{{0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 333.060630, 0.000030, 0.127000},
	{{0, 3, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 325.404690, 0.000010, 0.164000},
	{{0, 3, 5, -15, 0, 0, 0, 0, 2, -3, 0}, 156.703710, 0.000030, 0.076000},
	{{0, 3, 5, -15, 0, 0, 0, 0, 2, -1, 0}, 156.703710, 0.000030, 0.075000},
	{{0, 3, 5, 0, -2, 0, 0, 0, -4, 3, 0}, 184.662040, 0.000130, 4160.319000},
	{{0, 3, 7, -19, 0, 0, 0, 0, 2, -3, 0}, 304.874340, 0.000020, 0.075000},
	{{0, 3, 7, -19, 0, 0, 0, 0, 2, -2, 0}, 311.204880, 0.000250, 1812.670000},
	{{0, 3, 7, -19, 0, 0, 0, 0, 2, -1, 0}, 304.874340, 0.000020, 0.075000},
	{{0, 3, 27, -37, 0, 0, 0, 0, -1, -1, 1}, 43.227520, 0.000010, 441.870000},
	{{0, 3, 30, -44, 0, 0, 0, 0, -2, 1, 0}, 38.914670, 0.000100, 1378.938000},
	{{0, 4, -49, 55, 0, 0, 0, 0, 0, 1, 0}, 334.521570, 0.000070, 2078.312000},
	{{0, 4, -16, 15, 0, 0, 0, 0, -2, 1, 0}, 254.750460, 0.000010, 0.077000},
	{{0, 4, -16, 15, 0, 0, 0, 0, -2, 3, 0}, 254.750460, 0.000010, 0.074000},
	{{0, 4, -15, 14, 0, 0, 0, 0, -1, -1, 1}, 286.279690, 0.000020, 0.075000},
	{{0, 4, -15, 14, 0, 0, 0, 0, -1, 0, 1}, 286.279690, 0.000300, 1778.605000},
	{{0, 4, -15, 14, 0, 0, 0, 0, -1, 1, 1}, 286.279690, 0.000020, 0.075000},
	{{0, 4, -12, 7, 0, 0, 0, 0, -2, 2, 0}, 279.685050, 0.000060, 476.157000},
	{{0, 4, -11, 0, 2, 0, 0, 0, -2, 0, 0}, 322.673340, 0.000020, 0.034000},
	{{0, 4, -11, 5, 0, 0, 0, 0, -2, 2, 0}, 289.227810, 0.000020, 15.275000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, -1, 0}, 217.103170, 0.000010, 0.024000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 217.478250, 0.000010, 0.035000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 98.189240, 0.000010, 0.067000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 217.478250, 0.000010, 0.580000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 66.960370, 0.000010, 0.060000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 246.962830, 0.000020, 0.286000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 66.960370, 0.000010, 0.102000},
	{{0, 4, -10, 0, 1, 0, 0, 0, -2, 1, 0}, 321.500030, 0.000010, 0.067000},
	{{0, 4, -10, 0, 1, 0, 0, 0, -2, 3, 0}, 321.500030, 0.000010, 0.086000},
	{{0, 4, -10, 0, 2, 0, 0, 0, -2, 0, 0}, 231.662260, 0.000010, 0.036000},
	{{0, 4, -10, 0, 2, 0, 0, 0, -2, 1, 0}, 51.662260, 0.000010, 0.068000},
	{{0, 4, -10, 0, 2, 0, 0, 0, -2, 2, 0}, 231.662260, 0.000010, 0.643000},
	{{0, 4, -10, 0, 2, 0, 0, 0, -2, 3, 0}, 51.662260, 0.000010, 0.085000},
	{{0, 4, -10, 0, 2, 0, 0, 0, 0, -2, 0}, 51.634110, 0.000010, 0.034000},
	{{0, 4, -10, 0, 2, 0, 0, 0, 0, 0, 0}, 231.634110, 0.000010, 0.300000},
	{{0, 4, -10, 0, 3, 0, 0, 0, -2, 0, 0}, 221.882830, 0.000030, 0.036000},
	{{0, 4, -10, 0, 3, 0, 0, 0, -2, 1, 0}, 41.882830, 0.000020, 0.068000},
	{{0, 4, -10, 2, 0, 0, 0, 0, -2, 0, 0}, 231.904220, 0.000020, 0.037000},
	{{0, 4, -10, 2, 0, 0, 0, 0, -2, 2, 0}, 231.904220, 0.000020, 1.514000},
	{{0, 4, -10, 3, 0, 0, 0, 0, -2, 1, 0}, 332.551430, 0.000020, 0.075000},
	{{0, 4, -10, 3, 0, 0, 0, 0, -2, 3, 0}, 332.551430, 0.000020, 0.076000},
	{{0, 4, -9, 0, -1, 0, 0, 0, -2, 1, 0}, 331.513450, 0.000030, 0.071000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, -3, 0}, 324.001860, 0.000020, 0.015000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 324.001860, 0.000020, 0.025000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 20.067820, 0.000030, 0.072000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 312.086520, 0.000050, 1.381000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 37.038150, 0.000030, 0.080000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 142.875790, 0.000010, 0.034000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 322.875790, 0.000010, 0.063000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 133.107690, 0.000040, 0.400000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 322.875790, 0.000010, 0.093000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 313.558810, 0.000030, 0.111000},
	{{0, 4, -9, 0, 1, 0, 0, 0, -2, -2, 0}, 50.460800, 0.000010, 0.019000},
	{{0, 4, -9, 0, 1, 0, 0, 0, -2, 1, 0}, 115.749160, 0.000030, 0.072000},
	{{0, 4, -9, 0, 1, 0, 0, 0, -2, 2, 0}, 51.193520, 0.000020, 1.564000},
	{{0, 4, -9, 0, 1, 0, 0, 0, 0, -2, 0}, 50.460800, 0.000020, 0.035000},
	{{0, 4, -9, 0, 1, 0, 0, 0, 0, 0, 0}, 50.460800, 0.000020, 0.414000},
	{{0, 4, -9, 0, 2, 0, 0, 0, -2, 0, 0}, 291.841230, 0.000030, 0.037000},
	{{0, 4, -9, 0, 2, 0, 0, 0, -2, 1, 0}, 32.187730, 0.000010, 0.072000},
	{{0, 4, -9, 0, 2, 0, 0, 0, -2, 2, 0}, 111.768480, 0.000020, 1.801000},
	{{0, 4, -9, 0, 2, 0, 0, 0, -2, 3, 0}, 112.352560, 0.000010, 0.079000},
	{{0, 4, -9, 1, 0, 0, 0, 0, -2, 1, 0}, 51.338990, 0.000020, 0.074000},
	{{0, 4, -9, 1, 0, 0, 0, 0, -2, 3, 0}, 51.338990, 0.000020, 0.077000},
	{{0, 4, -9, 2, 0, 0, 0, 0, -2, 1, 0}, 320.074510, 0.000010, 0.077000},
	{{0, 4, -9, 2, 0, 0, 0, 0, -2, 3, 0}, 320.074510, 0.000010, 0.074000},
	{{0, 4, -9, 3, 0, 0, 0, 0, -2, 0, 0}, 288.619580, 0.000010, 0.039000},
	{{0, 4, -9, 3, 0, 0, 0, 0, -2, 1, 0}, 288.619580, 0.000020, 0.081000},
	{{0, 4, -9, 3, 0, 0, 0, 0, -2, 2, 0}, 288.619580, 0.000010, 1.148000},
	{{0, 4, -9, 3, 0, 0, 0, 0, -2, 3, 0}, 288.619580, 0.000020, 0.071000},
	{{0, 4, -9, 5, 0, 0, 0, 0, 0, 0, 0}, 39.331940, 0.000010, 6.230000},
	{{0, 4, -9, 8, 0, 0, 0, 0, 2, -3, 0}, 266.924230, 0.000020, 0.075000},
	{{0, 4, -9, 8, 0, 0, 0, 0, 2, -1, 0}, 266.924230, 0.000020, 0.076000},
	{{0, 4, -8, 0, -1, 0, 0, 0, -2, 0, 0}, 245.827030, 0.000010, 0.038000},
	{{0, 4, -8, 0, -1, 0, 0, 0, -2, 1, 0}, 324.284420, 0.000010, 0.077000},
	{{0, 4, -8, 0, -1, 0, 0, 0, -2, 3, 0}, 144.284420, 0.000010, 0.074000},
	{{0, 4, -8, 0, -1, 0, 0, 0, 0, -1, 0}, 240.474210, 0.000010, 0.067000},
	{{0, 4, -8, 0, -1, 0, 0, 0, 0, 1, 0}, 240.474210, 0.000010, 0.086000},
	{{0, 4, -8, 0, 0, -1, 0, 0, -2, 1, 0}, 324.315450, 0.000060, 0.077000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 231.789560, 0.000020, 0.020000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 51.789560, 0.000020, 0.041000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 48.022290, 0.000030, 0.038000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 107.517630, 0.000040, 0.077000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 60.479620, 0.000010, 3.622000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 133.872100, 0.000010, 0.074000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 326.221910, 0.000010, 2.252000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, -1, 2}, 51.789560, 0.000030, 0.083000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 294.860960, 0.000070, 0.668000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 177.766370, 0.000020, 0.043000},
	{{0, 4, -8, 0, 1, 0, 0, 0, -2, 0, 0}, 41.602620, 0.000030, 0.038000},
	{{0, 4, -8, 0, 1, 0, 0, 0, -2, 1, 0}, 180.300310, 0.000100, 0.078000},
	{{0, 4, -8, 0, 1, 0, 0, 0, 0, -1, 0}, 38.683530, 0.000010, 0.068000},
	{{0, 4, -8, 0, 1, 0, 0, 0, 0, 1, 0}, 38.683530, 0.000010, 0.084000},
	{{0, 4, -8, 2, 0, 0, 0, 0, 0, 0, 0}, 341.892980, 0.000010, 2.301000},
	{{0, 4, -8, 3, 0, 0, 0, 0, 0, 0, 0}, 226.963150, 0.000020, 10.294000},
	{{0, 4, -7, -3, 0, 0, 0, 0, -2, 0, 0}, 355.311150, 0.000010, 0.037000},
	{{0, 4, -7, -3, 0, 0, 0, 0, -2, 0, 2}, 103.202370, 0.000010, 68.630000},
	{{0, 4, -7, -3, 0, 0, 0, 0, -2, 2, 0}, 355.311150, 0.000010, 3.135000},
	{{0, 4, -7, -2, 0, 0, 0, 0, -2, 0, 0}, 11.228990, 0.000010, 0.038000},
	{{0, 4, -7, 0, -1, 0, 0, 0, -2, 0, 0}, 235.711930, 0.000010, 0.039000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, -2, 0}, 132.720330, 0.000020, 0.019000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 66.788810, 0.000040, 0.040000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 57.678080, 0.000100, 0.083000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 319.845380, 0.000010, 0.784000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 244.811520, 0.000030, 0.078000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 63.136380, 0.000030, 1.799000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 241.730360, 0.000010, 0.077000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -1, 3, -1}, 61.730360, 0.000010, 0.074000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 257.524880, 0.000140, 0.073000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 241.527320, 0.000550, 2.008000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 247.712830, 0.000100, 0.078000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 64.433770, 0.000060, 0.644000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 80.063420, 0.000010, 0.440000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 89.194500, 0.000210, 0.091000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 88.957650, 0.000110, 0.041000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 82.943580, 0.000020, 0.027000},
	{{0, 4, -7, 0, 1, 0, 0, 0, 0, 0, 0}, 12.054160, 0.000020, 2.418000},
	{{0, 4, -7, 0, 2, 0, 0, 0, 0, 0, 0}, 72.363450, 0.000010, 3.037000},
	{{0, 4, -7, 0, 3, 0, 0, 0, 0, 0, 0}, 103.381100, 0.000020, 4.082000},
	{{0, 4, -7, 0, 6, 0, 0, 0, -2, 0, 0}, 157.579590, 0.000010, 0.040000},
	{{0, 4, -7, 0, 6, 0, 0, 0, 2, 0, 0}, 157.579590, 0.000010, 0.040000},
	{{0, 4, -7, 5, 0, 0, 0, 0, 0, 0, 0}, 238.191250, 0.000010, 0.463000},
	{{0, 4, -6, -1, 0, 0, 0, 0, 0, 0, 0}, 238.429680, 0.000010, 33.794000},
	{{0, 4, -6, 0, -2, 0, 0, 0, -2, 0, 0}, 51.837320, 0.000020, 0.041000},
	{{0, 4, -6, 0, -2, 0, 0, 0, 0, -1, 0}, 51.837320, 0.000010, 0.077000},
	{{0, 4, -6, 0, -2, 0, 0, 0, 0, 1, 0}, 51.837320, 0.000010, 0.074000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 344.924540, 0.000040, 0.020000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -4, 1, 0}, 344.232000, 0.000080, 0.028000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -4, 2, 0}, 349.777220, 0.000040, 0.045000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, -2, 0}, 345.276570, 0.000030, 0.020000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 346.349620, 0.000270, 0.027000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 345.361110, 0.003100, 0.041000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 0, 2}, 346.108990, 0.000050, 0.383000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 345.807330, 0.004110, 0.091000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 342.128190, 0.000170, 0.439000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, -1, 1}, 354.998830, 0.000070, 0.085000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 162.351780, 0.000180, 0.084000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 354.176800, 0.000030, 0.643000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 1, -1}, 168.538280, 0.000020, 0.083000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 24.045290, 0.000010, 0.068000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 3, -1}, 348.138880, 0.000010, 0.069000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -3, 0}, 345.654900, 0.000020, 0.025000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 345.240270, 0.000390, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 342.657130, 0.005110, 0.078000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, -2}, 165.165190, 0.000010, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 348.547160, 0.000030, 0.077000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 343.213240, 0.025870, 1.992000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, 2}, 165.165190, 0.000010, 0.037000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 342.735420, 0.004390, 0.073000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 340.751180, 0.000280, 0.037000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 3, 0}, 339.482210, 0.000010, 0.025000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -2, 1}, 169.025930, 0.000050, 4.584000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, -1}, 349.213360, 0.000090, 0.072000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 339.997330, 0.000050, 2.598000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 169.232070, 0.000310, 0.077000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 349.418390, 0.000790, 1.813000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 340.606950, 0.000300, 0.078000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 169.342300, 0.000170, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 1, -1}, 349.213360, 0.000090, 0.079000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 1, 0}, 340.446120, 0.000020, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 171.847250, 0.000080, 0.786000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 321.232190, 0.000130, 0.083000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 0, -2}, 344.724660, 0.000020, 0.623000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 341.925920, 0.000630, 0.040000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 344.233450, 0.000100, 0.026000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 4, -2, 0}, 175.483300, 0.000020, 0.043000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 191.323370, 0.000020, 0.027000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 165.326440, 0.000040, 0.020000},
	{{0, 4, -6, 0, 1, 0, 0, 0, 0, 0, 0}, 50.148590, 0.000020, 1.705000},
	{{0, 4, -6, 0, 1, 0, 0, 0, 2, -2, 0}, 269.543650, 0.000030, 0.842000},
	{{0, 4, -6, 0, 1, 0, 0, 0, 2, 0, 0}, 89.412780, 0.000020, 0.039000},
	{{0, 4, -6, 0, 2, 0, 0, 0, -2, 0, 0}, 179.871380, 0.000050, 0.042000},
	{{0, 4, -6, 0, 2, 0, 0, 0, 0, -1, 0}, 0.312910, 0.000020, 0.079000},
	{{0, 4, -6, 0, 2, 0, 0, 0, 0, 0, 0}, 177.042010, 0.000110, 1.491000},
	{{0, 4, -6, 0, 2, 0, 0, 0, 0, 1, 0}, 0.312910, 0.000020, 0.072000},
	{{0, 4, -6, 0, 2, 0, 0, 0, 2, -3, 0}, 359.967570, 0.000010, 0.070000},
	{{0, 4, -6, 0, 2, 0, 0, 0, 2, -2, 0}, 359.967560, 0.000010, 0.906000},
	{{0, 4, -6, 0, 2, 0, 0, 0, 2, 0, 0}, 359.967560, 0.000010, 0.039000},
	{{0, 4, -6, 0, 3, 0, 0, 0, 0, 0, 0}, 169.456380, 0.000020, 1.325000},
	{{0, 4, -6, 1, 0, 0, 0, 0, 1, 0, -1}, 75.185240, 0.000020, 50.030000},
	{{0, 4, -6, 2, 0, 0, 0, 0, 0, -1, 0}, 180.097950, 0.000010, 0.086000},
	{{0, 4, -6, 2, 0, 0, 0, 0, 0, 1, 0}, 180.097950, 0.000010, 0.067000},
	{{0, 4, -6, 2, 0, 0, 0, 0, 2, -3, 0}, 128.672020, 0.000030, 0.074000},
	{{0, 4, -6, 2, 0, 0, 0, 0, 2, -1, 0}, 128.672020, 0.000030, 0.077000},
	{{0, 4, -6, 3, 0, 0, 0, 0, 2, 0, -2}, 302.564920, 0.000010, 96.289000},
	{{0, 4, -5, -3, 0, 0, 0, 0, 0, -1, 0}, 327.978230, 0.000010, 0.075000},
	{{0, 4, -5, -3, 0, 0, 0, 0, 0, 0, 0}, 162.574090, 0.000010, 10.758000},
	{{0, 4, -5, -3, 0, 0, 0, 0, 0, 1, 0}, 327.978230, 0.000010, 0.076000},
	{{0, 4, -5, 0, -1, 0, 0, 0, -2, 0, 0}, 103.965320, 0.000010, 0.043000},
	{{0, 4, -5, 0, -1, 0, 0, 0, -2, 2, 0}, 283.965320, 0.000010, 0.313000},
	{{0, 4, -5, 0, -1, 0, 0, 0, 2, -1, 0}, 98.189880, 0.000040, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 89.813490, 0.000030, 0.021000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 93.553260, 0.000090, 0.029000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 92.965380, 0.000060, 0.047000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -3, 0, 1}, 76.543210, 0.000020, 0.045000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -3, 1, 1}, 76.542860, 0.000020, 0.112000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, -2, 0}, 94.109350, 0.000030, 0.020000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 94.183360, 0.000200, 0.027000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 94.018690, 0.003390, 0.043000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, 2}, 93.292490, 0.000020, 0.277000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 93.332890, 0.004100, 0.100000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 94.907520, 0.000120, 0.305000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 270.748460, 0.000030, 0.060000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, -2, 1}, 76.521440, 0.000010, 0.042000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, -1, -1}, 86.338340, 0.000030, 0.027000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, -1, 1}, 76.466890, 0.000040, 0.093000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, -1}, 76.527620, 0.000360, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 269.871250, 0.000060, 0.092000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 256.711540, 0.000830, 0.391000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 1, -1}, 78.639360, 0.000160, 0.091000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 1, 1}, 256.537930, 0.000090, 0.063000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 2, -1}, 256.361330, 0.000020, 0.450000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 2, 0}, 268.088700, 0.000010, 0.064000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -3, 0}, 272.525790, 0.000030, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 271.910370, 0.000340, 0.040000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 270.661530, 0.005410, 0.085000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 256.450970, 0.000080, 0.084000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 130.839920, 0.000440, 0.666000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 76.368930, 0.000030, 0.067000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 262.237940, 0.000210, 0.068000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 279.761950, 0.000010, 0.036000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -2, -1}, 76.513430, 0.000090, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -2, 0}, 278.418390, 0.000010, 0.079000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -2, 1}, 251.712250, 0.000010, 1.279000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 76.513460, 0.001350, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 89.427270, 0.000080, 1.626000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 256.445580, 0.000790, 0.071000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, -3}, 257.156320, 0.000010, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 76.510910, 0.009870, 2.231000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 88.050330, 0.000290, 0.072000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 255.846930, 0.001180, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 76.512820, 0.001260, 0.073000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 88.596210, 0.000020, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, 1}, 256.096240, 0.000130, 0.025000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 2, -1}, 76.513500, 0.000090, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -4, 0}, 275.492100, 0.000010, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -3, 0}, 299.972970, 0.000030, 0.074000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 90.857910, 0.002690, 3.678000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, -2}, 91.516500, 0.000040, 0.072000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, -1}, 76.465680, 0.000030, 2.280000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 91.399170, 0.029520, 0.077000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, 2}, 271.592190, 0.000060, 0.025000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, -2}, 92.393260, 0.000250, 1.652000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 76.463130, 0.000170, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 92.152560, 0.004110, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 92.833620, 0.000400, 0.025000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 92.228520, 0.000040, 0.019000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, -2, -1}, 256.515270, 0.000010, 0.754000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, -1, -1}, 256.516020, 0.000130, 0.084000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, -1, 1}, 256.513170, 0.000030, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 0, -1}, 76.514260, 0.000080, 0.040000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 0, 0}, 92.480610, 0.000020, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 0, 1}, 256.513190, 0.000020, 0.019000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 1, -1}, 76.510840, 0.000010, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -3, 0}, 93.053240, 0.000060, 0.089000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 89.662410, 0.000380, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -1, 0}, 89.114850, 0.000250, 0.027000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 96.132630, 0.000110, 0.020000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, 1, 0}, 92.646790, 0.000010, 0.016000},
	{{0, 4, -5, 0, 0, 1, 0, 0, 2, -1, 0}, 359.716910, 0.000050, 0.077000},
	{{0, 4, -5, 0, 0, 2, 0, 0, 2, -3, 0}, 261.381640, 0.000010, 0.074000},
	{{0, 4, -5, 0, 0, 2, 0, 0, 2, -1, 0}, 81.381640, 0.000010, 0.077000},
	{{0, 4, -5, 0, 1, 0, 0, 0, -2, 0, 0}, 189.195210, 0.000100, 0.043000},
	{{0, 4, -5, 0, 1, 0, 0, 0, -2, 1, 0}, 188.103640, 0.000010, 0.101000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 0, -1, 0}, 178.138180, 0.000040, 0.086000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 0, 0, 0}, 171.360380, 0.000030, 0.630000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 0, 1, 0}, 178.009470, 0.000030, 0.067000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 2, -3, 0}, 359.769120, 0.000030, 0.074000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 2, -1, 0}, 89.765510, 0.000050, 0.077000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 2, 0, 0}, 178.713080, 0.000010, 0.038000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 2, 2, 0}, 358.713080, 0.000010, 0.019000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 0, 0, 0}, 62.741920, 0.000020, 0.599000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 2, -3, 0}, 229.894150, 0.000020, 0.075000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 2, -2, 0}, 240.316860, 0.000010, 9.679000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 2, -1, 0}, 49.894150, 0.000020, 0.076000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 2, 0, 0}, 60.323310, 0.000040, 0.038000},
	{{0, 4, -5, 0, 3, 0, 0, 0, 2, -3, 0}, 91.255350, 0.000010, 0.075000},
	{{0, 4, -5, 0, 3, 0, 0, 0, 2, -2, 0}, 38.073200, 0.000020, 52.601000},
	{{0, 4, -5, 0, 3, 0, 0, 0, 2, -1, 0}, 271.255350, 0.000010, 0.076000},
	{{0, 4, -5, 2, 0, 0, 0, 0, 2, -3, 0}, 224.657630, 0.000040, 0.080000},
	{{0, 4, -5, 2, 0, 0, 0, 0, 2, -1, 0}, 224.657630, 0.000040, 0.071000},
	{{0, 4, -5, 3, 0, 0, 0, 0, -2, 0, 0}, 236.427210, 0.000020, 0.046000},
	{{0, 4, -5, 3, 0, 0, 0, 0, -2, 2, 0}, 236.427210, 0.000020, 0.205000},
	{{0, 4, -4, -8, 0, 0, 0, 0, -2, 2, 0}, 295.867600, 0.000020, 44.178000},
	{{0, 4, -4, 0, -2, 0, 0, 0, -2, 0, 0}, 205.438020, 0.000010, 0.045000},
	{{0, 4, -4, 0, -1, 0, 0, 0, -2, 0, 0}, 190.216320, 0.000050, 0.045000},
	{{0, 4, -4, 0, -1, 0, 0, 0, -2, 1, 0}, 13.054830, 0.000030, 0.110000},
	{{0, 4, -4, 0, -1, 0, 0, 0, -2, 2, 0}, 185.514980, 0.000010, 0.239000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 0, -2, 0}, 193.054830, 0.000010, 0.042000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 0, 0, 0}, 51.536230, 0.000010, 0.414000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 2, -2, 0}, 14.079310, 0.000010, 1.553000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 2, -1, 0}, 12.648580, 0.000060, 0.072000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 2, 0, 0}, 194.079310, 0.000010, 0.037000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -4, 0, 0}, 0.084150, 0.000050, 0.021000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -4, 1, 0}, 359.746810, 0.000090, 0.030000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -4, 2, 0}, 359.853600, 0.000060, 0.049000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -3, 0, 0}, 357.748990, 0.000010, 0.029000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, -2, 0}, 359.522720, 0.000080, 0.021000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 358.924680, 0.000370, 0.028000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 359.152100, 0.004690, 0.045000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 0, 2}, 0.739470, 0.000030, 0.217000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 359.208430, 0.004390, 0.111000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 359.089540, 0.000330, 0.234000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 358.924070, 0.000050, 0.057000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 180.039120, 0.000020, 0.043000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 255.419440, 0.000010, 0.043000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 1.404560, 0.000140, 0.101000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 15.510970, 0.000050, 0.281000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 1, 0}, 359.939320, 0.000040, 0.295000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -3, 0}, 0.791260, 0.000030, 0.027000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 0.574600, 0.000570, 0.042000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 0.255430, 0.008820, 0.093000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -1, 2}, 180.050050, 0.000020, 0.062000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, -2}, 178.792300, 0.000100, 0.041000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 180.070810, 0.046260, 0.400000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, 2}, 358.726170, 0.000070, 0.034000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, -2}, 180.090620, 0.000170, 0.090000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 180.076540, 0.007460, 0.063000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, 2}, 0.093670, 0.000030, 0.023000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 180.009930, 0.000560, 0.034000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 3, 0}, 179.809780, 0.000040, 0.024000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 0.947930, 0.000100, 0.086000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 189.951830, 0.000040, 0.085000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 0.677010, 0.000120, 0.619000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 2.668340, 0.000020, 0.067000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 190.909120, 0.000370, 0.690000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 0.102280, 0.001110, 0.067000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 10.943720, 0.000020, 0.035000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 189.951830, 0.000040, 0.068000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 0.139120, 0.000060, 0.036000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 180.607570, 0.000140, 0.080000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -2, -2}, 179.703680, 0.000010, 0.038000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 179.883310, 0.001900, 1.374000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -2, 2}, 0.027460, 0.000010, 0.036000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, -2}, 179.692250, 0.000170, 0.078000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 180.009790, 0.082350, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, 2}, 0.030580, 0.000160, 0.024000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, -2}, 180.016820, 0.003920, 2.535000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 0.095830, 0.009090, 0.037000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, 2}, 180.044910, 0.000010, 0.018000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 0.081950, 0.000800, 0.025000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 359.892010, 0.000090, 0.019000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -3, -1}, 176.996850, 0.000010, 0.074000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -3, 0}, 180.022810, 0.000050, 6.292000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -2, 0}, 180.107750, 0.000390, 0.076000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 356.996850, 0.000010, 0.077000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, 0, -2}, 180.064520, 0.000040, 0.078000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, 0, 0}, 0.068820, 0.000040, 0.025000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, 1, 0}, 0.064550, 0.000010, 0.019000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -3, 0}, 178.039620, 0.000010, 0.082000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -2, 0}, 180.044430, 0.001110, 0.039000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -1, -2}, 180.291560, 0.000040, 0.084000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 180.093930, 0.000530, 0.026000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 0, -2}, 0.081770, 0.000020, 0.040000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 359.940880, 0.000040, 0.019000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 1, 0}, 0.229600, 0.000050, 0.015000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 6, -3, 0}, 180.017410, 0.000020, 0.027000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 6, -2, 0}, 180.023850, 0.000020, 0.020000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 6, -1, 0}, 0.038610, 0.000020, 0.016000},
	{{0, 4, -4, 0, 1, 0, 0, 0, -2, 0, 0}, 345.497240, 0.000050, 0.045000},
	{{0, 4, -4, 0, 1, 0, 0, 0, -2, 1, 0}, 171.264160, 0.000030, 0.112000},
	{{0, 4, -4, 0, 1, 0, 0, 0, 0, 0, 0}, 171.264160, 0.000020, 0.387000},
	{{0, 4, -4, 0, 1, 0, 0, 0, 2, -3, 0}, 168.802030, 0.000020, 0.080000},
	{{0, 4, -4, 0, 1, 0, 0, 0, 2, -1, 0}, 140.447580, 0.000060, 0.071000},
	{{0, 4, -3, -4, 0, 0, 0, 0, 0, 0, 0}, 30.446650, 0.000010, 0.727000},
	{{0, 4, -3, -3, 0, 0, 0, 0, 2, -3, 0}, 304.593590, 0.000010, 0.076000},
	{{0, 4, -3, -3, 0, 0, 0, 0, 2, -2, 0}, 303.526010, 0.000040, 7.518000},
	{{0, 4, -3, -3, 0, 0, 0, 0, 2, -1, 0}, 304.593590, 0.000010, 0.075000},
	{{0, 4, -3, -3, 0, 0, 0, 0, 2, 0, 0}, 303.563430, 0.000010, 0.038000},
	{{0, 4, -3, -1, 0, 0, 0, 0, 0, 0, 0}, 180.434560, 0.000020, 0.337000},
	{{0, 4, -3, 0, -2, 0, 0, 0, -2, 0, 0}, 78.344220, 0.000010, 0.047000},
	{{0, 4, -3, 0, -2, 0, 0, 0, -2, 1, 0}, 119.790240, 0.000010, 0.123000},
	{{0, 4, -3, 0, -2, 0, 0, 0, -2, 2, 0}, 88.127060, 0.000030, 0.196000},
	{{0, 4, -3, 0, -1, 0, 0, 0, -2, 0, 0}, 178.722420, 0.000010, 0.047000},
	{{0, 4, -3, 0, -1, 0, 0, 0, -2, 2, 0}, 178.722420, 0.000010, 0.193000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 0, -2, 0}, 181.706490, 0.000010, 0.043000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 0, 0, 0}, 181.094470, 0.000050, 0.293000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 0, 2, 0}, 181.138910, 0.000020, 0.033000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 2, -3, 0}, 3.964210, 0.000020, 0.086000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 2, -1, 0}, 183.964210, 0.000020, 0.067000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 2, 0, 0}, 3.964980, 0.000070, 0.036000},
	{{0, 4, -3, 0, 0, -1, 0, 0, -2, 0, 0}, 180.214190, 0.000010, 0.047000},
	{{0, 4, -3, 0, 0, -1, 0, 0, -2, 2, 0}, 0.214190, 0.000010, 0.191000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 77.049440, 0.000020, 0.022000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 252.255740, 0.000010, 0.031000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -3, 0, 1}, 103.298940, 0.000020, 0.050000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -3, 1, 1}, 103.313720, 0.000010, 0.144000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 253.418380, 0.000060, 0.029000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 251.393080, 0.000420, 0.047000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 253.263290, 0.000440, 0.125000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 273.914900, 0.000040, 0.190000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 86.933750, 0.000010, 0.054000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, -1, -1}, 102.955310, 0.000030, 0.028000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 283.646780, 0.000070, 0.115000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 102.907430, 0.000330, 0.045000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 283.311010, 0.000590, 0.220000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 1, -1}, 103.299640, 0.000170, 0.111000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 283.310550, 0.000050, 0.056000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 257.190220, 0.000060, 0.043000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 254.501730, 0.000600, 0.103000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 283.305110, 0.000030, 0.101000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 101.980350, 0.000480, 0.286000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 103.316370, 0.000020, 0.059000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 81.088600, 0.000100, 0.060000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 103.320500, 0.000290, 0.093000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 283.327760, 0.000170, 0.062000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 103.342360, 0.001960, 0.408000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 283.327450, 0.000130, 0.034000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 103.322320, 0.000240, 0.064000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 1, 1}, 283.330090, 0.000020, 0.024000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 2, -1}, 103.319210, 0.000010, 0.035000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 80.979470, 0.000030, 0.087000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 258.846140, 0.000060, 0.579000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 259.394180, 0.000810, 0.067000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 259.840550, 0.000030, 0.717000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 283.346340, 0.000050, 0.067000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 80.722650, 0.000250, 0.035000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 76.587250, 0.000060, 0.024000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, -2, -1}, 103.318170, 0.000010, 1.483000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, -1, -1}, 103.324930, 0.000130, 0.072000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, 0, -1}, 103.328240, 0.000030, 0.037000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 85.378530, 0.000010, 0.025000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 95.414540, 0.000010, 0.019000},
	{{0, 4, -3, 0, 1, 0, 0, 0, 0, 0, 0}, 16.005140, 0.000010, 0.279000},
	{{0, 4, -2, -4, 0, 0, 0, 0, 0, 0, 0}, 269.383220, 0.000010, 0.421000},
	{{0, 4, -2, -4, 0, 0, 0, 0, 2, -3, 0}, 302.016440, 0.000020, 0.079000},
	{{0, 4, -2, -4, 0, 0, 0, 0, 2, -1, 0}, 302.016440, 0.000020, 0.072000},
	{{0, 4, -2, -2, 0, 0, 0, 0, -2, 0, 0}, 0.654840, 0.000010, 0.047000},
	{{0, 4, -2, -2, 0, 0, 0, 0, -2, 2, 0}, 0.654840, 0.000010, 0.192000},
	{{0, 4, -2, -2, 0, 0, 0, 0, 0, -2, 0}, 179.892700, 0.000010, 0.043000},
	{{0, 4, -2, -2, 0, 0, 0, 0, 0, 0, 0}, 179.892700, 0.000010, 0.291000},
	{{0, 4, -2, 0, -3, 0, 0, 0, 0, 0, 0}, 189.692870, 0.000010, 0.235000},
	{{0, 4, -2, 0, -2, 0, 0, 0, -2, -2, 0}, 0.104260, 0.000010, 0.021000},
	{{0, 4, -2, 0, -2, 0, 0, 0, -2, 2, 0}, 0.310920, 0.000010, 0.164000},
	{{0, 4, -2, 0, -2, 0, 0, 0, 0, 0, 0}, 180.065910, 0.000020, 0.231000},
	{{0, 4, -2, 0, -1, 0, 0, 0, -2, 0, 0}, 90.165280, 0.000030, 0.049000},
	{{0, 4, -2, 0, -1, 0, 0, 0, -2, 2, 0}, 90.165280, 0.000030, 0.162000},
	{{0, 4, -2, 0, -1, 0, 0, 0, 0, 0, 0}, 347.768660, 0.000010, 0.226000},
	{{0, 4, -2, 0, -1, 0, 0, 0, 0, 2, 0}, 347.768660, 0.000010, 0.032000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 30.764000, 0.000030, 0.030000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 31.881950, 0.000290, 0.049000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 29.685540, 0.000190, 0.143000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 57.827610, 0.000010, 0.159000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 207.579420, 0.000030, 0.127000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 189.512360, 0.000020, 0.180000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 340.906760, 0.000020, 0.045000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 33.168000, 0.000190, 0.114000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 25.922180, 0.001470, 0.222000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 26.019360, 0.000150, 0.056000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 11.209630, 0.000030, 0.290000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 206.087290, 0.000020, 0.059000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 26.224890, 0.000020, 0.367000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 26.126900, 0.000240, 0.063000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 206.455400, 0.000100, 0.034000},
	{{0, 4, -1, -7, 0, 0, 0, 0, 2, -3, 0}, 2.922890, 0.000010, 0.075000},
	{{0, 4, -1, -7, 0, 0, 0, 0, 2, -2, 0}, 354.175400, 0.000030, 159.092000},
	{{0, 4, -1, -7, 0, 0, 0, 0, 2, -1, 0}, 2.922890, 0.000010, 0.075000},
	{{0, 4, -1, -5, 0, 0, 0, 0, 0, 0, 0}, 121.799390, 0.000010, 0.352000},
	{{0, 4, -1, 0, -3, 0, 0, 0, -2, 0, 0}, 356.691050, 0.000010, 0.051000},
	{{0, 4, -1, 0, -3, 0, 0, 0, -2, 2, 0}, 176.691050, 0.000010, 0.142000},
	{{0, 4, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 288.334380, 0.000050, 0.052000},
	{{0, 4, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 289.272010, 0.000020, 0.167000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 288.808190, 0.000080, 0.182000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 307.798360, 0.000020, 0.225000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 37.359960, 0.000030, 0.268000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 293.327340, 0.000020, 0.059000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 72.708580, 0.000020, 0.033000},
	{{0, 4, -1, 0, 1, 0, 0, 0, 2, 0, 0}, 132.618900, 0.000050, 0.033000},
	{{0, 4, 0, 0, -2, 0, 0, 0, 2, -2, 0}, 153.690310, 0.000010, 0.219000},
	{{0, 4, 0, 0, -2, 0, 0, 0, 2, 0, 0}, 153.690310, 0.000010, 0.032000},
	{{0, 4, 0, 0, -1, 0, 0, 0, 2, -2, 0}, 142.380520, 0.000020, 0.215000},
	{{0, 4, 0, 0, -1, 0, 0, 0, 2, -1, 0}, 141.307110, 0.000020, 0.056000},
	{{0, 4, 0, 0, -1, 0, 0, 0, 2, 0, 0}, 149.626970, 0.000040, 0.032000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 269.033620, 0.000040, 0.154000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 128.137580, 0.000010, 0.051000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 308.152820, 0.000040, 0.030000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 3, 0}, 128.137580, 0.000010, 0.022000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 308.140050, 0.000010, 0.117000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 127.988520, 0.000050, 0.212000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 129.663690, 0.000030, 0.032000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 308.137580, 0.000020, 0.022000},
	{{0, 4, 0, 0, 1, 0, 0, 0, 2, -2, 0}, 299.161760, 0.000010, 0.208000},
	{{0, 4, 0, 0, 1, 0, 0, 0, 2, -1, 0}, 299.516440, 0.000030, 0.055000},
	{{0, 4, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 296.644260, 0.000030, 0.032000},
	{{0, 4, 1, 0, -2, 0, 0, 0, 2, -2, 0}, 225.021010, 0.000010, 0.180000},
	{{0, 4, 1, 0, -2, 0, 0, 0, 2, 0, 0}, 45.021010, 0.000010, 0.031000},
	{{0, 4, 1, 0, -1, 0, 0, 0, 2, -3, 0}, 129.245440, 0.000020, 0.131000},
	{{0, 4, 1, 0, -1, 0, 0, 0, 2, -1, 0}, 129.245440, 0.000020, 0.053000},
	{{0, 4, 1, 0, -1, 0, 0, 0, 2, 0, 0}, 128.621940, 0.000040, 0.031000},
	{{0, 4, 1, 0, -1, 0, 0, 0, 2, 2, 0}, 129.529850, 0.000010, 0.017000},
	{{0, 4, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 302.062740, 0.000040, 0.058000},
	{{0, 4, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 302.066680, 0.000050, 0.108000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 59.129410, 0.000020, 0.133000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 217.389220, 0.000010, 0.133000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 218.707380, 0.000020, 0.175000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 217.389220, 0.000010, 0.053000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 218.707380, 0.000020, 0.031000},
	{{0, 4, 2, -2, 0, 0, 0, 0, 2, -2, 0}, 308.088150, 0.000010, 0.177000},
	{{0, 4, 2, -2, 0, 0, 0, 0, 2, 0, 0}, 308.088150, 0.000010, 0.031000},
	{{0, 4, 2, 0, -3, 0, 0, 0, 2, -2, 0}, 318.107820, 0.000010, 0.154000},
	{{0, 4, 2, 0, -3, 0, 0, 0, 2, 0, 0}, 318.107820, 0.000010, 0.030000},
	{{0, 4, 2, 0, -2, 0, 0, 0, 0, 0, 0}, 308.356540, 0.000010, 0.120000},
	{{0, 4, 2, 0, -2, 0, 0, 0, 0, 2, 0}, 128.356540, 0.000010, 0.029000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 333.371040, 0.000020, 0.118000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 153.371040, 0.000030, 0.050000},
	{{0, 4, 5, 0, 0, 0, 0, 0, -2, 1, 0}, 169.960040, 0.000020, 49.129000},
	{{0, 4, 7, 0, -3, 0, 0, 0, 0, -1, 0}, 163.134580, 0.000020, 152.083000},
	{{0, 4, 22, -32, 0, 0, 0, 0, -2, 1, 0}, 215.645940, 0.000010, 154.818000},
	{{0, 5, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 289.621970, 0.000010, 0.033000},
	{{0, 5, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 289.621970, 0.000010, 0.244000},
	{{0, 5, -14, 15, 0, 0, 0, 0, 2, 0, -2}, 337.847420, 0.000020, 214.986000},
	{{0, 5, -13, 6, 0, 0, 0, 0, -2, 1, 0}, 290.075130, 0.000040, 0.076000},
	{{0, 5, -13, 6, 0, 0, 0, 0, -2, 2, 0}, 110.090790, 0.000010, 10.901000},
	{{0, 5, -13, 6, 0, 0, 0, 0, -2, 3, 0}, 290.075130, 0.000040, 0.075000},
	{{0, 5, -12, 0, 2, 0, 0, 0, -2, 0, 0}, 322.734840, 0.000020, 0.035000},
	{{0, 5, -12, 4, 0, 0, 0, 0, -2, 1, 0}, 343.456500, 0.000010, 0.076000},
	{{0, 5, -12, 4, 0, 0, 0, 0, -2, 3, 0}, 343.456500, 0.000010, 0.075000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, -1, 0}, 218.754320, 0.000020, 0.024000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 217.499700, 0.000010, 0.036000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 223.945770, 0.000020, 0.070000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 217.499700, 0.000010, 0.910000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 66.968990, 0.000020, 0.062000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 266.750160, 0.000030, 0.348000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 66.968990, 0.000020, 0.096000},
	{{0, 5, -11, 0, 1, 0, 0, 0, -2, 1, 0}, 141.905830, 0.000030, 0.070000},
	{{0, 5, -11, 0, 2, 0, 0, 0, -2, 0, 0}, 231.651910, 0.000010, 0.036000},
	{{0, 5, -11, 0, 2, 0, 0, 0, -2, 1, 0}, 51.651920, 0.000040, 0.070000},
	{{0, 5, -11, 0, 2, 0, 0, 0, -2, 2, 0}, 231.651910, 0.000010, 1.076000},
	{{0, 5, -11, 0, 3, 0, 0, 0, -2, 0, 0}, 221.876490, 0.000020, 0.037000},
	{{0, 5, -11, 2, 0, 0, 0, 0, -2, 0, 0}, 231.769320, 0.000040, 0.038000},
	{{0, 5, -11, 2, 0, 0, 0, 0, -2, 1, 0}, 184.696530, 0.000010, 0.075000},
	{{0, 5, -11, 2, 0, 0, 0, 0, -2, 2, 0}, 252.888150, 0.000030, 28.573000},
	{{0, 5, -11, 2, 0, 0, 0, 0, -2, 3, 0}, 184.696530, 0.000010, 0.076000},
	{{0, 5, -10, 0, -1, 0, 0, 0, -2, 1, 0}, 156.699930, 0.000010, 0.074000},
	{{0, 5, -10, 0, -1, 0, 0, 0, -2, 3, 0}, 336.699930, 0.000010, 0.076000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 308.000220, 0.000030, 0.038000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 301.758050, 0.000050, 10.166000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 144.029500, 0.000020, 0.070000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 121.178660, 0.000030, 0.534000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 237.791400, 0.000010, 0.274000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 294.835600, 0.000030, 0.104000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 274.348260, 0.000030, 0.044000},
	{{0, 5, -10, 0, 0, 1, 0, 0, -2, 1, 0}, 232.355720, 0.000020, 0.075000},
	{{0, 5, -10, 0, 0, 3, 0, 0, -2, 1, 0}, 43.357670, 0.000030, 0.075000},
	{{0, 5, -10, 0, 0, 3, 0, 0, -2, 3, 0}, 43.357670, 0.000030, 0.075000},
	{{0, 5, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 51.183170, 0.000010, 0.038000},
	{{0, 5, -10, 0, 1, 0, 0, 0, -2, 1, 0}, 322.758290, 0.000050, 0.075000},
	{{0, 5, -10, 0, 1, 0, 0, 0, -2, 2, 0}, 88.455840, 0.000020, 71.113000},
	{{0, 5, -10, 0, 1, 0, 0, 0, -2, 3, 0}, 265.989290, 0.000010, 0.076000},
	{{0, 5, -10, 0, 1, 0, 0, 0, 0, -1, 0}, 50.731870, 0.000020, 0.066000},
	{{0, 5, -10, 0, 1, 0, 0, 0, 0, 0, 0}, 50.454460, 0.000030, 0.559000},
	{{0, 5, -10, 0, 1, 0, 0, 0, 0, 1, 0}, 50.731870, 0.000020, 0.087000},
	{{0, 5, -10, 0, 2, 0, 0, 0, -2, 1, 0}, 199.280880, 0.000020, 0.076000},
	{{0, 5, -10, 0, 2, 0, 0, 0, -2, 2, 0}, 319.761860, 0.000020, 14.237000},
	{{0, 5, -10, 0, 3, 0, 0, 0, -2, 1, 0}, 287.224580, 0.000010, 0.076000},
	{{0, 5, -10, 0, 3, 0, 0, 0, -2, 3, 0}, 107.224580, 0.000010, 0.075000},
	{{0, 5, -10, 3, 0, 0, 0, 0, -2, 0, 0}, 288.613250, 0.000010, 0.040000},
	{{0, 5, -10, 3, 0, 0, 0, 0, -2, 2, 0}, 288.613250, 0.000010, 0.668000},
	{{0, 5, -10, 3, 0, 0, 0, 0, 0, -1, 0}, 108.613250, 0.000020, 0.074000},
	{{0, 5, -10, 3, 0, 0, 0, 0, 0, 1, 0}, 108.613250, 0.000020, 0.077000},
	{{0, 5, -10, 7, 0, 0, 0, 0, 2, -3, 0}, 57.364390, 0.000010, 0.076000},
	{{0, 5, -10, 7, 0, 0, 0, 0, 2, -1, 0}, 57.364390, 0.000010, 0.075000},
	{{0, 5, -9, -2, 0, 0, 0, 0, -2, 1, 0}, 282.067780, 0.000010, 0.075000},
	{{0, 5, -9, -2, 0, 0, 0, 0, -2, 3, 0}, 282.067780, 0.000010, 0.076000},
	{{0, 5, -9, 0, -1, 0, 0, 0, -2, 0, 0}, 242.121430, 0.000030, 0.039000},
	{{0, 5, -9, 0, -1, 0, 0, 0, -2, 1, 0}, 245.849290, 0.000010, 0.080000},
	{{0, 5, -9, 0, -1, 0, 0, 0, -2, 2, 0}, 234.935020, 0.000010, 1.224000},
	{{0, 5, -9, 0, -1, 0, 0, 0, -2, 3, 0}, 65.849290, 0.000010, 0.071000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -4, 0, 0}, 231.788110, 0.000020, 0.020000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -4, 2, 0}, 54.261620, 0.000010, 0.042000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 51.691480, 0.000010, 0.026000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 37.485690, 0.000050, 0.039000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 0, 2}, 231.788110, 0.000010, 0.810000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 56.690650, 0.000060, 0.081000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 44.850950, 0.000020, 1.109000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 2, 2}, 231.788110, 0.000010, 0.036000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 83.214330, 0.000030, 0.071000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 309.413720, 0.000130, 0.076000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 1, 0}, 321.173710, 0.000150, 68.379000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 2, 0}, 232.233050, 0.000040, 0.075000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 197.524110, 0.000170, 1.146000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 1, -2}, 51.788110, 0.000020, 0.069000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 172.349700, 0.000070, 0.081000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 128.610030, 0.000020, 0.087000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 173.772290, 0.000220, 0.094000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 173.572010, 0.000200, 0.042000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 173.896120, 0.000020, 0.027000},
	{{0, 5, -9, 0, 1, 0, 0, 0, -2, 0, 0}, 41.516550, 0.000030, 0.039000},
	{{0, 5, -9, 0, 1, 0, 0, 0, -2, 1, 0}, 41.895340, 0.000020, 0.082000},
	{{0, 5, -9, 0, 1, 0, 0, 0, -2, 2, 0}, 43.669930, 0.000010, 1.014000},
	{{0, 5, -9, 0, 1, 0, 0, 0, 0, 0, 0}, 233.640200, 0.000010, 1.269000},
	{{0, 5, -9, 2, 0, 0, 0, 0, 0, 0, 0}, 254.957210, 0.000010, 5.236000},
	{{0, 5, -9, 3, 0, 0, 0, 0, 1, -2, 1}, 188.345210, 0.000070, 413.749000},
	{{0, 5, -9, 5, 0, 0, 0, 0, 2, -3, 0}, 199.057920, 0.000020, 0.076000},
	{{0, 5, -9, 5, 0, 0, 0, 0, 2, -1, 0}, 199.057920, 0.000020, 0.075000},
	{{0, 5, -8, -3, 0, 0, 0, 0, -2, 0, 0}, 355.308390, 0.000010, 0.038000},
	{{0, 5, -8, -3, 0, 0, 0, 0, -2, 2, 0}, 355.308390, 0.000010, 3.262000},
	{{0, 5, -8, -2, 0, 0, 0, 0, -2, 1, 0}, 11.005760, 0.000020, 0.081000},
	{{0, 5, -8, -2, 0, 0, 0, 0, -2, 3, 0}, 11.005760, 0.000020, 0.071000},
	{{0, 5, -8, 0, -2, 0, 0, 0, 0, -1, 0}, 18.041240, 0.000030, 0.075000},
	{{0, 5, -8, 0, -2, 0, 0, 0, 0, 1, 0}, 18.041240, 0.000030, 0.076000},
	{{0, 5, -8, 0, -1, 0, 0, 0, -2, 0, 0}, 235.672620, 0.000010, 0.040000},
	{{0, 5, -8, 0, -1, 0, 0, 0, -2, 1, 0}, 55.672620, 0.000030, 0.087000},
	{{0, 5, -8, 0, -1, 0, 0, 0, 0, -1, 0}, 147.012580, 0.000020, 0.076000},
	{{0, 5, -8, 0, -1, 0, 0, 0, 0, 1, 0}, 147.012580, 0.000020, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 80.546040, 0.000030, 0.020000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -4, 1, 0}, 72.165310, 0.000060, 0.028000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 86.049060, 0.000050, 0.044000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, -2, 0}, 97.679620, 0.000030, 0.020000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 71.275380, 0.000220, 0.026000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 72.103780, 0.002310, 0.041000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 2}, 72.241170, 0.000050, 0.447000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 72.396510, 0.003370, 0.088000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 59.621850, 0.000110, 0.526000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 251.681620, 0.000070, 0.082000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -3, 0}, 66.908910, 0.000010, 0.025000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 67.593420, 0.000280, 0.038000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 69.478880, 0.004180, 0.076000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, -2}, 252.376030, 0.000010, 0.037000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 243.764310, 0.000060, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 70.235540, 0.022960, 7.836000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, 2}, 252.376030, 0.000010, 0.037000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 1, -1}, 63.752710, 0.000020, 25.549000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 69.452280, 0.004030, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 69.298900, 0.000270, 0.038000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 3, 0}, 68.823490, 0.000010, 0.025000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 67.688150, 0.000120, 1.080000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 255.044230, 0.000030, 0.080000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, 1, -1}, 272.367180, 0.000010, 0.081000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 73.525020, 0.000090, 0.607000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 72.298660, 0.002530, 0.086000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 0, -2}, 71.636090, 0.000040, 0.505000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 71.421360, 0.001660, 0.040000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 71.031930, 0.000170, 0.026000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 2, 0}, 71.630920, 0.000020, 0.019000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 3, 0, -1}, 272.204360, 0.000010, 0.042000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 72.856720, 0.000020, 0.043000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 71.870790, 0.000030, 0.028000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 71.635220, 0.000020, 0.020000},
	{{0, 5, -8, 0, 1, 0, 0, 0, 0, 0, 0}, 199.487770, 0.000010, 4.719000},
	{{0, 5, -8, 0, 2, 0, 0, 0, 0, -1, 0}, 91.998140, 0.000030, 0.077000},
	{{0, 5, -8, 0, 2, 0, 0, 0, 0, 0, 0}, 267.140240, 0.000050, 3.376000},
	{{0, 5, -8, 0, 2, 0, 0, 0, 0, 1, 0}, 91.998140, 0.000030, 0.074000},
	{{0, 5, -8, 0, 2, 0, 0, 0, 2, -1, 0}, 270.987120, 0.000020, 0.085000},
	{{0, 5, -8, 0, 3, 0, 0, 0, 0, 0, 0}, 193.738340, 0.000040, 2.628000},
	{{0, 5, -8, 2, 0, 0, 0, 0, 0, 0, 0}, 93.113650, 0.000010, 0.840000},
	{{0, 5, -8, 3, 0, 0, 0, 0, 2, -3, 0}, 356.822160, 0.000030, 0.075000},
	{{0, 5, -8, 3, 0, 0, 0, 0, 2, -2, 0}, 175.161670, 0.000020, 19.475000},
	{{0, 5, -8, 3, 0, 0, 0, 0, 2, -1, 0}, 356.822160, 0.000030, 0.076000},
	{{0, 5, -8, 4, 0, 0, 0, 0, 0, 0, 0}, 30.592270, 0.000010, 0.444000},
	{{0, 5, -7, -4, 0, 0, 0, 0, 0, 0, 0}, 112.336110, 0.000050, 1.001000},
	{{0, 5, -7, -4, 0, 0, 0, 0, 2, -1, 0}, 112.335210, 0.000040, 0.095000},
	{{0, 5, -7, -4, 0, 0, 0, 0, 2, 0, 0}, 112.335210, 0.000040, 0.042000},
	{{0, 5, -7, -3, 0, 0, 0, 0, 0, 0, 0}, 27.053460, 0.000010, 2.139000},
	{{0, 5, -7, -2, 0, 0, 0, 0, 0, -1, 0}, 166.343590, 0.000010, 0.076000},
	{{0, 5, -7, -2, 0, 0, 0, 0, 0, 1, 0}, 166.343590, 0.000010, 0.075000},
	{{0, 5, -7, 0, -2, 0, 0, 0, -2, 0, 0}, 51.832850, 0.000010, 0.042000},
	{{0, 5, -7, 0, -2, 0, 0, 0, -2, 2, 0}, 231.832850, 0.000010, 0.366000},
	{{0, 5, -7, 0, -1, 0, 0, 0, 1, 0, -1}, 207.413410, 0.000020, 95.659000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -4, 0, 0}, 167.947740, 0.000040, 0.021000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -4, 1, 0}, 165.473180, 0.000070, 0.028000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -4, 2, 0}, 165.113670, 0.000050, 0.046000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, -2, 0}, 167.045780, 0.000030, 0.020000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 166.645750, 0.000230, 0.027000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 169.340990, 0.002900, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 0, 2}, 168.297700, 0.000020, 0.309000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 168.349970, 0.003650, 0.097000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 173.540940, 0.000150, 0.345000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, -1, -1}, 169.327030, 0.000040, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, -1, 1}, 166.065230, 0.000060, 0.090000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 169.222250, 0.000340, 0.041000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 344.091040, 0.000080, 0.089000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 350.572980, 0.000450, 0.458000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 349.852230, 0.000090, 0.088000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 1, 1}, 0.615550, 0.000030, 0.065000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 2, -1}, 349.428960, 0.000030, 0.541000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 158.720950, 0.000070, 0.039000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 170.321840, 0.001420, 0.082000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 170.492270, 0.008180, 0.887000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 169.107440, 0.001290, 0.070000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 175.283730, 0.000090, 0.036000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -2, -1}, 169.357700, 0.000170, 0.038000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -2, 0}, 350.194020, 0.000020, 0.077000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 169.370650, 0.002710, 0.076000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, 0}, 155.875570, 0.000020, 4.156000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 350.544130, 0.000460, 0.073000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, -3}, 350.294410, 0.000020, 0.037000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 169.267620, 0.018100, 13.541000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 154.981520, 0.000200, 0.074000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 349.307210, 0.001630, 0.037000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 169.370650, 0.002710, 0.075000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 1, 1}, 349.282330, 0.000180, 0.025000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 2, -1}, 169.370650, 0.000180, 0.038000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 137.604690, 0.000020, 0.072000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 160.982710, 0.000110, 1.547000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, -2}, 195.249220, 0.000040, 0.070000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 164.299730, 0.002810, 0.079000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 0, -2}, 175.203340, 0.000070, 1.021000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 166.825960, 0.000930, 0.039000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 1, -2}, 15.249220, 0.000050, 0.081000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 167.059490, 0.000100, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, -2, -1}, 349.430250, 0.000030, 0.588000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, -1, -1}, 349.574830, 0.000180, 0.087000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, -1, 1}, 349.282360, 0.000040, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 0, -1}, 169.266840, 0.000140, 0.040000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 0, 1}, 349.282410, 0.000020, 0.019000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 1, -1}, 169.327030, 0.000040, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, -2, 0}, 148.051100, 0.000020, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, -1, -2}, 195.309120, 0.000010, 0.095000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, -1, 0}, 161.094270, 0.000050, 0.027000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, 0, -2}, 15.232700, 0.000040, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 166.816010, 0.000050, 0.020000},
	{{0, 5, -7, 0, 0, 1, 0, 0, 0, 0, 0}, 268.922240, 0.000010, 0.861000},
	{{0, 5, -7, 0, 2, 0, 0, 0, -2, 0, 0}, 179.898290, 0.000020, 0.043000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 0, -1, 0}, 359.859210, 0.000030, 0.084000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 0, 0, 0}, 175.803980, 0.000030, 0.771000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 0, 1, 0}, 359.859210, 0.000030, 0.069000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 0, 2, 0}, 359.880050, 0.000010, 0.036000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 2, -1, 0}, 164.686710, 0.000040, 0.078000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 2, 0, 0}, 359.953620, 0.000010, 0.038000},
	{{0, 5, -7, 0, 3, 0, 0, 0, 0, 0, 0}, 169.630020, 0.000010, 0.724000},
	{{0, 5, -7, 0, 3, 0, 0, 0, 2, 0, 0}, 170.128780, 0.000030, 0.038000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, -3, 0}, 337.239450, 0.000020, 0.078000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, -2, 0}, 0.181320, 0.000030, 2.398000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, -1, 0}, 337.239450, 0.000020, 0.073000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, 0, -2}, 185.594800, 0.000020, 11.983000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, 0, 0}, 0.181320, 0.000030, 0.037000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -4, 1, 0}, 9.412150, 0.000010, 0.028000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, -1, 0}, 9.412150, 0.000040, 0.026000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 0, 0}, 9.365730, 0.000320, 0.040000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 1, 0}, 10.184610, 0.000540, 0.087000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 2, 0}, 9.412150, 0.000020, 0.563000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, -2, 0}, 5.599850, 0.000040, 0.038000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, -1, 0}, 5.261160, 0.000530, 0.075000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 0, 0}, 9.004970, 0.003230, 1137.638000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 1, 0}, 5.255910, 0.000530, 0.075000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 2, 0}, 5.600340, 0.000040, 0.038000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, -2, 0}, 9.400210, 0.000020, 0.564000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, -1, 0}, 10.172220, 0.000540, 0.087000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, 0, 0}, 9.354980, 0.000320, 0.040000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, 1, 0}, 9.400210, 0.000040, 0.026000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 4, -1, 0}, 9.400210, 0.000010, 0.028000},
	{{0, 5, -6, -2, 0, 0, 0, 0, 1, 0, -1}, 79.700220, 0.000030, 95.404000},
	{{0, 5, -6, 0, -1, 0, 0, 0, -2, 0, 0}, 104.024580, 0.000010, 0.044000},
	{{0, 5, -6, 0, -1, 0, 0, 0, -2, 2, 0}, 284.024580, 0.000010, 0.262000},
	{{0, 5, -6, 0, -1, 0, 0, 0, 0, -2, 0}, 27.696450, 0.000010, 0.041000},
	{{0, 5, -6, 0, -1, 0, 0, 0, 0, 0, 0}, 207.696450, 0.000010, 0.489000},
	{{0, 5, -6, 0, -1, 0, 0, 0, 2, -3, 0}, 284.867000, 0.000020, 0.077000},
	{{0, 5, -6, 0, -1, 0, 0, 0, 2, -1, 0}, 104.867000, 0.000020, 0.074000},
	{{0, 5, -6, 0, 0, -1, 0, 0, 2, 0, -2}, 3.421590, 0.000020, 72.134000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, -2, 0}, 273.771490, 0.000020, 0.020000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 87.466160, 0.000140, 0.028000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 85.425600, 0.001130, 0.044000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 0, 2}, 86.204630, 0.000010, 0.236000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 1, -2}, 272.295770, 0.000010, 0.028000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 85.333080, 0.001160, 0.107000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 2, -2}, 92.322940, 0.000010, 0.044000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 82.613030, 0.000030, 0.256000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 282.775480, 0.000020, 0.058000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, -1, 1}, 256.396420, 0.000010, 0.099000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 75.479950, 0.000180, 0.042000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 93.818240, 0.000020, 0.098000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 256.596860, 0.000390, 0.314000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 1, -1}, 77.186860, 0.000080, 0.096000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 256.332220, 0.000040, 0.061000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -3, 0}, 92.138030, 0.000020, 0.027000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 91.094740, 0.000230, 0.041000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, -2}, 272.304560, 0.000120, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 91.398580, 0.003860, 0.090000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, -2}, 272.296490, 0.000720, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 76.384770, 0.000050, 0.089000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 272.668960, 0.003670, 0.470000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, 1}, 76.331560, 0.000020, 0.064000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, -2}, 92.390800, 0.000260, 0.087000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 272.322040, 0.000840, 0.065000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 2, -2}, 92.322940, 0.000080, 0.557000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 272.471570, 0.000050, 0.035000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -2, -1}, 76.375940, 0.000030, 0.039000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -1, -1}, 76.453090, 0.000460, 0.082000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 92.553310, 0.000030, 0.806000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 256.385190, 0.000300, 0.068000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, -2}, 92.297560, 0.000030, 0.081000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 76.355490, 0.003100, 0.931000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 90.734110, 0.000150, 0.069000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 253.959180, 0.000310, 0.036000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 1, -1}, 76.597210, 0.000370, 0.070000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 1, 1}, 254.703030, 0.000030, 0.024000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 2, -1}, 76.376280, 0.000030, 0.036000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -3, -2}, 272.347040, 0.000040, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 133.384440, 0.000020, 0.078000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, -2}, 272.312290, 0.000500, 0.038000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 102.696270, 0.000110, 2.828000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -4}, 92.436170, 0.000010, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -2}, 272.309520, 0.007420, 0.076000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -1}, 253.680240, 0.000030, 5.352000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 271.881330, 0.022670, 0.073000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, 2}, 91.818940, 0.000050, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -4}, 92.541500, 0.000070, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -2}, 272.295770, 0.052720, 49.790000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 256.369440, 0.000370, 0.074000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 92.870570, 0.003420, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -2}, 272.312290, 0.007380, 0.075000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -1}, 256.369440, 0.000020, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 93.238790, 0.000450, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 2, -2}, 272.312290, 0.000500, 0.038000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 92.366180, 0.000060, 0.019000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 3, -2}, 272.312290, 0.000040, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, -3, 0}, 91.847480, 0.000010, 1.875000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, -1, -1}, 262.234170, 0.000120, 0.080000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, 0, -1}, 76.401670, 0.000030, 0.039000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, 0, 0}, 92.454980, 0.000020, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -2, -2}, 92.322940, 0.000080, 0.570000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -2, 0}, 273.211210, 0.000320, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -1, -2}, 92.359930, 0.000390, 0.087000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 273.380240, 0.000150, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 0, -2}, 272.294710, 0.000490, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 98.616610, 0.000080, 0.019000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 1, -2}, 272.305610, 0.000100, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 1, 0}, 92.571590, 0.000010, 0.015000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 6, -2, -2}, 92.322940, 0.000010, 0.044000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 6, -1, -2}, 272.295770, 0.000010, 0.028000},
	{{0, 5, -6, 0, 0, 1, 0, 0, 2, -3, 0}, 179.770120, 0.000020, 0.078000},
	{{0, 5, -6, 0, 0, 1, 0, 0, 2, -1, 0}, 179.770120, 0.000020, 0.073000},
	{{0, 5, -6, 0, 1, 0, 0, 0, -2, 0, 0}, 191.566460, 0.000090, 0.044000},
	{{0, 5, -6, 0, 1, 0, 0, 0, -2, 1, 0}, 189.254240, 0.000010, 0.108000},
	{{0, 5, -6, 0, 1, 0, 0, 0, 0, 0, 0}, 324.106360, 0.000020, 0.452000},
	{{0, 5, -6, 0, 1, 0, 0, 0, 2, -3, 0}, 201.099420, 0.000020, 0.078000},
	{{0, 5, -6, 0, 2, 0, 0, 0, 0, 0, 0}, 72.942780, 0.000020, 0.436000},
	{{0, 5, -6, 0, 2, 0, 0, 0, 2, -3, 0}, 257.297300, 0.000020, 0.079000},
	{{0, 5, -6, 0, 2, 0, 0, 0, 2, -1, 0}, 257.297300, 0.000020, 0.073000},
	{{0, 5, -6, 1, 0, 0, 0, 0, 0, 0, 0}, 179.549750, 0.000010, 0.376000},
	{{0, 5, -6, 2, 0, 0, 0, 0, 2, -3, 0}, 223.656990, 0.000020, 0.084000},
	{{0, 5, -6, 2, 0, 0, 0, 0, 2, -2, 0}, 43.656990, 0.000020, 0.706000},
	{{0, 5, -6, 2, 0, 0, 0, 0, 2, -1, 0}, 223.656990, 0.000020, 0.068000},
	{{0, 5, -6, 2, 0, 0, 0, 0, 2, 0, 0}, 43.656990, 0.000020, 0.036000},
	{{0, 5, -6, 3, 0, 0, 0, 0, -2, 0, 0}, 236.420880, 0.000020, 0.048000},
	{{0, 5, -6, 3, 0, 0, 0, 0, -2, 2, 0}, 236.420880, 0.000020, 0.182000},
	{{0, 5, -5, -4, 0, 0, 0, 0, -2, 0, 0}, 261.370650, 0.000030, 0.042000},
	{{0, 5, -5, -4, 0, 0, 0, 0, -2, 1, 0}, 261.370650, 0.000020, 0.095000},
	{{0, 5, -5, -4, 0, 0, 0, 0, 0, 0, 0}, 244.151230, 0.000020, 0.999000},
	{{0, 5, -5, -3, 0, 0, 0, 0, 2, -3, 0}, 34.533180, 0.000010, 0.074000},
	{{0, 5, -5, -3, 0, 0, 0, 0, 2, -1, 0}, 34.533180, 0.000010, 0.077000},
	{{0, 5, -5, 0, -2, 0, 0, 0, -2, 0, 0}, 205.435270, 0.000010, 0.046000},
	{{0, 5, -5, 0, -1, 0, 0, 0, -2, 0, 0}, 191.397950, 0.000060, 0.046000},
	{{0, 5, -5, 0, -1, 0, 0, 0, -2, 1, 0}, 13.052070, 0.000010, 0.119000},
	{{0, 5, -5, 0, -1, 0, 0, 0, -2, 2, 0}, 185.531890, 0.000010, 0.208000},
	{{0, 5, -5, 0, -1, 0, 0, 0, -2, 3, 0}, 193.052070, 0.000010, 0.055000},
	{{0, 5, -5, 0, -1, 0, 0, 0, 0, -2, 0}, 193.052070, 0.000010, 0.043000},
	{{0, 5, -5, 0, -1, 0, 0, 0, 0, 0, 0}, 54.387630, 0.000020, 0.329000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -4, -1, 0}, 179.517090, 0.000010, 0.017000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 359.115430, 0.000030, 0.022000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 358.794440, 0.000030, 0.030000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 1.010110, 0.000020, 0.050000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 356.504640, 0.000040, 0.029000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 358.249870, 0.001200, 0.046000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 358.303510, 0.001040, 0.120000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 358.896310, 0.000180, 0.204000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 356.391490, 0.000030, 0.055000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, -1, 0}, 180.286010, 0.000010, 0.044000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 0.066010, 0.000190, 0.108000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 14.863390, 0.000040, 0.239000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, 1, 0}, 0.000570, 0.000050, 0.249000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -3, 0}, 356.536370, 0.000020, 0.027000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 359.837510, 0.000140, 0.043000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 358.679020, 0.001970, 0.099000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, -2}, 175.220010, 0.000110, 0.042000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 180.028510, 0.033050, 0.320000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 2}, 0.117890, 0.000030, 0.033000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 1, -2}, 184.320860, 0.000040, 0.096000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 180.051320, 0.005320, 0.061000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 180.027460, 0.000430, 0.034000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 3, 0}, 179.994270, 0.000040, 0.023000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 4, 0}, 180.028550, 0.000010, 0.018000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, -2, 0}, 183.178460, 0.000020, 0.091000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 190.024210, 0.000020, 0.089000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 0.137080, 0.000090, 0.446000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, -2}, 180.063530, 0.000040, 0.088000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 190.024210, 0.000270, 0.482000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 0.293820, 0.000640, 0.065000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 190.024210, 0.000020, 0.065000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 0.442440, 0.000030, 0.035000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 180.030080, 0.001240, 0.739000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, -2}, 174.648150, 0.000090, 0.082000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 180.072990, 0.037590, 0.068000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, 2}, 0.039140, 0.000080, 0.024000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, -2}, 179.897730, 0.001260, 0.980000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 0.047880, 0.009520, 0.036000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, 2}, 180.022090, 0.000040, 0.018000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 1, -2}, 355.443530, 0.000080, 0.070000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 0.016660, 0.000800, 0.024000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 359.874780, 0.000120, 0.018000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, -2, 0}, 0.158370, 0.000120, 0.073000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, -1, -2}, 0.062580, 0.000010, 7.515000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, -1, -1}, 179.361560, 0.000020, 0.074000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, 0, -2}, 0.063530, 0.000180, 0.075000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, 0, 0}, 0.080320, 0.000030, 0.025000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, 1, 0}, 0.066340, 0.000010, 0.019000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -3, 0}, 182.091880, 0.000030, 0.078000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 180.066020, 0.000520, 0.038000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -1, -2}, 180.049450, 0.000040, 0.080000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -1, 0}, 180.069250, 0.000160, 0.025000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, 0, -2}, 0.017790, 0.000020, 0.039000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 359.976340, 0.000100, 0.019000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, 1, 0}, 0.013500, 0.000040, 0.015000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 6, -1, 0}, 0.035010, 0.000010, 0.016000},
	{{0, 5, -5, 0, 1, 0, 0, 0, -2, 0, 0}, 345.679100, 0.000040, 0.046000},
	{{0, 5, -5, 0, 1, 0, 0, 0, -2, 1, 0}, 171.261400, 0.000010, 0.121000},
	{{0, 5, -5, 0, 1, 0, 0, 0, -2, 3, 0}, 351.261400, 0.000010, 0.055000},
	{{0, 5, -5, 0, 1, 0, 0, 0, 0, 0, 0}, 171.261400, 0.000020, 0.311000},
	{{0, 5, -5, 0, 1, 0, 0, 0, 2, -2, 0}, 166.289600, 0.000020, 0.695000},
	{{0, 5, -5, 0, 1, 0, 0, 0, 2, -1, 0}, 346.289640, 0.000040, 0.068000},
	{{0, 5, -5, 0, 1, 0, 0, 0, 2, 0, 0}, 158.617540, 0.000030, 0.036000},
	{{0, 5, -4, -3, 0, 0, 0, 0, 2, -3, 0}, 123.560680, 0.000020, 0.080000},
	{{0, 5, -4, -3, 0, 0, 0, 0, 2, -2, 0}, 303.560680, 0.000010, 1.318000},
	{{0, 5, -4, -3, 0, 0, 0, 0, 2, -1, 0}, 123.560680, 0.000020, 0.071000},
	{{0, 5, -4, -3, 0, 0, 0, 0, 2, 0, 0}, 303.560680, 0.000010, 0.037000},
	{{0, 5, -4, -1, 0, 0, 0, 0, 0, 0, 0}, 180.431800, 0.000010, 0.278000},
	{{0, 5, -4, 0, -3, 0, 0, 0, 0, 0, 0}, 113.521500, 0.000020, 0.258000},
	{{0, 5, -4, 0, -2, 0, 0, 0, 0, 0, 0}, 276.752510, 0.000010, 0.253000},
	{{0, 5, -4, 0, -1, 0, 0, 0, -2, 0, 0}, 178.698270, 0.000010, 0.048000},
	{{0, 5, -4, 0, -1, 0, 0, 0, -2, 1, 0}, 181.486610, 0.000030, 0.134000},
	{{0, 5, -4, 0, -1, 0, 0, 0, -2, 2, 0}, 178.698270, 0.000010, 0.172000},
	{{0, 5, -4, 0, -1, 0, 0, 0, -2, 3, 0}, 1.486610, 0.000030, 0.052000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 0, -2, 0}, 181.700830, 0.000010, 0.045000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 0, -1, 0}, 181.274810, 0.000010, 0.109000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 0, 0, 0}, 181.470930, 0.000080, 0.247000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 0, 1, 0}, 181.274810, 0.000010, 0.058000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 2, -2, 0}, 183.924900, 0.000020, 0.441000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 2, -1, 0}, 183.924900, 0.000020, 0.064000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 2, 0, 0}, 3.924900, 0.000020, 0.035000},
	{{0, 5, -4, 0, 0, -1, 0, 0, -2, 0, 0}, 180.211430, 0.000010, 0.048000},
	{{0, 5, -4, 0, 0, -1, 0, 0, -2, 2, 0}, 0.211430, 0.000010, 0.170000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -3, 0, 1}, 103.290320, 0.000020, 0.051000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 249.560000, 0.000020, 0.030000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 234.178590, 0.000080, 0.049000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 250.505910, 0.000180, 0.136000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 283.555450, 0.000020, 0.169000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 250.732140, 0.000010, 0.052000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, -1, -1}, 103.297200, 0.000020, 0.029000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 283.724750, 0.000050, 0.124000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 103.294700, 0.000290, 0.046000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 283.460540, 0.000420, 0.193000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 103.293230, 0.000140, 0.119000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 283.415040, 0.000030, 0.054000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 241.553160, 0.000010, 0.045000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 253.940780, 0.000190, 0.110000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 283.309560, 0.000010, 0.108000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 95.599540, 0.000290, 0.242000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 75.105900, 0.000050, 0.058000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 103.320650, 0.000220, 0.098000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 283.326690, 0.000120, 0.060000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 103.327210, 0.001450, 0.325000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 283.323880, 0.000080, 0.033000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 103.323710, 0.000160, 0.061000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 266.996820, 0.000040, 0.425000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 263.825340, 0.000520, 0.064000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, -2}, 262.831820, 0.000020, 0.495000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 283.348810, 0.000030, 0.065000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 81.926190, 0.000310, 0.035000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 78.764710, 0.000070, 0.024000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 103.323450, 0.000060, 0.069000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 3, 0, -1}, 103.326790, 0.000030, 0.036000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 83.784640, 0.000020, 0.025000},
	{{0, 5, -3, -13, 0, 0, 0, 0, -2, 1, 0}, 328.443500, 0.000010, 0.075000},
	{{0, 5, -3, -13, 0, 0, 0, 0, -2, 3, 0}, 328.443500, 0.000010, 0.075000},
	{{0, 5, -3, -4, 0, 0, 0, 0, 0, 0, 0}, 303.536130, 0.000010, 0.333000},
	{{0, 5, -3, -3, 0, 0, 0, 0, -2, 0, 0}, 336.219450, 0.000010, 0.047000},
	{{0, 5, -3, -3, 0, 0, 0, 0, -2, 2, 0}, 336.219450, 0.000010, 0.188000},
	{{0, 5, -3, -2, 0, 0, 0, 0, -2, 0, 0}, 0.621590, 0.000010, 0.048000},
	{{0, 5, -3, -2, 0, 0, 0, 0, -2, 1, 0}, 179.689770, 0.000020, 0.135000},
	{{0, 5, -3, -2, 0, 0, 0, 0, -2, 2, 0}, 0.621590, 0.000010, 0.171000},
	{{0, 5, -3, -2, 0, 0, 0, 0, 0, -2, 0}, 179.889940, 0.000010, 0.045000},
	{{0, 5, -3, -2, 0, 0, 0, 0, 0, 0, 0}, 179.889940, 0.000010, 0.246000},
	{{0, 5, -3, 0, -2, 0, 0, 0, -2, -2, 0}, 0.101500, 0.000010, 0.022000},
	{{0, 5, -3, 0, -2, 0, 0, 0, -2, 2, 0}, 0.308580, 0.000020, 0.149000},
	{{0, 5, -3, 0, -2, 0, 0, 0, 0, -2, 0}, 359.762980, 0.000020, 0.046000},
	{{0, 5, -3, 0, -1, 0, 0, 0, -2, 0, 0}, 89.843340, 0.000020, 0.051000},
	{{0, 5, -3, 0, -1, 0, 0, 0, -2, 2, 0}, 269.843340, 0.000020, 0.147000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 28.893560, 0.000030, 0.030000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 29.999730, 0.000280, 0.051000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 28.132680, 0.000170, 0.157000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 25.996160, 0.000020, 0.145000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 185.742200, 0.000010, 0.048000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 205.642460, 0.000020, 0.138000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 188.993500, 0.000010, 0.162000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 25.763460, 0.000170, 0.123000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 26.391200, 0.001190, 0.195000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 25.990230, 0.000120, 0.054000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 149.877870, 0.000010, 0.032000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 8.063020, 0.000020, 0.245000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 206.273310, 0.000020, 0.057000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 336.820290, 0.000020, 0.298000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 29.034890, 0.000190, 0.060000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 216.673130, 0.000100, 0.033000},
	{{0, 5, -2, 0, -3, 0, 0, 0, -2, 0, 0}, 356.688290, 0.000010, 0.053000},
	{{0, 5, -2, 0, -3, 0, 0, 0, -2, 2, 0}, 176.688290, 0.000010, 0.131000},
	{{0, 5, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 290.034970, 0.000020, 0.054000},
	{{0, 5, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 288.463150, 0.000020, 0.187000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 288.020330, 0.000080, 0.163000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 308.314130, 0.000010, 0.197000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 249.941980, 0.000020, 0.032000},
	{{0, 5, -2, 0, 1, 0, 0, 0, 2, 0, 0}, 133.506890, 0.000040, 0.032000},
	{{0, 5, -1, 0, -2, 0, 0, 0, 2, -2, 0}, 333.687550, 0.000010, 0.193000},
	{{0, 5, -1, 0, -2, 0, 0, 0, 2, 0, 0}, 153.687550, 0.000010, 0.032000},
	{{0, 5, -1, 0, -1, 0, 0, 0, 2, -2, 0}, 141.867890, 0.000010, 0.190000},
	{{0, 5, -1, 0, -1, 0, 0, 0, 2, 0, 0}, 144.851980, 0.000080, 0.031000},
	{{0, 5, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 181.550700, 0.000010, 0.057000},
	{{0, 5, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 181.550700, 0.000010, 0.112000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, -2, 0}, 146.797690, 0.000010, 0.052000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 128.212470, 0.000020, 0.163000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 187.974540, 0.000020, 0.140000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 128.141990, 0.000030, 0.049000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 128.059080, 0.000010, 0.127000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 128.033850, 0.000020, 0.187000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 308.059080, 0.000010, 0.054000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 131.410070, 0.000020, 0.031000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, 2, 0}, 128.212470, 0.000020, 0.017000},
	{{0, 5, -1, 0, 1, 0, 0, 0, 2, -2, 0}, 299.517200, 0.000030, 0.184000},
	{{0, 5, -1, 0, 1, 0, 0, 0, 2, 0, 0}, 298.037760, 0.000050, 0.031000},
	{{0, 5, 0, 0, -1, 0, 0, 0, 0, 0, 0}, 129.527090, 0.000010, 0.124000},
	{{0, 5, 0, 0, -1, 0, 0, 0, 0, 2, 0}, 129.527090, 0.000010, 0.029000},
	{{0, 5, 0, 0, -1, 0, 0, 0, 2, 0, 0}, 128.783760, 0.000040, 0.031000},
	{{0, 5, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 302.050320, 0.000050, 0.060000},
	{{0, 5, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 302.050320, 0.000050, 0.101000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 212.281910, 0.000030, 0.157000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 210.019500, 0.000020, 0.051000},
	{{0, 5, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 153.604800, 0.000020, 0.049000},
	{{0, 5, 31, -52, 0, 0, 0, 0, -2, 1, 0}, 323.507770, 0.000020, 587.442000},
	{{0, 6, -14, 4, 0, 0, 0, 0, -2, 0, 2}, 79.805100, 0.000020, 79.413000},
	{{0, 6, -14, 6, 0, 0, 0, 0, -1, 0, 1}, 162.817380, 0.000010, 334.478000},
	{{0, 6, -14, 8, 0, 0, 0, 0, 0, -1, 0}, 174.654970, 0.000010, 0.075000},
	{{0, 6, -14, 8, 0, 0, 0, 0, 0, 0, 0}, 53.992660, 0.000010, 151.217000},
	{{0, 6, -14, 8, 0, 0, 0, 0, 0, 1, 0}, 174.654970, 0.000010, 0.075000},
	{{0, 6, -13, 0, 2, 0, 0, 0, -2, 0, 0}, 322.793420, 0.000020, 0.036000},
	{{0, 6, -13, 0, 2, 0, 0, 0, -2, 1, 0}, 142.793420, 0.000020, 0.069000},
	{{0, 6, -13, 4, 0, 0, 0, 0, -2, 1, 0}, 81.323460, 0.000010, 0.079000},
	{{0, 6, -13, 4, 0, 0, 0, 0, -2, 3, 0}, 81.323460, 0.000010, 0.072000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -4, 0, 0}, 40.207540, 0.000020, 0.019000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 220.207540, 0.000020, 0.025000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, -1, 2}, 220.207540, 0.000010, 0.075000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 219.605420, 0.000030, 0.037000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 0, 2}, 218.342380, 0.000010, 7.177000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 220.207540, 0.000020, 0.073000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 1, 2}, 220.207540, 0.000010, 0.076000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 219.605420, 0.000030, 2.115000},
	{{0, 6, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 276.701500, 0.000020, 0.445000},
	{{0, 6, -12, 0, 0, 4, 0, 0, -2, 0, 2}, 46.326530, 0.000030, 282.735000},
	{{0, 6, -12, 0, 2, 0, 0, 0, -2, 0, 0}, 231.630250, 0.000040, 0.037000},
	{{0, 6, -12, 0, 2, 0, 0, 0, -2, 0, 2}, 202.988490, 0.000020, 34.155000},
	{{0, 6, -12, 0, 2, 0, 0, 0, 0, -1, 0}, 51.619460, 0.000010, 0.065000},
	{{0, 6, -12, 0, 2, 0, 0, 0, 0, 1, 0}, 51.619460, 0.000010, 0.089000},
	{{0, 6, -12, 0, 3, 0, 0, 0, -2, 0, 0}, 221.868180, 0.000010, 0.037000},
	{{0, 6, -12, 0, 3, 0, 0, 0, -2, 1, 0}, 39.653570, 0.000010, 0.074000},
	{{0, 6, -12, 0, 3, 0, 0, 0, -2, 2, 0}, 41.868180, 0.000010, 4.547000},
	{{0, 6, -12, 0, 3, 0, 0, 0, -2, 3, 0}, 39.653570, 0.000010, 0.077000},
	{{0, 6, -12, 0, 4, 0, 0, 0, -2, 1, 0}, 32.274260, 0.000030, 0.075000},
	{{0, 6, -12, 1, 0, 0, 0, 0, -2, 1, 0}, 142.430430, 0.000010, 0.076000},
	{{0, 6, -12, 1, 0, 0, 0, 0, -2, 3, 0}, 142.430430, 0.000010, 0.075000},
	{{0, 6, -12, 2, 0, 0, 0, 0, -2, 0, 0}, 233.649010, 0.000050, 0.039000},
	{{0, 6, -12, 2, 0, 0, 0, 0, -2, 2, 0}, 231.762220, 0.000040, 1.693000},
	{{0, 6, -12, 2, 0, 0, 0, 0, 0, -1, 0}, 231.831010, 0.000010, 0.069000},
	{{0, 6, -12, 2, 0, 0, 0, 0, 0, 1, 0}, 231.831010, 0.000010, 0.083000},
	{{0, 6, -11, -1, 0, 0, 0, 0, -2, 1, 0}, 42.480040, 0.000020, 0.075000},
	{{0, 6, -11, -1, 0, 0, 0, 0, -2, 2, 0}, 106.863280, 0.000020, 220.866000},
	{{0, 6, -11, -1, 0, 0, 0, 0, -2, 3, 0}, 42.480040, 0.000020, 0.075000},
	{{0, 6, -11, 0, -1, 0, 0, 0, -2, 1, 0}, 332.713390, 0.000030, 0.078000},
	{{0, 6, -11, 0, -1, 0, 0, 0, -2, 3, 0}, 152.713390, 0.000030, 0.073000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -4, 3, 0}, 352.400180, 0.000010, 0.091000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, -1, 2}, 324.025440, 0.000010, 0.081000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 358.530530, 0.000010, 0.038000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 208.826500, 0.000040, 0.079000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 1, 2}, 324.025440, 0.000010, 0.071000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 333.082130, 0.000060, 1.897000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 197.217630, 0.000040, 0.073000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 183.067570, 0.000020, 0.802000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 169.743280, 0.000020, 0.040000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 334.740310, 0.000020, 0.061000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 57.852840, 0.000010, 0.331000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 334.740310, 0.000020, 0.098000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 57.852840, 0.000010, 0.043000},
	{{0, 6, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 51.170750, 0.000010, 0.039000},
	{{0, 6, -11, 0, 1, 0, 0, 0, -2, 1, 0}, 344.447690, 0.000030, 0.079000},
	{{0, 6, -11, 0, 1, 0, 0, 0, -2, 2, 0}, 51.170750, 0.000010, 1.635000},
	{{0, 6, -11, 0, 1, 0, 0, 0, 0, -1, 0}, 50.436740, 0.000040, 0.069000},
	{{0, 6, -11, 0, 1, 0, 0, 0, 0, 0, 0}, 50.446150, 0.000030, 0.860000},
	{{0, 6, -11, 0, 1, 0, 0, 0, 0, 1, 0}, 50.436740, 0.000040, 0.083000},
	{{0, 6, -11, 0, 2, 0, 0, 0, -2, 1, 0}, 291.957400, 0.000030, 0.080000},
	{{0, 6, -11, 0, 2, 0, 0, 0, -2, 3, 0}, 291.957400, 0.000030, 0.072000},
	{{0, 6, -11, 0, 3, 0, 0, 0, 0, 0, 0}, 35.647740, 0.000040, 1.006000},
	{{0, 6, -11, 0, 3, 0, 0, 0, 2, -1, 0}, 35.901020, 0.000050, 0.095000},
	{{0, 6, -11, 0, 3, 0, 0, 0, 2, 0, 0}, 35.901020, 0.000040, 0.042000},
	{{0, 6, -11, 2, 0, 0, 0, 0, -2, 1, 0}, 95.396400, 0.000010, 0.086000},
	{{0, 6, -11, 2, 0, 0, 0, 0, -2, 3, 0}, 95.396400, 0.000010, 0.067000},
	{{0, 6, -11, 2, 0, 0, 0, 0, 0, -1, 0}, 98.600470, 0.000020, 0.074000},
	{{0, 6, -11, 2, 0, 0, 0, 0, 0, 1, 0}, 98.600470, 0.000020, 0.076000},
	{{0, 6, -11, 3, 0, 0, 0, 0, 0, -1, 0}, 288.604930, 0.000010, 0.077000},
	{{0, 6, -11, 3, 0, 0, 0, 0, 0, 1, 0}, 288.604930, 0.000010, 0.074000},
	{{0, 6, -10, -3, 0, 0, 0, 0, -2, 1, 0}, 86.499690, 0.000020, 0.075000},
	{{0, 6, -10, -3, 0, 0, 0, 0, -2, 3, 0}, 86.499690, 0.000020, 0.076000},
	{{0, 6, -10, 0, -1, 0, 0, 0, -2, 0, 0}, 254.105500, 0.000040, 0.040000},
	{{0, 6, -10, 0, -1, 0, 0, 0, -2, 1, 0}, 241.626130, 0.000070, 0.085000},
	{{0, 6, -10, 0, -1, 0, 0, 0, 0, -2, 2}, 323.899880, 0.000030, 425.789000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -4, 2, 0}, 17.615760, 0.000010, 0.043000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, -2, 0}, 51.704940, 0.000020, 0.019000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 94.972980, 0.000060, 0.040000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 0, 2}, 231.784070, 0.000030, 0.537000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 120.963430, 0.000070, 0.085000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 60.202670, 0.000020, 0.655000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 55.068040, 0.000030, 0.068000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 212.950890, 0.000040, 0.074000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 196.296760, 0.000080, 4.051000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 198.196440, 0.000050, 0.077000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 150.918110, 0.000010, 0.769000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 152.015180, 0.000100, 0.089000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 156.575380, 0.000070, 0.041000},
	{{0, 6, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 41.436530, 0.000030, 0.040000},
	{{0, 6, -10, 0, 1, 0, 0, 0, -2, 1, 0}, 39.000000, 0.000030, 0.086000},
	{{0, 6, -10, 0, 1, 0, 0, 0, -2, 3, 0}, 219.000000, 0.000030, 0.067000},
	{{0, 6, -10, 0, 1, 0, 0, 0, 0, -1, 0}, 66.603080, 0.000010, 0.075000},
	{{0, 6, -10, 0, 1, 0, 0, 0, 0, 1, 0}, 66.603080, 0.000010, 0.076000},
	{{0, 6, -10, 0, 2, 0, 0, 0, 0, -1, 0}, 312.044600, 0.000010, 0.075000},
	{{0, 6, -10, 0, 2, 0, 0, 0, 0, 0, 0}, 346.210800, 0.000020, 12.779000},
	{{0, 6, -10, 0, 2, 0, 0, 0, 0, 1, 0}, 312.044600, 0.000010, 0.076000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -4, 1, 0}, 293.079240, 0.000010, 0.028000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, -1, 0}, 293.079240, 0.000040, 0.026000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 0, 0}, 293.027680, 0.000390, 0.040000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 1, 0}, 293.591060, 0.000610, 0.087000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 2, 0}, 293.079820, 0.000020, 0.562000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, -2, 0}, 290.705470, 0.000050, 0.038000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, -1, 0}, 290.547060, 0.000680, 0.075000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 0, 0}, 292.614280, 0.003730, 165.227000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 1, 0}, 290.540030, 0.000680, 0.075000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 2, 0}, 290.705240, 0.000050, 0.038000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, -2, 0}, 293.070230, 0.000020, 0.566000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, -1, 0}, 293.586450, 0.000600, 0.087000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, 0, 0}, 293.019480, 0.000380, 0.040000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, 1, 0}, 293.070830, 0.000040, 0.026000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 4, -1, 0}, 293.070830, 0.000010, 0.028000},
	{{0, 6, -10, 0, 4, 0, 0, 0, 0, 0, 0}, 203.251750, 0.000030, 11.067000},
	{{0, 6, -9, -3, 0, 0, 0, 0, -2, 0, 0}, 355.303930, 0.000010, 0.039000},
	{{0, 6, -9, -3, 0, 0, 0, 0, -2, 1, 0}, 355.303930, 0.000010, 0.081000},
	{{0, 6, -9, -3, 0, 0, 0, 0, -2, 2, 0}, 355.303930, 0.000010, 1.073000},
	{{0, 6, -9, -3, 0, 0, 0, 0, -2, 3, 0}, 355.303930, 0.000010, 0.070000},
	{{0, 6, -9, -2, 0, 0, 0, 0, -2, 1, 0}, 191.214340, 0.000010, 0.085000},
	{{0, 6, -9, -2, 0, 0, 0, 0, -2, 3, 0}, 191.214340, 0.000010, 0.068000},
	{{0, 6, -9, -2, 0, 0, 0, 0, 0, -1, 0}, 190.995430, 0.000020, 0.074000},
	{{0, 6, -9, -2, 0, 0, 0, 0, 0, 1, 0}, 190.995430, 0.000020, 0.077000},
	{{0, 6, -9, 0, -1, 0, 0, 0, -2, 0, 0}, 235.634110, 0.000010, 0.042000},
	{{0, 6, -9, 0, -1, 0, 0, 0, 0, -1, 0}, 55.634110, 0.000010, 0.079000},
	{{0, 6, -9, 0, -1, 0, 0, 0, 0, 1, 0}, 55.634110, 0.000010, 0.072000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -4, 1, 0}, 71.477350, 0.000010, 0.028000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -4, 2, 0}, 122.825540, 0.000020, 0.045000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 68.840680, 0.000040, 0.027000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 71.388500, 0.000380, 0.042000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 71.741300, 0.000470, 0.093000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 57.383480, 0.000020, 0.396000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -1, -1, 1}, 246.551870, 0.000060, 0.087000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 250.051080, 0.000030, 0.086000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 64.409220, 0.000020, 0.039000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 67.703890, 0.000480, 0.080000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 71.175810, 0.002540, 1.328000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 70.987760, 0.000410, 0.071000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 71.355580, 0.000030, 0.037000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -2, 1}, 245.668850, 0.000140, 30.407000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -1, -1}, 66.453290, 0.000020, 0.074000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 69.383980, 0.000030, 7.470000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -1, 1}, 66.575580, 0.000290, 0.075000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 66.755490, 0.000210, 3.326000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 70.051050, 0.000150, 0.076000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 247.825660, 0.000010, 0.038000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 1, -1}, 66.453290, 0.000020, 0.077000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 267.405400, 0.000060, 0.980000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 265.568280, 0.000630, 0.082000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 266.191410, 0.000090, 0.039000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 4, -3, 0}, 269.337460, 0.000040, 0.096000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 270.100340, 0.000100, 0.042000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 4, -1, 0}, 270.179600, 0.000050, 0.027000},
	{{0, 6, -9, 0, 2, 0, 0, 0, 0, 0, 0}, 271.000060, 0.000030, 1.085000},
	{{0, 6, -9, 0, 2, 0, 0, 0, 2, -2, 0}, 271.045710, 0.000010, 1.173000},
	{{0, 6, -9, 0, 2, 0, 0, 0, 2, 0, 0}, 271.045710, 0.000010, 0.039000},
	{{0, 6, -9, 0, 3, 0, 0, 0, -2, 0, 0}, 177.705770, 0.000020, 0.042000},
	{{0, 6, -9, 0, 3, 0, 0, 0, 0, 0, 0}, 21.772410, 0.000020, 0.994000},
	{{0, 6, -9, 2, 0, 0, 0, 0, 0, 0, 0}, 92.787830, 0.000010, 0.551000},
	{{0, 6, -9, 2, 0, 0, 0, 0, 2, -3, 0}, 1.524690, 0.000030, 0.076000},
	{{0, 6, -9, 2, 0, 0, 0, 0, 2, -1, 0}, 1.524690, 0.000030, 0.075000},
	{{0, 6, -8, 0, -2, 0, 0, 0, -2, 0, 0}, 51.826510, 0.000010, 0.043000},
	{{0, 6, -8, 0, -2, 0, 0, 0, -2, 2, 0}, 231.826510, 0.000010, 0.298000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, -2, 0}, 347.139080, 0.000020, 0.020000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 350.841060, 0.000100, 0.028000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 308.485920, 0.000050, 0.044000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 172.680910, 0.000250, 0.103000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 335.370270, 0.000010, 0.284000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -1, 0, -1}, 168.612940, 0.000020, 0.042000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 357.491920, 0.000060, 0.356000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -1, 1, -1}, 211.021060, 0.000020, 0.093000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 348.506960, 0.000320, 0.040000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -1, -2}, 167.245850, 0.000030, 0.026000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 347.129790, 0.014410, 0.087000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 342.872890, 0.002620, 0.570000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 344.328610, 0.000350, 0.067000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 343.351920, 0.000010, 0.035000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, -2, 0}, 347.208520, 0.000020, 0.081000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, -1, -1}, 168.986090, 0.000100, 0.080000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 166.189680, 0.000080, 1.155000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, -1, 1}, 348.988290, 0.000060, 0.070000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 169.089770, 0.000820, 1.430000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 162.222730, 0.000090, 0.071000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 349.167700, 0.000080, 0.036000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 1, -1}, 168.986090, 0.000100, 0.072000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -4, 0}, 168.880150, 0.000130, 0.038000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -3, -2}, 347.546480, 0.000020, 0.025000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 168.894830, 0.001920, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -2, -2}, 347.101750, 0.000040, 0.037000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 167.126860, 0.059460, 47.898000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -2, 2}, 347.134170, 0.000070, 0.037000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, -2}, 167.246270, 0.000130, 0.073000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, -1}, 173.174520, 0.000010, 5.330000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 167.222620, 0.076670, 0.076000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 2}, 347.232070, 0.000170, 0.025000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, -2}, 169.189060, 0.000060, 2.822000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 169.101730, 0.000070, 0.077000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 167.440830, 0.005580, 0.038000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, 2}, 347.246200, 0.000030, 0.019000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 167.217700, 0.000410, 0.025000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 2, 0}, 167.289680, 0.000030, 0.019000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 3, -2, 0}, 347.111300, 0.000020, 0.081000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 3, -1, 0}, 347.245570, 0.000030, 0.039000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -4, 0}, 164.601910, 0.000030, 0.557000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -3, 0}, 166.385620, 0.000930, 0.087000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 167.165160, 0.001660, 0.040000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -1, -2}, 347.246040, 0.000020, 0.090000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 167.266940, 0.000800, 0.026000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 167.525630, 0.000130, 0.020000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 6, -4, 0}, 166.396820, 0.000010, 0.044000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 6, -3, 0}, 166.978110, 0.000030, 0.028000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 6, -2, 0}, 167.198400, 0.000020, 0.020000},
	{{0, 6, -8, 0, 0, 0, 1, 0, 2, -2, 0}, 95.812770, 0.000010, 111.409000},
	{{0, 6, -8, 0, 0, 1, 0, 0, 2, -3, 0}, 302.599670, 0.000010, 0.076000},
	{{0, 6, -8, 0, 0, 1, 0, 0, 2, -2, 0}, 85.798650, 0.000070, 76.512000},
	{{0, 6, -8, 0, 0, 1, 0, 0, 2, -1, 0}, 122.599670, 0.000010, 0.075000},
	{{0, 6, -8, 0, 1, 0, 0, 0, 0, -1, 0}, 64.227040, 0.000030, 0.088000},
	{{0, 6, -8, 0, 1, 0, 0, 0, 0, 0, 0}, 91.254110, 0.000010, 0.544000},
	{{0, 6, -8, 0, 1, 0, 0, 0, 2, -2, 0}, 21.554750, 0.000030, 15.767000},
	{{0, 6, -8, 0, 1, 0, 0, 0, 2, -1, 0}, 244.226970, 0.000130, 0.075000},
	{{0, 6, -8, 0, 2, 0, 0, 0, -2, 0, 0}, 179.891950, 0.000010, 0.044000},
	{{0, 6, -8, 0, 2, 0, 0, 0, -2, 2, 0}, 359.891950, 0.000010, 0.271000},
	{{0, 6, -8, 0, 2, 0, 0, 0, 0, -1, 0}, 359.871740, 0.000010, 0.088000},
	{{0, 6, -8, 0, 2, 0, 0, 0, 0, 1, 0}, 359.871740, 0.000010, 0.066000},
	{{0, 6, -8, 0, 2, 0, 0, 0, 2, -1, 0}, 357.288020, 0.000030, 0.075000},
	{{0, 6, -8, 0, 2, 0, 0, 0, 2, 0, 0}, 359.860720, 0.000020, 0.038000},
	{{0, 6, -8, 0, 3, 0, 0, 0, 2, -3, 0}, 169.171140, 0.000010, 0.077000},
	{{0, 6, -8, 0, 3, 0, 0, 0, 2, -2, 0}, 350.120460, 0.000010, 4.310000},
	{{0, 6, -8, 0, 3, 0, 0, 0, 2, -1, 0}, 169.171140, 0.000010, 0.074000},
	{{0, 6, -8, 0, 3, 0, 0, 0, 2, 0, 0}, 170.120460, 0.000010, 0.037000},
	{{0, 6, -8, 0, 4, 0, 0, 0, 2, 0, -2}, 341.341120, 0.000020, 58.227000},
	{{0, 6, -8, 2, 0, 0, 0, 0, 2, -2, 0}, 0.171230, 0.000020, 0.959000},
	{{0, 6, -8, 2, 0, 0, 0, 0, 2, 0, 0}, 353.933990, 0.000020, 0.036000},
	{{0, 6, -7, -2, 0, 0, 0, 0, 2, -3, 0}, 309.222470, 0.000010, 0.075000},
	{{0, 6, -7, -2, 0, 0, 0, 0, 2, -1, 0}, 309.222470, 0.000010, 0.076000},
	{{0, 6, -7, 0, -1, 0, 0, 0, -2, 0, 0}, 104.449980, 0.000020, 0.045000},
	{{0, 6, -7, 0, -1, 0, 0, 0, 0, 0, 0}, 263.984090, 0.000010, 0.375000},
	{{0, 6, -7, 0, -1, 0, 0, 0, 2, -3, 0}, 99.885810, 0.000010, 0.081000},
	{{0, 6, -7, 0, -1, 0, 0, 0, 2, -1, 0}, 279.885810, 0.000010, 0.071000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 99.198360, 0.000020, 0.028000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 89.947890, 0.000200, 0.045000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 88.468780, 0.000320, 0.115000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 283.820870, 0.000020, 0.221000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 76.253860, 0.000110, 0.043000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 91.702300, 0.000010, 0.104000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 256.237400, 0.000230, 0.263000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 76.279900, 0.000060, 0.102000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 1, 1}, 256.266940, 0.000030, 0.059000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 93.696520, 0.000040, 0.042000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 144.869160, 0.000370, 0.095000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 271.207030, 0.003950, 0.363000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 271.547810, 0.000770, 0.062000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 270.762200, 0.000040, 0.034000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -2, 0}, 273.164740, 0.000030, 0.088000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 76.254200, 0.000370, 0.087000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, 0}, 91.861020, 0.000020, 0.536000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 258.794420, 0.000160, 0.065000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 76.262260, 0.001600, 0.588000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 91.457190, 0.000110, 0.066000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 255.619040, 0.000100, 0.035000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 76.274340, 0.000180, 0.067000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 1, 1}, 255.995440, 0.000010, 0.024000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 2, 1}, 76.296130, 0.000020, 0.018000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 260.739630, 0.000200, 1.021000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, -2}, 272.265960, 0.000020, 0.079000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, -1}, 262.586580, 0.000010, 1.231000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 270.786300, 0.008110, 0.070000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, -2}, 272.265960, 0.000310, 1.549000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 256.249240, 0.000080, 0.071000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 94.322260, 0.001400, 0.036000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 1, -2}, 272.265960, 0.000020, 0.072000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 94.215700, 0.000190, 0.025000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 2, 0}, 90.147630, 0.000040, 0.019000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -3, -1}, 256.284220, 0.000010, 0.075000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -3, 0}, 272.443110, 0.000020, 10.856000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -2, -1}, 256.217800, 0.000210, 13.397000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -2, 0}, 92.341340, 0.000120, 0.075000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -1, -1}, 256.218730, 0.000760, 0.076000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, 0, -1}, 256.131730, 0.000020, 0.038000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, 0, 0}, 92.442290, 0.000020, 0.025000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, -2, 0}, 272.142280, 0.000130, 0.039000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, -1, 0}, 274.547300, 0.000070, 0.026000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 98.952620, 0.000070, 0.019000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, 1, 0}, 92.585470, 0.000010, 0.015000},
	{{0, 6, -7, 0, 1, 0, 0, 0, -2, 0, 0}, 192.896310, 0.000090, 0.046000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 0, -2, 0}, 358.837090, 0.000020, 0.042000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 0, -1, 0}, 178.698430, 0.000010, 0.096000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 0, 0, 0}, 351.203670, 0.000030, 0.352000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 0, 1, 0}, 178.698430, 0.000010, 0.062000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 2, -2, 0}, 178.615770, 0.000020, 0.940000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 2, 0, 0}, 178.615770, 0.000020, 0.036000},
	{{0, 6, -7, 0, 2, 0, 0, 0, 2, -2, 0}, 60.185760, 0.000020, 0.871000},
	{{0, 6, -7, 0, 2, 0, 0, 0, 2, 0, 0}, 60.185760, 0.000020, 0.036000},
	{{0, 6, -7, 2, 0, 0, 0, 0, 2, -2, 0}, 43.648680, 0.000010, 0.490000},
	{{0, 6, -7, 2, 0, 0, 0, 0, 2, 0, 0}, 43.648680, 0.000010, 0.035000},
	{{0, 6, -7, 3, 0, 0, 0, 0, -2, 0, 0}, 236.412560, 0.000020, 0.049000},
	{{0, 6, -7, 3, 0, 0, 0, 0, -2, 2, 0}, 236.412560, 0.000020, 0.163000},
	{{0, 6, -6, -7, 0, 0, 0, 0, 0, -1, 0}, 144.208470, 0.000010, 0.076000},
	{{0, 6, -6, -7, 0, 0, 0, 0, 0, 1, 0}, 144.208470, 0.000010, 0.075000},
	{{0, 6, -6, 0, -2, 0, 0, 0, -2, 0, 0}, 205.430800, 0.000010, 0.047000},
	{{0, 6, -6, 0, -1, 0, 0, 0, -2, 0, 0}, 188.791980, 0.000080, 0.047000},
	{{0, 6, -6, 0, -1, 0, 0, 0, -2, 2, 0}, 185.547450, 0.000010, 0.184000},
	{{0, 6, -6, 0, -1, 0, 0, 0, 0, -2, 0}, 193.047610, 0.000010, 0.044000},
	{{0, 6, -6, 0, -1, 0, 0, 0, 0, 0, 0}, 13.047610, 0.000010, 0.273000},
	{{0, 6, -6, 0, -1, 0, 0, 0, 2, 0, 0}, 5.649580, 0.000030, 0.035000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -4, 2, 0}, 341.619260, 0.000010, 0.052000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 178.504580, 0.000010, 0.029000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 348.464140, 0.000040, 0.048000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 0, 2}, 359.693220, 0.000010, 0.171000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 351.641090, 0.000050, 0.129000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 356.914320, 0.000100, 0.181000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 0.209870, 0.000020, 0.053000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 359.981810, 0.000180, 0.116000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 13.324980, 0.000030, 0.208000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -1, 1, 0}, 0.420260, 0.000030, 0.216000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 359.521720, 0.000080, 0.105000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, -2}, 179.816080, 0.000010, 0.043000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 180.021650, 0.022630, 0.266000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, 2}, 0.087370, 0.000020, 0.033000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 1, -2}, 180.014530, 0.000020, 0.102000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 180.031690, 0.003690, 0.059000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 179.993800, 0.000310, 0.033000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 3, 0}, 179.980520, 0.000020, 0.023000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, -1, -1}, 190.387250, 0.000010, 0.095000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 0.013320, 0.000050, 0.349000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 190.387250, 0.000210, 0.370000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 0.020950, 0.000410, 0.062000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 1, -1}, 190.387250, 0.000010, 0.063000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 1, 0}, 359.960520, 0.000010, 0.034000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 1.636860, 0.000040, 0.089000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 180.033300, 0.000800, 0.505000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, -2}, 180.014690, 0.000030, 0.086000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 180.045740, 0.021160, 0.066000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, 2}, 0.022490, 0.000040, 0.024000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, -2}, 180.035410, 0.000670, 0.608000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 0.065810, 0.008480, 0.035000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, 2}, 180.024220, 0.000030, 0.018000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 1, -2}, 0.029860, 0.000030, 0.067000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 0.030270, 0.000700, 0.024000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 0.014200, 0.000090, 0.018000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, -2, 0}, 0.066330, 0.000050, 0.070000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, -1, 0}, 180.065870, 0.000010, 0.036000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, 0, -2}, 0.068230, 0.000030, 0.071000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, 0, 0}, 0.079360, 0.000030, 0.024000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, 1, 0}, 0.065690, 0.000010, 0.018000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -3, 0}, 180.576540, 0.000030, 0.074000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -2, 0}, 180.018010, 0.000300, 0.037000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -1, -2}, 180.033090, 0.000010, 0.076000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 179.995080, 0.000040, 0.025000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 0.025110, 0.000100, 0.019000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, 1, 0}, 0.028310, 0.000040, 0.015000},
	{{0, 6, -6, 0, 1, 0, 0, 0, -2, 0, 0}, 346.059120, 0.000050, 0.048000},
	{{0, 6, -6, 0, 1, 0, 0, 0, 0, 0, 0}, 165.720370, 0.000030, 0.261000},
	{{0, 6, -6, 0, 1, 0, 0, 0, 2, 0, 0}, 166.050790, 0.000020, 0.035000},
	{{0, 6, -5, -2, 0, 0, 0, 0, 2, -2, 0}, 139.466620, 0.000010, 0.522000},
	{{0, 6, -5, -2, 0, 0, 0, 0, 2, 0, 0}, 139.466620, 0.000010, 0.035000},
	{{0, 6, -5, 0, -2, 0, 0, 0, 0, 0, 0}, 276.819500, 0.000020, 0.218000},
	{{0, 6, -5, 0, -1, 0, 0, 0, -2, -2, 0}, 1.270340, 0.000010, 0.021000},
	{{0, 6, -5, 0, -1, 0, 0, 0, -2, 2, 0}, 178.668670, 0.000010, 0.155000},
	{{0, 6, -5, 0, -1, 0, 0, 0, 0, 0, 0}, 181.506690, 0.000080, 0.214000},
	{{0, 6, -5, 0, -1, 0, 0, 0, 2, -3, 0}, 179.107110, 0.000010, 0.097000},
	{{0, 6, -5, 0, -1, 0, 0, 0, 2, -2, 0}, 3.886400, 0.000020, 0.345000},
	{{0, 6, -5, 0, -1, 0, 0, 0, 2, -1, 0}, 359.107110, 0.000010, 0.062000},
	{{0, 6, -5, 0, -1, 0, 0, 0, 2, 0, 0}, 1.973360, 0.000030, 0.034000},
	{{0, 6, -5, 0, 0, -1, 0, 0, -2, 0, 0}, 180.206970, 0.000010, 0.050000},
	{{0, 6, -5, 0, 0, -1, 0, 0, -2, 2, 0}, 0.206970, 0.000010, 0.154000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -3, 0, 1}, 103.279350, 0.000020, 0.053000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 118.005210, 0.000030, 0.050000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 252.052670, 0.000080, 0.149000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 275.801680, 0.000030, 0.153000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, -1, -1}, 103.283830, 0.000030, 0.029000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, -1, 1}, 283.174990, 0.000010, 0.134000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, -1}, 103.281080, 0.000230, 0.048000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 283.275800, 0.000290, 0.172000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 1, -1}, 103.285190, 0.000090, 0.128000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 252.106800, 0.000020, 0.046000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 246.956650, 0.000080, 0.118000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 283.300820, 0.000010, 0.115000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 93.483170, 0.000130, 0.210000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 73.351760, 0.000030, 0.056000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 103.316290, 0.000170, 0.105000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 283.321820, 0.000080, 0.058000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 103.323970, 0.001060, 0.270000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 283.317250, 0.000040, 0.033000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 103.319990, 0.000110, 0.059000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 1, 1}, 103.321490, 0.000010, 0.023000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 251.752080, 0.000030, 0.336000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 266.765750, 0.000390, 0.062000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, -2}, 259.899240, 0.000010, 0.378000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 283.352270, 0.000020, 0.062000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 87.282460, 0.000330, 0.034000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 84.065300, 0.000060, 0.023000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 77.375230, 0.000010, 0.018000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 3, -1, -1}, 99.938700, 0.000030, 0.066000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 3, 0, -1}, 103.323160, 0.000020, 0.035000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 72.965100, 0.000010, 0.036000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 4, -1, 0}, 86.126140, 0.000020, 0.024000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 81.565860, 0.000020, 0.018000},
	{{0, 6, -5, 0, 1, 0, 0, 0, 2, -2, 0}, 151.660280, 0.000010, 0.326000},
	{{0, 6, -5, 0, 1, 0, 0, 0, 2, 0, 0}, 331.660280, 0.000010, 0.034000},
	{{0, 6, -4, -3, 0, 0, 0, 0, -2, 0, 0}, 336.218160, 0.000010, 0.049000},
	{{0, 6, -4, -3, 0, 0, 0, 0, -2, 2, 0}, 336.218160, 0.000010, 0.169000},
	{{0, 6, -4, -2, 0, 0, 0, 0, -2, 0, 0}, 0.592590, 0.000010, 0.050000},
	{{0, 6, -4, -2, 0, 0, 0, 0, -2, 1, 0}, 179.684760, 0.000030, 0.147000},
	{{0, 6, -4, -2, 0, 0, 0, 0, -2, 2, 0}, 0.592590, 0.000010, 0.155000},
	{{0, 6, -4, -2, 0, 0, 0, 0, 0, -2, 0}, 179.885480, 0.000010, 0.046000},
	{{0, 6, -4, 0, -3, 0, 0, 0, -2, 0, 0}, 7.779600, 0.000010, 0.052000},
	{{0, 6, -4, 0, -3, 0, 0, 0, -2, 2, 0}, 7.779600, 0.000010, 0.137000},
	{{0, 6, -4, 0, -2, 0, 0, 0, -2, 0, 0}, 0.304510, 0.000020, 0.052000},
	{{0, 6, -4, 0, -2, 0, 0, 0, -2, 1, 0}, 0.147970, 0.000040, 0.170000},
	{{0, 6, -4, 0, -2, 0, 0, 0, -2, 2, 0}, 0.304510, 0.000020, 0.136000},
	{{0, 6, -4, 0, -2, 0, 0, 0, -2, 3, 0}, 0.097040, 0.000010, 0.049000},
	{{0, 6, -4, 0, -2, 0, 0, 0, 0, -2, 0}, 359.747010, 0.000020, 0.048000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 27.682590, 0.000030, 0.031000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 27.927810, 0.000260, 0.053000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 25.508560, 0.000150, 0.175000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 24.869780, 0.000020, 0.133000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 205.797410, 0.000020, 0.151000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 184.295950, 0.000010, 0.147000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 25.803790, 0.000170, 0.133000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 26.147000, 0.000970, 0.174000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 25.973020, 0.000090, 0.053000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 3.304710, 0.000010, 0.213000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 206.390260, 0.000020, 0.055000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 332.047440, 0.000030, 0.251000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 28.875620, 0.000150, 0.058000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 219.073270, 0.000110, 0.033000},
	{{0, 6, -3, 0, -3, 0, 0, 0, -2, 0, 0}, 356.683820, 0.000010, 0.055000},
	{{0, 6, -3, 0, -3, 0, 0, 0, -2, 2, 0}, 176.683820, 0.000010, 0.121000},
	{{0, 6, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 280.412000, 0.000020, 0.211000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 289.303300, 0.000070, 0.148000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 308.706080, 0.000010, 0.175000},
	{{0, 6, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 125.383670, 0.000030, 0.032000},
	{{0, 6, -2, 0, -1, 0, 0, 0, 2, -2, 0}, 220.737250, 0.000010, 0.170000},
	{{0, 6, -2, 0, -1, 0, 0, 0, 2, 0, 0}, 151.802260, 0.000080, 0.031000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 128.239430, 0.000030, 0.182000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 159.371590, 0.000010, 0.129000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 128.239430, 0.000030, 0.048000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 184.039560, 0.000010, 0.029000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 127.835100, 0.000010, 0.167000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 128.085970, 0.000030, 0.031000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, 2, 0}, 128.212270, 0.000020, 0.017000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 4, 0, 0}, 308.008430, 0.000020, 0.017000},
	{{0, 6, -2, 0, 1, 0, 0, 0, 2, 0, 0}, 298.774120, 0.000080, 0.031000},
	{{0, 6, -1, 0, -1, 0, 0, 0, 0, 0, 0}, 129.522630, 0.000020, 0.115000},
	{{0, 6, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 302.033200, 0.000040, 0.063000},
	{{0, 6, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 302.033200, 0.000040, 0.095000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 79.421720, 0.000010, 0.114000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 216.984080, 0.000040, 0.143000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 216.984080, 0.000040, 0.030000},
	{{0, 6, 0, -15, 0, 0, 0, 0, 2, -3, 0}, 323.850910, 0.000010, 0.075000},
	{{0, 6, 0, -15, 0, 0, 0, 0, 2, -1, 0}, 323.850910, 0.000010, 0.075000},
	{{0, 6, 0, -2, 0, 0, 0, 0, 2, -2, 0}, 308.300590, 0.000020, 0.145000},
	{{0, 6, 0, -2, 0, 0, 0, 0, 2, 0, 0}, 308.241780, 0.000030, 0.030000},
	{{0, 6, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 327.133970, 0.000010, 0.029000},
	{{0, 6, 4, 0, -6, 0, 0, 0, 0, -1, 0}, 124.178000, 0.000020, 118.454000},
	{{0, 7, -42, 36, 0, 0, 0, 0, 2, -1, 0}, 306.337640, 0.000010, 968.212000},
	{{0, 7, -19, 11, 0, 0, 0, 0, -2, 1, 0}, 158.556360, 0.000050, 0.075000},
	{{0, 7, -19, 11, 0, 0, 0, 0, -2, 2, 0}, 132.899840, 0.000070, 828.943000},
	{{0, 7, -19, 11, 0, 0, 0, 0, -2, 3, 0}, 158.556360, 0.000050, 0.075000},
	{{0, 7, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 289.614720, 0.000020, 0.034000},
	{{0, 7, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 289.621400, 0.000010, 0.351000},
	{{0, 7, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 305.272080, 0.000020, 0.381000},
	{{0, 7, -14, 0, 2, 0, 0, 0, -2, 0, 0}, 322.847990, 0.000020, 0.037000},
	{{0, 7, -14, 0, 2, 0, 0, 0, -2, 1, 0}, 322.940010, 0.000020, 0.072000},
	{{0, 7, -14, 0, 2, 0, 0, 0, -2, 3, 0}, 142.940010, 0.000020, 0.080000},
	{{0, 7, -14, 2, 0, 0, 0, 0, -2, 1, 0}, 323.059070, 0.000020, 0.077000},
	{{0, 7, -14, 2, 0, 0, 0, 0, -2, 3, 0}, 323.059070, 0.000020, 0.074000},
	{{0, 7, -14, 5, 0, 0, 0, 0, 0, -1, 0}, 289.176360, 0.000030, 0.076000},
	{{0, 7, -14, 5, 0, 0, 0, 0, 0, 1, 0}, 289.176360, 0.000030, 0.075000},
	{{0, 7, -13, 0, -1, 0, 0, 0, -2, 1, 0}, 51.983800, 0.000070, 0.076000},
	{{0, 7, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 230.983890, 0.000010, 14.625000},
	{{0, 7, -13, 0, -1, 0, 0, 0, 0, 1, 0}, 231.983800, 0.000020, 0.087000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 221.480240, 0.000020, 0.025000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 219.962420, 0.000020, 0.038000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 244.050550, 0.000050, 0.076000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 219.962420, 0.000020, 6.550000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 100.899810, 0.000020, 0.075000},
	{{0, 7, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 268.196600, 0.000020, 0.617000},
	{{0, 7, -13, 0, 1, 0, 0, 0, -2, 1, 0}, 142.517470, 0.000010, 0.077000},
	{{0, 7, -13, 0, 1, 0, 0, 0, -2, 2, 0}, 141.674680, 0.000010, 4.220000},
	{{0, 7, -13, 0, 1, 0, 0, 0, -2, 3, 0}, 142.517470, 0.000010, 0.074000},
	{{0, 7, -13, 0, 2, 0, 0, 0, -2, 1, 0}, 203.162160, 0.000010, 0.077000},
	{{0, 7, -13, 0, 2, 0, 0, 0, -2, 2, 0}, 51.577780, 0.000020, 3.113000},
	{{0, 7, -13, 0, 2, 0, 0, 0, -2, 3, 0}, 203.162160, 0.000010, 0.074000},
	{{0, 7, -13, 0, 3, 0, 0, 0, -2, 1, 0}, 41.586680, 0.000030, 0.078000},
	{{0, 7, -13, 0, 3, 0, 0, 0, -2, 3, 0}, 41.586680, 0.000030, 0.073000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 0, 0}, 233.726680, 0.000050, 0.040000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 1, 0}, 231.752980, 0.000030, 0.083000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 2, 0}, 231.752980, 0.000030, 0.822000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 3, 0}, 231.752980, 0.000030, 0.069000},
	{{0, 7, -13, 2, 0, 0, 0, 0, 0, -1, 0}, 51.752980, 0.000030, 0.072000},
	{{0, 7, -13, 2, 0, 0, 0, 0, 0, 1, 0}, 51.752980, 0.000030, 0.079000},
	{{0, 7, -13, 3, 0, 0, 0, 0, 0, -1, 0}, 20.157360, 0.000040, 0.075000},
	{{0, 7, -13, 3, 0, 0, 0, 0, 0, 1, 0}, 20.157360, 0.000040, 0.076000},
	{{0, 7, -12, -2, 0, 0, 0, 0, -2, 1, 0}, 1.738670, 0.000010, 0.076000},
	{{0, 7, -12, -2, 0, 0, 0, 0, -2, 3, 0}, 1.738670, 0.000010, 0.075000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 346.662270, 0.000010, 0.039000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 357.991460, 0.000060, 0.083000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 334.223320, 0.000040, 0.868000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 346.882520, 0.000060, 0.069000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 173.178510, 0.000010, 0.037000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 205.745750, 0.000020, 0.072000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 77.650850, 0.000030, 1.609000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 192.771600, 0.000030, 0.079000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 142.715870, 0.000010, 0.039000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 237.870600, 0.000020, 0.417000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 237.878030, 0.000020, 0.092000},
	{{0, 7, -12, 0, 1, 0, 0, 0, 0, 0, 0}, 50.435800, 0.000020, 1.862000},
	{{0, 7, -12, 0, 2, 0, 0, 0, -2, 1, 0}, 111.923130, 0.000030, 0.084000},
	{{0, 7, -12, 0, 2, 0, 0, 0, 0, -1, 0}, 291.923130, 0.000020, 0.073000},
	{{0, 7, -12, 0, 2, 0, 0, 0, 0, 1, 0}, 291.923130, 0.000020, 0.078000},
	{{0, 7, -12, 1, 0, 0, 0, 0, 0, -1, 0}, 231.246120, 0.000010, 0.075000},
	{{0, 7, -12, 1, 0, 0, 0, 0, 0, 1, 0}, 231.246120, 0.000010, 0.076000},
	{{0, 7, -12, 2, 0, 0, 0, 0, -2, 0, 0}, 95.386050, 0.000020, 0.041000},
	{{0, 7, -12, 2, 0, 0, 0, 0, -2, 2, 0}, 95.386050, 0.000020, 0.451000},
	{{0, 7, -12, 2, 0, 0, 0, 0, 0, -1, 0}, 95.386050, 0.000010, 0.078000},
	{{0, 7, -12, 2, 0, 0, 0, 0, 0, 1, 0}, 95.386050, 0.000010, 0.073000},
	{{0, 7, -11, -4, 0, 0, 0, 0, -2, 1, 0}, 344.273830, 0.000010, 0.076000},
	{{0, 7, -11, -4, 0, 0, 0, 0, -2, 3, 0}, 344.273830, 0.000010, 0.075000},
	{{0, 7, -11, 0, -1, 0, 0, 0, -2, 0, 0}, 242.173070, 0.000030, 0.041000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 145.902830, 0.000060, 0.041000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 0, 2}, 231.777430, 0.000020, 0.402000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 126.373720, 0.000070, 0.090000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 61.069120, 0.000010, 0.465000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 51.941400, 0.000030, 0.065000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 130.281570, 0.000100, 0.078000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 153.113450, 0.000580, 2.641000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 130.281570, 0.000100, 0.073000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 151.660550, 0.000020, 1.481000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 58.886940, 0.000020, 0.078000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 172.452570, 0.000030, 0.084000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 153.035580, 0.000040, 0.040000},
	{{0, 7, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 39.151620, 0.000050, 0.041000},
	{{0, 7, -11, 0, 1, 0, 0, 0, -2, 1, 0}, 218.658540, 0.000030, 0.091000},
	{{0, 7, -11, 0, 1, 0, 0, 0, -2, 2, 0}, 38.657180, 0.000030, 0.447000},
	{{0, 7, -11, 0, 1, 0, 0, 0, 0, -1, 0}, 38.920480, 0.000030, 0.078000},
	{{0, 7, -11, 0, 1, 0, 0, 0, 0, 1, 0}, 38.920480, 0.000030, 0.073000},
	{{0, 7, -10, -2, 0, 0, 0, 0, 0, -1, 0}, 10.983020, 0.000020, 0.077000},
	{{0, 7, -10, -2, 0, 0, 0, 0, 0, 1, 0}, 10.983020, 0.000020, 0.074000},
	{{0, 7, -10, 0, -1, 0, 0, 0, -2, 0, 0}, 235.596530, 0.000010, 0.043000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -4, 0, 0}, 120.982430, 0.000030, 0.021000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 261.602730, 0.000080, 0.043000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 254.318650, 0.000110, 0.099000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 72.522350, 0.000110, 0.084000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 49.025180, 0.000100, 0.725000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 254.347080, 0.000010, 0.068000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 72.637430, 0.000010, 0.036000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, -1, -1}, 248.426460, 0.000020, 0.077000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 248.426460, 0.000360, 3.078000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 250.088950, 0.000030, 0.073000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 68.379610, 0.000040, 0.037000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 1, -1}, 248.426460, 0.000020, 0.074000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 2, -3}, 67.854810, 0.000010, 116.052000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 42.119260, 0.000010, 0.073000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 254.512570, 0.000060, 2.529000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 253.773280, 0.000640, 0.078000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 253.813950, 0.000140, 0.038000},
	{{0, 7, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 24.477210, 0.000010, 0.043000},
	{{0, 7, -10, 0, 1, 0, 0, 0, -2, 2, 0}, 204.477210, 0.000010, 0.309000},
	{{0, 7, -10, 0, 1, 0, 0, 0, 2, -3, 0}, 169.252740, 0.000020, 0.074000},
	{{0, 7, -10, 0, 1, 0, 0, 0, 2, -1, 0}, 169.252740, 0.000020, 0.077000},
	{{0, 7, -10, 0, 2, 0, 0, 0, 2, -3, 0}, 91.242940, 0.000010, 0.074000},
	{{0, 7, -10, 0, 2, 0, 0, 0, 2, -1, 0}, 91.242940, 0.000010, 0.077000},
	{{0, 7, -10, 0, 2, 0, 0, 0, 2, 0, 0}, 271.100270, 0.000020, 0.038000},
	{{0, 7, -10, 0, 3, 0, 0, 0, 2, -3, 0}, 81.412010, 0.000020, 0.075000},
	{{0, 7, -10, 0, 3, 0, 0, 0, 2, -1, 0}, 214.097140, 0.000060, 0.076000},
	{{0, 7, -10, 0, 4, 0, 0, 0, 2, -1, 0}, 172.193320, 0.000030, 0.076000},
	{{0, 7, -10, 2, 0, 0, 0, 0, 2, -3, 0}, 271.311830, 0.000010, 0.079000},
	{{0, 7, -10, 2, 0, 0, 0, 0, 2, -1, 0}, 271.311830, 0.000010, 0.072000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 171.552450, 0.000060, 0.045000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 165.246090, 0.000070, 0.110000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 225.481960, 0.000010, 0.241000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 356.805630, 0.000010, 0.057000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 168.278520, 0.000010, 0.043000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 6.320910, 0.000040, 0.291000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 171.278100, 0.000290, 0.092000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 342.003750, 0.001010, 0.420000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 345.545390, 0.000180, 0.064000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, -3, 1}, 168.938610, 0.000020, 0.086000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, -1, -1}, 168.924850, 0.000040, 0.084000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, -1, 1}, 348.938610, 0.000020, 0.067000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 168.984610, 0.000370, 0.755000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 163.217850, 0.000040, 0.068000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 348.938580, 0.000030, 0.035000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 1, -1}, 168.924850, 0.000040, 0.069000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 351.316440, 0.000060, 0.079000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 331.069740, 0.000010, 1.654000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 348.849700, 0.002380, 0.072000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, -2}, 350.086970, 0.000150, 3.688000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 349.068060, 0.000030, 0.073000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 174.398740, 0.000230, 0.037000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 168.914410, 0.000040, 0.025000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 4, -3, 0}, 171.792390, 0.000010, 0.083000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 347.897120, 0.000040, 0.039000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 4, 0, 0}, 169.730180, 0.000030, 0.019000},
	{{0, 7, -9, 0, 1, 0, 0, 0, -2, 0, 0}, 270.394750, 0.000010, 0.045000},
	{{0, 7, -9, 0, 1, 0, 0, 0, -2, 2, 0}, 90.394750, 0.000010, 0.236000},
	{{0, 7, -9, 0, 1, 0, 0, 0, 0, 0, 0}, 90.970020, 0.000010, 0.406000},
	{{0, 7, -9, 0, 1, 0, 0, 0, 2, -3, 0}, 269.896320, 0.000020, 0.080000},
	{{0, 7, -9, 0, 1, 0, 0, 0, 2, -2, 0}, 89.926960, 0.000020, 1.452000},
	{{0, 7, -9, 0, 1, 0, 0, 0, 2, -1, 0}, 269.896320, 0.000020, 0.072000},
	{{0, 7, -9, 0, 1, 0, 0, 0, 2, 0, 0}, 89.926960, 0.000020, 0.037000},
	{{0, 7, -9, 0, 2, 0, 0, 0, -2, 0, 0}, 179.883640, 0.000010, 0.045000},
	{{0, 7, -9, 0, 2, 0, 0, 0, -2, 2, 0}, 359.883640, 0.000010, 0.231000},
	{{0, 7, -9, 0, 2, 0, 0, 0, 2, -3, 0}, 179.922690, 0.000010, 0.080000},
	{{0, 7, -9, 0, 2, 0, 0, 0, 2, -1, 0}, 179.922690, 0.000010, 0.071000},
	{{0, 7, -9, 0, 2, 0, 0, 0, 2, 0, 0}, 359.843790, 0.000030, 0.037000},
	{{0, 7, -9, 0, 3, 0, 0, 0, 2, -1, 0}, 350.110120, 0.000030, 0.071000},
	{{0, 7, -9, 2, 0, 0, 0, 0, 2, -2, 0}, 0.159300, 0.000020, 0.600000},
	{{0, 7, -9, 4, 0, 0, 0, 0, 0, 0, 0}, 57.643510, 0.000010, 0.222000},
	{{0, 7, -8, -3, 0, 0, 0, 0, 2, -2, 0}, 350.566940, 0.000030, 104.252000},
	{{0, 7, -8, 0, -1, 0, 0, 0, -2, 0, 0}, 104.472090, 0.000020, 0.047000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 83.231380, 0.000020, 0.047000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 90.526990, 0.000160, 0.123000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 275.096810, 0.000010, 0.194000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, -1, 1}, 76.151140, 0.000020, 0.113000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, -1}, 76.124000, 0.000070, 0.045000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 93.674820, 0.000040, 0.111000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 256.102380, 0.000140, 0.226000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 1, -1}, 76.139680, 0.000050, 0.109000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 89.652010, 0.000250, 0.101000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 271.722930, 0.003030, 0.296000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 271.814230, 0.000590, 0.060000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 271.634620, 0.000040, 0.033000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, -1, -1}, 76.144350, 0.000140, 0.091000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 91.920880, 0.000010, 0.401000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, -1, 1}, 256.148930, 0.000070, 0.063000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 76.144960, 0.000970, 0.430000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 90.992290, 0.000070, 0.064000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 256.120830, 0.000020, 0.034000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 1, -1}, 76.142240, 0.000100, 0.064000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 270.858100, 0.000030, 0.086000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 270.957820, 0.000090, 0.623000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 272.009950, 0.004220, 0.067000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, -2}, 272.175870, 0.000140, 0.787000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 258.113720, 0.000040, 0.068000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 93.510510, 0.001470, 0.036000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 93.925940, 0.000200, 0.024000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 2, 0}, 92.344540, 0.000030, 0.018000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 3, -1, -1}, 84.029250, 0.000090, 0.072000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 3, 0, -1}, 76.144410, 0.000010, 0.037000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 3, 0, 0}, 92.436200, 0.000020, 0.025000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 273.500690, 0.000070, 0.038000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 261.871960, 0.000010, 0.025000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 98.443850, 0.000070, 0.019000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 4, 1, 0}, 92.566360, 0.000010, 0.015000},
	{{0, 7, -8, 0, 1, 0, 0, 0, -2, 0, 0}, 194.210630, 0.000080, 0.047000},
	{{0, 7, -8, 0, 1, 0, 0, 0, 0, 0, 0}, 11.584500, 0.000020, 0.289000},
	{{0, 7, -8, 0, 1, 0, 0, 0, 2, -2, 0}, 178.563950, 0.000010, 0.592000},
	{{0, 7, -8, 0, 1, 0, 0, 0, 2, 0, 0}, 178.652680, 0.000040, 0.035000},
	{{0, 7, -8, 0, 2, 0, 0, 0, 2, 0, 0}, 60.175410, 0.000030, 0.035000},
	{{0, 7, -8, 0, 2, 0, 0, 0, 4, -4, 0}, 60.175410, 0.000130, 1309.823000},
	{{0, 7, -8, 2, 0, 0, 0, 0, -2, 1, 0}, 40.495810, 0.000010, 0.142000},
	{{0, 7, -8, 3, 0, 0, 0, 0, -2, 0, 0}, 236.402220, 0.000020, 0.051000},
	{{0, 7, -8, 3, 0, 0, 0, 0, -2, 2, 0}, 236.402220, 0.000020, 0.148000},
	{{0, 7, -7, 0, -2, 0, 0, 0, 0, 0, 0}, 194.589680, 0.000020, 0.238000},
	{{0, 7, -7, 0, -1, 0, 0, 0, -2, 0, 0}, 187.378030, 0.000070, 0.049000},
	{{0, 7, -7, 0, -1, 0, 0, 0, -2, 2, 0}, 185.561290, 0.000010, 0.165000},
	{{0, 7, -7, 0, -1, 0, 0, 0, 0, 0, 0}, 161.148440, 0.000020, 0.233000},
	{{0, 7, -7, 0, -1, 0, 0, 0, 2, -1, 0}, 188.701490, 0.000030, 0.063000},
	{{0, 7, -7, 0, -1, 0, 0, 0, 2, 0, 0}, 5.578360, 0.000020, 0.034000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -4, 2, 0}, 179.801360, 0.000020, 0.054000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 180.994340, 0.000040, 0.030000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 181.037950, 0.000310, 0.049000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 180.851180, 0.000230, 0.141000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 359.736700, 0.000100, 0.163000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 359.757320, 0.000020, 0.052000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 359.956780, 0.000140, 0.125000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 17.560190, 0.000020, 0.184000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 1, 0}, 0.051430, 0.000020, 0.190000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 179.292960, 0.000020, 0.045000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 181.431560, 0.000410, 0.113000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, -2}, 179.924210, 0.000010, 0.045000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 179.985870, 0.015470, 0.228000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, 2}, 0.023740, 0.000020, 0.032000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 180.077800, 0.002580, 0.057000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 180.182030, 0.000200, 0.032000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 3, 0}, 180.130160, 0.000020, 0.023000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, -1, 0}, 0.321240, 0.000050, 0.286000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 190.864770, 0.000170, 0.301000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 0.018870, 0.000230, 0.060000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 1, 0}, 359.959620, 0.000010, 0.033000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -4, 0}, 0.021430, 0.000010, 0.042000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 0.078500, 0.000030, 0.094000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 180.201080, 0.000550, 0.384000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, -2}, 180.023170, 0.000040, 0.091000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 180.051520, 0.012900, 0.063000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, 2}, 0.030960, 0.000030, 0.023000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, -2}, 180.029630, 0.000380, 0.440000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 0.047120, 0.007080, 0.034000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, 2}, 180.009810, 0.000030, 0.018000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 0.005670, 0.000590, 0.024000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 2, 0}, 359.995260, 0.000080, 0.018000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 3, -2, 0}, 0.011160, 0.000030, 0.067000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 3, -1, 0}, 180.062700, 0.000010, 0.035000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 3, 0, 0}, 0.076450, 0.000030, 0.024000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 3, 1, 0}, 0.062510, 0.000010, 0.018000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, -2, 0}, 179.903960, 0.000180, 0.037000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, -1, 0}, 359.927590, 0.000010, 0.025000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 0.004040, 0.000090, 0.019000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, 1, 0}, 0.017320, 0.000030, 0.015000},
	{{0, 7, -7, 0, 1, 0, 0, 0, -2, 0, 0}, 346.204780, 0.000050, 0.049000},
	{{0, 7, -7, 0, 1, 0, 0, 0, 0, -2, 0}, 351.250590, 0.000010, 0.045000},
	{{0, 7, -7, 0, 1, 0, 0, 0, 0, 0, 0}, 171.250590, 0.000010, 0.224000},
	{{0, 7, -7, 0, 1, 0, 0, 0, 2, -1, 0}, 346.910820, 0.000020, 0.063000},
	{{0, 7, -6, -2, 0, 0, 0, 0, 2, -2, 0}, 139.456270, 0.000010, 0.394000},
	{{0, 7, -6, -2, 0, 0, 0, 0, 2, 0, 0}, 139.456270, 0.000010, 0.034000},
	{{0, 7, -6, 0, -2, 0, 0, 0, -2, 0, 0}, 108.077590, 0.000010, 0.051000},
	{{0, 7, -6, 0, -2, 0, 0, 0, -2, 2, 0}, 108.077590, 0.000010, 0.143000},
	{{0, 7, -6, 0, -2, 0, 0, 0, 0, 0, 0}, 277.935010, 0.000010, 0.192000},
	{{0, 7, -6, 0, -1, 0, 0, 0, -2, -2, 0}, 181.264010, 0.000010, 0.022000},
	{{0, 7, -6, 0, -1, 0, 0, 0, -2, 2, 0}, 178.636090, 0.000010, 0.141000},
	{{0, 7, -6, 0, -1, 0, 0, 0, 0, 0, 0}, 181.508850, 0.000080, 0.189000},
	{{0, 7, -6, 0, -1, 0, 0, 0, 2, 0, 0}, 3.848810, 0.000030, 0.033000},
	{{0, 7, -6, 0, 0, -1, 0, 0, -2, 0, 0}, 180.200630, 0.000010, 0.052000},
	{{0, 7, -6, 0, 0, -1, 0, 0, -2, 2, 0}, 0.200630, 0.000010, 0.140000},
	{{0, 7, -6, 0, 0, -1, 0, 0, 0, 0, 0}, 180.190920, 0.000010, 0.187000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -3, 0, 1}, 103.266020, 0.000020, 0.055000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 85.009200, 0.000040, 0.052000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 257.104780, 0.000030, 0.164000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 287.654310, 0.000030, 0.140000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, -1, -1}, 103.272120, 0.000020, 0.030000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 103.265060, 0.000180, 0.049000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 283.163140, 0.000220, 0.155000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 1, -1}, 103.268970, 0.000070, 0.140000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 103.315140, 0.000010, 0.051000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 238.177580, 0.000030, 0.127000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 283.290410, 0.000010, 0.124000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 103.870080, 0.000030, 0.186000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 81.953300, 0.000030, 0.054000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 353.012590, 0.000010, 0.031000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, -1, -1}, 103.309320, 0.000140, 0.112000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 283.315700, 0.000060, 0.056000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 103.317930, 0.000810, 0.231000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 1, -1}, 103.313590, 0.000090, 0.057000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 1, 1}, 103.315360, 0.000010, 0.023000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 258.704840, 0.000010, 0.277000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 269.105040, 0.000290, 0.059000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, -2}, 261.801230, 0.000010, 0.306000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 283.350770, 0.000020, 0.060000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 89.199620, 0.000330, 0.033000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 85.488050, 0.000050, 0.023000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 3, 0, -1}, 103.316030, 0.000020, 0.034000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 87.865490, 0.000020, 0.024000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 81.801140, 0.000030, 0.018000},
	{{0, 7, -5, -3, 0, 0, 0, 0, -2, 0, 0}, 336.215400, 0.000010, 0.050000},
	{{0, 7, -5, -3, 0, 0, 0, 0, -2, 2, 0}, 336.215400, 0.000010, 0.152000},
	{{0, 7, -5, -2, 0, 0, 0, 0, -2, 0, 0}, 0.566700, 0.000010, 0.051000},
	{{0, 7, -5, -2, 0, 0, 0, 0, -2, 2, 0}, 0.566700, 0.000010, 0.141000},
	{{0, 7, -5, -2, 0, 0, 0, 0, 0, -2, 0}, 179.879140, 0.000010, 0.047000},
	{{0, 7, -5, 0, -3, 0, 0, 0, -2, 0, 0}, 7.675810, 0.000010, 0.054000},
	{{0, 7, -5, 0, -3, 0, 0, 0, -2, 2, 0}, 7.675810, 0.000010, 0.127000},
	{{0, 7, -5, 0, -2, 0, 0, 0, -2, 2, 0}, 0.298930, 0.000020, 0.125000},
	{{0, 7, -5, 0, -2, 0, 0, 0, 0, -2, 0}, 0.116390, 0.000030, 0.049000},
	{{0, 7, -5, 0, -2, 0, 0, 0, 0, 0, 0}, 359.919450, 0.000070, 0.161000},
	{{0, 7, -5, 0, -2, 0, 0, 0, 2, -2, 0}, 179.984220, 0.000010, 0.225000},
	{{0, 7, -5, 0, -1, 0, 0, 0, 0, 0, 0}, 89.241180, 0.000010, 0.159000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 26.839170, 0.000030, 0.032000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 27.821190, 0.000220, 0.054000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 25.619160, 0.000130, 0.196000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 205.919540, 0.000020, 0.167000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 342.072310, 0.000010, 0.050000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 26.392560, 0.000140, 0.145000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 26.206660, 0.000760, 0.157000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 25.948630, 0.000070, 0.051000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 327.220990, 0.000030, 0.217000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 25.919580, 0.000110, 0.056000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 218.643060, 0.000110, 0.032000},
	{{0, 7, -4, 0, -3, 0, 0, 0, -2, 0, 0}, 356.677480, 0.000010, 0.057000},
	{{0, 7, -4, 0, -3, 0, 0, 0, -2, 2, 0}, 176.677480, 0.000010, 0.112000},
	{{0, 7, -4, 0, -1, 0, 0, 0, 2, -2, 0}, 156.554440, 0.000010, 0.181000},
	{{0, 7, -4, 0, -1, 0, 0, 0, 2, 0, 0}, 336.554440, 0.000010, 0.031000},
	{{0, 7, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 279.313210, 0.000020, 0.244000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 286.237380, 0.000050, 0.136000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 309.008000, 0.000010, 0.158000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 44.093990, 0.000030, 0.178000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 29.300850, 0.000010, 0.031000},
	{{0, 7, -4, 0, 1, 0, 0, 0, 2, -2, 0}, 307.294560, 0.000030, 0.176000},
	{{0, 7, -4, 0, 1, 0, 0, 0, 2, 0, 0}, 311.498710, 0.000020, 0.031000},
	{{0, 7, -3, 0, -1, 0, 0, 0, 2, -2, 0}, 294.470010, 0.000020, 0.153000},
	{{0, 7, -3, 0, -1, 0, 0, 0, 2, 0, 0}, 157.406160, 0.000050, 0.030000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 128.235840, 0.000030, 0.205000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 184.338820, 0.000010, 0.119000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 128.235840, 0.000030, 0.046000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 130.592540, 0.000010, 0.151000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 128.197120, 0.000020, 0.050000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 127.789120, 0.000030, 0.030000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 128.253720, 0.000030, 0.022000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 128.210980, 0.000020, 0.017000},
	{{0, 7, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 298.782140, 0.000070, 0.030000},
	{{0, 7, -2, -2, 0, 0, 0, 0, 2, -2, 0}, 84.566040, 0.000010, 0.153000},
	{{0, 7, -2, -2, 0, 0, 0, 0, 2, 0, 0}, 84.566040, 0.000010, 0.030000},
	{{0, 7, -2, 0, 0, 0, 0, 0, -4, 1, 2}, 307.568120, 0.000030, 224.432000},
	{{0, 7, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 302.012200, 0.000040, 0.065000},
	{{0, 7, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 302.012200, 0.000040, 0.090000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 106.152470, 0.000020, 0.107000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 221.976720, 0.000020, 0.132000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 221.976720, 0.000020, 0.029000},
	{{0, 7, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 146.633920, 0.000050, 0.075000},
	{{0, 7, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 333.575000, 0.000020, 9.702000},
	{{0, 7, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 146.633920, 0.000050, 0.076000},
	{{0, 7, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 81.623140, 0.000070, 100.849000},
	{{0, 7, 4, -4, 0, 0, 0, 0, 0, -1, 0}, 255.057490, 0.000040, 261.124000},
	{{0, 8, -47, 39, 0, 0, 0, 0, 0, 1, 0}, 14.697840, 0.000010, 228.633000},
	{{0, 8, -21, 19, 0, 0, 0, 0, 2, 0, -2}, 29.966740, 0.000010, 743.522000},
	{{0, 8, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 289.622370, 0.000040, 0.035000},
	{{0, 8, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 109.621090, 0.000010, 0.065000},
	{{0, 8, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 289.622370, 0.000040, 0.450000},
	{{0, 8, -17, 0, 0, 0, 0, 0, -2, 3, 0}, 109.621090, 0.000010, 0.091000},
	{{0, 8, -16, 0, 0, 0, 0, 0, -3, 1, 2}, 189.094270, 0.000090, 784.579000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 135.623890, 0.000020, 0.074000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 3, 0}, 121.176500, 0.000040, 0.077000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 103.764680, 0.000020, 0.066000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 66.929640, 0.000040, 0.501000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 96.507380, 0.000040, 0.089000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 84.104400, 0.000120, 0.105000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 83.492780, 0.000170, 0.044000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 83.703990, 0.000010, 0.028000},
	{{0, 8, -15, 0, 1, 0, 0, 0, -2, 1, 0}, 220.524100, 0.000010, 0.075000},
	{{0, 8, -15, 0, 1, 0, 0, 0, -2, 3, 0}, 220.524100, 0.000010, 0.076000},
	{{0, 8, -15, 0, 2, 0, 0, 0, -2, 0, 0}, 322.898030, 0.000010, 0.038000},
	{{0, 8, -15, 0, 2, 0, 0, 0, -2, 1, 0}, 144.672370, 0.000030, 0.075000},
	{{0, 8, -15, 0, 3, 0, 0, 0, -2, 1, 0}, 311.040690, 0.000020, 0.076000},
	{{0, 8, -15, 0, 3, 0, 0, 0, -2, 3, 0}, 311.040690, 0.000020, 0.075000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 196.536200, 0.000020, 0.026000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 161.916950, 0.000170, 0.039000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 0, 2}, 160.847410, 0.000010, 0.900000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 168.495610, 0.000110, 0.080000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 338.724470, 0.000010, 0.075000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 342.434820, 0.000300, 0.070000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 339.887250, 0.002970, 1.004000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 339.140580, 0.000920, 0.082000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 2, 0}, 338.525670, 0.000070, 0.039000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 342.199560, 0.000100, 0.361000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 340.867900, 0.002650, 0.095000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 0, -2}, 340.776990, 0.000030, 0.322000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 340.027780, 0.002420, 0.042000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 339.650270, 0.000240, 0.027000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 2, 0}, 340.378870, 0.000020, 0.020000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 4, -2, 0}, 341.020690, 0.000050, 0.046000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 4, -1, 0}, 340.123330, 0.000100, 0.028000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 4, 0, 0}, 339.869550, 0.000060, 0.021000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 4, 1, 0}, 160.781000, 0.000010, 0.016000},
	{{0, 8, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 141.724720, 0.000020, 0.039000},
	{{0, 8, -14, 0, 1, 0, 0, 0, -2, 1, 0}, 322.055800, 0.000010, 0.081000},
	{{0, 8, -14, 0, 1, 0, 0, 0, -2, 2, 0}, 141.724720, 0.000020, 1.159000},
	{{0, 8, -14, 0, 1, 0, 0, 0, -2, 3, 0}, 142.055800, 0.000010, 0.071000},
	{{0, 8, -14, 0, 2, 0, 0, 0, -2, 0, 0}, 51.543430, 0.000010, 0.039000},
	{{0, 8, -14, 0, 2, 0, 0, 0, -2, 2, 0}, 51.518620, 0.000010, 1.056000},
	{{0, 8, -14, 0, 2, 0, 0, 0, 0, -1, 0}, 231.624180, 0.000020, 0.071000},
	{{0, 8, -14, 0, 2, 0, 0, 0, 0, 1, 0}, 231.624180, 0.000020, 0.080000},
	{{0, 8, -14, 1, 0, 0, 0, 0, 0, 0, 0}, 57.728550, 0.000010, 2.155000},
	{{0, 8, -14, 2, 0, 0, 0, 0, -2, 0, 0}, 233.911010, 0.000040, 0.041000},
	{{0, 8, -14, 2, 0, 0, 0, 0, -2, 1, 0}, 51.808250, 0.000010, 0.088000},
	{{0, 8, -14, 2, 0, 0, 0, 0, -2, 2, 0}, 231.741570, 0.000030, 0.543000},
	{{0, 8, -14, 2, 0, 0, 0, 0, -2, 3, 0}, 51.808250, 0.000010, 0.066000},
	{{0, 8, -14, 2, 0, 0, 0, 0, 0, -1, 0}, 42.040440, 0.000020, 0.076000},
	{{0, 8, -14, 2, 0, 0, 0, 0, 0, 1, 0}, 42.040440, 0.000020, 0.075000},
	{{0, 8, -13, 0, -1, 0, 0, 0, 0, -1, 0}, 151.610170, 0.000020, 0.075000},
	{{0, 8, -13, 0, -1, 0, 0, 0, 0, 1, 0}, 151.610170, 0.000020, 0.076000},
	{{0, 8, -13, 0, 0, -1, 0, 0, 0, -1, 0}, 55.487360, 0.000010, 0.075000},
	{{0, 8, -13, 0, 0, -1, 0, 0, 0, 1, 0}, 55.487360, 0.000010, 0.076000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -6, 1, 0}, 236.615410, 0.000010, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -6, 2, 0}, 236.943220, 0.000020, 0.021000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, -1, 0}, 233.073500, 0.000050, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 0, 0}, 234.822070, 0.000270, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 1, 0}, 237.515510, 0.000720, 0.028000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 1, 2}, 237.887440, 0.000010, 0.107000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 2, 0}, 236.549480, 0.000510, 0.044000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 3, 0}, 234.338140, 0.000010, 0.103000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -3, 1, 0}, 57.301470, 0.000030, 0.042000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -3, 0}, 280.672750, 0.000020, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -2, 0}, 236.109630, 0.000190, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, -2}, 57.560750, 0.000010, 0.015000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 237.056280, 0.002270, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, 2}, 57.186800, 0.000060, 0.090000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, -2}, 56.922850, 0.000050, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 237.416760, 0.024180, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 2}, 237.887440, 0.000550, 0.474000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, -2}, 57.958690, 0.000090, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 238.008170, 0.038780, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, 2}, 236.327800, 0.000020, 0.065000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 241.536270, 0.001520, 0.562000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 240.357550, 0.000110, 0.067000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, -1, 0}, 55.566030, 0.000070, 0.039000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 55.681430, 0.000650, 0.081000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, 1, 0}, 59.356960, 0.000090, 1.122000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -3, 0}, 232.112100, 0.000180, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -2, -2}, 54.214200, 0.000020, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 233.249490, 0.002630, 0.038000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, -2}, 54.361520, 0.000100, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 233.446250, 0.038780, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 2}, 232.426500, 0.000060, 0.074000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, -2}, 57.937440, 0.000110, 0.037000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 235.750130, 0.226530, 238.919000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 2}, 57.967600, 0.000110, 0.037000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, -2}, 232.816800, 0.000060, 0.074000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 233.445270, 0.038740, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 2}, 54.361520, 0.000100, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 233.465840, 0.002620, 0.038000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 2, 2}, 54.271330, 0.000020, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 3, 0}, 233.313250, 0.000180, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, -1, 0}, 59.454630, 0.000090, 1.133000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 58.122770, 0.000640, 0.081000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, 1, 0}, 57.060790, 0.000070, 0.039000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 239.769010, 0.000110, 0.067000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 239.146610, 0.001490, 0.565000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, -2}, 236.577290, 0.000020, 0.065000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 237.969350, 0.038500, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, 2}, 57.910310, 0.000090, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, -2}, 237.856790, 0.000550, 0.475000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 237.222800, 0.023930, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, 2}, 56.714920, 0.000050, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, -2}, 57.131730, 0.000060, 0.090000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 236.298150, 0.002260, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, 2}, 57.387090, 0.000010, 0.015000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 2, 0}, 235.815630, 0.000180, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 3, 0}, 237.432350, 0.000020, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 3, -1, 0}, 57.856820, 0.000030, 0.042000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 3, 0, 0}, 238.678990, 0.000020, 0.027000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -3, 0}, 237.322250, 0.000010, 0.103000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -2, 0}, 237.959090, 0.000510, 0.044000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -1, -2}, 237.854490, 0.000010, 0.107000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -1, 0}, 237.320320, 0.000710, 0.028000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, 0, 0}, 234.653690, 0.000270, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, 1, 0}, 236.481670, 0.000050, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 6, -2, 0}, 237.299570, 0.000020, 0.021000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 6, -1, 0}, 236.567640, 0.000010, 0.016000},
	{{0, 8, -13, 0, 0, 1, 0, 0, 0, -1, 0}, 231.331010, 0.000020, 0.076000},
	{{0, 8, -13, 0, 0, 1, 0, 0, 0, 1, 0}, 231.331010, 0.000020, 0.075000},
	{{0, 8, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 50.448880, 0.000030, 0.041000},
	{{0, 8, -13, 0, 1, 0, 0, 0, -2, 3, 0}, 229.989440, 0.000020, 0.066000},
	{{0, 8, -13, 0, 1, 0, 0, 0, 0, -2, 0}, 230.423380, 0.000010, 0.038000},
	{{0, 8, -13, 0, 1, 0, 0, 0, 0, -1, 0}, 160.867950, 0.000030, 0.076000},
	{{0, 8, -13, 0, 1, 0, 0, 0, 0, 0, 0}, 50.423380, 0.000010, 11.301000},
	{{0, 8, -13, 0, 1, 0, 0, 0, 0, 1, 0}, 160.867950, 0.000030, 0.075000},
	{{0, 8, -13, 0, 2, 0, 0, 0, -2, 0, 0}, 111.910720, 0.000030, 0.041000},
	{{0, 8, -13, 0, 2, 0, 0, 0, 0, -1, 0}, 292.349760, 0.000020, 0.076000},
	{{0, 8, -13, 0, 2, 0, 0, 0, 0, 0, 0}, 66.154110, 0.000010, 5.787000},
	{{0, 8, -13, 0, 2, 0, 0, 0, 0, 1, 0}, 292.349760, 0.000020, 0.074000},
	{{0, 8, -13, 2, 0, 0, 0, 0, -2, 0, 0}, 95.373640, 0.000010, 0.042000},
	{{0, 8, -13, 2, 0, 0, 0, 0, -2, 2, 0}, 95.373640, 0.000010, 0.352000},
	{{0, 8, -13, 2, 0, 0, 0, 0, 1, 0, -1}, 248.766530, 0.000030, 72.525000},
	{{0, 8, -12, -2, 0, 0, 0, 0, 0, -1, 0}, 282.329720, 0.000020, 0.075000},
	{{0, 8, -12, -2, 0, 0, 0, 0, 0, 1, 0}, 282.329720, 0.000020, 0.076000},
	{{0, 8, -12, -1, 0, 0, 0, 0, 0, 0, 0}, 81.345000, 0.000010, 2.116000},
	{{0, 8, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 242.396470, 0.000050, 0.042000},
	{{0, 8, -12, 0, -1, 0, 0, 0, -2, 1, 0}, 60.436800, 0.000010, 0.095000},
	{{0, 8, -12, 0, -1, 0, 0, 0, -2, 2, 0}, 240.432010, 0.000030, 0.371000},
	{{0, 8, -12, 0, -1, 0, 0, 0, -2, 3, 0}, 240.436800, 0.000010, 0.063000},
	{{0, 8, -12, 0, -1, 0, 0, 0, 0, -1, 0}, 60.436800, 0.000010, 0.081000},
	{{0, 8, -12, 0, -1, 0, 0, 0, 0, 1, 0}, 60.436800, 0.000010, 0.071000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -4, 0, 0}, 127.992020, 0.000030, 0.021000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -4, 1, 0}, 122.522480, 0.000060, 0.028000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -4, 2, 0}, 146.864810, 0.000010, 0.046000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 111.721350, 0.000140, 0.027000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, -1, 2}, 231.768180, 0.000010, 0.099000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 99.956900, 0.001080, 0.042000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 0, 2}, 178.216710, 0.000010, 0.321000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 91.842760, 0.001020, 0.095000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 1, 2}, 231.768180, 0.000010, 0.061000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 64.735540, 0.000060, 0.360000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 226.477100, 0.000020, 0.062000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -1, -1, 1}, 333.735920, 0.000020, 0.089000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 153.726090, 0.000010, 0.040000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -1, 1, -1}, 153.468280, 0.000020, 0.087000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 4.925850, 0.000040, 0.039000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 7.206040, 0.000700, 0.082000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 350.368830, 0.003880, 0.996000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 1, -2}, 231.768180, 0.000030, 0.079000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 342.840840, 0.000830, 0.070000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 333.212410, 0.000080, 0.036000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, -1, -1}, 333.463250, 0.000050, 0.075000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, -1, 0}, 135.380980, 0.000020, 8.534000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, -1, 1}, 154.040910, 0.000040, 0.074000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 153.455950, 0.000280, 20.170000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 155.822410, 0.000160, 0.075000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 333.481400, 0.000500, 0.037000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 1, -1}, 333.463250, 0.000050, 0.076000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 1, 1}, 333.476070, 0.000050, 0.025000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 139.805000, 0.000030, 1.299000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 328.373780, 0.000400, 0.080000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, 0, -2}, 325.293170, 0.000020, 0.906000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 330.956910, 0.000380, 0.039000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 324.378030, 0.000020, 0.026000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 3, 0, -1}, 333.476070, 0.000020, 0.041000},
	{{0, 8, -12, 0, 1, 0, 0, 0, -2, 0, 0}, 39.039360, 0.000070, 0.042000},
	{{0, 8, -12, 0, 1, 0, 0, 0, -2, 2, 0}, 38.051580, 0.000010, 0.349000},
	{{0, 8, -11, -4, 0, 0, 0, 0, 0, 0, 0}, 35.344570, 0.000010, 8.160000},
	{{0, 8, -11, -2, 0, 0, 0, 0, -2, 0, 0}, 191.191580, 0.000020, 0.042000},
	{{0, 8, -11, -2, 0, 0, 0, 0, -2, 2, 0}, 191.191580, 0.000020, 0.368000},
	{{0, 8, -11, 0, -1, 0, 0, 0, -2, 2, 0}, 52.491720, 0.000010, 0.271000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -4, 0, 0}, 119.589150, 0.000020, 0.021000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, -2, 0}, 64.687320, 0.000010, 0.020000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 307.996360, 0.000070, 0.044000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 281.914440, 0.000080, 0.106000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 322.029830, 0.000020, 0.265000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 256.016050, 0.000200, 0.089000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 79.718200, 0.000090, 0.499000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 247.876390, 0.000100, 1.052000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 52.748760, 0.000020, 0.077000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 255.422870, 0.000030, 4.345000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 76.073810, 0.000970, 0.074000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 66.357320, 0.000050, 0.075000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 249.573900, 0.000020, 0.037000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 4, -2, 0}, 76.432120, 0.000010, 0.040000},
	{{0, 8, -11, 0, 0, 3, 0, 0, 2, 0, -2}, 176.953980, 0.000060, 666.222000},
	{{0, 8, -11, 0, 1, 0, 0, 0, 2, -1, 0}, 349.978450, 0.000030, 0.074000},
	{{0, 8, -11, 0, 2, 0, 0, 0, 2, -2, 0}, 91.150310, 0.000010, 2.508000},
	{{0, 8, -11, 0, 2, 0, 0, 0, 2, 0, -2}, 91.150310, 0.000010, 15.323000},
	{{0, 8, -11, 0, 2, 0, 0, 0, 2, 0, 0}, 271.150310, 0.000010, 0.037000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 162.842950, 0.000020, 0.046000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 168.443580, 0.000030, 0.118000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 335.294630, 0.000010, 0.209000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -1, 0, 1}, 3.776790, 0.000020, 0.246000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 186.144870, 0.000050, 0.098000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 343.308060, 0.000750, 0.333000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 346.918040, 0.000120, 0.062000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 349.673250, 0.000020, 0.034000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, -1, -1}, 168.834390, 0.000010, 0.088000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, -2}, 349.944550, 0.000020, 0.087000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 168.834390, 0.000210, 0.513000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 164.208430, 0.000030, 0.065000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 1, -1}, 168.834390, 0.000010, 0.066000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 345.348850, 0.000020, 0.083000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 351.802200, 0.000030, 0.813000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 351.470670, 0.001040, 0.069000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, -2}, 350.965080, 0.000040, 1.115000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 173.860390, 0.000240, 0.036000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 1, 0}, 170.263250, 0.000030, 0.024000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 3, -2, -2}, 168.656560, 0.000020, 0.075000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 3, -1, -2}, 349.784080, 0.000080, 103.674000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 3, -1, -1}, 168.884980, 0.000050, 0.074000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 3, 0, -2}, 169.944540, 0.000120, 0.075000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 4, -2, 0}, 349.388130, 0.000020, 0.039000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 4, -1, 0}, 171.087300, 0.000010, 0.025000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 4, 0, 0}, 170.844680, 0.000030, 0.019000},
	{{0, 8, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 270.456250, 0.000010, 0.046000},
	{{0, 8, -10, 0, 1, 0, 0, 0, -2, 2, 0}, 90.456250, 0.000010, 0.206000},
	{{0, 8, -10, 0, 1, 0, 0, 0, 2, -1, 0}, 269.977000, 0.000030, 0.069000},
	{{0, 8, -10, 0, 1, 0, 0, 0, 2, 0, 0}, 89.977000, 0.000030, 0.036000},
	{{0, 8, -10, 0, 3, 0, 0, 0, 0, 0, 0}, 168.808550, 0.000010, 0.307000},
	{{0, 8, -10, 2, 0, 0, 0, 0, 2, -3, 0}, 180.060530, 0.000010, 0.091000},
	{{0, 8, -10, 2, 0, 0, 0, 0, 2, -1, 0}, 180.060530, 0.000010, 0.064000},
	{{0, 8, -10, 4, 0, 0, 0, 0, -2, 0, 0}, 57.952330, 0.000010, 0.051000},
	{{0, 8, -10, 4, 0, 0, 0, 0, -2, 2, 0}, 57.952330, 0.000010, 0.145000},
	{{0, 8, -10, 4, 0, 0, 0, 0, 0, 0, 0}, 57.635200, 0.000010, 0.195000},
	{{0, 8, -9, 0, -1, 0, 0, 0, -2, 0, 0}, 104.497480, 0.000020, 0.048000},
	{{0, 8, -9, 0, -1, 0, 0, 0, 0, 0, 0}, 353.072340, 0.000010, 0.255000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 272.401910, 0.000040, 0.048000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 87.189220, 0.000080, 0.134000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 275.434020, 0.000010, 0.173000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 75.950300, 0.000030, 0.046000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 91.408410, 0.000010, 0.120000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 255.943170, 0.000130, 0.198000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 1, -1}, 75.966780, 0.000020, 0.117000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 95.477700, 0.000070, 0.108000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 271.865370, 0.002260, 0.250000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 272.450450, 0.000470, 0.058000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 289.556450, 0.000020, 0.033000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 3, 0}, 273.195410, 0.000020, 0.023000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, -1, -1}, 75.958530, 0.000100, 0.097000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 91.972630, 0.000010, 0.321000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, -1, 1}, 254.283920, 0.000040, 0.060000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 75.979000, 0.000630, 0.339000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 90.791870, 0.000050, 0.061000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 1, -1}, 75.948370, 0.000060, 0.062000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 283.153830, 0.000060, 0.091000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 245.974260, 0.000080, 0.448000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 272.640140, 0.002670, 0.065000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, -2}, 272.315440, 0.000080, 0.527000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 255.935740, 0.000020, 0.065000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 95.075140, 0.001340, 0.035000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 94.372630, 0.000200, 0.024000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 2, 0}, 92.964440, 0.000020, 0.018000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 3, 0, 0}, 92.433330, 0.000020, 0.024000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 4, -3, 0}, 102.531240, 0.000010, 0.073000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 283.417090, 0.000030, 0.037000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 4, 0, 0}, 98.430390, 0.000050, 0.019000},
	{{0, 8, -9, 0, 1, 0, 0, 0, -2, 0, 0}, 192.749830, 0.000090, 0.048000},
	{{0, 8, -9, 0, 1, 0, 0, 0, 0, 0, 0}, 7.150180, 0.000030, 0.245000},
	{{0, 8, -9, 0, 1, 0, 0, 0, 2, -1, 0}, 178.698900, 0.000050, 0.064000},
	{{0, 8, -9, 0, 1, 0, 0, 0, 2, 0, 0}, 178.540980, 0.000030, 0.035000},
	{{0, 8, -9, 0, 2, 0, 0, 0, -2, 0, 0}, 232.656720, 0.000010, 0.049000},
	{{0, 8, -9, 0, 2, 0, 0, 0, -2, 2, 0}, 232.656720, 0.000010, 0.168000},
	{{0, 8, -9, 0, 2, 0, 0, 0, 2, -2, 0}, 240.163000, 0.000010, 0.417000},
	{{0, 8, -9, 0, 2, 0, 0, 0, 2, 0, 0}, 60.163000, 0.000010, 0.035000},
	{{0, 8, -9, 3, 0, 0, 0, 0, -2, 0, 0}, 236.389800, 0.000010, 0.052000},
	{{0, 8, -9, 3, 0, 0, 0, 0, -2, 2, 0}, 236.389800, 0.000010, 0.136000},
	{{0, 8, -8, 0, -2, 0, 0, 0, 0, 0, 0}, 201.544030, 0.000010, 0.207000},
	{{0, 8, -8, 0, -1, 0, 0, 0, -2, 0, 0}, 185.871680, 0.000070, 0.050000},
	{{0, 8, -8, 0, -1, 0, 0, 0, -2, 1, 0}, 299.107310, 0.000010, 0.152000},
	{{0, 8, -8, 0, -1, 0, 0, 0, -2, 2, 0}, 185.573180, 0.000010, 0.149000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 179.699500, 0.000020, 0.022000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -4, 1, 0}, 180.249690, 0.000020, 0.032000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 179.812670, 0.000020, 0.056000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -4, 3, 0}, 180.442280, 0.000010, 0.213000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 180.370990, 0.000060, 0.030000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 180.373770, 0.000420, 0.051000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 179.865140, 0.000310, 0.154000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 359.498190, 0.000080, 0.148000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 0.718260, 0.000010, 0.050000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 359.914550, 0.000110, 0.136000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 17.333810, 0.000010, 0.165000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -1, 1, 0}, 0.064640, 0.000010, 0.170000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -3, 0}, 1.425100, 0.000020, 0.029000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 184.431610, 0.000010, 0.046000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 180.374180, 0.000520, 0.121000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 0, -2}, 179.113270, 0.000010, 0.046000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 179.966060, 0.010700, 0.200000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 180.044750, 0.001800, 0.055000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 179.315850, 0.000170, 0.032000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 359.990150, 0.000030, 0.243000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 190.471850, 0.000150, 0.253000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 0.016800, 0.000160, 0.058000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 1, 0}, 180.056840, 0.000010, 0.033000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 186.379660, 0.000010, 0.100000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 180.543450, 0.000370, 0.310000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, -2}, 179.993950, 0.000020, 0.097000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 180.037020, 0.008240, 0.061000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, 2}, 0.011320, 0.000020, 0.023000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, -2}, 179.990810, 0.000250, 0.345000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 0.044980, 0.005710, 0.034000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, 2}, 180.003590, 0.000020, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 0.008020, 0.000480, 0.023000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 2, 0}, 0.003490, 0.000070, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 3, -4, 0}, 0.056850, 0.000010, 0.092000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 3, -1, 0}, 180.052540, 0.000010, 0.035000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 3, 0, 0}, 0.056860, 0.000040, 0.024000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 3, 1, 0}, 0.056820, 0.000010, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 179.625440, 0.000120, 0.036000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 0.047730, 0.000050, 0.024000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 359.999980, 0.000100, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, 1, 0}, 0.004650, 0.000020, 0.015000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 6, -1, 0}, 0.017310, 0.000010, 0.015000},
	{{0, 8, -8, 0, 1, 0, 0, 0, -2, 0, 0}, 348.213640, 0.000070, 0.051000},
	{{0, 8, -8, 0, 1, 0, 0, 0, -2, 1, 0}, 172.709610, 0.000020, 0.156000},
	{{0, 8, -8, 0, 1, 0, 0, 0, 0, -2, 0}, 351.242280, 0.000010, 0.047000},
	{{0, 8, -8, 0, 1, 0, 0, 0, 0, 0, 0}, 171.242280, 0.000010, 0.197000},
	{{0, 8, -7, 0, -1, 0, 0, 0, -2, 0, 0}, 178.601880, 0.000010, 0.053000},
	{{0, 8, -7, 0, -1, 0, 0, 0, -2, 1, 0}, 181.255690, 0.000010, 0.180000},
	{{0, 8, -7, 0, -1, 0, 0, 0, -2, 2, 0}, 178.601880, 0.000010, 0.130000},
	{{0, 8, -7, 0, -1, 0, 0, 0, -2, 3, 0}, 181.255690, 0.000010, 0.048000},
	{{0, 8, -7, 0, -1, 0, 0, 0, 0, 0, 0}, 181.507980, 0.000070, 0.169000},
	{{0, 8, -7, 0, -1, 0, 0, 0, 2, 0, 0}, 3.812030, 0.000020, 0.033000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 104.478610, 0.000010, 0.053000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 257.075490, 0.000020, 0.183000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 256.708540, 0.000030, 0.129000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, -1, -1}, 103.258200, 0.000020, 0.030000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, -1, 1}, 283.250370, 0.000020, 0.161000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 103.213530, 0.000140, 0.051000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 283.241490, 0.000170, 0.142000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 103.260480, 0.000070, 0.153000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 77.404700, 0.000030, 0.049000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 229.848380, 0.000010, 0.138000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 0, -1}, 283.278180, 0.000010, 0.135000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 65.420570, 0.000030, 0.052000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 103.299770, 0.000110, 0.120000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 283.306930, 0.000030, 0.054000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 103.355290, 0.000600, 0.202000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 103.300050, 0.000020, 0.031000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 103.307030, 0.000050, 0.055000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 1, 1}, 103.306890, 0.000020, 0.022000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 2, 1}, 103.307180, 0.000020, 0.017000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 270.780340, 0.000210, 0.057000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 90.310230, 0.000300, 0.033000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 86.785620, 0.000050, 0.023000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 4, -1, 0}, 89.807430, 0.000010, 0.024000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 83.368420, 0.000030, 0.018000},
	{{0, 8, -6, -3, 0, 0, 0, 0, -2, 0, 0}, 336.210940, 0.000010, 0.052000},
	{{0, 8, -6, -3, 0, 0, 0, 0, -2, 2, 0}, 336.210940, 0.000010, 0.139000},
	{{0, 8, -6, -2, 0, 0, 0, 0, -2, 0, 0}, 0.542850, 0.000010, 0.053000},
	{{0, 8, -6, -2, 0, 0, 0, 0, -2, 2, 0}, 0.542850, 0.000010, 0.130000},
	{{0, 8, -6, 0, -3, 0, 0, 0, -2, 0, 0}, 7.573960, 0.000010, 0.056000},
	{{0, 8, -6, 0, -3, 0, 0, 0, -2, 2, 0}, 7.573960, 0.000010, 0.117000},
	{{0, 8, -6, 0, -2, 0, 0, 0, -2, 2, 0}, 0.291870, 0.000020, 0.116000},
	{{0, 8, -6, 0, -2, 0, 0, 0, 0, -2, 0}, 0.159840, 0.000010, 0.051000},
	{{0, 8, -6, 0, -2, 0, 0, 0, 0, 0, 0}, 359.819830, 0.000040, 0.146000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 26.480570, 0.000020, 0.032000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 26.524420, 0.000210, 0.056000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 26.069000, 0.000120, 0.223000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 206.016480, 0.000020, 0.186000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 342.154010, 0.000010, 0.051000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 26.884440, 0.000130, 0.160000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 26.021700, 0.000610, 0.143000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 25.875800, 0.000050, 0.049000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 282.566740, 0.000010, 0.191000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 22.167420, 0.000080, 0.054000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 214.135980, 0.000100, 0.032000},
	{{0, 8, -5, 0, -3, 0, 0, 0, -2, 0, 0}, 356.669170, 0.000010, 0.059000},
	{{0, 8, -5, 0, -3, 0, 0, 0, -2, 2, 0}, 176.669170, 0.000010, 0.105000},
	{{0, 8, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 277.307940, 0.000020, 0.288000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 283.917030, 0.000030, 0.125000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 39.478110, 0.000020, 0.161000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 38.760000, 0.000020, 0.051000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 39.478110, 0.000020, 0.031000},
	{{0, 8, -4, 0, -1, 0, 0, 0, 2, -2, 0}, 323.432960, 0.000010, 0.140000},
	{{0, 8, -4, 0, -1, 0, 0, 0, 2, 0, 0}, 220.070580, 0.000020, 0.030000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 308.194310, 0.000010, 0.235000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 289.762880, 0.000020, 0.111000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 308.208210, 0.000020, 0.028000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 128.069310, 0.000020, 0.049000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 129.009620, 0.000030, 0.030000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 128.112400, 0.000030, 0.021000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 128.208220, 0.000020, 0.017000},
	{{0, 8, -3, 0, -2, 0, 0, 0, 2, -2, 0}, 248.020640, 0.000010, 0.124000},
	{{0, 8, -3, 0, -2, 0, 0, 0, 2, 0, 0}, 68.020640, 0.000010, 0.029000},
	{{0, 8, -3, 0, -1, 0, 0, 0, 2, -3, 0}, 129.507980, 0.000010, 0.196000},
	{{0, 8, -3, 0, -1, 0, 0, 0, 2, -1, 0}, 309.507980, 0.000010, 0.047000},
	{{0, 8, -3, 0, -1, 0, 0, 0, 2, 0, 0}, 129.230580, 0.000020, 0.029000},
	{{0, 8, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 302.104380, 0.000010, 0.085000},
	{{0, 8, -2, 0, -2, 0, 0, 0, 2, -2, 0}, 308.306510, 0.000010, 0.110000},
	{{0, 8, -2, 0, -2, 0, 0, 0, 2, 0, 0}, 308.306510, 0.000010, 0.028000},
	{{0, 8, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 334.031870, 0.000020, 0.108000},
	{{0, 8, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 334.031870, 0.000020, 0.028000},
	{{0, 8, -1, -1, 0, 0, 0, 0, -2, 1, 0}, 63.282390, 0.000020, 108.269000},
	{{0, 8, -1, 0, -6, 0, 0, 0, -2, 1, 0}, 253.392480, 0.000030, 60.164000},
	{{0, 9, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 289.618430, 0.000010, 0.036000},
	{{0, 9, -18, 3, 0, 0, 0, 0, -2, 2, 0}, 234.590250, 0.000200, 818.910000},
	{{0, 9, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 208.117670, 0.000030, 0.072000},
	{{0, 9, -17, 0, 3, 0, 0, 0, -2, 0, 2}, 358.662480, 0.000050, 101.557000},
	{{0, 9, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 302.155000, 0.000030, 0.078000},
	{{0, 9, -16, 0, 0, 0, 0, 0, -2, 3, 0}, 268.300280, 0.000010, 0.073000},
	{{0, 9, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 306.942220, 0.000020, 0.730000},
	{{0, 9, -16, 0, 2, 0, 0, 0, -2, 1, 0}, 143.026140, 0.000020, 0.079000},
	{{0, 9, -16, 0, 2, 0, 0, 0, -2, 3, 0}, 323.026140, 0.000020, 0.072000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, -1, 0}, 223.572500, 0.000010, 0.026000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 224.867480, 0.000010, 0.040000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 238.531560, 0.000040, 0.084000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 224.867480, 0.000010, 0.712000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 59.198340, 0.000030, 0.073000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, -1, 2}, 223.572500, 0.000020, 0.076000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 238.244620, 0.000030, 2.701000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 59.198340, 0.000030, 0.078000},
	{{0, 9, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 141.770090, 0.000020, 0.040000},
	{{0, 9, -15, 0, 1, 0, 0, 0, -2, 1, 0}, 141.770090, 0.000010, 0.085000},
	{{0, 9, -15, 0, 1, 0, 0, 0, -2, 2, 0}, 141.770090, 0.000020, 0.672000},
	{{0, 9, -15, 0, 1, 0, 0, 0, -2, 3, 0}, 321.770090, 0.000010, 0.068000},
	{{0, 9, -15, 0, 1, 0, 0, 0, 0, -1, 0}, 142.096570, 0.000020, 0.074000},
	{{0, 9, -15, 0, 1, 0, 0, 0, 0, 1, 0}, 142.096570, 0.000020, 0.077000},
	{{0, 9, -15, 0, 2, 0, 0, 0, -2, 0, 0}, 51.571870, 0.000030, 0.040000},
	{{0, 9, -15, 0, 2, 0, 0, 0, -2, 1, 0}, 51.587030, 0.000060, 0.086000},
	{{0, 9, -15, 0, 2, 0, 0, 0, -2, 2, 0}, 51.512450, 0.000010, 0.636000},
	{{0, 9, -15, 0, 2, 0, 0, 0, 0, -1, 0}, 51.589800, 0.000020, 0.074000},
	{{0, 9, -15, 0, 2, 0, 0, 0, 0, 1, 0}, 51.589800, 0.000020, 0.077000},
	{{0, 9, -15, 0, 3, 0, 0, 0, 0, -1, 0}, 221.574630, 0.000030, 0.075000},
	{{0, 9, -15, 0, 3, 0, 0, 0, 0, 1, 0}, 221.574630, 0.000030, 0.076000},
	{{0, 9, -15, 0, 4, 0, 0, 0, 0, -1, 0}, 32.237000, 0.000010, 0.075000},
	{{0, 9, -15, 0, 4, 0, 0, 0, 0, 1, 0}, 32.237000, 0.000010, 0.076000},
	{{0, 9, -15, 2, 0, 0, 0, 0, -2, 0, 0}, 231.747700, 0.000040, 0.042000},
	{{0, 9, -15, 2, 0, 0, 0, 0, -2, 2, 0}, 231.728000, 0.000030, 0.405000},
	{{0, 9, -15, 2, 0, 0, 0, 0, 0, -1, 0}, 51.793760, 0.000010, 0.080000},
	{{0, 9, -15, 2, 0, 0, 0, 0, 0, 1, 0}, 51.793760, 0.000010, 0.072000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -4, 2, 0}, 112.962620, 0.000010, 0.045000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 324.054640, 0.000040, 0.027000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 304.688500, 0.000070, 0.041000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 260.811650, 0.000030, 0.092000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 292.962620, 0.000070, 0.416000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 226.875540, 0.000020, 0.079000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 185.045200, 0.000050, 1.588000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 226.875540, 0.000020, 0.072000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 2, -3, 0}, 57.879530, 0.000030, 0.069000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 57.879530, 0.000030, 0.083000},
	{{0, 9, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 50.387250, 0.000030, 0.042000},
	{{0, 9, -14, 0, 1, 0, 0, 0, -2, 1, 0}, 230.370610, 0.000010, 0.093000},
	{{0, 9, -14, 0, 1, 0, 0, 0, -2, 3, 0}, 50.387250, 0.000030, 0.064000},
	{{0, 9, -14, 0, 1, 0, 0, 0, 0, -1, 0}, 230.387250, 0.000040, 0.080000},
	{{0, 9, -14, 0, 1, 0, 0, 0, 0, 1, 0}, 230.387250, 0.000040, 0.072000},
	{{0, 9, -14, 0, 2, 0, 0, 0, -2, 0, 0}, 111.896230, 0.000030, 0.042000},
	{{0, 9, -14, 2, 0, 0, 0, 0, -2, 0, 0}, 95.359140, 0.000010, 0.043000},
	{{0, 9, -14, 2, 0, 0, 0, 0, -2, 2, 0}, 95.359140, 0.000010, 0.288000},
	{{0, 9, -13, -3, 0, 0, 0, 0, 0, -1, 0}, 266.567940, 0.000030, 0.076000},
	{{0, 9, -13, -3, 0, 0, 0, 0, 0, 1, 0}, 266.567940, 0.000030, 0.075000},
	{{0, 9, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 241.439700, 0.000080, 0.043000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 42.753840, 0.000030, 0.043000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 229.529650, 0.000020, 0.102000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 39.898320, 0.000010, 0.294000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 231.778650, 0.000030, 0.060000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 184.147430, 0.000060, 0.086000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 168.805750, 0.000030, 0.614000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 231.778640, 0.000030, 0.067000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 333.076920, 0.000020, 1.736000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 61.457420, 0.000040, 0.075000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 336.467750, 0.000040, 6.930000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 340.434040, 0.000240, 0.076000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 75.106420, 0.000020, 0.038000},
	{{0, 9, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 38.840720, 0.000070, 0.043000},
	{{0, 9, -13, 0, 1, 0, 0, 0, 2, -3, 0}, 36.651350, 0.000010, 0.075000},
	{{0, 9, -13, 0, 1, 0, 0, 0, 2, -1, 0}, 295.978740, 0.000020, 0.076000},
	{{0, 9, -13, 0, 2, 0, 0, 0, 2, -2, 0}, 15.670610, 0.000010, 41.153000},
	{{0, 9, -12, -2, 0, 0, 0, 0, -2, 0, 0}, 191.177080, 0.000010, 0.043000},
	{{0, 9, -12, -2, 0, 0, 0, 0, -2, 2, 0}, 191.177080, 0.000010, 0.299000},
	{{0, 9, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 53.653610, 0.000060, 0.045000},
	{{0, 9, -12, 0, -1, 0, 0, 0, -2, 2, 0}, 50.807740, 0.000020, 0.232000},
	{{0, 9, -12, 0, -1, 0, 0, 0, 0, 0, 0}, 232.525830, 0.000020, 0.393000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 316.728300, 0.000020, 0.045000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 113.380050, 0.000020, 0.113000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 300.044240, 0.000030, 0.227000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 255.255190, 0.000060, 0.094000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 66.726450, 0.000160, 0.380000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 249.695590, 0.000050, 0.635000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 82.164720, 0.000010, 1.169000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 75.258440, 0.000240, 0.071000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 255.214820, 0.000060, 0.037000},
	{{0, 9, -12, 0, 2, 0, 0, 0, 2, -1, 0}, 91.195680, 0.000020, 0.070000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 197.796850, 0.000020, 0.047000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 341.844090, 0.000030, 0.185000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 23.954180, 0.000010, 0.054000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -1, 0, 1}, 8.275020, 0.000020, 0.214000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 316.655110, 0.000020, 0.104000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 344.551750, 0.000570, 0.276000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 348.221450, 0.000090, 0.059000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 168.782100, 0.000140, 0.388000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 165.110120, 0.000020, 0.063000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 351.688860, 0.000020, 0.539000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 352.734880, 0.000610, 0.066000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, -2}, 351.936900, 0.000020, 0.657000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 173.679340, 0.000240, 0.035000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 170.945790, 0.000030, 0.024000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 4, -1, 0}, 171.733220, 0.000010, 0.025000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 4, 0, 0}, 171.822750, 0.000020, 0.019000},
	{{0, 9, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 270.514840, 0.000010, 0.048000},
	{{0, 9, -11, 0, 1, 0, 0, 0, -2, 2, 0}, 90.514840, 0.000010, 0.182000},
	{{0, 9, -11, 0, 1, 0, 0, 0, 2, 0, 0}, 90.022370, 0.000020, 0.035000},
	{{0, 9, -11, 0, 2, 0, 0, 0, 2, -2, 0}, 179.827190, 0.000020, 0.494000},
	{{0, 9, -11, 2, 0, 0, 0, 0, -2, 0, 0}, 179.190910, 0.000010, 0.050000},
	{{0, 9, -11, 2, 0, 0, 0, 0, -2, 2, 0}, 179.190910, 0.000010, 0.155000},
	{{0, 9, -11, 2, 0, 0, 0, 0, 0, 0, 0}, 0.794190, 0.000010, 0.213000},
	{{0, 9, -11, 2, 0, 0, 0, 0, 2, -2, 0}, 0.046040, 0.000020, 0.343000},
	{{0, 9, -11, 2, 0, 0, 0, 0, 2, 0, 0}, 0.046040, 0.000020, 0.034000},
	{{0, 9, -11, 4, 0, 0, 0, 0, -2, 0, 0}, 57.941990, 0.000010, 0.053000},
	{{0, 9, -11, 4, 0, 0, 0, 0, -2, 2, 0}, 57.941990, 0.000010, 0.133000},
	{{0, 9, -10, 0, -1, 0, 0, 0, -2, 0, 0}, 104.244950, 0.000020, 0.050000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 275.889600, 0.000050, 0.050000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 74.995890, 0.000020, 0.146000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 94.058250, 0.000020, 0.156000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 271.080050, 0.000010, 0.051000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 75.743340, 0.000020, 0.047000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, 1}, 254.984840, 0.000090, 0.176000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 1, -1}, 75.724020, 0.000020, 0.126000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 267.468160, 0.000040, 0.116000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 271.751130, 0.001680, 0.216000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 272.201750, 0.000380, 0.056000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 272.375030, 0.000030, 0.032000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, -1, -1}, 81.289610, 0.000070, 0.103000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, -1, 1}, 255.781680, 0.000030, 0.058000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 75.779840, 0.000450, 0.280000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 90.023000, 0.000030, 0.059000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 75.802060, 0.000010, 0.033000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 1, -1}, 83.445310, 0.000050, 0.059000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 278.318790, 0.000020, 0.096000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 244.340990, 0.000050, 0.350000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 272.608210, 0.001790, 0.062000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, -2}, 272.304470, 0.000060, 0.396000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 94.082800, 0.001170, 0.034000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 1, 0}, 93.630960, 0.000170, 0.023000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 2, 0}, 92.610050, 0.000020, 0.018000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 3, 0, 0}, 92.431840, 0.000020, 0.024000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 4, -2, 0}, 279.104980, 0.000030, 0.036000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 4, -1, 0}, 266.286760, 0.000010, 0.024000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 4, 0, 0}, 98.020000, 0.000040, 0.018000},
	{{0, 9, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 210.576200, 0.000040, 0.050000},
	{{0, 9, -10, 0, 1, 0, 0, 0, -2, 2, 0}, 358.416900, 0.000020, 0.154000},
	{{0, 9, -10, 0, 2, 0, 0, 0, -2, 0, 0}, 232.648400, 0.000010, 0.050000},
	{{0, 9, -10, 0, 2, 0, 0, 0, -2, 2, 0}, 232.648400, 0.000010, 0.152000},
	{{0, 9, -10, 3, 0, 0, 0, 0, -2, 0, 0}, 236.375310, 0.000010, 0.054000},
	{{0, 9, -10, 3, 0, 0, 0, 0, -2, 2, 0}, 236.375310, 0.000010, 0.125000},
	{{0, 9, -10, 3, 0, 0, 0, 0, 0, 0, 0}, 236.824600, 0.000010, 0.161000},
	{{0, 9, -9, 0, -1, 0, 0, 0, -2, 0, 0}, 184.278060, 0.000070, 0.052000},
	{{0, 9, -9, 0, -1, 0, 0, 0, -2, 2, 0}, 185.582980, 0.000010, 0.137000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -4, 1, 0}, 180.132910, 0.000010, 0.033000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -4, 2, 0}, 178.599300, 0.000020, 0.058000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -4, 3, 0}, 180.182280, 0.000010, 0.245000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, -2, 0}, 0.169190, 0.000030, 0.022000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 181.593440, 0.000020, 0.031000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 180.531090, 0.000390, 0.052000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 180.237880, 0.000270, 0.171000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 358.383540, 0.000090, 0.135000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 359.557600, 0.000010, 0.048000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 14.729230, 0.000010, 0.050000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 359.905680, 0.000090, 0.148000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 17.205390, 0.000010, 0.150000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 180.002820, 0.000510, 0.131000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 179.956370, 0.007480, 0.178000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 0, 2}, 0.006680, 0.000010, 0.031000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 180.199340, 0.001280, 0.053000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 180.786360, 0.000130, 0.031000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 3.433320, 0.000010, 0.211000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 191.192340, 0.000110, 0.219000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 0.298760, 0.000070, 0.056000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 191.191650, 0.000020, 0.032000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 1, 0}, 180.048630, 0.000010, 0.032000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 177.755650, 0.000020, 0.106000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 179.932270, 0.000270, 0.259000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 179.997020, 0.005360, 0.058000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, -2}, 180.007630, 0.000170, 0.284000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 0.062110, 0.004510, 0.033000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, 2}, 180.003270, 0.000020, 0.017000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 359.998510, 0.000380, 0.023000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 2, 0}, 359.966930, 0.000050, 0.018000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 3, -1, 0}, 180.046280, 0.000020, 0.034000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 3, 0, 0}, 0.047020, 0.000040, 0.023000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 179.999280, 0.000080, 0.035000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, -1, 0}, 0.002280, 0.000050, 0.024000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, 0, 0}, 0.000260, 0.000080, 0.018000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, 1, 0}, 0.001810, 0.000010, 0.015000},
	{{0, 9, -9, 0, 1, 0, 0, 0, -2, 0, 0}, 348.227080, 0.000070, 0.053000},
	{{0, 9, -9, 0, 1, 0, 0, 0, -2, 1, 0}, 172.684120, 0.000020, 0.173000},
	{{0, 9, -9, 0, 1, 0, 0, 0, 0, 0, 0}, 175.712380, 0.000020, 0.175000},
	{{0, 9, -9, 0, 1, 0, 0, 0, 2, -2, 0}, 166.883910, 0.000010, 0.254000},
	{{0, 9, -9, 0, 1, 0, 0, 0, 2, 0, 0}, 166.883910, 0.000010, 0.033000},
	{{0, 9, -9, 11, 0, 0, 0, 0, -2, 1, 0}, 301.336980, 0.000010, 285.530000},
	{{0, 9, -8, -3, 0, 0, 0, 0, -2, 0, 0}, 303.086560, 0.000020, 0.051000},
	{{0, 9, -8, -3, 0, 0, 0, 0, -2, 2, 0}, 303.086560, 0.000020, 0.147000},
	{{0, 9, -8, -2, 0, 0, 0, 0, -2, 1, 0}, 136.295090, 0.000010, 0.169000},
	{{0, 9, -8, -2, 0, 0, 0, 0, 0, 0, 0}, 311.830970, 0.000010, 0.180000},
	{{0, 9, -8, 0, -1, 0, 0, 0, -2, 2, 0}, 178.566710, 0.000010, 0.120000},
	{{0, 9, -8, 0, -1, 0, 0, 0, 0, -2, 0}, 180.961830, 0.000020, 0.050000},
	{{0, 9, -8, 0, -1, 0, 0, 0, 0, 0, 0}, 181.368080, 0.000090, 0.153000},
	{{0, 9, -8, 0, -1, 0, 0, 0, 2, 0, 0}, 181.293790, 0.000020, 0.032000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 255.056750, 0.000020, 0.055000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 257.168850, 0.000010, 0.206000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, -1, 1}, 283.232430, 0.000020, 0.179000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 0, -1}, 103.233410, 0.000120, 0.052000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 283.231030, 0.000150, 0.130000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 1, -1}, 103.244780, 0.000060, 0.169000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 2, 1}, 283.295250, 0.000020, 0.029000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 206.211340, 0.000010, 0.151000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 346.149700, 0.000010, 0.151000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, -1, -1}, 103.287640, 0.000090, 0.130000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, -1, 1}, 283.295630, 0.000020, 0.052000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 103.302280, 0.000450, 0.179000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 103.292840, 0.000030, 0.031000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 1, -1}, 103.295800, 0.000040, 0.053000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 269.126710, 0.000200, 0.055000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 89.780930, 0.000300, 0.032000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 92.059410, 0.000030, 0.022000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 90.368360, 0.000010, 0.023000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 84.679790, 0.000020, 0.018000},
	{{0, 9, -7, -3, 0, 0, 0, 0, -2, 0, 0}, 336.204600, 0.000010, 0.053000},
	{{0, 9, -7, -3, 0, 0, 0, 0, -2, 2, 0}, 336.204600, 0.000010, 0.128000},
	{{0, 9, -7, -2, 0, 0, 0, 0, -2, 0, 0}, 0.520160, 0.000010, 0.055000},
	{{0, 9, -7, -2, 0, 0, 0, 0, -2, 2, 0}, 0.520160, 0.000010, 0.120000},
	{{0, 9, -7, 0, -3, 0, 0, 0, -2, 0, 0}, 7.473930, 0.000010, 0.058000},
	{{0, 9, -7, 0, -3, 0, 0, 0, -2, 2, 0}, 7.473930, 0.000010, 0.109000},
	{{0, 9, -7, 0, -2, 0, 0, 0, -2, 2, 0}, 0.283250, 0.000020, 0.108000},
	{{0, 9, -7, 0, -2, 0, 0, 0, 0, 0, 0}, 359.885460, 0.000050, 0.134000},
	{{0, 9, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 26.007390, 0.000020, 0.033000},
	{{0, 9, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 24.896200, 0.000210, 0.058000},
	{{0, 9, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 26.224590, 0.000120, 0.260000},
	{{0, 9, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 206.093600, 0.000020, 0.211000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 19.985130, 0.000120, 0.178000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 26.555640, 0.000470, 0.131000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 15.931400, 0.000040, 0.048000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 315.874750, 0.000020, 0.171000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 25.867810, 0.000070, 0.052000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 210.596180, 0.000080, 0.031000},
	{{0, 9, -6, -4, 0, 0, 0, 0, 0, 0, 0}, 150.731540, 0.000010, 0.154000},
	{{0, 9, -6, 0, -3, 0, 0, 0, -2, 0, 0}, 356.658820, 0.000020, 0.061000},
	{{0, 9, -6, 0, -1, 0, 0, 0, -2, 0, 0}, 24.104600, 0.000010, 0.062000},
	{{0, 9, -6, 0, -1, 0, 0, 0, -2, 2, 0}, 204.104600, 0.000010, 0.097000},
	{{0, 9, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 275.913380, 0.000020, 0.351000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 262.412770, 0.000040, 0.116000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 39.367680, 0.000010, 0.156000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 39.473680, 0.000010, 0.146000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 39.367680, 0.000010, 0.050000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 39.473680, 0.000010, 0.030000},
	{{0, 9, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 217.161630, 0.000010, 0.540000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 307.957840, 0.000020, 0.276000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 308.203750, 0.000020, 0.104000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 308.203750, 0.000020, 0.028000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 129.264790, 0.000020, 0.127000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 128.260610, 0.000010, 0.047000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 127.741750, 0.000060, 0.029000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 128.260610, 0.000010, 0.021000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 128.223700, 0.000040, 0.016000},
	{{0, 9, -4, 0, -1, 0, 0, 0, 2, -2, 0}, 309.931610, 0.000010, 0.114000},
	{{0, 9, -4, 0, -1, 0, 0, 0, 2, 0, 0}, 309.931610, 0.000010, 0.028000},
	{{0, 9, -4, 0, 0, -1, 0, 0, -3, 2, 0}, 128.093570, 0.000050, 969.469000},
	{{0, 9, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 302.084920, 0.000020, 0.071000},
	{{0, 9, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 302.084920, 0.000020, 0.081000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 36.070820, 0.000020, 0.113000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 36.070820, 0.000020, 0.028000},
	{{0, 9, -3, 0, -2, 0, 0, 0, -2, 0, 0}, 87.068530, 0.000010, 0.075000},
	{{0, 9, -3, 0, -2, 0, 0, 0, -2, 1, 0}, 349.737370, 0.000070, 48.456000},
	{{0, 9, -3, 0, -2, 0, 0, 0, -2, 2, 0}, 267.068530, 0.000010, 0.076000},
	{{0, 9, -3, 0, -2, 0, 0, 0, 2, -2, 0}, 128.380120, 0.000010, 0.103000},
	{{0, 9, -3, 0, -2, 0, 0, 0, 2, 0, 0}, 308.380120, 0.000010, 0.028000},
	{{0, 9, -3, 0, -1, 0, 0, 0, -2, 1, 0}, 354.017180, 0.000020, 15.707000},
	{{0, 9, -3, 0, 0, -4, 0, 0, -2, 1, 0}, 201.985560, 0.000030, 82.115000},
	{{0, 9, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 21.570500, 0.000010, 0.076000},
	{{0, 9, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 62.474790, 0.000040, 6.758000},
	{{0, 9, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 21.570500, 0.000010, 0.075000},
	{{0, 9, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 334.114260, 0.000020, 0.027000},
	{{0, 9, -2, 0, -3, 0, 0, 0, -1, 0, 0}, 80.896530, 0.000010, 124.238000},
	{{0, 9, -1, -4, 0, 0, 0, 0, -2, 1, 0}, 65.971840, 0.000040, 47.095000},
	{{0, 9, -1, 0, -4, 0, 0, 0, 0, -1, 0}, 29.003780, 0.000010, 27.222000},
	{{0, 9, 8, -21, 0, 0, 0, 0, -2, 1, 0}, 243.481360, 0.000030, 57.479000},
	{{0, 10, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 289.615290, 0.000020, 0.036000},
	{{0, 10, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 289.615920, 0.000010, 1.030000},
	{{0, 10, -18, 0, 0, -1, 0, 0, -2, 2, 0}, 122.039490, 0.000010, 212.821000},
	{{0, 10, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 66.910610, 0.000020, 0.076000},
	{{0, 10, -18, 0, 0, 0, 0, 0, -2, 3, 0}, 352.581920, 0.000010, 0.075000},
	{{0, 10, -18, 0, 2, 0, 0, 0, -2, 1, 0}, 44.202600, 0.000010, 0.077000},
	{{0, 10, -18, 0, 2, 0, 0, 0, -2, 3, 0}, 44.202600, 0.000010, 0.074000},
	{{0, 10, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 307.725840, 0.000020, 1.343000},
	{{0, 10, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 224.433860, 0.000010, 0.026000},
	{{0, 10, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 224.433860, 0.000010, 0.089000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 279.138350, 0.000020, 3.918000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 44.433860, 0.000020, 0.085000},
	{{0, 10, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 141.810850, 0.000030, 0.041000},
	{{0, 10, -16, 0, 1, 0, 0, 0, 0, 2, -2}, 321.810850, 0.000010, 166.045000},
	{{0, 10, -16, 0, 2, 0, 0, 0, -2, 0, 0}, 51.540530, 0.000020, 0.041000},
	{{0, 10, -16, 0, 2, 0, 0, 0, -2, 1, 0}, 231.565640, 0.000020, 0.090000},
	{{0, 10, -16, 0, 2, 0, 0, 0, -2, 2, 0}, 51.540530, 0.000020, 0.455000},
	{{0, 10, -16, 0, 2, 0, 0, 0, -2, 3, 0}, 231.565640, 0.000020, 0.065000},
	{{0, 10, -16, 0, 2, 0, 0, 0, 0, -1, 0}, 51.540540, 0.000020, 0.078000},
	{{0, 10, -16, 0, 2, 0, 0, 0, 0, 1, 0}, 51.540540, 0.000020, 0.073000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, -1, 0}, 324.060360, 0.000030, 0.027000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 357.637020, 0.000010, 0.043000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 328.788480, 0.000010, 0.098000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 339.270370, 0.000030, 0.330000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 173.319720, 0.000020, 0.797000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 55.652120, 0.000010, 4.964000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -3, 0}, 237.880510, 0.000040, 0.073000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 237.880510, 0.000040, 0.079000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 57.911670, 0.000020, 0.038000},
	{{0, 10, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 50.367420, 0.000030, 0.043000},
	{{0, 10, -15, 0, 1, 0, 0, 0, -2, 1, 0}, 50.392330, 0.000040, 0.099000},
	{{0, 10, -15, 0, 1, 0, 0, 0, 0, -1, 0}, 50.392330, 0.000010, 0.084000},
	{{0, 10, -15, 0, 1, 0, 0, 0, 0, 1, 0}, 50.392330, 0.000010, 0.069000},
	{{0, 10, -15, 0, 2, 0, 0, 0, -2, 0, 0}, 111.879660, 0.000020, 0.043000},
	{{0, 10, -15, 1, 0, 0, 0, 0, 2, -2, 0}, 231.202650, 0.000010, 77.527000},
	{{0, 10, -15, 2, 0, 0, 0, 0, -2, 0, 0}, 95.342580, 0.000010, 0.045000},
	{{0, 10, -15, 2, 0, 0, 0, 0, -2, 2, 0}, 95.342580, 0.000010, 0.244000},
	{{0, 10, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 241.433790, 0.000070, 0.044000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 69.427950, 0.000030, 0.044000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 231.649260, 0.000010, 0.108000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 33.932990, 0.000040, 0.248000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 3, 0}, 231.649260, 0.000010, 0.058000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 231.741990, 0.000020, 0.099000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 163.729690, 0.000030, 0.443000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 333.741610, 0.000010, 0.832000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 2, -1, -2}, 229.685610, 0.000010, 0.076000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 155.561170, 0.000070, 0.073000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 126.202400, 0.000020, 0.037000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 2, 1, -2}, 229.685610, 0.000010, 0.075000},
	{{0, 10, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 38.840740, 0.000030, 0.045000},
	{{0, 10, -14, 0, 1, 0, 0, 0, -2, 2, 0}, 218.840740, 0.000030, 0.243000},
	{{0, 10, -13, -2, 0, 0, 0, 0, -2, 0, 0}, 191.160520, 0.000010, 0.044000},
	{{0, 10, -13, -2, 0, 0, 0, 0, -2, 2, 0}, 191.160520, 0.000010, 0.252000},
	{{0, 10, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 53.638010, 0.000060, 0.046000},
	{{0, 10, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 230.813570, 0.000020, 0.202000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 109.179500, 0.000010, 0.122000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 240.278830, 0.000030, 0.100000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 67.563990, 0.000130, 0.307000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 250.348900, 0.000030, 0.454000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 76.426380, 0.000120, 0.068000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 255.976010, 0.000070, 0.036000},
	{{0, 10, -13, 0, 1, 0, 0, 0, 0, 0, 0}, 353.345160, 0.000010, 0.299000},
	{{0, 10, -13, 0, 2, 0, 0, 0, 0, 0, 0}, 269.924000, 0.000010, 0.292000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 353.916480, 0.000010, 0.049000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 334.716770, 0.000020, 0.166000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 353.809020, 0.000050, 0.111000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 344.850390, 0.000430, 0.235000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 348.934460, 0.000050, 0.057000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 168.722450, 0.000100, 0.312000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 348.759100, 0.000020, 0.033000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 354.099500, 0.000020, 0.403000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 353.918860, 0.000390, 0.064000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, 0, -2}, 352.786780, 0.000010, 0.466000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 174.420520, 0.000210, 0.034000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 171.928630, 0.000020, 0.024000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 4, -3, 0}, 196.002280, 0.000010, 0.072000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 4, -1, 0}, 172.603330, 0.000010, 0.025000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 4, 0, 0}, 172.684220, 0.000020, 0.019000},
	{{0, 10, -12, 0, 1, 0, 0, 0, -2, 0, 0}, 270.569400, 0.000010, 0.049000},
	{{0, 10, -12, 0, 1, 0, 0, 0, -2, 2, 0}, 90.569400, 0.000010, 0.164000},
	{{0, 10, -12, 0, 2, 0, 0, 0, 0, 0, 0}, 179.686470, 0.000010, 0.226000},
	{{0, 10, -12, 0, 2, 0, 0, 0, 2, -2, 0}, 179.792720, 0.000010, 0.377000},
	{{0, 10, -12, 0, 2, 0, 0, 0, 2, -1, 0}, 359.817920, 0.000030, 0.063000},
	{{0, 10, -12, 0, 2, 0, 0, 0, 2, 0, 0}, 179.804110, 0.000040, 0.034000},
	{{0, 10, -12, 2, 0, 0, 0, 0, -2, 0, 0}, 179.180560, 0.000010, 0.051000},
	{{0, 10, -12, 2, 0, 0, 0, 0, -2, 2, 0}, 179.180560, 0.000010, 0.141000},
	{{0, 10, -12, 2, 0, 0, 0, 0, 0, 0, 0}, 0.778230, 0.000010, 0.188000},
	{{0, 10, -12, 2, 0, 0, 0, 0, 2, -2, 0}, 0.029480, 0.000010, 0.282000},
	{{0, 10, -12, 2, 0, 0, 0, 0, 2, 0, 0}, 0.029480, 0.000010, 0.033000},
	{{0, 10, -11, 0, -1, 0, 0, 0, -2, 0, 0}, 104.736470, 0.000020, 0.051000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -4, 2, 0}, 271.889640, 0.000010, 0.056000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 273.629190, 0.000050, 0.051000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 90.924850, 0.000020, 0.142000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 271.166970, 0.000010, 0.049000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 63.556880, 0.000030, 0.049000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, 1}, 255.508250, 0.000070, 0.159000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 1, -1}, 75.530610, 0.000010, 0.137000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 270.882180, 0.000060, 0.125000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 272.007850, 0.001220, 0.190000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 272.006530, 0.000280, 0.054000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 272.239660, 0.000010, 0.031000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, -1, -1}, 75.552710, 0.000030, 0.110000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, -1, 1}, 75.555000, 0.000020, 0.056000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 75.565440, 0.000320, 0.238000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 85.911670, 0.000020, 0.057000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 75.558120, 0.000010, 0.032000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 1, -1}, 75.553360, 0.000010, 0.057000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 290.075020, 0.000020, 0.102000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 299.734460, 0.000010, 0.287000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 272.508180, 0.001230, 0.060000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, -2}, 272.310300, 0.000040, 0.318000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 93.370670, 0.000990, 0.033000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 92.266540, 0.000130, 0.023000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 2, 0}, 92.379870, 0.000020, 0.018000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 3, 0, 0}, 92.430660, 0.000020, 0.024000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 4, -2, 0}, 269.166260, 0.000030, 0.035000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 4, -1, 0}, 99.610070, 0.000010, 0.024000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 4, 0, 0}, 97.771060, 0.000060, 0.018000},
	{{0, 10, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 215.614380, 0.000040, 0.052000},
	{{0, 10, -11, 0, 1, 0, 0, 0, 2, -1, 0}, 178.644610, 0.000030, 0.059000},
	{{0, 10, -11, 0, 1, 0, 0, 0, 2, 0, 0}, 358.688460, 0.000040, 0.033000},
	{{0, 10, -11, 0, 2, 0, 0, 0, -2, 0, 0}, 232.638060, 0.000020, 0.052000},
	{{0, 10, -11, 3, 0, 0, 0, 0, -2, 0, 0}, 236.358740, 0.000010, 0.056000},
	{{0, 10, -11, 3, 0, 0, 0, 0, -2, 2, 0}, 236.358740, 0.000010, 0.116000},
	{{0, 10, -10, 0, -1, 0, 0, 0, -2, 0, 0}, 182.597620, 0.000060, 0.054000},
	{{0, 10, -10, 0, -1, 0, 0, 0, -2, 1, 0}, 7.485100, 0.000010, 0.188000},
	{{0, 10, -10, 0, -1, 0, 0, 0, -2, 2, 0}, 185.590620, 0.000010, 0.126000},
	{{0, 10, -10, 0, -1, 0, 0, 0, 2, 0, 0}, 8.658020, 0.000020, 0.032000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -4, 1, 0}, 180.061990, 0.000010, 0.033000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -4, 2, 0}, 178.725160, 0.000020, 0.060000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, -2, 0}, 359.799460, 0.000010, 0.022000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, -1, 0}, 177.067240, 0.000020, 0.032000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 179.304900, 0.000390, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 181.776740, 0.000280, 0.191000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 358.567500, 0.000090, 0.125000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 14.595580, 0.000010, 0.051000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 359.937850, 0.000080, 0.164000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 180.217800, 0.000410, 0.143000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 0, -2}, 179.946890, 0.000020, 0.049000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 179.939210, 0.005270, 0.160000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 179.938200, 0.000880, 0.051000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 180.893210, 0.000060, 0.031000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, -1, 0}, 359.995680, 0.000020, 0.186000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 191.380260, 0.000090, 0.192000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 359.693060, 0.000040, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 191.379630, 0.000020, 0.031000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 181.137660, 0.000030, 0.114000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -2, -2}, 0.006010, 0.000010, 0.045000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 180.448360, 0.000190, 0.223000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 179.991900, 0.003590, 0.056000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, -2}, 179.992860, 0.000090, 0.241000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 0.076270, 0.003480, 0.032000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, 2}, 180.000600, 0.000010, 0.017000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 1, 0}, 0.005000, 0.000290, 0.023000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 2, 0}, 359.988570, 0.000060, 0.017000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 3, -1, 0}, 180.035600, 0.000020, 0.033000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 3, 0, 0}, 0.036330, 0.000030, 0.023000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, -2, 0}, 179.711050, 0.000050, 0.034000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, -1, 0}, 0.041550, 0.000030, 0.024000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, 0, 0}, 0.003170, 0.000060, 0.018000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, 1, 0}, 359.992560, 0.000020, 0.014000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, 2, 0}, 359.991100, 0.000010, 0.012000},
	{{0, 10, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 349.180140, 0.000040, 0.054000},
	{{0, 10, -10, 0, 1, 0, 0, 0, -2, 1, 0}, 172.658350, 0.000020, 0.194000},
	{{0, 10, -10, 0, 1, 0, 0, 0, -2, 2, 0}, 346.546740, 0.000020, 0.123000},
	{{0, 10, -10, 0, 1, 0, 0, 0, 2, -2, 0}, 346.867350, 0.000010, 0.219000},
	{{0, 10, -10, 0, 1, 0, 0, 0, 2, 0, 0}, 166.867350, 0.000010, 0.032000},
	{{0, 10, -9, -3, 0, 0, 0, 0, -2, 0, 0}, 303.074150, 0.000020, 0.052000},
	{{0, 10, -9, -3, 0, 0, 0, 0, -2, 2, 0}, 303.074150, 0.000020, 0.135000},
	{{0, 10, -9, -2, 0, 0, 0, 0, 0, 0, 0}, 291.472380, 0.000020, 0.162000},
	{{0, 10, -9, 0, -1, 0, 0, 0, -2, 2, 0}, 178.530940, 0.000010, 0.112000},
	{{0, 10, -9, 0, -1, 0, 0, 0, 0, -2, 0}, 180.951630, 0.000020, 0.052000},
	{{0, 10, -9, 0, -1, 0, 0, 0, 0, 0, 0}, 181.357580, 0.000080, 0.139000},
	{{0, 10, -9, 0, -1, 0, 0, 0, 2, -2, 0}, 1.273910, 0.000010, 0.185000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 249.537920, 0.000030, 0.057000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 239.442300, 0.000010, 0.111000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, -1, 1}, 283.212290, 0.000020, 0.202000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 103.201630, 0.000090, 0.054000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 283.219030, 0.000130, 0.120000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 1, -1}, 103.226870, 0.000060, 0.189000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 2, -1}, 283.276580, 0.000020, 0.125000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 248.078190, 0.000030, 0.167000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 261.771610, 0.000040, 0.138000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, -3, 1}, 103.281480, 0.000020, 0.149000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, -1, -1}, 103.398820, 0.000060, 0.142000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 103.289150, 0.000350, 0.161000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 103.279400, 0.000030, 0.030000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 1, -1}, 103.283840, 0.000020, 0.051000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 269.538980, 0.000160, 0.053000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 92.007750, 0.000230, 0.031000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 98.305130, 0.000020, 0.022000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 4, -1, 0}, 91.241200, 0.000010, 0.023000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 4, 0, 0}, 85.789700, 0.000020, 0.018000},
	{{0, 10, -8, -3, 0, 0, 0, 0, -2, 0, 0}, 336.196290, 0.000010, 0.055000},
	{{0, 10, -8, -3, 0, 0, 0, 0, -2, 2, 0}, 336.196290, 0.000010, 0.119000},
	{{0, 10, -8, -2, 0, 0, 0, 0, -2, 0, 0}, 0.497940, 0.000010, 0.057000},
	{{0, 10, -8, -2, 0, 0, 0, 0, -2, 2, 0}, 0.497940, 0.000010, 0.112000},
	{{0, 10, -8, 0, -3, 0, 0, 0, -2, 0, 0}, 8.629430, 0.000020, 0.060000},
	{{0, 10, -8, 0, -2, 0, 0, 0, -2, 0, 0}, 0.273010, 0.000020, 0.060000},
	{{0, 10, -8, 0, -2, 0, 0, 0, -2, 2, 0}, 0.273010, 0.000020, 0.101000},
	{{0, 10, -8, 0, -2, 0, 0, 0, 0, -2, 0}, 359.857240, 0.000020, 0.054000},
	{{0, 10, -8, 0, -2, 0, 0, 0, 0, 0, 0}, 359.444920, 0.000010, 0.124000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 25.990870, 0.000020, 0.034000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 25.441230, 0.000200, 0.061000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 26.643310, 0.000120, 0.310000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 29.620510, 0.000010, 0.100000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 200.299060, 0.000020, 0.243000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 26.644490, 0.000080, 0.200000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 26.612260, 0.000380, 0.121000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 27.269890, 0.000050, 0.051000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 205.732750, 0.000060, 0.030000},
	{{0, 10, -7, 0, -3, 0, 0, 0, -2, 0, 0}, 356.646410, 0.000030, 0.064000},
	{{0, 10, -7, 0, -3, 0, 0, 0, -2, 1, 0}, 356.646410, 0.000010, 0.403000},
	{{0, 10, -7, 0, -1, 0, 0, 0, -2, 0, 0}, 24.531250, 0.000010, 0.064000},
	{{0, 10, -7, 0, -1, 0, 0, 0, -2, 1, 0}, 24.527040, 0.000010, 0.433000},
	{{0, 10, -7, 0, -1, 0, 0, 0, -2, 2, 0}, 24.531250, 0.000010, 0.091000},
	{{0, 10, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 275.435500, 0.000020, 0.449000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 258.973510, 0.000030, 0.108000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 38.595130, 0.000010, 0.134000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 38.595130, 0.000010, 0.029000},
	{{0, 10, -6, 0, -1, 0, 0, 0, 2, 0, 0}, 321.262480, 0.000030, 0.029000},
	{{0, 10, -6, 0, 0, 0, 0, 0, -3, 0, 2}, 48.443400, 0.000130, 167.135000},
	{{0, 10, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 220.956340, 0.000020, 0.815000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 308.209360, 0.000020, 0.333000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 308.214880, 0.000040, 0.098000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 308.252300, 0.000010, 0.043000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 308.214880, 0.000040, 0.027000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 128.197410, 0.000020, 0.209000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 128.083860, 0.000010, 0.118000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 128.197410, 0.000020, 0.046000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 129.128140, 0.000030, 0.029000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 128.649260, 0.000020, 0.016000},
	{{0, 10, -6, 0, 1, 0, 0, 0, 2, -2, 0}, 119.471800, 0.000010, 0.117000},
	{{0, 10, -6, 0, 1, 0, 0, 0, 2, 0, 0}, 119.471800, 0.000010, 0.029000},
	{{0, 10, -5, 0, -3, 0, 0, 0, -2, 1, 0}, 199.940520, 0.000010, 2.086000},
	{{0, 10, -5, 0, -2, 0, 0, 0, -2, 1, 0}, 109.906420, 0.000010, 2.531000},
	{{0, 10, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 148.480310, 0.000020, 16.737000},
	{{0, 10, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 130.889790, 0.000080, 4.415000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 179.179370, 0.000020, 0.044000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 35.579820, 0.000010, 0.028000},
	{{0, 10, -4, -2, 0, 0, 0, 0, -2, 1, 0}, 128.100350, 0.000010, 3.450000},
	{{0, 10, -4, 0, -9, 0, 0, 0, -2, 1, 0}, 30.230560, 0.000010, 67.776000},
	{{0, 10, -4, 0, -2, 0, 0, 0, 2, -2, 0}, 308.311900, 0.000020, 0.097000},
	{{0, 10, -4, 0, -2, 0, 0, 0, 2, 0, 0}, 308.311900, 0.000020, 0.027000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -2, -2, 0}, 256.242440, 0.000010, 0.026000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 256.242440, 0.000070, 0.039000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 256.242440, 0.000040, 0.080000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 76.242440, 0.000020, 0.075000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 234.207750, 0.000010, 18.782000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 244.746590, 0.000010, 8.810000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, -3, 0}, 256.242440, 0.000020, 0.036000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 256.242440, 0.000150, 0.070000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 76.242440, 0.000200, 0.082000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 76.242440, 0.000030, 0.039000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 76.242440, 0.000280, 0.095000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 76.242440, 0.000450, 0.042000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 76.242440, 0.000060, 0.027000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 4, -2, 0}, 76.242440, 0.000020, 0.028000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 76.242440, 0.000010, 0.021000},
	{{0, 10, -3, 0, -2, 0, 0, 0, 0, -1, 0}, 209.513550, 0.000020, 5.913000},
	{{0, 10, -3, 0, -1, 0, 0, 0, 0, -1, 0}, 331.118910, 0.000020, 11.789000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, -2, 0}, 333.305510, 0.000010, 0.016000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, -1, 0}, 333.305510, 0.000080, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 333.305510, 0.000160, 0.028000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 333.305510, 0.000080, 0.044000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -3, 0}, 333.305510, 0.000080, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -2, 0}, 333.305510, 0.000790, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, -2}, 153.305510, 0.000030, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 333.305510, 0.006470, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 0, -2}, 153.305510, 0.000040, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 333.580300, 0.006230, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 153.305510, 0.000020, 0.067000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -1, -2, 0}, 153.305510, 0.000020, 0.039000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 153.305510, 0.000170, 0.081000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -5, 0}, 333.305510, 0.000010, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -4, 0}, 333.305510, 0.000150, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -3, -2}, 153.305510, 0.000020, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 333.070070, 0.002110, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, -2}, 153.305510, 0.000180, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 333.106280, 0.030910, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, 2}, 153.305510, 0.000050, 0.074000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, -2}, 153.210250, 0.001110, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 333.305510, 0.563410, 1911.695000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 2}, 153.210250, 0.001110, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 153.305510, 0.000050, 0.074000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 333.034080, 0.031110, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, 2}, 153.305510, 0.000180, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 333.070070, 0.002110, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 1, 2}, 153.305510, 0.000020, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 333.305510, 0.000150, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 3, 0}, 333.305510, 0.000010, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 153.305510, 0.000170, 0.081000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 153.305510, 0.000020, 0.039000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -4, 0}, 153.305510, 0.000020, 0.067000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 333.504600, 0.006270, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -2, 2}, 153.305510, 0.000040, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 333.305510, 0.006470, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, 2}, 153.305510, 0.000030, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 333.305510, 0.000790, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 333.305510, 0.000080, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -3, 0}, 333.305510, 0.000080, 0.044000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -2, 0}, 333.305510, 0.000160, 0.028000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 333.305510, 0.000080, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 333.305510, 0.000010, 0.016000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -4, -1, 0}, 230.368580, 0.000010, 0.021000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -4, 0, 0}, 230.368580, 0.000020, 0.028000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 230.368580, 0.000060, 0.027000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 230.368580, 0.000450, 0.042000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 230.368580, 0.000280, 0.095000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, -3, 0}, 230.368580, 0.000030, 0.039000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 230.368580, 0.000200, 0.082000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 50.368580, 0.000150, 0.070000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 50.368580, 0.000020, 0.036000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 230.368580, 0.000020, 0.075000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 50.368580, 0.000040, 0.080000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 50.368580, 0.000070, 0.039000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 50.368580, 0.000010, 0.026000},
	{{0, 10, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 127.431650, 0.000020, 0.044000},
	{{0, 10, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 127.431650, 0.000010, 0.105000},
	{{0, 10, 0, -9, 0, 0, 0, 0, -2, 1, 0}, 106.829240, 0.000010, 85.736000},
	{{0, 10, 8, -24, 0, 0, 0, 0, -2, 1, 0}, 220.314900, 0.000010, 76.498000},
	{{0, 11, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 289.610860, 0.000020, 0.037000},
	{{0, 11, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 289.624850, 0.000030, 0.074000},
	{{0, 11, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 289.612280, 0.000010, 2.897000},
	{{0, 11, -20, 0, 0, 0, 0, 0, -2, 3, 0}, 289.628510, 0.000020, 0.077000},
	{{0, 11, -20, 0, 4, 0, 0, 0, -2, 2, 0}, 131.520750, 0.000030, 124.848000},
	{{0, 11, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 30.147350, 0.000030, 0.079000},
	{{0, 11, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 88.227000, 0.000010, 0.075000},
	{{0, 11, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 308.471350, 0.000020, 8.386000},
	{{0, 11, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 88.227000, 0.000010, 0.076000},
	{{0, 11, -18, 0, 1, 0, 0, 0, 0, -1, 0}, 222.582940, 0.000020, 0.075000},
	{{0, 11, -18, 0, 1, 0, 0, 0, 0, 0, 0}, 312.535660, 0.000010, 28.621000},
	{{0, 11, -18, 0, 1, 0, 0, 0, 0, 1, 0}, 222.582940, 0.000020, 0.076000},
	{{0, 11, -18, 0, 2, 0, 0, 0, 0, -1, 0}, 323.123400, 0.000020, 0.076000},
	{{0, 11, -18, 0, 2, 0, 0, 0, 0, 1, 0}, 323.123400, 0.000020, 0.075000},
	{{0, 11, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 225.195760, 0.000010, 0.027000},
	{{0, 11, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 225.195760, 0.000010, 0.094000},
	{{0, 11, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 247.017440, 0.000020, 1.135000},
	{{0, 11, -17, 0, 0, 0, 0, 0, 1, -1, 0}, 322.601460, 0.000030, 159.914000},
	{{0, 11, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 45.195760, 0.000030, 0.081000},
	{{0, 11, -17, 0, 1, 0, 0, 0, -2, 0, 0}, 141.847150, 0.000030, 0.042000},
	{{0, 11, -17, 0, 2, 0, 0, 0, -2, 0, 0}, 51.549600, 0.000050, 0.042000},
	{{0, 11, -17, 0, 2, 0, 0, 0, -2, 2, 0}, 51.550620, 0.000040, 0.354000},
	{{0, 11, -17, 2, 0, 0, 0, 0, -2, 0, 0}, 51.758570, 0.000020, 0.044000},
	{{0, 11, -17, 2, 0, 0, 0, 0, -2, 2, 0}, 51.758570, 0.000020, 0.269000},
	{{0, 11, -16, 0, -1, 0, 0, 0, 2, -2, 0}, 331.860560, 0.000010, 44.577000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 324.064010, 0.000020, 0.028000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 315.785580, 0.000020, 0.044000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 231.027220, 0.000030, 0.104000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 302.118120, 0.000030, 0.274000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 3, 0}, 110.302960, 0.000020, 0.059000},
	{{0, 11, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 122.283900, 0.000020, 0.532000},
	{{0, 11, -16, 0, 0, 0, 0, 0, 2, -2, 0}, 237.864560, 0.000010, 9.369000},
	{{0, 11, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 235.887740, 0.000030, 0.075000},
	{{0, 11, -16, 0, 1, 0, 0, 0, -2, 1, 0}, 50.373700, 0.000010, 0.105000},
	{{0, 11, -16, 0, 1, 0, 0, 0, -2, 2, 0}, 229.945970, 0.000020, 0.267000},
	{{0, 11, -16, 0, 1, 0, 0, 0, -2, 3, 0}, 230.373700, 0.000010, 0.059000},
	{{0, 11, -16, 0, 2, 0, 0, 0, -2, 0, 0}, 111.861040, 0.000010, 0.044000},
	{{0, 11, -16, 0, 2, 0, 0, 0, -2, 2, 0}, 291.861040, 0.000010, 0.262000},
	{{0, 11, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 241.611750, 0.000030, 0.046000},
	{{0, 11, -15, 0, -1, 0, 0, 0, -2, 2, 0}, 61.611750, 0.000030, 0.219000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 62.769520, 0.000030, 0.046000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 56.416500, 0.000010, 0.116000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 28.595710, 0.000020, 0.215000},
	{{0, 11, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 165.586760, 0.000040, 0.347000},
	{{0, 11, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 158.445450, 0.000010, 0.036000},
	{{0, 11, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 55.451740, 0.000030, 0.048000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 114.139190, 0.000020, 0.048000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 255.720150, 0.000020, 0.107000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 67.069930, 0.000110, 0.258000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 250.929580, 0.000020, 0.354000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 75.398290, 0.000080, 0.065000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 256.701410, 0.000060, 0.035000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 4, -2, -2}, 259.258200, 0.000480, 1260.592000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 4, -1, -2}, 100.466200, 0.000020, 0.075000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 356.981370, 0.000030, 0.050000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 339.540950, 0.000030, 0.150000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -1, 0, 1}, 32.102460, 0.000020, 0.169000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 23.663910, 0.000010, 0.046000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 342.287730, 0.000030, 0.119000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 347.655570, 0.000330, 0.205000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 348.374080, 0.000030, 0.055000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 168.692630, 0.000070, 0.261000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 1, 0, 1}, 348.685130, 0.000020, 0.033000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 356.766900, 0.000020, 0.322000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 353.370560, 0.000260, 0.061000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 175.572830, 0.000180, 0.034000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 173.019050, 0.000020, 0.023000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 4, -1, 0}, 173.373000, 0.000010, 0.024000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 4, 0, 0}, 173.446220, 0.000020, 0.018000},
	{{0, 11, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 270.619440, 0.000010, 0.051000},
	{{0, 11, -13, 0, 1, 0, 0, 0, -2, 2, 0}, 90.619440, 0.000010, 0.148000},
	{{0, 11, -13, 2, 0, 0, 0, 0, -2, 0, 0}, 179.168140, 0.000010, 0.053000},
	{{0, 11, -13, 2, 0, 0, 0, 0, -2, 2, 0}, 179.168140, 0.000010, 0.130000},
	{{0, 11, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 124.508230, 0.000020, 0.053000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -4, 2, 0}, 272.804140, 0.000010, 0.059000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 273.974310, 0.000040, 0.053000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 98.825120, 0.000030, 0.179000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 93.499700, 0.000030, 0.131000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 75.268090, 0.000030, 0.050000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, 1}, 255.248210, 0.000040, 0.144000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 1, -1}, 94.340130, 0.000020, 0.150000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 88.291310, 0.000010, 0.048000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 282.105920, 0.000070, 0.136000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 272.033390, 0.000940, 0.170000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 275.630890, 0.000220, 0.052000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 277.274650, 0.000010, 0.031000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, -1, -1}, 75.296090, 0.000030, 0.119000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, -1, 1}, 75.298610, 0.000010, 0.054000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 75.296740, 0.000250, 0.207000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 83.890940, 0.000020, 0.055000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 75.300870, 0.000010, 0.032000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 1, -1}, 75.296950, 0.000010, 0.055000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 146.320010, 0.000020, 0.244000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 272.699400, 0.000870, 0.058000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, -2}, 272.314030, 0.000030, 0.265000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 94.307130, 0.000830, 0.033000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 92.708420, 0.000130, 0.023000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 3, 0, 0}, 92.429170, 0.000020, 0.023000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 4, -2, 0}, 280.249710, 0.000030, 0.035000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 4, 0, 0}, 92.711220, 0.000020, 0.018000},
	{{0, 11, -12, 0, 1, 0, 0, 0, -2, 0, 0}, 220.613140, 0.000030, 0.053000},
	{{0, 11, -12, 0, 1, 0, 0, 0, 2, 0, 0}, 358.674810, 0.000030, 0.033000},
	{{0, 11, -12, 0, 2, 0, 0, 0, -2, 0, 0}, 232.625640, 0.000010, 0.054000},
	{{0, 11, -12, 0, 2, 0, 0, 0, -2, 2, 0}, 52.625640, 0.000010, 0.128000},
	{{0, 11, -12, 2, 0, 0, 0, 0, 0, 0, 0}, 39.909720, 0.000010, 0.144000},
	{{0, 11, -12, 3, 0, 0, 0, 0, -2, 0, 0}, 236.340120, 0.000010, 0.058000},
	{{0, 11, -12, 3, 0, 0, 0, 0, -2, 2, 0}, 236.340120, 0.000010, 0.108000},
	{{0, 11, -11, 0, -1, 0, 0, 0, -2, 0, 0}, 180.050040, 0.000060, 0.056000},
	{{0, 11, -11, 0, -1, 0, 0, 0, -2, 1, 0}, 7.707330, 0.000020, 0.213000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -4, 1, 0}, 180.021570, 0.000010, 0.034000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -4, 2, 0}, 178.552090, 0.000020, 0.062000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, -1, 0}, 180.283760, 0.000030, 0.032000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 179.879900, 0.000370, 0.056000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 180.079980, 0.000270, 0.217000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 358.347030, 0.000080, 0.116000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 11.103140, 0.000020, 0.046000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 0.377400, 0.000080, 0.182000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 179.975630, 0.000370, 0.157000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 0, -2}, 179.932120, 0.000010, 0.050000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 179.929180, 0.003740, 0.145000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 179.977670, 0.000610, 0.050000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 2, -2}, 359.932120, 0.000010, 0.153000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 179.970650, 0.000070, 0.030000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, -2, 1}, 11.543990, 0.000020, 0.162000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, -1, 0}, 2.167050, 0.000010, 0.167000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 191.544270, 0.000070, 0.172000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 358.505880, 0.000020, 0.052000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, 2, 0}, 0.024780, 0.000010, 0.022000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -5, 0}, 179.973360, 0.000010, 0.029000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 181.164620, 0.000020, 0.123000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 181.064550, 0.000110, 0.196000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 179.974700, 0.002420, 0.054000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, -2}, 179.976030, 0.000050, 0.210000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 0.102240, 0.002680, 0.032000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, 2}, 180.005380, 0.000010, 0.017000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 0.015680, 0.000250, 0.022000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 2, 0}, 359.989320, 0.000050, 0.017000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 3, -1, 0}, 180.022460, 0.000010, 0.033000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 3, 0, 0}, 0.024790, 0.000040, 0.023000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 3, 2, 0}, 180.024750, 0.000010, 0.014000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 4, -2, 0}, 179.389820, 0.000040, 0.034000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 4, -1, 0}, 0.095620, 0.000030, 0.023000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 4, 0, 0}, 0.025420, 0.000050, 0.018000},
	{{0, 11, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 349.118750, 0.000040, 0.056000},
	{{0, 11, -11, 0, 1, 0, 0, 0, -2, 1, 0}, 172.631970, 0.000020, 0.221000},
	{{0, 11, -11, 0, 1, 0, 0, 0, -2, 2, 0}, 346.633120, 0.000020, 0.114000},
	{{0, 11, -10, -3, 0, 0, 0, 0, -2, 0, 0}, 303.059650, 0.000010, 0.054000},
	{{0, 11, -10, -3, 0, 0, 0, 0, -2, 2, 0}, 303.059650, 0.000010, 0.124000},
	{{0, 11, -10, -3, 0, 0, 0, 0, 0, 0, 0}, 303.912250, 0.000010, 0.159000},
	{{0, 11, -10, 0, -2, 0, 0, 0, -2, 1, 0}, 119.063010, 0.000020, 0.265000},
	{{0, 11, -10, 0, -1, 0, 0, 0, -2, 0, 0}, 178.494640, 0.000010, 0.059000},
	{{0, 11, -10, 0, -1, 0, 0, 0, -2, 2, 0}, 178.494640, 0.000010, 0.104000},
	{{0, 11, -10, 0, -1, 0, 0, 0, 0, 0, 0}, 181.394730, 0.000060, 0.128000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 255.321610, 0.000030, 0.059000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 241.297760, 0.000010, 0.104000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, -1, 1}, 283.841860, 0.000010, 0.231000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 103.157730, 0.000060, 0.056000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, 1}, 283.197830, 0.000100, 0.112000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 1, -1}, 103.206780, 0.000060, 0.215000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 239.216730, 0.000020, 0.186000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 282.101960, 0.000030, 0.127000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, -1, -1}, 103.597590, 0.000050, 0.156000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, -1, 1}, 103.264880, 0.000020, 0.049000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 103.273510, 0.000280, 0.146000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 103.295180, 0.000020, 0.030000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 1, -1}, 103.267360, 0.000010, 0.050000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 268.740230, 0.000150, 0.052000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 92.723750, 0.000190, 0.031000},
	{{0, 11, -9, -3, 0, 0, 0, 0, -2, 0, 0}, 336.185940, 0.000010, 0.057000},
	{{0, 11, -9, -3, 0, 0, 0, 0, -2, 2, 0}, 336.185940, 0.000010, 0.110000},
	{{0, 11, -9, -2, 0, 0, 0, 0, -2, 0, 0}, 359.986070, 0.000040, 0.059000},
	{{0, 11, -9, -2, 0, 0, 0, 0, -2, 2, 0}, 0.475670, 0.000010, 0.104000},
	{{0, 11, -9, 0, -3, 0, 0, 0, -2, 0, 0}, 7.278710, 0.000010, 0.062000},
	{{0, 11, -9, 0, -3, 0, 0, 0, -2, 2, 0}, 7.278710, 0.000010, 0.096000},
	{{0, 11, -9, 0, -2, 0, 0, 0, -2, 0, 0}, 0.261060, 0.000020, 0.062000},
	{{0, 11, -9, 0, -2, 0, 0, 0, -2, 2, 0}, 0.261060, 0.000020, 0.095000},
	{{0, 11, -9, 0, -2, 0, 0, 0, 0, -2, 0}, 180.188450, 0.000010, 0.056000},
	{{0, 11, -9, 0, -2, 0, 0, 0, 0, 0, 0}, 359.729840, 0.000030, 0.115000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 26.159160, 0.000020, 0.034000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 24.734980, 0.000180, 0.063000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 25.533610, 0.000140, 0.384000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 191.398940, 0.000010, 0.094000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 196.966300, 0.000020, 0.287000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 26.698840, 0.000080, 0.229000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 28.714090, 0.000300, 0.113000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 25.786850, 0.000040, 0.049000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 205.706320, 0.000050, 0.030000},
	{{0, 11, -8, 0, -3, 0, 0, 0, -2, 0, 0}, 356.631920, 0.000010, 0.066000},
	{{0, 11, -8, 0, -3, 0, 0, 0, -2, 2, 0}, 356.631920, 0.000010, 0.088000},
	{{0, 11, -8, 0, -2, 0, 0, 0, -4, 3, 0}, 260.634910, 0.000040, 225.944000},
	{{0, 11, -8, 0, -2, 0, 0, 0, -2, 1, 0}, 86.710230, 0.000020, 0.565000},
	{{0, 11, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 278.559080, 0.000020, 0.625000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 223.301520, 0.000020, 0.029000},
	{{0, 11, -8, 0, 1, 0, 0, 0, 2, 0, 0}, 127.570390, 0.000020, 0.029000},
	{{0, 11, -8, 3, 0, 0, 0, 0, -2, 0, 0}, 184.477400, 0.000010, 0.075000},
	{{0, 11, -8, 3, 0, 0, 0, 0, -2, 1, 0}, 15.089010, 0.000020, 168.641000},
	{{0, 11, -8, 3, 0, 0, 0, 0, -2, 2, 0}, 184.477400, 0.000010, 0.075000},
	{{0, 11, -7, 0, -1, 0, 0, 0, 2, -2, 0}, 141.247990, 0.000010, 0.111000},
	{{0, 11, -7, 0, -1, 0, 0, 0, 2, 0, 0}, 321.247990, 0.000010, 0.028000},
	{{0, 11, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 228.411760, 0.000020, 0.072000},
	{{0, 11, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 227.658130, 0.000080, 1.664000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 309.555620, 0.000010, 0.092000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 308.199930, 0.000030, 0.027000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 128.621740, 0.000030, 0.241000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 128.621740, 0.000030, 0.045000},
	{{0, 11, -7, 0, 1, 0, 0, 0, 2, 0, 0}, 119.457310, 0.000020, 0.028000},
	{{0, 11, -6, 0, -5, 0, 0, 0, -2, 1, 0}, 260.353730, 0.000050, 44.436000},
	{{0, 11, -6, 0, -4, 0, 0, 0, -2, 1, 0}, 223.694490, 0.000020, 16.182000},
	{{0, 11, -6, 0, -3, 0, 0, 0, -2, 1, 0}, 39.275880, 0.000010, 6.845000},
	{{0, 11, -6, 0, -2, 0, 0, 0, -2, 1, 0}, 97.733170, 0.000020, 4.340000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 121.908340, 0.000030, 0.078000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 128.886960, 0.000020, 2.506000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 121.899660, 0.000020, 0.073000},
	{{0, 11, -5, 0, -4, 0, 0, 0, -1, 1, -1}, 167.953660, 0.000050, 124.469000},
	{{0, 11, -5, 0, -2, 0, 0, 0, 0, -1, 0}, 308.352320, 0.000010, 1.840000},
	{{0, 11, -3, -3, 0, 0, 0, 0, 0, -1, 0}, 58.413660, 0.000030, 33.392000},
	{{0, 11, 6, -20, 0, 0, 0, 0, 0, -1, 0}, 321.986300, 0.000010, 115.147000},
	{{0, 12, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 289.605030, 0.000020, 0.038000},
	{{0, 12, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 109.620180, 0.000020, 0.077000},
	{{0, 12, -21, 0, 0, 0, 0, 0, -2, 3, 0}, 109.620180, 0.000020, 0.074000},
	{{0, 12, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 328.820950, 0.000010, 0.078000},
	{{0, 12, -19, 0, 0, 0, 0, 0, 0, 1, 0}, 328.820950, 0.000010, 0.073000},
	{{0, 12, -18, 0, 0, 0, 0, 0, -2, -1, 0}, 225.872720, 0.000010, 0.027000},
	{{0, 12, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 225.872720, 0.000010, 0.100000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 247.017420, 0.000020, 0.085000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 247.019060, 0.000020, 0.664000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 247.017420, 0.000020, 0.068000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 2, -3, 0}, 28.060880, 0.000020, 0.074000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 28.060880, 0.000020, 0.077000},
	{{0, 12, -18, 0, 1, 0, 0, 0, -2, 0, 0}, 141.879230, 0.000020, 0.043000},
	{{0, 12, -18, 0, 2, 0, 0, 0, -2, 0, 0}, 51.528930, 0.000070, 0.043000},
	{{0, 12, -18, 0, 3, 0, 0, 0, 2, -2, 0}, 221.536200, 0.000030, 67.451000},
	{{0, 12, -18, 0, 3, 0, 0, 0, 2, -1, 0}, 41.775080, 0.000030, 0.076000},
	{{0, 12, -18, 2, 0, 0, 0, 0, -2, 0, 0}, 51.737910, 0.000020, 0.045000},
	{{0, 12, -18, 2, 0, 0, 0, 0, -2, 2, 0}, 51.737910, 0.000020, 0.230000},
	{{0, 12, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 324.065650, 0.000020, 0.028000},
	{{0, 12, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 207.349520, 0.000010, 0.111000},
	{{0, 12, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 314.643570, 0.000020, 0.234000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 2, -3, 0}, 57.873340, 0.000030, 0.080000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 237.859730, 0.000010, 1.366000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 57.873340, 0.000030, 0.071000},
	{{0, 12, -17, 0, 1, 0, 0, 0, -2, 0, 0}, 229.927340, 0.000020, 0.045000},
	{{0, 12, -17, 0, 1, 0, 0, 0, -2, 2, 0}, 229.927340, 0.000020, 0.229000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -4, -1, 0}, 231.705780, 0.000020, 0.017000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -4, 1, 0}, 231.705780, 0.000020, 0.031000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, -2, 2}, 231.705780, 0.000010, 0.048000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 61.837200, 0.000040, 0.047000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 0, 2}, 231.705780, 0.000010, 0.178000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 40.184650, 0.000040, 0.189000},
	{{0, 12, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 165.608340, 0.000040, 0.285000},
	{{0, 12, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 159.368170, 0.000010, 0.035000},
	{{0, 12, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 55.415710, 0.000030, 0.049000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 110.015160, 0.000020, 0.049000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 173.961820, 0.000010, 0.143000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 3, 0}, 173.961820, 0.000010, 0.051000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 72.392970, 0.000080, 0.222000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 251.446170, 0.000020, 0.290000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 2, -3, 0}, 255.988470, 0.000020, 0.095000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 76.277630, 0.000030, 0.063000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 257.222770, 0.000060, 0.034000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -4, 0, 0}, 212.872980, 0.000020, 0.023000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 335.565890, 0.000020, 0.052000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 345.533770, 0.000020, 0.167000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 344.168860, 0.000010, 0.137000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 346.749690, 0.000250, 0.182000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 168.609200, 0.000050, 0.225000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 1, 0, 1}, 348.602900, 0.000010, 0.032000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 353.758220, 0.000010, 0.268000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 353.984140, 0.000200, 0.059000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 176.292420, 0.000160, 0.033000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 173.571650, 0.000010, 0.023000},
	{{0, 12, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 270.664810, 0.000010, 0.052000},
	{{0, 12, -14, 0, 1, 0, 0, 0, -2, 2, 0}, 90.664810, 0.000010, 0.136000},
	{{0, 12, -14, 0, 2, 0, 0, 0, 2, -2, 0}, 179.778640, 0.000010, 0.256000},
	{{0, 12, -14, 0, 2, 0, 0, 0, 2, 0, 0}, 179.778640, 0.000010, 0.033000},
	{{0, 12, -14, 2, 0, 0, 0, 0, -2, 0, 0}, 179.153650, 0.000010, 0.055000},
	{{0, 12, -14, 2, 0, 0, 0, 0, -2, 2, 0}, 179.153650, 0.000010, 0.120000},
	{{0, 12, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 104.777360, 0.000020, 0.055000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -4, 2, 0}, 272.251670, 0.000010, 0.061000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 273.042760, 0.000030, 0.055000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 92.078910, 0.000020, 0.121000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 74.976250, 0.000030, 0.052000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 1, -1}, 74.978400, 0.000010, 0.166000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, -3, 0}, 91.902200, 0.000010, 0.030000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 89.692160, 0.000020, 0.050000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 280.432810, 0.000070, 0.148000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 271.973360, 0.000770, 0.154000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 276.074290, 0.000160, 0.051000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, -1, -1}, 75.007850, 0.000010, 0.128000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 75.009120, 0.000190, 0.183000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 92.623930, 0.000010, 0.053000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, 1}, 75.012910, 0.000010, 0.031000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 279.142100, 0.000010, 0.211000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 273.024240, 0.000610, 0.056000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, -2}, 272.315730, 0.000020, 0.227000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 93.488330, 0.000630, 0.032000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 92.505190, 0.000110, 0.022000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 3, 0, 0}, 92.425130, 0.000020, 0.023000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 4, -2, 0}, 271.715770, 0.000020, 0.034000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 4, 0, 0}, 92.431050, 0.000020, 0.018000},
	{{0, 12, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 218.855210, 0.000040, 0.055000},
	{{0, 12, -13, 0, 2, 0, 0, 0, -2, 0, 0}, 232.611150, 0.000010, 0.055000},
	{{0, 12, -13, 0, 2, 0, 0, 0, -2, 2, 0}, 52.611150, 0.000010, 0.118000},
	{{0, 12, -13, 2, 0, 0, 0, 0, 0, 0, 0}, 39.893160, 0.000010, 0.132000},
	{{0, 12, -13, 3, 0, 0, 0, 0, -2, 0, 0}, 236.319460, 0.000010, 0.060000},
	{{0, 12, -13, 3, 0, 0, 0, 0, -2, 2, 0}, 236.319460, 0.000010, 0.101000},
	{{0, 12, -12, 0, -2, 0, 0, 0, -2, 0, 0}, 207.229770, 0.000010, 0.057000},
	{{0, 12, -12, 0, -2, 0, 0, 0, -2, 2, 0}, 207.229770, 0.000010, 0.110000},
	{{0, 12, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 183.417480, 0.000040, 0.058000},
	{{0, 12, -12, 0, -1, 0, 0, 0, -2, 1, 0}, 7.941290, 0.000020, 0.246000},
	{{0, 12, -12, 0, -1, 0, 0, 0, -2, 2, 0}, 162.932440, 0.000010, 0.109000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -4, 2, 0}, 178.577910, 0.000020, 0.065000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, -2, 0}, 359.938250, 0.000040, 0.023000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 180.193050, 0.000040, 0.033000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 180.302210, 0.000340, 0.058000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 180.487610, 0.000210, 0.252000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 358.205710, 0.000080, 0.108000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 176.450900, 0.000020, 0.044000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 359.936730, 0.000050, 0.206000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 179.920500, 0.000340, 0.174000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 179.883230, 0.002700, 0.133000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 180.013140, 0.000480, 0.048000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 179.992980, 0.000030, 0.029000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 191.687670, 0.000050, 0.155000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 11.687610, 0.000020, 0.030000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 1, 2, 0}, 0.009210, 0.000010, 0.022000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -3, 0}, 180.034380, 0.000020, 0.133000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 179.902220, 0.000090, 0.174000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 179.953510, 0.001620, 0.053000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, -2}, 179.956050, 0.000050, 0.185000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 359.962990, 0.002070, 0.031000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, 2}, 359.949230, 0.000010, 0.017000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 359.958280, 0.000200, 0.022000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 2, 0}, 359.959060, 0.000030, 0.017000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 3, -1, 0}, 180.006880, 0.000010, 0.032000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 3, 0, 0}, 0.009210, 0.000040, 0.022000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 4, -2, 0}, 180.127130, 0.000020, 0.033000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 4, -1, 0}, 359.951890, 0.000030, 0.023000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 4, 0, 0}, 359.959140, 0.000040, 0.018000},
	{{0, 12, -12, 0, 1, 0, 0, 0, -2, 0, 0}, 347.647260, 0.000030, 0.058000},
	{{0, 12, -12, 0, 1, 0, 0, 0, -2, 2, 0}, 347.647260, 0.000030, 0.107000},
	{{0, 12, -11, -3, 0, 0, 0, 0, -2, 0, 0}, 303.043090, 0.000010, 0.056000},
	{{0, 12, -11, -3, 0, 0, 0, 0, -2, 2, 0}, 303.043090, 0.000010, 0.115000},
	{{0, 12, -11, 0, -2, 0, 0, 0, 0, 0, 0}, 114.916040, 0.000020, 0.120000},
	{{0, 12, -11, 0, -1, 0, 0, 0, -2, 0, 0}, 178.457860, 0.000010, 0.061000},
	{{0, 12, -11, 0, -1, 0, 0, 0, -2, 2, 0}, 178.457860, 0.000010, 0.098000},
	{{0, 12, -11, 0, -1, 0, 0, 0, 0, -2, 0}, 1.205470, 0.000020, 0.055000},
	{{0, 12, -11, 0, -1, 0, 0, 0, 0, 0, 0}, 181.256650, 0.000070, 0.119000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 267.454920, 0.000040, 0.062000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 84.548960, 0.000010, 0.336000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, -1, 1}, 283.822470, 0.000010, 0.271000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 103.131340, 0.000060, 0.058000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 0, 1}, 284.049130, 0.000070, 0.105000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 1, -1}, 103.184550, 0.000050, 0.248000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 346.208250, 0.000020, 0.118000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 114.142130, 0.000010, 0.046000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 81.905410, 0.000020, 0.029000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, -1, -1}, 103.230760, 0.000040, 0.172000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, -1, 1}, 103.245960, 0.000010, 0.048000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 103.214140, 0.000260, 0.134000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 103.245430, 0.000020, 0.029000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 270.300590, 0.000100, 0.050000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 91.714300, 0.000170, 0.030000},
	{{0, 12, -10, -3, 0, 0, 0, 0, -2, 0, 0}, 336.173520, 0.000010, 0.059000},
	{{0, 12, -10, -3, 0, 0, 0, 0, -2, 2, 0}, 336.173520, 0.000010, 0.103000},
	{{0, 12, -10, -2, 0, 0, 0, 0, -2, 0, 0}, 0.452960, 0.000020, 0.061000},
	{{0, 12, -10, -2, 0, 0, 0, 0, -2, 2, 0}, 0.452960, 0.000020, 0.098000},
	{{0, 12, -10, 0, -3, 0, 0, 0, -2, 0, 0}, 7.183170, 0.000010, 0.065000},
	{{0, 12, -10, 0, -3, 0, 0, 0, -2, 2, 0}, 7.183170, 0.000010, 0.091000},
	{{0, 12, -10, 0, -2, 0, 0, 0, -2, 0, 0}, 0.247260, 0.000030, 0.065000},
	{{0, 12, -10, 0, -2, 0, 0, 0, -2, 1, 0}, 0.247090, 0.000010, 0.466000},
	{{0, 12, -10, 0, -2, 0, 0, 0, -2, 2, 0}, 0.247610, 0.000010, 0.090000},
	{{0, 12, -10, 0, -2, 0, 0, 0, 0, -2, 0}, 180.171870, 0.000010, 0.058000},
	{{0, 12, -10, 0, -2, 0, 0, 0, 0, 0, 0}, 359.707790, 0.000030, 0.107000},
	{{0, 12, -10, 0, 0, 0, 0, 0, -2, -1, 0}, 26.201800, 0.000020, 0.035000},
	{{0, 12, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 25.536520, 0.000190, 0.066000},
	{{0, 12, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 25.988890, 0.000170, 0.506000},
	{{0, 12, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 199.192850, 0.000020, 0.349000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 26.623750, 0.000080, 0.267000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 32.698160, 0.000260, 0.105000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 198.771080, 0.000010, 0.044000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 25.768070, 0.000030, 0.048000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 214.199350, 0.000050, 0.029000},
	{{0, 12, -9, -4, 0, 0, 0, 0, -2, 1, 0}, 150.324560, 0.000010, 0.322000},
	{{0, 12, -9, 0, -3, 0, 0, 0, -3, 0, 2}, 355.640990, 0.000030, 127.390000},
	{{0, 12, -9, 0, -2, 0, 0, 0, -2, 0, 0}, 86.024250, 0.000020, 0.069000},
	{{0, 12, -9, 0, -2, 0, 0, 0, -2, 1, 0}, 252.444170, 0.000010, 0.874000},
	{{0, 12, -9, 0, -2, 0, 0, 0, -2, 2, 0}, 266.024250, 0.000020, 0.083000},
	{{0, 12, -9, 0, -1, 0, 0, 0, -3, 1, 1}, 193.652820, 0.000040, 166.720000},
	{{0, 12, -9, 0, 0, -2, 0, 0, -3, 1, 1}, 104.885150, 0.000020, 96.065000},
	{{0, 12, -9, 0, 0, 0, 0, 0, -3, 1, 1}, 130.951170, 0.000060, 12.771000},
	{{0, 12, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 273.674220, 0.000030, 1.025000},
	{{0, 12, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 310.633010, 0.000020, 0.081000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 331.445320, 0.000020, 0.095000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 331.445320, 0.000030, 0.042000},
	{{0, 12, -9, 0, 1, 0, 0, 0, -3, 2, 0}, 304.538330, 0.000020, 241.182000},
	{{0, 12, -8, 0, -3, 0, 0, 0, -2, 1, 0}, 235.411850, 0.000070, 4.379000},
	{{0, 12, -8, 0, -2, 0, 0, 0, -2, 0, 0}, 203.318110, 0.000010, 0.075000},
	{{0, 12, -8, 0, -2, 0, 0, 0, -2, 1, 0}, 157.247340, 0.000070, 6.941000},
	{{0, 12, -8, 0, -2, 0, 0, 0, -2, 2, 0}, 203.318110, 0.000010, 0.076000},
	{{0, 12, -8, 0, -1, 0, 0, 0, -2, 1, 0}, 283.550980, 0.000040, 16.733000},
	{{0, 12, -8, 0, 0, -3, 0, 0, -2, 1, 0}, 269.583590, 0.000010, 12.936000},
	{{0, 12, -8, 0, 0, -2, 0, 0, -2, 1, 0}, 190.060570, 0.000050, 23.065000},
	{{0, 12, -8, 0, 0, -1, 0, 0, -2, 1, 0}, 196.795640, 0.000050, 106.299000},
	{{0, 12, -8, 0, 0, 0, -3, 0, -2, 1, 0}, 18.391900, 0.000010, 89.563000},
	{{0, 12, -8, 0, 0, 0, -2, 0, -2, 0, 0}, 272.382580, 0.000030, 0.075000},
	{{0, 12, -8, 0, 0, 0, -2, 0, -2, 1, 0}, 272.382580, 0.000480, 1357.743000},
	{{0, 12, -8, 0, 0, 0, -2, 0, -2, 2, 0}, 272.382580, 0.000030, 0.075000},
	{{0, 12, -8, 0, 0, 0, -1, 0, -2, 1, 0}, 291.496740, 0.000040, 79.124000},
	{{0, 12, -8, 0, 0, 0, 0, -2, -2, 1, 0}, 205.164890, 0.000030, 80.631000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 228.508390, 0.000050, 0.026000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 1, 0}, 228.486900, 0.000390, 0.040000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 228.388650, 0.000370, 0.087000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -3, 1, 0}, 48.508390, 0.000010, 0.081000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 228.154880, 0.000080, 0.038000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 0, -2}, 48.508390, 0.000010, 0.025000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 228.154650, 0.001190, 0.076000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, -2}, 48.508390, 0.000070, 0.037000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 228.508390, 0.034890, 40.749000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, 2}, 48.508390, 0.000070, 0.037000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 228.619170, 0.001990, 0.075000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 2, 2}, 48.508390, 0.000010, 0.025000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 228.619080, 0.000140, 0.038000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -1, 1, 0}, 48.508390, 0.000010, 0.081000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 128.305830, 0.000010, 0.067000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 227.345130, 0.000530, 0.087000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 228.528780, 0.000410, 0.040000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 228.508390, 0.000050, 0.026000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 128.191320, 0.000030, 0.284000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 128.191320, 0.000030, 0.044000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 264.185910, 0.000010, 0.028000},
	{{0, 12, -8, 0, 0, 1, 0, 0, -2, 1, 0}, 204.161740, 0.000020, 17.098000},
	{{0, 12, -8, 0, 1, 0, 0, 0, -2, 1, 0}, 56.735500, 0.000030, 9.188000},
	{{0, 12, -7, -2, 0, 0, 0, 0, -2, 0, 0}, 288.130490, 0.000030, 0.075000},
	{{0, 12, -7, -2, 0, 0, 0, 0, -2, 1, 0}, 267.431570, 0.000050, 25.755000},
	{{0, 12, -7, -2, 0, 0, 0, 0, -2, 2, 0}, 288.130490, 0.000030, 0.076000},
	{{0, 12, -7, 0, -2, 0, 0, 0, -1, 0, 0}, 84.525630, 0.000020, 32.179000},
	{{0, 12, -7, 0, -1, 0, 0, 0, 2, -2, 0}, 129.185020, 0.000020, 0.094000},
	{{0, 12, -7, 0, -1, 0, 0, 0, 2, 0, 0}, 309.185020, 0.000020, 0.027000},
	{{0, 12, -7, 0, 0, -4, 0, 0, -1, 0, 0}, 116.181140, 0.000020, 574.972000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -4, 1, 0}, 125.571460, 0.000030, 0.042000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -4, 2, 0}, 125.571460, 0.000020, 0.096000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 125.571460, 0.000010, 0.082000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 149.227960, 0.000040, 0.075000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 316.292660, 0.000030, 7.271000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 149.227960, 0.000820, 34.218000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 2, -1}, 149.227960, 0.000040, 0.076000},
	{{0, 12, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 144.725050, 0.000010, 0.071000},
	{{0, 12, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 223.975280, 0.000010, 1.334000},
	{{0, 12, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 324.725050, 0.000010, 0.080000},
	{{0, 12, -6, -4, 0, 0, 0, 0, -2, 1, 0}, 250.621070, 0.000010, 9.785000},
	{{0, 12, -6, -2, 0, 0, 0, 0, -1, 0, 0}, 308.069290, 0.000010, 13.484000},
	{{0, 12, -6, 0, -3, 0, 0, 0, 0, -2, 0}, 34.906520, 0.000020, 0.075000},
	{{0, 12, -6, 0, -3, 0, 0, 0, 0, -1, 0}, 212.064460, 0.000060, 418.437000},
	{{0, 12, -6, 0, -3, 0, 0, 0, 0, 0, 0}, 167.320330, 0.000030, 0.075000},
	{{0, 12, -6, 0, -2, 0, 0, 0, 0, -1, 0}, 45.389390, 0.000020, 12.208000},
	{{0, 12, -6, 0, 1, 0, 0, 0, 0, 0, -2}, 278.686710, 0.000010, 0.075000},
	{{0, 12, -6, 0, 1, 0, 0, 0, 0, 1, -2}, 278.686710, 0.000270, 761.128000},
	{{0, 12, -6, 0, 1, 0, 0, 0, 0, 2, -2}, 278.686710, 0.000010, 0.075000},
	{{0, 12, -3, -6, 0, 0, 0, 0, 0, -1, 0}, 282.810660, 0.000010, 16.552000},
	{{0, 12, -2, -8, 0, 0, 0, 0, 0, -1, 0}, 227.445030, 0.000080, 338.916000},
	{{0, 12, 1, -17, 0, 0, 0, 0, -2, 1, 0}, 23.947730, 0.000020, 70.966000},
	{{0, 13, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 24.224040, 0.000040, 0.075000},
	{{0, 13, -23, 0, 0, 0, 0, 0, -2, 3, 0}, 14.556870, 0.000020, 0.076000},
	{{0, 13, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 289.590710, 0.000020, 0.039000},
	{{0, 13, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 289.610150, 0.000040, 0.081000},
	{{0, 13, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 289.601210, 0.000010, 1.104000},
	{{0, 13, -22, 0, 0, 0, 0, 0, -2, 3, 0}, 289.610150, 0.000040, 0.071000},
	{{0, 13, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 309.847360, 0.000010, 0.097000},
	{{0, 13, -20, 0, 0, 0, 0, 0, -2, 3, 0}, 309.847360, 0.000010, 0.062000},
	{{0, 13, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 309.847360, 0.000020, 0.082000},
	{{0, 13, -20, 0, 0, 0, 0, 0, 0, 1, 0}, 309.847360, 0.000020, 0.070000},
	{{0, 13, -19, 0, 0, 0, 0, 0, -2, -1, 0}, 226.476890, 0.000010, 0.028000},
	{{0, 13, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 226.476890, 0.000010, 0.107000},
	{{0, 13, -19, 0, 0, 0, 0, 0, 2, -3, 0}, 329.091230, 0.000010, 0.078000},
	{{0, 13, -19, 0, 0, 0, 0, 0, 2, -1, 0}, 277.236420, 0.000030, 0.073000},
	{{0, 13, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 141.907300, 0.000010, 0.044000},
	{{0, 13, -19, 0, 1, 0, 0, 0, -2, 2, 0}, 321.907300, 0.000010, 0.251000},
	{{0, 13, -19, 0, 2, 0, 0, 0, -2, 0, 0}, 51.505560, 0.000040, 0.045000},
	{{0, 13, -19, 0, 2, 0, 0, 0, -2, 2, 0}, 231.506290, 0.000030, 0.245000},
	{{0, 13, -19, 2, 0, 0, 0, 0, -2, 0, 0}, 51.715250, 0.000010, 0.046000},
	{{0, 13, -19, 2, 0, 0, 0, 0, -2, 2, 0}, 51.715250, 0.000010, 0.201000},
	{{0, 13, -18, 0, 0, 0, 0, 0, -2, -1, 0}, 324.065360, 0.000020, 0.029000},
	{{0, 13, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 170.659980, 0.000020, 0.046000},
	{{0, 13, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 291.182510, 0.000010, 0.120000},
	{{0, 13, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 144.065360, 0.000030, 0.099000},
	{{0, 13, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 124.907560, 0.000020, 0.068000},
	{{0, 13, -18, 0, 1, 0, 0, 0, -2, 0, 0}, 230.307010, 0.000050, 0.046000},
	{{0, 13, -18, 0, 1, 0, 0, 0, -2, 2, 0}, 230.297450, 0.000040, 0.200000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -4, -1, 0}, 231.684010, 0.000010, 0.017000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -4, 3, 0}, 51.684010, 0.000020, 0.179000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 64.556920, 0.000040, 0.049000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 0, 2}, 231.684010, 0.000030, 0.160000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 55.760710, 0.000010, 0.136000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 41.863080, 0.000040, 0.169000},
	{{0, 13, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 158.577980, 0.000010, 0.242000},
	{{0, 13, -16, 0, -1, 0, 0, 0, -2, 0, 0}, 55.379320, 0.000030, 0.051000},
	{{0, 13, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 108.110790, 0.000020, 0.051000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 74.239460, 0.000060, 0.195000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 251.906060, 0.000010, 0.245000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 257.897500, 0.000050, 0.033000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 352.509180, 0.000050, 0.054000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 346.226720, 0.000020, 0.187000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 333.158160, 0.000030, 0.126000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 347.611430, 0.000170, 0.163000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 168.517230, 0.000040, 0.197000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 1, 0, 1}, 348.511930, 0.000010, 0.031000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 354.605150, 0.000140, 0.057000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 174.416770, 0.000160, 0.032000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 174.465610, 0.000020, 0.023000},
	{{0, 13, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 270.705570, 0.000010, 0.054000},
	{{0, 13, -15, 0, 1, 0, 0, 0, -2, 2, 0}, 90.705570, 0.000010, 0.125000},
	{{0, 13, -15, 0, 2, 0, 0, 0, 2, 0, 0}, 179.755970, 0.000020, 0.032000},
	{{0, 13, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 104.794360, 0.000020, 0.057000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -4, 2, 0}, 272.338580, 0.000010, 0.063000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 273.469200, 0.000030, 0.057000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 92.023820, 0.000020, 0.112000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 74.651790, 0.000020, 0.054000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 281.161370, 0.000060, 0.163000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 272.076990, 0.000610, 0.140000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 276.243030, 0.000120, 0.049000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 2, 0}, 274.830330, 0.000010, 0.030000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 3, 0}, 272.317840, 0.000010, 0.021000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 1, -1, -1}, 74.687470, 0.000010, 0.139000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 74.688740, 0.000140, 0.165000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 1, 0, 1}, 74.690790, 0.000020, 0.030000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 272.081800, 0.000410, 0.054000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 0, -2}, 272.315490, 0.000020, 0.199000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 94.759650, 0.000540, 0.031000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 92.818470, 0.000100, 0.022000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 3, 0, 0}, 92.424140, 0.000010, 0.023000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 4, -2, 0}, 271.510970, 0.000010, 0.033000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 4, 0, 0}, 92.466000, 0.000050, 0.018000},
	{{0, 13, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 220.355710, 0.000040, 0.057000},
	{{0, 13, -14, 0, 1, 0, 0, 0, -2, 1, 0}, 178.233630, 0.000020, 0.234000},
	{{0, 13, -14, 0, 1, 0, 0, 0, 2, 0, 0}, 358.582660, 0.000030, 0.031000},
	{{0, 13, -14, 3, 0, 0, 0, 0, -2, 0, 0}, 236.296800, 0.000010, 0.062000},
	{{0, 13, -14, 3, 0, 0, 0, 0, -2, 2, 0}, 236.296800, 0.000010, 0.095000},
	{{0, 13, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 182.249530, 0.000040, 0.060000},
	{{0, 13, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 159.417860, 0.000010, 0.102000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -4, 2, 0}, 178.772960, 0.000020, 0.067000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, -2, 0}, 0.018770, 0.000020, 0.023000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 180.141790, 0.000040, 0.033000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 180.015760, 0.000320, 0.060000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 180.041280, 0.000230, 0.299000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 358.562710, 0.000090, 0.101000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 359.932380, 0.000050, 0.236000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -3, 0}, 358.454560, 0.000010, 0.032000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 338.762300, 0.000020, 0.054000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 179.883550, 0.000300, 0.195000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 180.014890, 0.001980, 0.123000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 180.076530, 0.000330, 0.047000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 178.466100, 0.000010, 0.029000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 191.813270, 0.000040, 0.141000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 359.997630, 0.000010, 0.049000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 1, 0, 1}, 11.813220, 0.000010, 0.029000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 179.849320, 0.000010, 0.145000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 178.730820, 0.000070, 0.157000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 180.071680, 0.001110, 0.051000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 0, -2}, 179.932970, 0.000050, 0.166000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 359.914880, 0.001570, 0.030000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 359.924180, 0.000150, 0.022000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 2, 0}, 359.930470, 0.000040, 0.017000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 3, 0, 0}, 359.991260, 0.000030, 0.022000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 4, 0, 0}, 359.928830, 0.000030, 0.017000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 4, 1, 0}, 359.932970, 0.000010, 0.014000},
	{{0, 13, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 347.692530, 0.000030, 0.061000},
	{{0, 13, -13, 0, 1, 0, 0, 0, -2, 1, 0}, 347.692590, 0.000010, 0.306000},
	{{0, 13, -13, 0, 1, 0, 0, 0, -2, 2, 0}, 347.692530, 0.000030, 0.100000},
	{{0, 13, -12, -3, 0, 0, 0, 0, -2, 0, 0}, 303.024460, 0.000010, 0.058000},
	{{0, 13, -12, -3, 0, 0, 0, 0, -2, 2, 0}, 303.024460, 0.000010, 0.107000},
	{{0, 13, -12, 0, -2, 0, 0, 0, 0, 0, 0}, 109.073020, 0.000020, 0.112000},
	{{0, 13, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 178.420570, 0.000010, 0.064000},
	{{0, 13, -12, 0, -1, 0, 0, 0, -2, 2, 0}, 178.420570, 0.000010, 0.092000},
	{{0, 13, -12, 0, -1, 0, 0, 0, 0, 0, 0}, 181.261450, 0.000050, 0.111000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 259.541120, 0.000040, 0.064000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 74.564010, 0.000020, 0.426000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 253.705340, 0.000010, 0.092000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, -1, 1}, 283.139390, 0.000010, 0.326000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 103.104300, 0.000050, 0.060000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 0, 1}, 287.104050, 0.000030, 0.098000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 1, -1}, 103.160210, 0.000050, 0.294000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 38.925810, 0.000020, 0.110000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, -1, -1}, 103.222370, 0.000030, 0.193000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, -1, 1}, 103.224570, 0.000010, 0.046000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 103.233020, 0.000210, 0.124000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 103.224600, 0.000030, 0.029000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 270.719770, 0.000080, 0.049000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 92.095310, 0.000140, 0.030000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 93.497100, 0.000020, 0.021000},
	{{0, 13, -11, -3, 0, 0, 0, 0, -2, 0, 0}, 336.159030, 0.000010, 0.062000},
	{{0, 13, -11, -3, 0, 0, 0, 0, -2, 2, 0}, 336.159030, 0.000010, 0.097000},
	{{0, 13, -11, -2, 0, 0, 0, 0, -2, 0, 0}, 0.429500, 0.000020, 0.064000},
	{{0, 13, -11, -2, 0, 0, 0, 0, -2, 2, 0}, 0.429500, 0.000020, 0.092000},
	{{0, 13, -11, 0, -3, 0, 0, 0, -2, 1, 0}, 10.437430, 0.000020, 0.624000},
	{{0, 13, -11, 0, -2, 0, 0, 0, -2, 0, 0}, 0.231840, 0.000030, 0.068000},
	{{0, 13, -11, 0, -2, 0, 0, 0, -2, 2, 0}, 0.231840, 0.000030, 0.085000},
	{{0, 13, -11, 0, -2, 0, 0, 0, 0, -2, 0}, 179.797970, 0.000020, 0.060000},
	{{0, 13, -11, 0, -2, 0, 0, 0, 0, 0, 0}, 359.797970, 0.000020, 0.100000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, -1, 0}, 26.703800, 0.000020, 0.036000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 26.512210, 0.000240, 0.068000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 25.963230, 0.000270, 0.741000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 199.535230, 0.000020, 0.084000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 203.607750, 0.000020, 0.447000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 26.663990, 0.000090, 0.320000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 29.283350, 0.000230, 0.099000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 200.015630, 0.000010, 0.043000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 25.750740, 0.000020, 0.046000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 205.522380, 0.000070, 0.029000},
	{{0, 13, -10, 0, -4, 0, 0, 0, -2, 1, 0}, 7.126810, 0.000030, 1.455000},
	{{0, 13, -10, 0, -3, 0, 0, 0, -2, 0, 0}, 350.985310, 0.000010, 0.072000},
	{{0, 13, -10, 0, -3, 0, 0, 0, -2, 1, 0}, 68.977980, 0.000020, 1.659000},
	{{0, 13, -10, 0, -3, 0, 0, 0, -2, 2, 0}, 350.985310, 0.000010, 0.079000},
	{{0, 13, -10, 0, -2, 0, 0, 0, -2, 0, 0}, 256.531630, 0.000020, 0.073000},
	{{0, 13, -10, 0, -2, 0, 0, 0, -2, 1, 0}, 248.225650, 0.000060, 1.929000},
	{{0, 13, -10, 0, -2, 0, 0, 0, -2, 2, 0}, 76.531630, 0.000020, 0.079000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -4, 2, 0}, 105.895990, 0.000010, 0.085000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, -2, 2}, 102.345190, 0.000020, 0.075000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, -1, 2}, 102.345190, 0.000340, 60.894000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 281.059620, 0.000070, 0.073000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 1}, 307.799180, 0.000030, 5.459000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 2}, 102.345190, 0.000020, 0.076000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 280.363780, 0.000250, 2.858000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 289.771520, 0.000050, 0.077000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -1, 1, -1}, 309.075310, 0.000010, 0.712000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 105.895990, 0.000010, 0.090000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 39.418310, 0.000020, 0.107000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 39.418310, 0.000020, 0.028000},
	{{0, 13, -10, 0, 1, 0, 0, 0, -2, 1, 0}, 280.375370, 0.000020, 3.765000},
	{{0, 13, -10, 2, 0, 0, 0, 0, -1, -1, 1}, 251.770030, 0.000030, 146.642000},
	{{0, 13, -10, 4, 0, 0, 0, 0, 0, -1, 0}, 351.012720, 0.000040, 359.272000},
	{{0, 13, -9, 0, -7, 0, 0, 0, -2, 1, 0}, 27.417980, 0.000010, 16.686000},
	{{0, 13, -9, 0, -4, 0, 0, 0, -2, 1, 0}, 352.595730, 0.000020, 3.197000},
	{{0, 13, -9, 0, -2, 0, 0, 0, -2, 0, 0}, 24.525280, 0.000010, 0.078000},
	{{0, 13, -9, 0, -2, 0, 0, 0, -2, 2, 0}, 204.525280, 0.000010, 0.073000},
	{{0, 13, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 189.532200, 0.000020, 0.079000},
	{{0, 13, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 229.033720, 0.000040, 1.538000},
	{{0, 13, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 251.812460, 0.000010, 0.072000},
	{{0, 13, -9, 0, 0, 0, 0, 0, -1, -1, 1}, 24.460010, 0.000090, 14.248000},
	{{0, 13, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 49.600700, 0.000070, 4.220000},
	{{0, 13, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 106.280620, 0.000020, 0.070000},
	{{0, 13, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 231.123560, 0.000010, 0.890000},
	{{0, 13, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 154.547480, 0.000020, 0.082000},
	{{0, 13, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 67.143910, 0.000010, 0.097000},
	{{0, 13, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 348.120100, 0.000010, 0.027000},
	{{0, 13, -9, 0, 0, 0, 0, 0, 2, 2, 0}, 308.215040, 0.000020, 0.016000},
	{{0, 13, -9, 2, 0, 0, 0, 0, 0, -1, 0}, 242.184150, 0.000020, 16.506000},
	{{0, 13, -8, -3, 0, 0, 0, 0, -2, 1, 0}, 31.669350, 0.000030, 18.178000},
	{{0, 13, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 134.572380, 0.000010, 0.086000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 314.572380, 0.000050, 0.075000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 122.652700, 0.000110, 8.068000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 314.572380, 0.000050, 0.076000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 134.572380, 0.000010, 0.088000},
	{{0, 13, -7, -5, 0, 0, 0, 0, -2, 1, 0}, 238.152520, 0.000030, 119.657000},
	{{0, 13, -7, -3, 0, 0, 0, 0, -1, 1, -1}, 334.161140, 0.000170, 802.892000},
	{{0, 13, -6, -7, 0, 0, 0, 0, -2, 1, 0}, 328.349430, 0.000020, 13.942000},
	{{0, 14, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 289.582240, 0.000020, 0.040000},
	{{0, 14, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 289.593400, 0.000010, 0.653000},
	{{0, 14, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 310.479720, 0.000020, 0.103000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -3, 0}, 54.740720, 0.000040, 0.075000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -2, 0}, 17.253520, 0.000010, 59.908000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 86.611400, 0.000040, 0.076000},
	{{0, 14, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 30.047070, 0.000010, 0.045000},
	{{0, 14, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 210.047070, 0.000010, 0.221000},
	{{0, 14, -20, 0, 0, 0, 0, 0, 2, -1, 0}, 227.018410, 0.000020, 0.070000},
	{{0, 14, -20, 2, 0, 0, 0, 0, -2, 0, 0}, 51.690610, 0.000010, 0.048000},
	{{0, 14, -20, 2, 0, 0, 0, 0, -2, 2, 0}, 51.690610, 0.000010, 0.179000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 154.992890, 0.000030, 0.048000},
	{{0, 14, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 147.885550, 0.000040, 0.105000},
	{{0, 14, -19, 0, 0, 0, 0, 0, 0, 1, 0}, 154.624720, 0.000010, 0.059000},
	{{0, 14, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 57.859340, 0.000010, 0.035000},
	{{0, 14, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 230.276470, 0.000080, 0.048000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -4, -1, 0}, 231.659860, 0.000010, 0.017000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -4, 1, 0}, 51.659860, 0.000020, 0.032000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 49.438600, 0.000030, 0.050000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 0, 2}, 231.659860, 0.000020, 0.146000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 55.896970, 0.000010, 0.149000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 51.796250, 0.000050, 0.153000},
	{{0, 14, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 49.672450, 0.000020, 0.210000},
	{{0, 14, -18, 0, 1, 0, 0, 0, -2, 0, 0}, 218.528480, 0.000010, 0.050000},
	{{0, 14, -18, 0, 1, 0, 0, 0, -2, 2, 0}, 218.528480, 0.000010, 0.151000},
	{{0, 14, -17, 0, -1, 0, 0, 0, -2, 0, 0}, 55.342390, 0.000020, 0.052000},
	{{0, 14, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 144.591760, 0.000010, 0.031000},
	{{0, 14, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 130.143580, 0.000020, 0.053000},
	{{0, 14, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 144.591760, 0.000010, 0.175000},
	{{0, 14, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 288.509110, 0.000010, 0.133000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 73.955430, 0.000050, 0.174000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 258.535930, 0.000040, 0.033000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -4, 2, 0}, 175.760180, 0.000010, 0.062000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 34.947120, 0.000010, 0.032000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 359.857250, 0.000060, 0.056000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 7.447210, 0.000030, 0.212000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 351.178080, 0.000040, 0.117000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 16.973070, 0.000010, 0.154000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 346.781160, 0.000120, 0.148000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 168.416300, 0.000030, 0.175000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 355.161720, 0.000110, 0.055000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 174.968930, 0.000140, 0.032000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 175.023050, 0.000020, 0.022000},
	{{0, 14, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 270.741870, 0.000010, 0.056000},
	{{0, 14, -16, 0, 1, 0, 0, 0, -2, 2, 0}, 90.741870, 0.000010, 0.116000},
	{{0, 14, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 104.808950, 0.000020, 0.059000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -4, 2, 0}, 272.416520, 0.000010, 0.066000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 276.804420, 0.000010, 0.059000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 92.005180, 0.000030, 0.105000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 74.292940, 0.000020, 0.055000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 272.452820, 0.000010, 0.053000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 280.602480, 0.000040, 0.182000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 272.242550, 0.000480, 0.129000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 276.298000, 0.000100, 0.048000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 74.333770, 0.000110, 0.149000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 189.276850, 0.000010, 0.167000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 271.878720, 0.000270, 0.052000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 0, -2}, 272.313380, 0.000010, 0.177000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 95.680550, 0.000420, 0.031000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 93.210930, 0.000080, 0.022000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 3, 0, 0}, 92.419920, 0.000010, 0.022000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 4, 0, 0}, 92.331890, 0.000040, 0.017000},
	{{0, 14, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 208.849510, 0.000030, 0.059000},
	{{0, 14, -15, 0, 1, 0, 0, 0, -2, 1, 0}, 178.229550, 0.000030, 0.275000},
	{{0, 14, -15, 0, 1, 0, 0, 0, -2, 2, 0}, 227.290710, 0.000010, 0.104000},
	{{0, 14, -15, 0, 1, 0, 0, 0, 2, 0, 0}, 358.558020, 0.000020, 0.031000},
	{{0, 14, -15, 3, 0, 0, 0, 0, -2, 0, 0}, 236.272160, 0.000010, 0.065000},
	{{0, 14, -15, 3, 0, 0, 0, 0, -2, 1, 0}, 236.272160, 0.000020, 0.470000},
	{{0, 14, -15, 3, 0, 0, 0, 0, -2, 2, 0}, 236.272160, 0.000010, 0.090000},
	{{0, 14, -15, 7, 0, 0, 0, 0, -2, 1, 0}, 24.126510, 0.000020, 381.207000},
	{{0, 14, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 197.141970, 0.000040, 0.062000},
	{{0, 14, -14, 0, -1, 0, 0, 0, -2, 1, 0}, 149.223860, 0.000010, 0.356000},
	{{0, 14, -14, 0, -1, 0, 0, 0, -2, 2, 0}, 203.387690, 0.000010, 0.096000},
	{{0, 14, -14, 0, -1, 0, 0, 0, 0, 0, 0}, 272.549910, 0.000010, 0.115000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -4, 2, 0}, 178.777450, 0.000020, 0.070000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 179.915700, 0.000040, 0.034000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 179.748690, 0.000330, 0.063000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 180.124890, 0.000240, 0.367000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 358.561640, 0.000080, 0.095000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 359.929580, 0.000040, 0.277000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 179.869240, 0.000270, 0.222000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 180.277240, 0.001480, 0.114000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 180.116120, 0.000240, 0.045000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 191.923480, 0.000030, 0.130000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 359.256740, 0.000020, 0.047000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 1, 0, 1}, 11.923430, 0.000010, 0.029000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 175.960260, 0.000040, 0.143000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 179.918730, 0.000750, 0.049000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 0, -2}, 179.908750, 0.000030, 0.150000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 0.019700, 0.001200, 0.030000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 359.960800, 0.000160, 0.021000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 2, 0}, 359.926840, 0.000030, 0.017000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 3, -3, 0}, 179.971000, 0.000010, 0.164000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 3, -1, 0}, 179.971000, 0.000010, 0.031000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 3, 0, 0}, 359.969210, 0.000030, 0.022000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 4, -2, 0}, 181.701410, 0.000020, 0.032000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 4, -1, 0}, 359.881010, 0.000010, 0.022000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 4, 0, 0}, 359.956430, 0.000030, 0.017000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 4, 1, 0}, 359.908760, 0.000010, 0.014000},
	{{0, 14, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 346.827040, 0.000020, 0.063000},
	{{0, 14, -14, 0, 1, 0, 0, 0, -2, 1, 0}, 347.729680, 0.000010, 0.379000},
	{{0, 14, -14, 0, 1, 0, 0, 0, -2, 2, 0}, 346.827040, 0.000020, 0.094000},
	{{0, 14, -13, -3, 0, 0, 0, 0, -2, 0, 0}, 303.003810, 0.000010, 0.060000},
	{{0, 14, -13, -3, 0, 0, 0, 0, -2, 2, 0}, 303.003810, 0.000010, 0.101000},
	{{0, 14, -13, 0, -2, 0, 0, 0, -2, 1, 0}, 95.171640, 0.000030, 0.528000},
	{{0, 14, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 178.382640, 0.000010, 0.066000},
	{{0, 14, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 178.382640, 0.000010, 0.087000},
	{{0, 14, -13, 0, -1, 0, 0, 0, 0, -2, 0}, 1.242740, 0.000020, 0.059000},
	{{0, 14, -13, 0, -1, 0, 0, 0, 0, 0, 0}, 181.242740, 0.000020, 0.103000},
	{{0, 14, -13, 0, 0, -1, 0, 0, -4, 3, 0}, 179.995740, 0.000010, 63.874000},
	{{0, 14, -13, 0, 0, -1, 0, 0, -2, 0, 0}, 180.099210, 0.000010, 0.067000},
	{{0, 14, -13, 0, 0, -1, 0, 0, -2, 2, 0}, 180.099210, 0.000010, 0.087000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -4, 3, 0}, 78.486340, 0.000030, 20.160000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 266.371480, 0.000020, 0.067000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 266.371480, 0.000020, 0.087000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, -1, 1}, 283.081220, 0.000010, 0.409000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 103.077050, 0.000050, 0.062000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, 1}, 289.910590, 0.000020, 0.092000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 1, -1}, 103.133810, 0.000060, 0.360000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 35.313360, 0.000010, 0.102000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, -1, -1}, 103.198810, 0.000030, 0.220000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 103.210770, 0.000170, 0.115000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, 1}, 103.200780, 0.000030, 0.028000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 263.571340, 0.000040, 0.047000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 92.547420, 0.000110, 0.029000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 93.907630, 0.000010, 0.021000},
	{{0, 14, -13, 3, 0, 0, 0, 0, -2, 1, 0}, 260.827770, 0.000020, 7.730000},
	{{0, 14, -12, -3, 0, 0, 0, 0, -2, 0, 0}, 336.142470, 0.000010, 0.064000},
	{{0, 14, -12, -3, 0, 0, 0, 0, -2, 1, 0}, 336.142470, 0.000010, 0.431000},
	{{0, 14, -12, -3, 0, 0, 0, 0, -2, 2, 0}, 336.142470, 0.000010, 0.091000},
	{{0, 14, -12, -2, 0, 0, 0, 0, -2, 0, 0}, 0.405100, 0.000020, 0.066000},
	{{0, 14, -12, -2, 0, 0, 0, 0, -2, 2, 0}, 0.405100, 0.000020, 0.087000},
	{{0, 14, -12, 0, -3, 0, 0, 0, -2, 0, 0}, 10.449180, 0.000050, 0.070000},
	{{0, 14, -12, 0, -3, 0, 0, 0, -2, 1, 0}, 60.794640, 0.000010, 1.023000},
	{{0, 14, -12, 0, -2, 0, 0, 0, -2, 0, 0}, 0.284750, 0.000020, 0.071000},
	{{0, 14, -12, 0, -2, 0, 0, 0, -2, 1, 0}, 359.233210, 0.000030, 1.120000},
	{{0, 14, -12, 0, -2, 0, 0, 0, -2, 2, 0}, 0.284750, 0.000020, 0.081000},
	{{0, 14, -12, 0, -2, 0, 0, 0, 0, -2, 0}, 179.774150, 0.000020, 0.063000},
	{{0, 14, -12, 0, -2, 0, 0, 0, 0, 0, 0}, 359.774150, 0.000020, 0.094000},
	{{0, 14, -12, 0, -1, 0, 0, 0, -2, 1, 0}, 116.497800, 0.000050, 1.237000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -4, 2, 0}, 19.628700, 0.000020, 0.082000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -3, 2, -1}, 352.330080, 0.000010, 0.075000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -3, 3, -1}, 352.330080, 0.000230, 240.318000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -3, 4, -1}, 352.330080, 0.000010, 0.075000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 27.774790, 0.000020, 0.037000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 27.930500, 0.000340, 0.072000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 26.722800, 0.000650, 1.380000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 194.213340, 0.000050, 0.080000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 204.441450, 0.000030, 0.621000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 26.535770, 0.000100, 0.400000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 26.118040, 0.000220, 0.093000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 25.749590, 0.000020, 0.027000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 25.733020, 0.000010, 0.045000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 205.751240, 0.000060, 0.028000},
	{{0, 14, -12, 3, 0, 0, 0, 0, -1, 0, 0}, 99.715220, 0.000010, 61.092000},
	{{0, 14, -11, -4, 0, 0, 0, 0, -2, 1, 0}, 150.055440, 0.000020, 0.540000},
	{{0, 14, -11, -3, 0, 0, 0, 0, -2, 1, 0}, 359.806220, 0.000010, 0.758000},
	{{0, 14, -11, -2, 0, 0, 0, 0, -2, 1, 0}, 344.262700, 0.000010, 1.269000},
	{{0, 14, -11, 0, -3, 0, 0, 0, -2, 0, 0}, 108.646910, 0.000070, 0.076000},
	{{0, 14, -11, 0, -3, 0, 0, 0, -2, 1, 0}, 81.025980, 0.000060, 44.104000},
	{{0, 14, -11, 0, -3, 0, 0, 0, -2, 2, 0}, 328.248370, 0.000020, 0.075000},
	{{0, 14, -11, 0, -2, 0, 0, 0, -2, 0, 0}, 71.864100, 0.000130, 0.076000},
	{{0, 14, -11, 0, -2, 0, 0, 0, -2, 1, 0}, 338.234410, 0.000050, 9.348000},
	{{0, 14, -11, 0, -2, 0, 0, 0, -2, 2, 0}, 145.220630, 0.000010, 0.075000},
	{{0, 14, -11, 0, -2, 0, 0, 0, 0, 0, 0}, 251.863710, 0.000030, 0.086000},
	{{0, 14, -11, 0, -1, 0, 0, 0, -2, 1, 0}, 24.570930, 0.000060, 5.228000},
	{{0, 14, -11, 0, 0, -4, 0, 0, -2, 1, 0}, 92.105410, 0.000010, 7.153000},
	{{0, 14, -11, 0, 0, -3, 0, 0, -2, 1, 0}, 358.248020, 0.000030, 5.756000},
	{{0, 14, -11, 0, 0, -2, 0, 0, -2, 1, 0}, 266.135980, 0.000010, 4.815000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 107.038630, 0.000030, 0.077000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 281.630140, 0.000260, 3.629000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 107.038630, 0.000030, 0.074000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -1, -1, 1}, 128.801700, 0.000020, 2.249000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 101.665890, 0.000010, 1.636000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -1, 1, -1}, 309.218270, 0.000030, 1.285000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 39.585280, 0.000030, 0.100000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 39.585280, 0.000030, 0.027000},
	{{0, 14, -10, -3, 0, 0, 0, 0, -2, 1, 0}, 178.367880, 0.000030, 3.130000},
	{{0, 14, -10, 0, -2, 0, 0, 0, -1, 1, -1}, 12.469640, 0.000020, 18.793000},
	{{0, 14, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 51.729050, 0.000020, 2.574000},
	{{0, 14, -10, 0, 0, 0, 0, 0, -1, 1, -1}, 202.050000, 0.000020, 4.508000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 308.123770, 0.000040, 0.073000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 224.074260, 0.000060, 2.006000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 264.214710, 0.000040, 0.078000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 128.198480, 0.000010, 0.025000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 308.198480, 0.000020, 0.440000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 308.198480, 0.000020, 0.041000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 308.198480, 0.000010, 0.027000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 2, 2, 0}, 308.198480, 0.000010, 0.016000},
	{{0, 14, -9, -4, 0, 0, 0, 0, -2, 1, 0}, 289.193250, 0.000010, 6.718000},
	{{0, 14, -9, 0, -6, 0, 0, 0, 0, -1, 0}, 287.404870, 0.000050, 234.929000},
	{{0, 14, -9, 0, -2, 0, 0, 0, -2, 1, -2}, 320.240460, 0.000020, 0.040000},
	{{0, 14, -9, 0, -2, 0, 0, 0, -2, 2, -2}, 320.240460, 0.000020, 0.087000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, -1, 0}, 51.716890, 0.000010, 3.003000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 0, -2}, 300.622840, 0.000110, 0.075000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 1, -2}, 320.240460, 0.002050, 1808.606000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 2, -2}, 318.814920, 0.000110, 0.075000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 2, 0, -2}, 320.240460, 0.000020, 0.087000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 2, 1, -2}, 320.240460, 0.000020, 0.040000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 315.550350, 0.000010, 0.078000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 135.550350, 0.000010, 0.073000},
	{{0, 14, -9, 3, 0, 0, 0, 0, 2, -1, -2}, 29.591740, 0.000030, 91.671000},
	{{0, 14, -8, -3, 0, 0, 0, 0, 0, -1, 0}, 96.283120, 0.000020, 10.697000},
	{{0, 14, -8, 0, -2, 0, 0, 0, 2, -2, 0}, 308.220250, 0.000010, 0.078000},
	{{0, 14, -8, 0, -2, 0, 0, 0, 2, 0, 0}, 128.220250, 0.000010, 0.025000},
	{{0, 14, -7, -8, 0, 0, 0, 0, -2, 1, 0}, 302.035580, 0.000060, 45.223000},
	{{0, 14, -7, -4, 0, 0, 0, 0, 0, 1, -2}, 278.537560, 0.000010, 24.202000},
	{{0, 14, -6, -10, 0, 0, 0, 0, -2, 1, 0}, 23.730390, 0.000020, 24.240000},
	{{0, 14, -1, -16, 0, 0, 0, 0, 0, -1, 0}, 44.005340, 0.000020, 185.940000},
	{{0, 15, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 289.583900, 0.000010, 0.078000},
	{{0, 15, -24, 0, 0, 0, 0, 0, 0, 1, 0}, 289.583900, 0.000010, 0.073000},
	{{0, 15, -23, 19, 0, 0, 0, 0, -2, 1, 0}, 96.413310, 0.000010, 321.466000},
	{{0, 15, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 311.077050, 0.000020, 0.110000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 160.271560, 0.000040, 0.049000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 169.008250, 0.000010, 0.162000},
	{{0, 15, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 147.308000, 0.000030, 0.113000},
	{{0, 15, -20, 0, 0, 0, 0, 0, 2, -2, 0}, 57.853620, 0.000020, 0.383000},
	{{0, 15, -20, 0, 0, 0, 0, 0, 2, -1, 0}, 144.059300, 0.000020, 0.063000},
	{{0, 15, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 57.845560, 0.000010, 0.034000},
	{{0, 15, -20, 0, 1, 0, 0, 0, -2, 0, 0}, 230.248090, 0.000070, 0.049000},
	{{0, 15, -19, 0, -1, 0, 0, 0, -2, 0, 0}, 60.292580, 0.000030, 0.051000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -4, 1, 0}, 51.633370, 0.000020, 0.032000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, -1, 0}, 231.633370, 0.000010, 0.031000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 48.830570, 0.000020, 0.052000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 0, 2}, 231.633370, 0.000020, 0.134000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 52.875850, 0.000030, 0.164000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 51.768730, 0.000030, 0.140000},
	{{0, 15, -19, 0, 0, 0, 0, 0, 0, -2, 0}, 51.476050, 0.000010, 0.047000},
	{{0, 15, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 50.746680, 0.000030, 0.186000},
	{{0, 15, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 218.501900, 0.000020, 0.052000},
	{{0, 15, -18, 0, -1, 0, 0, 0, -2, 0, 0}, 55.304790, 0.000010, 0.054000},
	{{0, 15, -18, 0, -1, 0, 0, 0, -2, 2, 0}, 235.304790, 0.000010, 0.124000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 138.986300, 0.000010, 0.146000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 77.055030, 0.000020, 0.157000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 138.986300, 0.000010, 0.051000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 259.216470, 0.000010, 0.056000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 259.120240, 0.000030, 0.032000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 351.233920, 0.000050, 0.058000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 5.468000, 0.000020, 0.244000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 350.467260, 0.000020, 0.109000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 349.864360, 0.000140, 0.135000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 1, 0, -1}, 168.306000, 0.000020, 0.158000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 355.641940, 0.000080, 0.053000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 175.564710, 0.000130, 0.031000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, 1, 0}, 175.638410, 0.000010, 0.022000},
	{{0, 15, -17, 0, 1, 0, 0, 0, -2, 0, 0}, 270.773950, 0.000010, 0.058000},
	{{0, 15, -17, 0, 1, 0, 0, 0, -2, 2, 0}, 90.773950, 0.000010, 0.108000},
	{{0, 15, -17, 4, 0, 0, 0, 0, -2, 0, 0}, 57.836570, 0.000010, 0.066000},
	{{0, 15, -17, 4, 0, 0, 0, 0, -2, 2, 0}, 57.836570, 0.000010, 0.089000},
	{{0, 15, -17, 11, 0, 0, 0, 0, 0, -1, 0}, 93.559970, 0.000010, 41.017000},
	{{0, 15, -16, 0, -1, 0, 0, 0, -2, 0, 0}, 104.821130, 0.000020, 0.061000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 272.129230, 0.000020, 0.061000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 270.307330, 0.000020, 0.323000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 90.175080, 0.000030, 0.098000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 73.888980, 0.000020, 0.057000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 271.855290, 0.000020, 0.205000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 272.305620, 0.000400, 0.119000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 272.676340, 0.000040, 0.046000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 87.693370, 0.000060, 0.136000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 1, 0, 1}, 253.944360, 0.000020, 0.029000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, -2, 0}, 221.246180, 0.000020, 0.151000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 272.066650, 0.000190, 0.050000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 95.090550, 0.000330, 0.030000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 92.970570, 0.000060, 0.022000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 3, -2, 0}, 92.415360, 0.000010, 0.053000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 3, 0, 0}, 92.415360, 0.000010, 0.022000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 4, -1, 0}, 92.247150, 0.000010, 0.022000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 4, 0, 0}, 92.265000, 0.000020, 0.017000},
	{{0, 15, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 226.771970, 0.000020, 0.061000},
	{{0, 15, -16, 0, 1, 0, 0, 0, -2, 2, 0}, 228.010620, 0.000010, 0.098000},
	{{0, 15, -16, 3, 0, 0, 0, 0, -2, 0, 0}, 236.245580, 0.000010, 0.068000},
	{{0, 15, -16, 3, 0, 0, 0, 0, -2, 2, 0}, 236.245580, 0.000010, 0.085000},
	{{0, 15, -15, 0, -2, 0, 0, 0, -2, 0, 0}, 209.278840, 0.000020, 0.064000},
	{{0, 15, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 189.553380, 0.000060, 0.065000},
	{{0, 15, -15, 0, -1, 0, 0, 0, -2, 2, 0}, 185.370160, 0.000010, 0.090000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -6, 1, 2}, 359.603860, 0.000020, 0.040000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -6, 2, 2}, 359.603860, 0.000020, 0.087000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 0, 2}, 359.603860, 0.000120, 0.075000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 1, 2}, 359.603860, 0.002110, 115.724000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 2, 0}, 178.778170, 0.000020, 0.074000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 2, 2}, 359.603860, 0.000120, 0.075000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, -1, 0}, 179.937790, 0.000020, 0.035000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 179.790880, 0.000330, 0.065000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 0, 2}, 359.603860, 0.000020, 0.087000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 179.950630, 0.000280, 0.476000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 1, 2}, 359.603860, 0.000020, 0.040000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 358.530610, 0.000090, 0.090000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -1, 0, 0}, 359.928800, 0.000050, 0.335000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 0.121860, 0.000020, 0.058000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 180.028060, 0.000250, 0.258000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 180.646000, 0.001130, 0.107000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 181.279900, 0.000190, 0.044000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 192.020300, 0.000030, 0.120000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 0.222850, 0.000010, 0.046000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 181.840930, 0.000040, 0.131000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 179.811960, 0.000500, 0.048000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 0, -2}, 179.882190, 0.000020, 0.137000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 359.985530, 0.000880, 0.029000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 359.925110, 0.000140, 0.021000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 2, 0}, 359.908570, 0.000020, 0.016000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 3, 0, 0}, 359.946640, 0.000030, 0.022000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 4, -2, 0}, 178.733090, 0.000010, 0.031000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 4, 0, 0}, 359.932600, 0.000020, 0.017000},
	{{0, 15, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 346.873380, 0.000050, 0.065000},
	{{0, 15, -15, 0, 1, 0, 0, 0, -2, 1, 0}, 346.873380, 0.000020, 0.496000},
	{{0, 15, -15, 2, 0, 0, 0, 0, -3, 1, 1}, 140.056300, 0.000020, 54.813000},
	{{0, 15, -14, -3, 0, 0, 0, 0, -2, 0, 0}, 302.981140, 0.000010, 0.063000},
	{{0, 15, -14, -3, 0, 0, 0, 0, -2, 2, 0}, 302.981140, 0.000010, 0.095000},
	{{0, 15, -14, 0, -3, 0, 0, 0, -2, 0, 0}, 282.150800, 0.000010, 0.068000},
	{{0, 15, -14, 0, -3, 0, 0, 0, -2, 2, 0}, 282.150800, 0.000010, 0.084000},
	{{0, 15, -14, 0, -2, 0, 0, 0, -2, 0, 0}, 94.756090, 0.000060, 0.069000},
	{{0, 15, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 178.344100, 0.000020, 0.069000},
	{{0, 15, -14, 0, -1, 0, 0, 0, -2, 2, 0}, 178.344100, 0.000020, 0.083000},
	{{0, 15, -14, 0, -1, 0, 0, 0, 0, -2, 0}, 1.220320, 0.000020, 0.062000},
	{{0, 15, -14, 0, -1, 0, 0, 0, 0, 0, 0}, 181.220320, 0.000020, 0.097000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 0, 1}, 283.198260, 0.000070, 0.075000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 1, 1}, 283.388290, 0.000730, 22.161000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 2, 1}, 283.379500, 0.000040, 0.076000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 277.532240, 0.000020, 0.070000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 110.343020, 0.000030, 0.910000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 233.437380, 0.000010, 0.082000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, -1, 1}, 283.046830, 0.000010, 0.550000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 103.049970, 0.000050, 0.065000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 0, 1}, 290.671890, 0.000020, 0.087000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 1, -1}, 103.105390, 0.000070, 0.465000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 242.265530, 0.000010, 0.062000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 36.936390, 0.000020, 0.096000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 129.260080, 0.000020, 0.042000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, -1, -1}, 103.172850, 0.000030, 0.255000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 103.186810, 0.000140, 0.107000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, 0, 1}, 103.174580, 0.000020, 0.028000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 263.827920, 0.000030, 0.046000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 91.328890, 0.000110, 0.028000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 94.107980, 0.000010, 0.021000},
	{{0, 15, -14, 0, 1, 0, 0, 0, -2, 1, 0}, 48.630530, 0.000020, 0.986000},
	{{0, 15, -14, 2, 0, 0, 0, 0, -2, 1, 0}, 240.512330, 0.000050, 28.153000},
	{{0, 15, -13, -3, 0, 0, 0, 0, -2, 0, 0}, 336.123840, 0.000010, 0.067000},
	{{0, 15, -13, -3, 0, 0, 0, 0, -2, 2, 0}, 336.123840, 0.000010, 0.086000},
	{{0, 15, -13, 0, -4, 0, 0, 0, -2, 1, 0}, 55.028330, 0.000020, 2.293000},
	{{0, 15, -13, 0, -3, 0, 0, 0, -2, -1, 2}, 181.770580, 0.000040, 54.678000},
	{{0, 15, -13, 0, -3, 0, 0, 0, -2, 0, 0}, 53.028270, 0.000040, 0.073000},
	{{0, 15, -13, 0, -3, 0, 0, 0, -2, 1, 0}, 359.059630, 0.000040, 2.843000},
	{{0, 15, -13, 0, -2, 0, 0, 0, -2, 0, 0}, 358.811220, 0.000030, 0.074000},
	{{0, 15, -13, 0, -2, 0, 0, 0, -2, 1, 0}, 348.750630, 0.000020, 3.738000},
	{{0, 15, -13, 0, -2, 0, 0, 0, -2, 2, 0}, 359.178010, 0.000040, 0.077000},
	{{0, 15, -13, 0, -2, 0, 0, 0, 0, -2, 0}, 359.748330, 0.000020, 0.065000},
	{{0, 15, -13, 0, -2, 0, 0, 0, 0, -1, 0}, 359.753490, 0.000020, 0.490000},
	{{0, 15, -13, 0, -2, 0, 0, 0, 0, 0, 0}, 359.748330, 0.000020, 0.089000},
	{{0, 15, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 143.524990, 0.000040, 0.074000},
	{{0, 15, -13, 0, -1, 0, 0, 0, -2, 1, 0}, 78.004960, 0.000100, 5.459000},
	{{0, 15, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 52.567960, 0.000040, 0.076000},
	{{0, 15, -13, 0, 0, -2, 0, 0, -2, 0, 0}, 0.100780, 0.000020, 0.075000},
	{{0, 15, -13, 0, 0, -2, 0, 0, -2, 1, 0}, 358.573760, 0.000040, 5.996000},
	{{0, 15, -13, 0, 0, -2, 0, 0, -2, 2, 0}, 0.100780, 0.000020, 0.076000},
	{{0, 15, -13, 0, 0, -1, 0, 0, -2, 1, 0}, 97.847680, 0.000050, 7.528000},
	{{0, 15, -13, 0, 0, 0, -2, 0, -2, 1, 0}, 180.590820, 0.000020, 8.151000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 0, 0}, 26.275220, 0.000060, 0.026000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 1, 0}, 26.315080, 0.000320, 0.040000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 2, 0}, 26.396130, 0.000290, 0.086000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 26.241910, 0.000250, 0.038000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, -1, 2}, 202.813520, 0.000010, 4.262000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 26.238470, 0.003640, 0.075000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 0, 1}, 3.949010, 0.000090, 14.735000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, -2}, 206.323150, 0.000050, 0.037000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 26.323150, 0.025140, 10.112000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, 2}, 206.323150, 0.000050, 0.037000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 26.245720, 0.001340, 0.076000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 26.245720, 0.000090, 0.038000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 206.280910, 0.000060, 1.014000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 29.513520, 0.000080, 0.534000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 27.437440, 0.000100, 0.088000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 26.333160, 0.000260, 0.041000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 26.301690, 0.000030, 0.026000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 202.637940, 0.000010, 0.042000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 205.730310, 0.000020, 0.044000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 215.563430, 0.000040, 0.028000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 2, 2, 0}, 344.298330, 0.000010, 0.016000},
	{{0, 15, -13, 0, 0, 2, 0, 0, -2, 1, 0}, 16.039730, 0.000020, 32.265000},
	{{0, 15, -13, 0, 0, 3, 0, 0, -2, 1, 0}, 278.909110, 0.000010, 338.444000},
	{{0, 15, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 287.821160, 0.000050, 0.075000},
	{{0, 15, -13, 0, 1, 0, 0, 0, -2, 1, 0}, 70.823350, 0.000040, 68.563000},
	{{0, 15, -13, 0, 1, 0, 0, 0, -2, 2, 0}, 144.084110, 0.000010, 0.076000},
	{{0, 15, -13, 0, 2, 0, 0, 0, -2, 1, 0}, 254.407290, 0.000010, 14.344000},
	{{0, 15, -12, -4, 0, 0, 0, 0, -2, 0, 0}, 150.028140, 0.000020, 0.069000},
	{{0, 15, -12, -4, 0, 0, 0, 0, -2, 2, 0}, 150.028140, 0.000020, 0.083000},
	{{0, 15, -12, -3, 0, 0, 0, 0, -2, 0, 0}, 359.783550, 0.000010, 0.072000},
	{{0, 15, -12, -3, 0, 0, 0, 0, -2, 2, 0}, 359.783550, 0.000010, 0.080000},
	{{0, 15, -12, -2, 0, 0, 0, 0, -2, 1, 0}, 2.183350, 0.000010, 6.163000},
	{{0, 15, -12, 0, -4, 0, 0, 0, -2, 1, 0}, 7.067790, 0.000030, 1.773000},
	{{0, 15, -12, 0, -3, 0, 0, 0, -2, 1, 0}, 74.162770, 0.000010, 1.543000},
	{{0, 15, -12, 0, -2, 0, 0, 0, -2, 1, 0}, 253.509840, 0.000020, 1.365000},
	{{0, 15, -12, 0, -2, 0, 0, 0, -1, -2, 1}, 283.238300, 0.000010, 0.076000},
	{{0, 15, -12, 0, -2, 0, 0, 0, -1, -1, 1}, 281.989310, 0.000020, 81.636000},
	{{0, 15, -12, 0, -2, 0, 0, 0, -1, 0, 1}, 283.238300, 0.000010, 0.075000},
	{{0, 15, -12, 0, -2, 0, 0, 0, -1, 1, -1}, 283.278620, 0.000030, 3.113000},
	{{0, 15, -12, 0, 0, -1, 0, 0, -1, 0, 0}, 205.323750, 0.000020, 50.387000},
	{{0, 15, -12, 0, 0, 0, -1, 0, -1, 0, 0}, 33.488600, 0.000010, 454.655000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -4, 1, 0}, 283.386220, 0.000020, 0.042000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -4, 2, 0}, 283.458950, 0.000010, 0.095000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, -1, 0}, 99.701010, 0.000020, 0.026000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, 0, 0}, 99.701010, 0.000170, 0.040000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, 1, 0}, 99.701010, 0.000160, 0.087000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 283.304980, 0.000020, 0.081000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 223.343920, 0.000010, 1.110000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, -2, 0}, 99.701010, 0.000050, 0.038000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, -1, 0}, 99.749200, 0.000820, 0.076000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, -1, 1}, 128.936750, 0.000100, 5.529000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, -2}, 279.701010, 0.000030, 0.037000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 309.316120, 0.000120, 0.075000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 99.701010, 0.014670, 70.915000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, 2}, 279.701010, 0.000030, 0.037000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 1, -1}, 309.250860, 0.000600, 6.551000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 1, 0}, 99.749200, 0.000820, 0.075000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 2, -1}, 309.251100, 0.000030, 0.076000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 2, 0}, 99.701010, 0.000050, 0.038000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 252.425390, 0.000020, 1.146000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, -1, 0}, 99.701010, 0.000160, 0.087000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 129.340320, 0.000020, 0.088000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 99.701010, 0.000170, 0.040000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, 1, 0}, 99.701010, 0.000020, 0.026000},
	{{0, 15, -11, -6, 0, 0, 0, 0, -2, 1, 0}, 121.503600, 0.000010, 0.776000},
	{{0, 15, -11, -3, 0, 0, 0, 0, -2, 1, 0}, 178.700920, 0.000030, 3.267000},
	{{0, 15, -11, 0, -3, 0, 0, 0, 0, -1, 0}, 240.033320, 0.000020, 7.948000},
	{{0, 15, -11, 0, -2, 0, 0, 0, 0, -1, 0}, 183.764390, 0.000080, 24.088000},
	{{0, 15, -11, 0, -2, 0, 0, 0, 0, 0, 0}, 25.728520, 0.000020, 0.076000},
	{{0, 15, -11, 0, -1, 0, 0, 0, 0, -2, 0}, 144.736590, 0.000030, 0.076000},
	{{0, 15, -11, 0, -1, 0, 0, 0, 0, 0, 0}, 324.736590, 0.000030, 0.075000},
	{{0, 15, -11, 0, 0, -5, 0, 0, 0, -1, 0}, 71.530210, 0.000010, 23.448000},
	{{0, 15, -11, 0, 0, -4, 0, 0, 0, -1, 0}, 44.373920, 0.000010, 114.947000},
	{{0, 15, -11, 0, 0, -1, 0, 0, 0, -1, 0}, 220.779480, 0.000020, 10.736000},
	{{0, 15, -11, 0, 0, 0, 0, 0, -3, 0, 0}, 356.764090, 0.000010, 0.042000},
	{{0, 15, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 231.453220, 0.000020, 0.088000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 231.697910, 0.000040, 0.076000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 231.719990, 0.000820, 7.868000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, 0, -1}, 22.884660, 0.000130, 25.212000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 59.224840, 0.000030, 0.075000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 128.179850, 0.000010, 0.025000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 308.179850, 0.000010, 0.607000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 277.049170, 0.000020, 0.040000},
	{{0, 15, -10, -2, 0, 0, 0, 0, 0, -1, 0}, 262.651600, 0.000020, 15.693000},
	{{0, 15, -10, 0, -1, 0, 0, 0, 1, -1, -1}, 33.225820, 0.000020, 91.100000},
	{{0, 15, -10, 0, 0, -2, 0, 0, 1, -1, -1}, 127.836280, 0.000030, 184.133000},
	{{0, 15, -10, 0, 0, 0, 0, 0, 1, -1, -1}, 153.795440, 0.000060, 13.638000},
	{{0, 15, -9, -8, 0, 0, 0, 0, -2, -1, 2}, 123.753410, 0.000010, 53.052000},
	{{0, 15, -9, -8, 0, 0, 0, 0, -2, 1, 0}, 303.753410, 0.000010, 2.838000},
	{{0, 15, -9, -6, 0, 0, 0, 0, -1, -1, 1}, 118.587970, 0.000030, 108.145000},
	{{0, 15, -9, -4, 0, 0, 0, 0, -2, -1, 0}, 207.177360, 0.000070, 0.040000},
	{{0, 15, -9, -4, 0, 0, 0, 0, -2, 0, 0}, 216.914710, 0.000090, 0.087000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -3, 0}, 186.805970, 0.000020, 0.038000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -2, 0}, 184.307020, 0.000220, 0.075000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -1, -2}, 27.177360, 0.000010, 0.037000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -1, 0}, 207.177360, 0.006130, 2809.635000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -1, 2}, 27.177360, 0.000010, 0.037000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, 0, 0}, 189.147370, 0.000230, 0.075000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, 1, 0}, 186.805970, 0.000020, 0.038000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 2, -2, 0}, 216.914710, 0.000090, 0.087000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 2, -1, 0}, 207.177360, 0.000070, 0.040000},
	{{0, 15, -9, 0, -2, 0, 0, 0, 2, -1, -2}, 128.272400, 0.000010, 6.709000},
	{{0, 15, -9, 0, 0, -2, 0, 0, 2, -1, -2}, 308.136340, 0.000010, 20.689000},
	{{0, 15, -9, 0, 0, -1, 0, 0, 2, -1, -2}, 30.581340, 0.000010, 69.511000},
	{{0, 15, -6, -13, 0, 0, 0, 0, -2, 1, 0}, 116.907810, 0.000030, 92.724000},
	{{0, 15, -6, -11, 0, 0, 0, 0, -1, 1, -1}, 27.318380, 0.000080, 846.029000},
	{{0, 15, -5, -15, 0, 0, 0, 0, -2, 1, 0}, 122.901960, 0.000030, 13.486000},
	{{0, 16, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 32.546530, 0.000020, 0.075000},
	{{0, 16, -26, 0, 0, 0, 0, 0, 0, 1, 0}, 32.546530, 0.000020, 0.075000},
	{{0, 16, -22, 0, 0, 0, 0, 0, -2, -2, 0}, 47.946060, 0.000020, 0.021000},
	{{0, 16, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 47.946060, 0.000020, 0.048000},
	{{0, 16, -22, 0, 0, 0, 0, 0, 0, -1, 0}, 227.946060, 0.000020, 0.108000},
	{{0, 16, -22, 0, 0, 0, 0, 0, 0, 1, 0}, 227.946060, 0.000020, 0.058000},
	{{0, 16, -22, 0, 2, 0, 0, 0, -2, 0, 0}, 231.424000, 0.000020, 0.049000},
	{{0, 16, -22, 0, 2, 0, 0, 0, -2, 2, 0}, 231.424000, 0.000020, 0.168000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -4, 0, 0}, 324.053670, 0.000020, 0.022000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -4, 2, 0}, 324.053670, 0.000020, 0.056000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 166.989840, 0.000050, 0.051000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 203.586470, 0.000020, 0.147000},
	{{0, 16, -21, 0, 0, 0, 0, 0, 0, -2, 0}, 56.413130, 0.000010, 0.047000},
	{{0, 16, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 144.053670, 0.000020, 0.121000},
	{{0, 16, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 236.413130, 0.000010, 0.200000},
	{{0, 16, -21, 0, 1, 0, 0, 0, -2, 0, 0}, 230.211690, 0.000050, 0.051000},
	{{0, 16, -20, 0, -1, 0, 0, 0, -2, 0, 0}, 60.264110, 0.000020, 0.053000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -4, 1, 0}, 51.604590, 0.000020, 0.033000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, -3, 0}, 231.604590, 0.000010, 0.017000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, -1, 0}, 231.604590, 0.000030, 0.031000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 48.967700, 0.000020, 0.053000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 0, 2}, 231.604590, 0.000020, 0.123000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 53.193680, 0.000020, 0.183000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 51.744780, 0.000030, 0.128000},
	{{0, 16, -20, 0, 1, 0, 0, 0, -2, 0, 0}, 218.473430, 0.000010, 0.054000},
	{{0, 16, -20, 0, 1, 0, 0, 0, -2, 2, 0}, 38.473430, 0.000010, 0.127000},
	{{0, 16, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 134.493810, 0.000010, 0.224000},
	{{0, 16, -19, 0, 0, 0, 0, 0, -2, 3, 0}, 134.493810, 0.000010, 0.045000},
	{{0, 16, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 77.233910, 0.000020, 0.143000},
	{{0, 16, -19, 0, 0, 0, 0, 0, 2, -2, 0}, 79.889910, 0.000020, 0.191000},
	{{0, 16, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 259.403830, 0.000010, 0.032000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, -2, 0}, 217.177160, 0.000010, 0.023000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 342.581150, 0.000040, 0.060000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 17.350240, 0.000040, 0.288000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 9.276770, 0.000020, 0.102000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 350.843170, 0.000120, 0.125000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 175.575180, 0.000010, 0.047000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 168.182840, 0.000010, 0.144000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 356.092810, 0.000060, 0.051000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 176.017910, 0.000110, 0.031000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 2, 1, 0}, 176.087790, 0.000010, 0.022000},
	{{0, 16, -18, 0, 1, 0, 0, 0, -2, 0, 0}, 270.802020, 0.000010, 0.060000},
	{{0, 16, -18, 0, 1, 0, 0, 0, -2, 2, 0}, 90.802020, 0.000010, 0.101000},
	{{0, 16, -18, 6, 0, 0, 0, 0, -2, 1, 0}, 280.121440, 0.000030, 3.530000},
	{{0, 16, -17, 0, -1, 0, 0, 0, -2, 0, 0}, 104.830950, 0.000030, 0.063000},
	{{0, 16, -17, 0, -1, 0, 0, 0, -2, 1, 0}, 104.518440, 0.000010, 0.391000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 271.842490, 0.000030, 0.064000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 270.176110, 0.000030, 0.404000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 90.068260, 0.000020, 0.093000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 73.455730, 0.000020, 0.060000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 271.916880, 0.000050, 0.235000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 271.763650, 0.000290, 0.111000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, 1, 0}, 269.617720, 0.000020, 0.045000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 1, 0, -1}, 82.928380, 0.000040, 0.126000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 1, 0, 1}, 253.513920, 0.000010, 0.029000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 272.056560, 0.000160, 0.049000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 91.405050, 0.000250, 0.030000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, 1, 0}, 91.298010, 0.000030, 0.021000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 3, -2, 0}, 92.408760, 0.000010, 0.051000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 3, 0, 0}, 92.408760, 0.000010, 0.022000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 4, -2, 0}, 84.136040, 0.000010, 0.031000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 4, -1, 0}, 91.928590, 0.000030, 0.022000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 4, 0, 0}, 92.303090, 0.000030, 0.017000},
	{{0, 16, -17, 0, 1, 0, 0, 0, -2, 0, 0}, 198.134870, 0.000020, 0.064000},
	{{0, 16, -17, 2, 0, 0, 0, 0, -2, 0, 0}, 39.527920, 0.000010, 0.068000},
	{{0, 16, -17, 2, 0, 0, 0, 0, -2, 2, 0}, 39.527920, 0.000010, 0.084000},
	{{0, 16, -17, 6, 0, 0, 0, 0, -1, -1, 1}, 335.826870, 0.000020, 284.671000},
	{{0, 16, -17, 8, 0, 0, 0, 0, 0, -1, 0}, 225.659790, 0.000060, 164.206000},
	{{0, 16, -16, 0, -1, 0, 0, 0, -2, 0, 0}, 202.773300, 0.000060, 0.068000},
	{{0, 16, -16, 0, -1, 0, 0, 0, -2, 1, 0}, 199.303990, 0.000030, 0.642000},
	{{0, 16, -16, 0, 0, -1, 0, 0, -2, 1, 0}, 92.158050, 0.000010, 0.663000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -4, 2, 0}, 178.692760, 0.000020, 0.077000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 359.906910, 0.000020, 0.024000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 180.158150, 0.000030, 0.036000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 179.887420, 0.000370, 0.068000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 179.861790, 0.000420, 0.679000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 358.321200, 0.000070, 0.085000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -1, 0, 0}, 1.188030, 0.000050, 0.424000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 359.173520, 0.000050, 0.061000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 180.118920, 0.000220, 0.308000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 180.837260, 0.000860, 0.100000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 180.291250, 0.000130, 0.043000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 192.105390, 0.000020, 0.112000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 179.849690, 0.000340, 0.047000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 0, -2}, 179.853330, 0.000020, 0.127000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 359.860290, 0.000640, 0.029000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 359.852880, 0.000120, 0.021000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 3, 0}, 359.856800, 0.000010, 0.013000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 3, 0, 0}, 359.921820, 0.000020, 0.021000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 4, -2, 0}, 180.190230, 0.000010, 0.030000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 4, 0, 0}, 359.856490, 0.000020, 0.017000},
	{{0, 16, -16, 0, 0, 1, 0, 0, -2, 1, 0}, 87.352650, 0.000010, 0.695000},
	{{0, 16, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 347.666560, 0.000070, 0.068000},
	{{0, 16, -16, 2, 0, 0, 0, 0, -2, 1, 0}, 306.646700, 0.000020, 2.439000},
	{{0, 16, -16, 3, 0, 0, 0, 0, -2, 1, 0}, 180.346530, 0.000010, 8.218000},
	{{0, 16, -16, 6, 0, 0, 0, 0, 0, -1, 0}, 185.916870, 0.000010, 17.459000},
	{{0, 16, -15, -3, 0, 0, 0, 0, -2, 0, 0}, 302.956500, 0.000010, 0.065000},
	{{0, 16, -15, -3, 0, 0, 0, 0, -2, 1, 0}, 302.956500, 0.000020, 0.483000},
	{{0, 16, -15, -3, 0, 0, 0, 0, -2, 2, 0}, 302.956500, 0.000010, 0.089000},
	{{0, 16, -15, -2, 0, 0, 0, 0, -2, 0, 0}, 272.700010, 0.000020, 0.068000},
	{{0, 16, -15, -2, 0, 0, 0, 0, -2, 2, 0}, 272.700010, 0.000020, 0.085000},
	{{0, 16, -15, 0, -3, 0, 0, 0, -2, 1, 0}, 102.450690, 0.000020, 1.377000},
	{{0, 16, -15, 0, -2, 0, 0, 0, -2, 0, 0}, 105.243860, 0.000020, 0.072000},
	{{0, 16, -15, 0, -2, 0, 0, 0, -2, 1, 0}, 110.892130, 0.000040, 1.558000},
	{{0, 16, -15, 0, -2, 0, 0, 0, -2, 2, 0}, 105.243860, 0.000020, 0.079000},
	{{0, 16, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 178.304540, 0.000050, 0.072000},
	{{0, 16, -15, 0, -1, 0, 0, 0, -2, 1, 0}, 150.493240, 0.000020, 1.793000},
	{{0, 16, -15, 0, -1, 0, 0, 0, -2, 2, 0}, 178.305330, 0.000020, 0.079000},
	{{0, 16, -15, 0, -1, 0, 0, 0, 0, -2, 0}, 359.652110, 0.000010, 0.064000},
	{{0, 16, -15, 0, -1, 0, 0, 0, 0, -1, 0}, 181.195770, 0.000020, 0.429000},
	{{0, 16, -15, 0, -1, 0, 0, 0, 0, 0, 0}, 181.684490, 0.000040, 0.092000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 137.404380, 0.000050, 0.073000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 0, 1}, 103.017910, 0.000040, 3.262000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 100.329170, 0.000170, 2.113000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 245.443150, 0.000020, 0.078000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, -1, 1}, 283.552770, 0.000030, 0.838000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 103.049160, 0.000080, 0.068000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, 0, 1}, 291.466190, 0.000020, 0.083000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, 1, -1}, 103.074990, 0.000100, 0.655000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 261.908880, 0.000020, 0.091000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, -2, 1}, 283.146260, 0.000020, 0.097000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, -1, -1}, 103.144520, 0.000030, 0.303000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 103.162100, 0.000110, 0.100000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 2, -3, 0}, 84.786250, 0.000010, 0.249000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 94.273520, 0.000090, 0.028000},
	{{0, 16, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 38.431030, 0.000030, 0.073000},
	{{0, 16, -15, 0, 1, 0, 0, 0, -2, 1, 0}, 342.926420, 0.000040, 2.570000},
	{{0, 16, -15, 0, 1, 0, 0, 0, -2, 2, 0}, 250.707720, 0.000010, 0.078000},
	{{0, 16, -15, 0, 2, 0, 0, 0, -2, 1, 0}, 78.153640, 0.000030, 3.281000},
	{{0, 16, -15, 1, 0, 0, 0, 0, -2, 1, 0}, 202.317430, 0.000020, 17.148000},
	{{0, 16, -14, -3, 0, 0, 0, 0, -3, 1, 1}, 28.495130, 0.000020, 68.243000},
	{{0, 16, -14, -3, 0, 0, 0, 0, -2, 1, 0}, 328.652670, 0.000010, 0.936000},
	{{0, 16, -14, -2, 0, 0, 0, 0, -2, 1, 0}, 182.891130, 0.000030, 1.863000},
	{{0, 16, -14, -1, 0, 0, 0, 0, -4, 2, 0}, 265.336790, 0.000010, 0.087000},
	{{0, 16, -14, -1, 0, 0, 0, 0, -2, 0, 0}, 85.336790, 0.000060, 0.075000},
	{{0, 16, -14, -1, 0, 0, 0, 0, -2, 1, 0}, 187.277930, 0.000030, 197.991000},
	{{0, 16, -14, -1, 0, 0, 0, 0, -2, 2, 0}, 85.336790, 0.000060, 0.075000},
	{{0, 16, -14, -1, 0, 0, 0, 0, 0, 0, 0}, 265.336790, 0.000010, 0.087000},
	{{0, 16, -14, 0, -5, 0, 0, 0, -2, 1, 0}, 38.209820, 0.000020, 9.514000},
	{{0, 16, -14, 0, -3, 0, 0, 0, -2, 0, 0}, 223.096370, 0.000030, 0.077000},
	{{0, 16, -14, 0, -3, 0, 0, 0, -2, 1, 0}, 354.175890, 0.000040, 3.653000},
	{{0, 16, -14, 0, -3, 0, 0, 0, -2, 2, 0}, 237.575160, 0.000010, 0.074000},
	{{0, 16, -14, 0, -2, 0, 0, 0, -2, 0, 0}, 179.947190, 0.000020, 0.078000},
	{{0, 16, -14, 0, -2, 0, 0, 0, -2, 1, 0}, 343.183530, 0.000020, 2.793000},
	{{0, 16, -14, 0, -2, 0, 0, 0, -2, 2, 0}, 359.947190, 0.000020, 0.073000},
	{{0, 16, -14, 0, -2, 0, 0, 0, 0, 0, 0}, 359.697760, 0.000050, 0.084000},
	{{0, 16, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 61.847690, 0.000020, 0.078000},
	{{0, 16, -14, 0, -1, 0, 0, 0, -2, 1, 0}, 79.058520, 0.000040, 2.261000},
	{{0, 16, -14, 0, -1, 0, 0, 0, -2, 2, 0}, 94.667430, 0.000030, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -4, 2, 0}, 202.972310, 0.000010, 0.091000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 207.283570, 0.000010, 0.038000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 207.884690, 0.000300, 0.079000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 26.561710, 0.000640, 1.899000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 24.309700, 0.000090, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 3, 0}, 27.283570, 0.000010, 0.037000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, -1, 0}, 206.355620, 0.000020, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, -1, 1}, 166.855310, 0.000030, 5.165000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 206.355620, 0.000330, 2.775000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 1, -1}, 330.250410, 0.000020, 1.897000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 1, 0}, 206.355620, 0.000020, 0.078000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 8.822410, 0.000040, 0.069000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 26.617020, 0.000210, 0.802000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 28.062100, 0.000350, 0.083000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 2, -3, 0}, 345.429440, 0.000010, 0.331000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 251.343590, 0.000010, 0.043000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 214.614700, 0.000040, 0.027000},
	{{0, 16, -14, 0, 1, 0, 0, 0, -2, 1, 0}, 17.739140, 0.000020, 1.637000},
	{{0, 16, -14, 1, 0, 0, 0, 0, -1, 1, -1}, 327.526230, 0.000020, 219.684000},
	{{0, 16, -14, 2, 0, 0, 0, 0, 0, -1, 0}, 92.583970, 0.000010, 5.434000},
	{{0, 16, -13, -3, 0, 0, 0, 0, -2, 0, 0}, 191.203470, 0.000030, 0.075000},
	{{0, 16, -13, -3, 0, 0, 0, 0, -2, 2, 0}, 191.203470, 0.000030, 0.076000},
	{{0, 16, -13, -2, 0, 0, 0, 0, -2, 1, 0}, 25.248040, 0.000010, 2.159000},
	{{0, 16, -13, 0, -3, 0, 0, 0, -2, 1, 0}, 356.528770, 0.000010, 0.785000},
	{{0, 16, -13, 0, -2, 0, 0, 0, -1, 1, -1}, 283.255960, 0.000020, 3.287000},
	{{0, 16, -13, 0, -1, 0, 0, 0, -2, 1, 0}, 26.253120, 0.000010, 0.693000},
	{{0, 16, -13, 0, 0, 0, 0, 0, -1, 1, -1}, 309.444970, 0.000050, 2.115000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 221.412110, 0.000030, 0.074000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 247.532900, 0.000140, 4.042000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, 0, -1}, 129.461890, 0.000020, 2.415000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 235.782900, 0.000060, 0.077000},
	{{0, 16, -13, 0, 1, 0, 0, 0, 0, -1, 0}, 30.260290, 0.000030, 6.132000},
	{{0, 16, -13, 0, 2, 0, 0, 0, 0, -1, 0}, 167.605860, 0.000020, 12.695000},
	{{0, 16, -12, -5, 0, 0, 0, 0, -2, 1, 0}, 353.111100, 0.000030, 7.588000},
	{{0, 16, -12, -4, 0, 0, 0, 0, -2, 1, 0}, 10.214470, 0.000030, 2.501000},
	{{0, 16, -12, 0, -5, 0, 0, 0, 0, 1, -2}, 220.559110, 0.000030, 413.281000},
	{{0, 16, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 308.132230, 0.000010, 0.080000},
	{{0, 16, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 232.010010, 0.000020, 1.329000},
	{{0, 16, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 308.132230, 0.000010, 0.071000},
	{{0, 16, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 120.664210, 0.000010, 46.727000},
	{{0, 16, -8, -9, 0, 0, 0, 0, 0, -1, 0}, 124.591360, 0.000030, 30.730000},
	{{0, 17, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 44.633810, 0.000040, 0.050000},
	{{0, 17, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 228.345270, 0.000010, 0.116000},
	{{0, 17, -23, 0, 0, 0, 0, 0, 0, 1, 0}, 228.345270, 0.000010, 0.056000},
	{{0, 17, -23, 0, 2, 0, 0, 0, -2, 0, 0}, 231.393680, 0.000030, 0.050000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -4, 0, 0}, 324.046410, 0.000030, 0.023000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 218.654060, 0.000020, 0.052000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 297.113890, 0.000040, 0.135000},
	{{0, 17, -22, 0, 0, 0, 0, 0, 0, -2, 0}, 117.613530, 0.000020, 0.048000},
	{{0, 17, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 187.101770, 0.000020, 0.178000},
	{{0, 17, -22, 0, 1, 0, 0, 0, -2, 0, 0}, 230.473950, 0.000010, 0.053000},
	{{0, 17, -22, 0, 1, 0, 0, 0, -2, 2, 0}, 50.473950, 0.000010, 0.133000},
	{{0, 17, -22, 11, 0, 0, 0, 0, -2, 0, 0}, 39.349610, 0.000040, 0.075000},
	{{0, 17, -22, 11, 0, 0, 0, 0, -2, 1, 0}, 47.781670, 0.000810, 1463.573000},
	{{0, 17, -22, 11, 0, 0, 0, 0, -2, 2, 0}, 39.349610, 0.000040, 0.075000},
	{{0, 17, -21, 0, -1, 0, 0, 0, -2, 0, 0}, 60.233780, 0.000010, 0.055000},
	{{0, 17, -21, 0, -1, 0, 0, 0, -2, 2, 0}, 240.233780, 0.000010, 0.120000},
	{{0, 17, -21, 0, 0, 0, 0, 0, -2, -1, 0}, 231.573550, 0.000030, 0.032000},
	{{0, 17, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 53.462990, 0.000020, 0.206000},
	{{0, 17, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 51.573550, 0.000020, 0.055000},
	{{0, 17, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 73.546840, 0.000010, 0.131000},
	{{0, 17, -20, 7, 0, 0, 0, 0, -2, 1, 0}, 166.890970, 0.000010, 7.933000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 333.855070, 0.000040, 0.062000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 12.916280, 0.000030, 0.351000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 8.503310, 0.000020, 0.096000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 350.123480, 0.000020, 0.216000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 349.891680, 0.000100, 0.116000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 0, 1, 0}, 176.022360, 0.000010, 0.046000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 1, 0, -1}, 168.053320, 0.000010, 0.132000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 176.445610, 0.000100, 0.030000},
	{{0, 17, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 270.826350, 0.000020, 0.062000},
	{{0, 17, -19, 2, 0, 0, 0, 0, -2, 0, 0}, 179.050500, 0.000010, 0.066000},
	{{0, 17, -19, 2, 0, 0, 0, 0, -2, 2, 0}, 179.050500, 0.000010, 0.087000},
	{{0, 17, -19, 6, 0, 0, 0, 0, -2, 1, 0}, 280.267590, 0.000010, 2.922000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -4, 3, 0}, 276.834290, 0.000030, 13.546000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 271.608610, 0.000040, 0.066000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 272.200440, 0.000060, 0.541000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 90.216310, 0.000030, 0.088000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 89.898680, 0.000020, 0.059000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 271.764120, 0.000030, 0.276000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 272.169530, 0.000220, 0.104000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 93.553820, 0.000030, 0.044000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 73.040010, 0.000020, 0.117000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, -2, 0}, 272.296690, 0.000010, 0.127000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 272.033440, 0.000120, 0.047000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 92.165620, 0.000190, 0.029000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, 1, 0}, 92.237950, 0.000020, 0.021000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 4, -1, 0}, 92.296660, 0.000010, 0.022000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 4, 0, 0}, 92.296640, 0.000030, 0.017000},
	{{0, 17, -18, 0, 0, 2, 0, 0, -4, 3, 0}, 251.916020, 0.000010, 168.646000},
	{{0, 17, -18, 0, 1, 0, 0, 0, -2, 0, 0}, 191.036050, 0.000030, 0.067000},
	{{0, 17, -18, 0, 1, 0, 0, 0, -2, 1, 0}, 208.765860, 0.000030, 0.567000},
	{{0, 17, -18, 0, 2, 0, 0, 0, -2, 0, 0}, 232.508000, 0.000020, 0.067000},
	{{0, 17, -18, 3, 0, 0, 0, 0, -2, -1, 2}, 56.186790, 0.000010, 12.388000},
	{{0, 17, -17, 0, -1, 0, 0, 0, -2, 0, 0}, 199.695640, 0.000060, 0.070000},
	{{0, 17, -17, 0, -1, 0, 0, 0, -2, 1, 0}, 231.282880, 0.000020, 1.073000},
	{{0, 17, -17, 0, 0, -1, 0, 0, -2, 0, 0}, 92.131480, 0.000010, 0.071000},
	{{0, 17, -17, 0, 0, -1, 0, 0, -2, 1, 0}, 92.023030, 0.000020, 1.134000},
	{{0, 17, -17, 0, 0, -1, 0, 0, -2, 2, 0}, 272.131480, 0.000010, 0.081000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -4, 1, 0}, 180.044740, 0.000010, 0.039000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -4, 2, 0}, 179.820540, 0.000020, 0.081000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -3, 2, 0}, 0.241490, 0.000330, 25.533000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -3, 3, 0}, 3.763420, 0.000020, 0.075000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, -2, 0}, 359.884250, 0.000010, 0.025000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 179.932430, 0.000040, 0.037000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 179.716400, 0.000560, 0.071000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 180.049820, 0.000900, 1.179000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 359.433940, 0.000030, 0.081000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -1, 0, 0}, 359.639790, 0.000060, 0.576000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -1, 1, -1}, 193.580810, 0.000020, 0.526000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 0.620820, 0.000030, 0.063000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 179.940070, 0.000250, 0.381000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 180.894290, 0.000650, 0.094000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, 1, 0}, 180.001230, 0.000110, 0.042000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 1, 0, -1}, 192.180180, 0.000020, 0.104000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 179.715790, 0.000240, 0.045000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, 0, -2}, 179.822210, 0.000010, 0.117000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 359.827540, 0.000450, 0.028000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, 1, 0}, 359.822620, 0.000100, 0.021000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 3, 0, 0}, 359.894790, 0.000020, 0.021000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 4, -2, 0}, 359.801810, 0.000020, 0.030000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 4, 0, 0}, 359.820590, 0.000040, 0.017000},
	{{0, 17, -17, 0, 0, 1, 0, 0, -2, 0, 0}, 87.326070, 0.000020, 0.071000},
	{{0, 17, -17, 0, 1, 0, 0, 0, -2, 0, 0}, 347.224340, 0.000060, 0.071000},
	{{0, 17, -17, 0, 1, 0, 0, 0, -2, 1, 0}, 76.046590, 0.000010, 1.310000},
	{{0, 17, -17, 0, 1, 0, 0, 0, -2, 2, 0}, 347.802980, 0.000030, 0.080000},
	{{0, 17, -17, 0, 2, 0, 0, 0, -2, 1, 0}, 162.842610, 0.000010, 1.472000},
	{{0, 17, -17, 2, 0, 0, 0, 0, -2, 1, 0}, 350.827160, 0.000030, 4.640000},
	{{0, 17, -17, 3, 0, 0, 0, 0, -1, -1, 1}, 337.904200, 0.000020, 37.096000},
	{{0, 17, -16, -3, 0, 0, 0, 0, -2, 1, 0}, 304.064470, 0.000030, 0.693000},
	{{0, 17, -16, -2, 0, 0, 0, 0, -2, 0, 0}, 122.136170, 0.000020, 0.071000},
	{{0, 17, -16, -2, 0, 0, 0, 0, -2, 1, 0}, 109.908730, 0.000030, 1.097000},
	{{0, 17, -16, -2, 0, 0, 0, 0, -2, 2, 0}, 122.136170, 0.000020, 0.081000},
	{{0, 17, -16, 0, -4, 0, 0, 0, -2, 1, 0}, 139.898450, 0.000020, 5.404000},
	{{0, 17, -16, 0, -3, 0, 0, 0, -2, 1, 0}, 130.197190, 0.000030, 9.925000},
	{{0, 17, -16, 0, -2, 0, 0, 0, -2, 0, 0}, 37.682600, 0.000030, 0.075000},
	{{0, 17, -16, 0, -2, 0, 0, 0, -2, 1, 0}, 351.856580, 0.000010, 60.783000},
	{{0, 17, -16, 0, -2, 0, 0, 0, -2, 2, 0}, 91.578270, 0.000010, 0.076000},
	{{0, 17, -16, 0, -1, 0, 0, 0, -2, 0, 0}, 63.325300, 0.000030, 0.076000},
	{{0, 17, -16, 0, -1, 0, 0, 0, -2, 1, 0}, 16.895320, 0.000050, 14.738000},
	{{0, 17, -16, 0, -1, 0, 0, 0, -2, 2, 0}, 243.325300, 0.000030, 0.075000},
	{{0, 17, -16, 0, -1, 0, 0, 0, 0, -1, 0}, 181.378090, 0.000030, 0.586000},
	{{0, 17, -16, 0, -1, 0, 0, 0, 0, 0, 0}, 181.273270, 0.000050, 0.087000},
	{{0, 17, -16, 0, 0, -5, 0, 0, -2, 1, 0}, 12.598780, 0.000010, 56.870000},
	{{0, 17, -16, 0, 0, -4, 0, 0, -2, 1, 0}, 279.568290, 0.000020, 61.111000},
	{{0, 17, -16, 0, 0, -3, 0, 0, -2, 1, 0}, 194.866600, 0.000040, 19.876000},
	{{0, 17, -16, 0, 0, -2, 0, 0, -2, 0, 0}, 273.800640, 0.000010, 0.076000},
	{{0, 17, -16, 0, 0, -2, 0, 0, -2, 1, 0}, 108.062300, 0.000080, 11.868000},
	{{0, 17, -16, 0, 0, -2, 0, 0, -2, 2, 0}, 93.800640, 0.000010, 0.075000},
	{{0, 17, -16, 0, 0, -1, 0, 0, -2, 1, 0}, 171.927370, 0.000030, 8.460000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -4, 1, 0}, 96.977580, 0.000010, 0.041000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 282.378140, 0.000070, 0.076000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 0, 1}, 102.984980, 0.000030, 3.136000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 1, -1}, 283.025690, 0.000050, 0.075000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 96.977580, 0.001280, 6.572000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 2, -1}, 283.048470, 0.000740, 68.493000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 95.753010, 0.000120, 0.075000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 3, -1}, 283.025690, 0.000050, 0.076000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, -1, 1}, 282.972760, 0.000080, 1.760000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 102.903800, 0.000160, 0.071000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 0, 0}, 275.001130, 0.000010, 1.361000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 0, 1}, 283.016420, 0.000060, 0.079000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 1, -1}, 103.042670, 0.000200, 1.109000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 2, -1}, 103.043440, 0.000010, 0.081000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 0, 0, -1}, 283.086760, 0.000010, 0.559000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 154.423210, 0.000010, 0.086000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 96.977580, 0.000010, 0.040000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 1, -1, -1}, 103.499990, 0.000040, 0.374000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 103.143460, 0.000080, 0.095000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 1, 0, 1}, 283.115560, 0.000020, 0.027000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 94.518980, 0.000070, 0.027000},
	{{0, 17, -16, 0, 0, 1, 0, 0, -2, 1, 0}, 352.436750, 0.000030, 5.373000},
	{{0, 17, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 240.457290, 0.000010, 0.077000},
	{{0, 17, -16, 0, 1, 0, 0, 0, -2, 1, 0}, 306.858750, 0.000020, 4.229000},
	{{0, 17, -16, 0, 1, 0, 0, 0, -2, 2, 0}, 240.457290, 0.000010, 0.074000},
	{{0, 17, -16, 3, 0, 0, 0, 0, 0, -1, 0}, 242.036020, 0.000050, 37.303000},
	{{0, 17, -15, -3, 0, 0, 0, 0, -2, 0, 0}, 328.793010, 0.000020, 0.073000},
	{{0, 17, -15, -3, 0, 0, 0, 0, -2, 1, 0}, 67.663960, 0.000020, 2.258000},
	{{0, 17, -15, -3, 0, 0, 0, 0, -2, 2, 0}, 328.793010, 0.000020, 0.078000},
	{{0, 17, -15, -2, 0, 0, 0, 0, -2, 0, 0}, 2.887090, 0.000040, 0.076000},
	{{0, 17, -15, -2, 0, 0, 0, 0, -2, 1, 0}, 345.360110, 0.000010, 11.263000},
	{{0, 17, -15, -2, 0, 0, 0, 0, -2, 2, 0}, 2.887090, 0.000040, 0.075000},
	{{0, 17, -15, 0, -3, 0, 0, 0, -2, 0, 0}, 189.819970, 0.000010, 0.081000},
	{{0, 17, -15, 0, -3, 0, 0, 0, -2, 2, 0}, 9.819970, 0.000010, 0.071000},
	{{0, 17, -15, 0, -3, 0, 0, 0, -1, 0, 0}, 39.335630, 0.000010, 81.736000},
	{{0, 17, -15, 0, -2, 0, 0, 0, -2, 0, 0}, 180.151280, 0.000020, 0.081000},
	{{0, 17, -15, 0, -2, 0, 0, 0, -2, 1, 0}, 0.217290, 0.000020, 1.017000},
	{{0, 17, -15, 0, -2, 0, 0, 0, -2, 2, 0}, 180.151280, 0.000020, 0.070000},
	{{0, 17, -15, 0, -2, 0, 0, 0, -1, 0, 0}, 180.509770, 0.000020, 10.359000},
	{{0, 17, -15, 0, -2, 0, 0, 0, 0, -2, 0}, 0.846940, 0.000010, 0.071000},
	{{0, 17, -15, 0, -2, 0, 0, 0, 0, 0, 0}, 0.308740, 0.000020, 0.080000},
	{{0, 17, -15, 0, -1, 0, 0, 0, -1, 1, -1}, 112.740400, 0.000020, 70.990000},
	{{0, 17, -15, 0, 0, -3, 0, 0, -1, 1, -1}, 96.927560, 0.000030, 289.567000},
	{{0, 17, -15, 0, 0, -2, 0, 0, -2, 1, 0}, 179.836750, 0.000010, 0.922000},
	{{0, 17, -15, 0, 0, -2, 0, 0, -1, 1, -1}, 15.841090, 0.000050, 32.793000},
	{{0, 17, -15, 0, 0, -1, 0, 0, -1, 1, -1}, 102.908250, 0.000030, 15.518000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 204.964850, 0.000160, 0.083000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 26.156340, 0.000090, 0.868000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 18.027070, 0.000020, 0.069000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, -1, 0}, 206.359800, 0.000020, 0.077000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 320.290310, 0.000020, 0.076000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 0, 0}, 206.359800, 0.000420, 3.772000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 1, -1}, 320.290310, 0.000300, 10.164000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 1, 0}, 206.359800, 0.000020, 0.074000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 2, -1}, 320.290310, 0.000020, 0.075000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 30.366220, 0.000060, 0.072000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 26.705870, 0.000670, 1.608000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 27.502770, 0.000470, 0.079000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 27.906640, 0.000030, 0.039000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 205.691130, 0.000010, 0.041000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 205.692640, 0.000030, 0.027000},
	{{0, 17, -14, -5, 0, 0, 0, 0, -2, 1, 0}, 74.439340, 0.000010, 1.975000},
	{{0, 17, -14, -4, 0, 0, 0, 0, -4, 2, 0}, 150.365720, 0.000010, 0.087000},
	{{0, 17, -14, -4, 0, 0, 0, 0, -2, 0, 0}, 330.365720, 0.000050, 0.076000},
	{{0, 17, -14, -4, 0, 0, 0, 0, -2, 1, 0}, 159.439540, 0.000030, 39.340000},
	{{0, 17, -14, -4, 0, 0, 0, 0, -2, 2, 0}, 330.365720, 0.000050, 0.075000},
	{{0, 17, -14, -4, 0, 0, 0, 0, 0, 0, 0}, 150.365720, 0.000010, 0.087000},
	{{0, 17, -14, -2, 0, 0, 0, 0, -1, 1, -1}, 248.822960, 0.000020, 28.554000},
	{{0, 17, -14, 0, -5, 0, 0, 0, 0, -1, 0}, 184.370190, 0.000030, 23.051000},
	{{0, 17, -14, 0, -4, 0, 0, 0, 0, -2, 0}, 7.583470, 0.000010, 0.076000},
	{{0, 17, -14, 0, -4, 0, 0, 0, 0, -1, 0}, 174.165100, 0.000030, 24.437000},
	{{0, 17, -14, 0, -4, 0, 0, 0, 0, 0, 0}, 187.583470, 0.000010, 0.075000},
	{{0, 17, -14, 0, -3, 0, 0, 0, 0, -2, 0}, 178.060810, 0.000010, 0.076000},
	{{0, 17, -14, 0, -3, 0, 0, 0, 0, -1, 0}, 245.411010, 0.000030, 7.986000},
	{{0, 17, -14, 0, -3, 0, 0, 0, 0, 0, 0}, 177.387200, 0.000040, 0.075000},
	{{0, 17, -14, 0, -2, 0, 0, 0, 0, -1, 0}, 286.155250, 0.000060, 4.773000},
	{{0, 17, -14, 0, -1, 0, 0, 0, 0, -1, 0}, 244.683420, 0.000010, 3.403000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 250.212320, 0.000040, 2.645000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 0, 0, -1}, 130.463900, 0.000050, 4.731000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 63.147140, 0.000020, 0.073000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 0, 1, -2}, 205.545340, 0.000030, 22.409000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 1, -1, -1}, 310.302480, 0.000020, 1.480000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 219.713450, 0.000020, 0.084000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 219.713450, 0.000020, 0.026000},
	{{0, 17, -13, -6, 0, 0, 0, 0, -2, 1, 0}, 256.749180, 0.000050, 26.352000},
	{{0, 17, -13, -4, 0, 0, 0, 0, -1, 1, -1}, 64.796360, 0.000020, 35.279000},
	{{0, 17, -13, 0, -4, 0, 0, 0, 1, -1, -1}, 285.402760, 0.000030, 77.860000},
	{{0, 17, -12, -7, 0, 0, 0, 0, -2, 1, 0}, 302.839740, 0.000020, 2.324000},
	{{0, 17, -12, 0, -3, 0, 0, 0, 2, -1, -2}, 253.642660, 0.000020, 56.514000},
	{{0, 17, -8, -12, 0, 0, 0, 0, 0, -1, 0}, 335.144700, 0.000080, 482.725000},
	{{0, 17, -5, -19, 0, 0, 0, 0, -1, 1, -1}, 230.619900, 0.000030, 277.048000},
	{{0, 18, -27, 17, 0, 0, 0, 0, -2, 1, 0}, 231.880640, 0.000010, 5.444000},
	{{0, 18, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 48.708410, 0.000020, 0.051000},
	{{0, 18, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 228.708410, 0.000020, 0.161000},
	{{0, 18, -24, 0, 0, 0, 0, 0, -2, 3, 0}, 228.708410, 0.000020, 0.049000},
	{{0, 18, -24, 0, 2, 0, 0, 0, -2, 0, 0}, 231.361540, 0.000020, 0.052000},
	{{0, 18, -24, 15, 0, 0, 0, 0, 0, -1, 0}, 43.502310, 0.000010, 47.453000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -4, 0, 0}, 324.037580, 0.000020, 0.023000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 216.798480, 0.000030, 0.054000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 287.203230, 0.000010, 0.191000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 235.925880, 0.000040, 0.124000},
	{{0, 18, -23, 0, 0, 0, 0, 0, 0, -2, 0}, 55.521440, 0.000010, 0.049000},
	{{0, 18, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 159.492980, 0.000030, 0.160000},
	{{0, 18, -23, 9, 0, 0, 0, 0, -2, 1, 0}, 296.251040, 0.000010, 2.288000},
	{{0, 18, -22, 0, 0, 0, 0, 0, -2, -1, 0}, 231.540300, 0.000020, 0.033000},
	{{0, 18, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 237.473220, 0.000010, 0.057000},
	{{0, 18, -22, 8, 0, 0, 0, 0, -2, 1, 0}, 127.213320, 0.000050, 32.099000},
	{{0, 18, -21, 0, 0, 0, 0, 0, -2, -2, 0}, 325.769180, 0.000010, 0.023000},
	{{0, 18, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 325.769180, 0.000010, 0.061000},
	{{0, 18, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 145.769180, 0.000020, 0.310000},
	{{0, 18, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 74.882430, 0.000010, 0.121000},
	{{0, 18, -21, 6, 0, 0, 0, 0, -2, 1, 0}, 75.598690, 0.000060, 31.042000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 348.505270, 0.000040, 0.065000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 13.952890, 0.000010, 0.450000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 352.317470, 0.000030, 0.091000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 350.646830, 0.000020, 0.250000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 352.370020, 0.000110, 0.108000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 0, 2, 0}, 356.960690, 0.000010, 0.028000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 176.832130, 0.000090, 0.029000},
	{{0, 18, -20, 0, 1, 0, 0, 0, -2, 0, 0}, 270.847160, 0.000010, 0.065000},
	{{0, 18, -20, 0, 1, 0, 0, 0, -2, 1, 0}, 270.847160, 0.000010, 0.468000},
	{{0, 18, -20, 0, 1, 0, 0, 0, -2, 2, 0}, 270.847160, 0.000010, 0.090000},
	{{0, 18, -20, 2, 0, 0, 0, 0, -2, 0, 0}, 177.501390, 0.000020, 0.069000},
	{{0, 18, -20, 2, 0, 0, 0, 0, -2, 1, 0}, 178.082690, 0.000030, 0.863000},
	{{0, 18, -20, 2, 0, 0, 0, 0, -2, 2, 0}, 177.501390, 0.000020, 0.083000},
	{{0, 18, -20, 3, 0, 0, 0, 0, -2, 1, 0}, 330.382350, 0.000030, 1.594000},
	{{0, 18, -20, 4, 0, 0, 0, 0, -2, 0, 0}, 57.036080, 0.000010, 0.075000},
	{{0, 18, -20, 4, 0, 0, 0, 0, -2, 1, 0}, 100.514360, 0.000030, 10.462000},
	{{0, 18, -20, 4, 0, 0, 0, 0, -2, 2, 0}, 57.036080, 0.000010, 0.076000},
	{{0, 18, -19, 0, -1, 0, 0, 0, -2, 1, 0}, 344.347950, 0.000020, 0.765000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -5, 0, 2}, 270.038120, 0.000020, 0.040000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -5, 1, 2}, 270.038120, 0.000020, 0.087000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -4, 2, 0}, 271.788640, 0.000010, 0.079000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, -1, 2}, 270.038120, 0.000090, 0.075000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 0, 2}, 270.038120, 0.001580, 556.277000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 1, 2}, 270.038120, 0.000090, 0.075000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 271.297770, 0.000060, 0.069000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 271.232900, 0.000110, 0.818000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 91.790070, 0.000070, 0.083000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -1, -1, 2}, 270.038120, 0.000020, 0.087000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -1, 0, 2}, 270.038120, 0.000020, 0.040000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 0, -2, 0}, 89.926440, 0.000020, 0.062000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 273.170010, 0.000030, 0.334000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 271.667760, 0.000160, 0.097000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 0, 1, 0}, 93.694430, 0.000020, 0.043000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 1, 0, -1}, 67.749310, 0.000020, 0.109000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, -2, 0}, 314.322800, 0.000010, 0.118000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, -1, 0}, 284.055360, 0.000100, 0.046000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 92.157930, 0.000150, 0.029000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, 1, 0}, 92.230980, 0.000020, 0.021000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 4, -1, 0}, 92.287820, 0.000010, 0.022000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 4, 0, 0}, 92.287810, 0.000020, 0.017000},
	{{0, 18, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 209.728650, 0.000060, 0.069000},
	{{0, 18, -19, 0, 1, 0, 0, 0, -2, 1, 0}, 132.854970, 0.000040, 0.879000},
	{{0, 18, -19, 2, 0, 0, 0, 0, -2, 0, 0}, 38.558960, 0.000020, 0.075000},
	{{0, 18, -19, 2, 0, 0, 0, 0, -2, 1, 0}, 118.050570, 0.000010, 6.291000},
	{{0, 18, -19, 2, 0, 0, 0, 0, -2, 2, 0}, 38.558960, 0.000020, 0.076000},
	{{0, 18, -19, 3, 0, 0, 0, 0, -2, 0, 0}, 56.145400, 0.000030, 0.078000},
	{{0, 18, -19, 3, 0, 0, 0, 0, -2, 1, 0}, 56.221840, 0.000020, 2.683000},
	{{0, 18, -19, 3, 0, 0, 0, 0, -2, 2, 0}, 56.145400, 0.000030, 0.073000},
	{{0, 18, -18, 0, -2, 0, 0, 0, -2, 1, 0}, 193.776660, 0.000040, 2.558000},
	{{0, 18, -18, 0, -1, 0, 0, 0, -2, -1, 2}, 92.640630, 0.000010, 37.190000},
	{{0, 18, -18, 0, -1, 0, 0, 0, -2, 0, 0}, 232.475550, 0.000050, 0.074000},
	{{0, 18, -18, 0, -1, 0, 0, 0, -2, 1, 0}, 265.151800, 0.000010, 3.261000},
	{{0, 18, -18, 0, 0, -1, 0, 0, -2, 1, 0}, 271.320560, 0.000030, 3.902000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -4, 0, 0}, 179.888100, 0.000010, 0.026000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -4, 1, 0}, 179.959240, 0.000130, 0.040000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -4, 2, 0}, 180.293100, 0.000100, 0.085000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, -1, 0}, 176.492980, 0.000160, 0.037000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, -1, 1}, 195.188540, 0.000010, 0.075000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, -1, 2}, 359.901900, 0.000120, 8.993000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 178.350560, 0.002330, 0.074000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 1}, 195.188540, 0.000260, 17.998000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, -2}, 359.888100, 0.000020, 0.037000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 179.888260, 0.009330, 4.498000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, 1}, 195.188540, 0.000010, 0.076000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, 2}, 359.888100, 0.000020, 0.038000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 179.543130, 0.000550, 0.077000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 3, 0}, 179.544100, 0.000040, 0.038000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -1, 0, -1}, 210.768570, 0.000020, 0.069000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -1, 0, 0}, 359.512260, 0.000100, 0.901000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -1, 1, -1}, 193.552910, 0.000030, 0.784000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 41.002590, 0.000050, 0.066000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 179.775210, 0.000270, 0.501000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 189.718810, 0.000470, 0.089000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 183.273280, 0.000180, 0.041000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 2, 0}, 179.870060, 0.000020, 0.026000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 192.245820, 0.000010, 0.098000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, -2, 0}, 230.119580, 0.000260, 0.105000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 221.648170, 0.000660, 0.044000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 348.193500, 0.000310, 0.028000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, 1, 0}, 354.147830, 0.000070, 0.020000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, 3, 0}, 359.788890, 0.000010, 0.013000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 3, 0, 0}, 359.862680, 0.000020, 0.021000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 4, -3, 0}, 232.856040, 0.000010, 0.048000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 4, -2, 0}, 233.879750, 0.000030, 0.029000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 4, -1, 0}, 237.671220, 0.000020, 0.021000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 4, 0, 0}, 359.785720, 0.000030, 0.016000},
	{{0, 18, -18, 0, 0, 1, 0, 0, -2, 0, 0}, 266.902740, 0.000010, 0.074000},
	{{0, 18, -18, 0, 0, 1, 0, 0, -2, 2, 0}, 86.902740, 0.000010, 0.077000},
	{{0, 18, -18, 0, 1, 0, 0, 0, -2, 0, 0}, 66.834020, 0.000010, 0.075000},
	{{0, 18, -18, 0, 1, 0, 0, 0, -2, 1, 0}, 32.638620, 0.000030, 7.246000},
	{{0, 18, -18, 0, 1, 0, 0, 0, -2, 2, 0}, 66.834020, 0.000010, 0.076000},
	{{0, 18, -18, 0, 2, 0, 0, 0, -2, 0, 0}, 9.689710, 0.000020, 0.075000},
	{{0, 18, -18, 0, 2, 0, 0, 0, -2, 1, 0}, 58.644260, 0.000050, 18.618000},
	{{0, 18, -18, 0, 2, 0, 0, 0, -2, 2, 0}, 189.689710, 0.000020, 0.076000},
	{{0, 18, -18, 0, 3, 0, 0, 0, -2, 1, 0}, 81.103560, 0.000040, 32.688000},
	{{0, 18, -17, -3, 0, 0, 0, 0, -2, 0, 0}, 307.337650, 0.000020, 0.071000},
	{{0, 18, -17, -3, 0, 0, 0, 0, -2, 2, 0}, 307.337650, 0.000020, 0.080000},
	{{0, 18, -17, -2, 0, 0, 0, 0, -2, -1, 2}, 300.975970, 0.000040, 20.910000},
	{{0, 18, -17, -2, 0, 0, 0, 0, -2, 0, 0}, 109.590900, 0.000030, 0.074000},
	{{0, 18, -17, -2, 0, 0, 0, 0, -2, 1, 0}, 247.348390, 0.000020, 3.500000},
	{{0, 18, -17, -2, 0, 0, 0, 0, -2, 2, 0}, 109.590900, 0.000030, 0.077000},
	{{0, 18, -17, 0, -3, 0, 0, 0, -2, 1, 0}, 120.811260, 0.000020, 1.906000},
	{{0, 18, -17, 0, -2, 0, 0, 0, -2, 0, 0}, 278.461170, 0.000010, 0.079000},
	{{0, 18, -17, 0, -2, 0, 0, 0, -2, 1, 0}, 109.594620, 0.000030, 1.642000},
	{{0, 18, -17, 0, -2, 0, 0, 0, -2, 2, 0}, 278.461170, 0.000010, 0.072000},
	{{0, 18, -17, 0, -1, 0, 0, 0, -2, 0, 0}, 358.223610, 0.000020, 0.080000},
	{{0, 18, -17, 0, -1, 0, 0, 0, -2, 1, 0}, 179.190900, 0.000060, 1.442000},
	{{0, 18, -17, 0, -1, 0, 0, 0, -2, 2, 0}, 358.223610, 0.000020, 0.072000},
	{{0, 18, -17, 0, -1, 0, 0, 0, -1, -1, 1}, 148.190890, 0.000020, 37.208000},
	{{0, 18, -17, 0, -1, 0, 0, 0, 0, 0, 0}, 181.287200, 0.000080, 0.082000},
	{{0, 18, -17, 0, 0, -2, 0, 0, -1, -1, 1}, 296.740530, 0.000050, 95.528000},
	{{0, 18, -17, 0, 0, -1, 0, 0, -2, 1, 0}, 179.867980, 0.000010, 1.345000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -4, -1, 0}, 309.479540, 0.000040, 0.020000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -4, 0, 0}, 309.479540, 0.000070, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -4, 1, 0}, 309.479540, 0.000020, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, -1, 0}, 129.479540, 0.000020, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, -1, 1}, 283.019560, 0.000060, 0.041000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, 0, 0}, 129.479540, 0.000020, 0.040000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, 0, 1}, 282.976780, 0.000120, 0.088000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, 1, -1}, 102.949810, 0.000020, 0.040000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, 2, -1}, 102.949870, 0.000020, 0.085000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -3, 0}, 309.479540, 0.000040, 0.019000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -2, 0}, 309.479540, 0.000300, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 309.479380, 0.001690, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 310.912510, 0.001010, 0.080000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 108.418340, 0.000040, 1.286000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -3, 1}, 283.019310, 0.000020, 0.038000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, 0}, 129.479540, 0.000090, 0.038000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, 1}, 283.019280, 0.000310, 0.076000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, -1}, 103.011260, 0.000040, 0.037000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 0}, 130.431480, 0.000600, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 1}, 283.019560, 0.005470, 17.413000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 3}, 103.019560, 0.000010, 0.037000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 102.997650, 0.000470, 0.074000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 0}, 286.163300, 0.000460, 9.147000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 1}, 284.768100, 0.000010, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 1, -1}, 102.949810, 0.001520, 3.622000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 1, 0}, 293.694130, 0.000040, 0.076000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 2, -1}, 102.949780, 0.000080, 0.077000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -4, 0}, 309.479540, 0.000060, 0.025000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -3, 0}, 309.480160, 0.000530, 0.036000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -2, -2}, 129.479540, 0.000030, 0.024000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 309.561960, 0.003800, 0.070000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -1, -2}, 129.479540, 0.000030, 0.036000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 292.424250, 0.000040, 1.004000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 0, -1}, 283.713120, 0.000020, 0.860000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 129.686950, 0.004780, 0.082000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 0, 2}, 309.479540, 0.000030, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 1, 0}, 129.482520, 0.000630, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 2, 0}, 129.479540, 0.000070, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -2, 1}, 283.019860, 0.000060, 0.087000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -1, -1}, 103.505770, 0.000050, 0.488000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -1, 0}, 309.479540, 0.000020, 0.088000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -1, 1}, 283.019560, 0.000060, 0.040000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, 0, -1}, 103.162430, 0.000040, 0.089000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, 0, 1}, 283.082470, 0.000010, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, 1, -1}, 102.949810, 0.000020, 0.041000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -4, 0}, 309.479540, 0.000020, 0.062000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 129.480080, 0.007040, 0.095000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -2, 2}, 309.479540, 0.000040, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 129.414970, 0.011370, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, 2}, 309.479540, 0.000050, 0.020000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, -2}, 309.479540, 0.000010, 0.099000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 128.248010, 0.001520, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, 2}, 309.479540, 0.000010, 0.016000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 1, 0}, 129.479540, 0.000160, 0.020000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 2, 0}, 129.479540, 0.000020, 0.016000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 3, -2, 0}, 309.479540, 0.000020, 0.044000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -3, 0}, 129.479540, 0.000190, 0.046000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -2, 0}, 129.475620, 0.000450, 0.028000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -1, 0}, 129.479540, 0.000260, 0.021000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, 0, 0}, 129.479540, 0.000050, 0.016000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 6, -3, 0}, 129.479540, 0.000010, 0.021000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 6, -2, 0}, 129.479540, 0.000010, 0.017000},
	{{0, 18, -17, 0, 1, 0, 0, 0, -1, 0, 0}, 222.203960, 0.000080, 39.962000},
	{{0, 18, -17, 2, 0, 0, 0, 0, 0, -1, 0}, 239.831120, 0.000040, 14.919000},
	{{0, 18, -16, -3, 0, 0, 0, 0, -2, 0, 0}, 149.783810, 0.000020, 0.076000},
	{{0, 18, -16, -3, 0, 0, 0, 0, -2, 1, 0}, 203.454740, 0.000030, 5.476000},
	{{0, 18, -16, -3, 0, 0, 0, 0, -2, 2, 0}, 149.783810, 0.000020, 0.074000},
	{{0, 18, -16, -2, 0, 0, 0, 0, -1, -1, 1}, 168.391460, 0.000050, 168.341000},
	{{0, 18, -16, -2, 0, 0, 0, 0, 0, -2, 0}, 179.675380, 0.000010, 0.070000},
	{{0, 18, -16, -2, 0, 0, 0, 0, 0, -1, 0}, 179.624220, 0.000030, 0.944000},
	{{0, 18, -16, -2, 0, 0, 0, 0, 0, 0, 0}, 179.675380, 0.000010, 0.082000},
	{{0, 18, -16, 0, -3, 0, 0, 0, -2, 1, 0}, 191.335830, 0.000020, 0.656000},
	{{0, 18, -16, 0, -3, 0, 0, 0, 0, -2, 0}, 189.598940, 0.000020, 0.074000},
	{{0, 18, -16, 0, -3, 0, 0, 0, 0, -1, 0}, 66.833160, 0.000020, 4.012000},
	{{0, 18, -16, 0, -3, 0, 0, 0, 0, 0, 0}, 9.598940, 0.000020, 0.077000},
	{{0, 18, -16, 0, -2, 0, 0, 0, -2, 0, 0}, 179.968490, 0.000030, 0.086000},
	{{0, 18, -16, 0, -2, 0, 0, 0, -2, 2, 0}, 179.968490, 0.000030, 0.067000},
	{{0, 18, -16, 0, -2, 0, 0, 0, 0, -1, 0}, 357.070840, 0.000040, 6.063000},
	{{0, 18, -16, 0, -2, 0, 0, 0, 0, 0, 0}, 168.825040, 0.000030, 0.076000},
	{{0, 18, -16, 0, -1, 0, 0, 0, 0, -1, 0}, 47.037900, 0.000060, 12.401000},
	{{0, 18, -16, 0, 0, -2, 0, 0, 0, -1, 0}, 177.475270, 0.000020, 15.568000},
	{{0, 18, -16, 0, 0, -1, 0, 0, 0, -1, 0}, 135.362820, 0.000040, 33.019000},
	{{0, 18, -16, 0, 0, 0, -1, 0, 0, -1, 0}, 348.755120, 0.000030, 121.368000},
	{{0, 18, -16, 0, 0, 0, 0, -1, 0, -1, 0}, 182.408390, 0.000010, 415.528000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, -1, 0}, 26.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 0, 0}, 26.542610, 0.000070, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 1, 0}, 26.542610, 0.000080, 0.021000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 2, 0}, 26.542610, 0.000030, 0.029000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -3, 0}, 26.542610, 0.000050, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -2, 0}, 26.542610, 0.000340, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, -2}, 206.542610, 0.000020, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, 0}, 26.542380, 0.001930, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, -2}, 206.542610, 0.000030, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, 0}, 26.541610, 0.004060, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, 2}, 26.542610, 0.000010, 0.107000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 1, -2}, 206.542610, 0.000020, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 1, 0}, 26.539920, 0.002240, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 2, 0}, 26.542610, 0.000040, 0.103000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, -1, 0}, 26.542610, 0.000040, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, 0, 0}, 206.542610, 0.000220, 0.042000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, 1, 0}, 206.542610, 0.000040, 0.094000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -5, 0}, 26.542610, 0.000020, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -4, 0}, 26.542610, 0.000180, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, -2}, 206.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, 0}, 26.542870, 0.002000, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, 2}, 206.542610, 0.000030, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, -2}, 206.542610, 0.000170, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 26.542740, 0.019990, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 2}, 206.542610, 0.000220, 0.090000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, -2}, 206.542610, 0.000790, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 26.542230, 0.164400, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 2}, 26.526380, 0.000040, 0.474000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, -2}, 206.542240, 0.000980, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 26.539850, 0.167100, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, -2}, 206.542610, 0.000040, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 26.583380, 0.000810, 0.563000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, 2}, 26.542610, 0.000040, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 206.464920, 0.000410, 0.067000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 3, 0}, 206.542610, 0.000070, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -3, 0}, 206.542610, 0.000060, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -2, 0}, 206.542050, 0.000590, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, -2}, 26.542610, 0.000030, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, 0}, 206.542610, 0.004320, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, 2}, 26.542610, 0.000020, 0.069000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, 0, 0}, 206.618260, 0.000060, 1.123000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, 1, 0}, 26.542610, 0.000060, 0.071000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -6, 0}, 26.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -5, 0}, 26.541550, 0.000280, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -4, -2}, 206.542610, 0.000060, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -4, 0}, 26.543240, 0.003770, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, -2}, 206.542070, 0.000560, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, 0}, 26.543240, 0.053540, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, -4}, 26.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, -2}, 206.542940, 0.004650, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 26.543240, 0.788110, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 2}, 206.542330, 0.001320, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -4}, 26.542610, 0.000060, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -2}, 206.542800, 0.028100, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 26.542610, 14.248830, 273.043000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 2}, 206.542800, 0.028100, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 4}, 26.542610, 0.000060, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -2}, 206.540230, 0.001410, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -1}, 147.613950, 0.000010, 6.132000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 26.545600, 0.739300, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 2}, 206.543710, 0.004550, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 4}, 26.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, -2}, 24.759140, 0.000030, 3.032000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 26.545600, 0.050220, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 2}, 206.543160, 0.000540, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 2, 0}, 26.545590, 0.003540, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 2, 2}, 206.542610, 0.000060, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 3, 0}, 26.543730, 0.000260, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 4, 0}, 26.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -3, 0}, 26.542610, 0.000060, 0.071000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, -2}, 26.542610, 0.000020, 0.069000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, 0}, 206.542610, 0.004320, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, 2}, 26.542610, 0.000030, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 206.543180, 0.000570, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, 1, 0}, 206.542610, 0.000060, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -5, 0}, 206.542610, 0.000070, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -4, 0}, 206.544480, 0.000470, 0.067000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, -2}, 26.542610, 0.000040, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, 0}, 206.624100, 0.000110, 0.565000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, 2}, 206.542610, 0.000040, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 0}, 26.542270, 0.157110, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 2}, 206.542980, 0.000960, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, -2}, 26.526380, 0.000040, 0.475000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 26.543010, 0.163020, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 2}, 206.542610, 0.000790, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, -2}, 206.542610, 0.000220, 0.090000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 26.544860, 0.019460, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, 2}, 206.542610, 0.000170, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, -2}, 206.542610, 0.000030, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 26.544120, 0.001930, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, 2}, 206.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 2, 0}, 26.542610, 0.000180, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 3, 0}, 26.542610, 0.000020, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -3, 0}, 206.542610, 0.000040, 0.094000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -2, 0}, 206.542610, 0.000220, 0.042000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -1, 0}, 26.542610, 0.000040, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -4, 0}, 26.542610, 0.000040, 0.103000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -3, 0}, 26.541960, 0.002110, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -3, 2}, 206.542610, 0.000020, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, -2}, 26.542610, 0.000010, 0.107000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, 0}, 26.542470, 0.003960, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, 2}, 206.542610, 0.000030, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, 0}, 26.542840, 0.001910, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, 2}, 206.542610, 0.000020, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, 0, 0}, 26.542610, 0.000340, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, 1, 0}, 26.542610, 0.000050, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -4, 0}, 26.542610, 0.000030, 0.029000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -3, 0}, 26.542610, 0.000080, 0.021000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -2, 0}, 26.542610, 0.000070, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -1, 0}, 26.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 1, 0, 0, 0, -1, 0}, 251.566590, 0.000040, 26.589000},
	{{0, 18, -16, 0, 1, 0, 0, 0, 0, -1, 0}, 311.769770, 0.000020, 11.368000},
	{{0, 18, -16, 2, 0, 0, 0, 0, 1, -1, -1}, 353.909660, 0.000030, 75.385000},
	{{0, 18, -15, -6, 0, 0, 0, 0, -2, 1, 0}, 255.032500, 0.000010, 2.425000},
	{{0, 18, -15, -5, 0, 0, 0, 0, -2, 1, 0}, 94.053930, 0.000020, 8.385000},
	{{0, 18, -15, -4, 0, 0, 0, 0, -2, 0, 0}, 329.935690, 0.000020, 0.079000},
	{{0, 18, -15, -4, 0, 0, 0, 0, -2, 2, 0}, 329.935690, 0.000020, 0.072000},
	{{0, 18, -15, -2, 0, 0, 0, 0, 0, -1, 0}, 263.424660, 0.000010, 16.749000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -6, 0, 0}, 283.605680, 0.000010, 0.017000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -6, 1, 0}, 283.605680, 0.000010, 0.021000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, -2, 0}, 283.605680, 0.000050, 0.016000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, -1, 0}, 283.605680, 0.000260, 0.021000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, 0, 0}, 283.605680, 0.000450, 0.028000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, 1, 0}, 283.605680, 0.000190, 0.046000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -3, 0, 0}, 103.605680, 0.000020, 0.044000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -4, 0}, 283.605680, 0.000020, 0.016000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -3, 0}, 283.605680, 0.000160, 0.020000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, -2}, 103.605680, 0.000010, 0.016000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, 0}, 283.605830, 0.001510, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, 2}, 103.605680, 0.000010, 0.099000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, -2}, 103.605680, 0.000050, 0.020000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, 0}, 283.605580, 0.011410, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 0, -2}, 103.605680, 0.000040, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 283.602990, 0.007480, 0.095000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 283.553920, 0.000030, 0.360000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 103.605680, 0.000020, 0.062000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -1, -1, -1}, 310.091230, 0.000040, 0.040000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -1, -1, 0}, 103.605680, 0.000020, 0.088000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -4, 0}, 283.605680, 0.000070, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -3, 0}, 283.606310, 0.000670, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -2, -2}, 103.605680, 0.000030, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 283.606310, 0.005130, 0.082000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 283.570680, 0.000030, 0.996000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -1, 2}, 283.605680, 0.000030, 0.036000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 103.608680, 0.003570, 0.070000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 0, 2}, 283.605680, 0.000030, 0.024000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 103.608670, 0.000500, 0.036000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 2, 0}, 103.605680, 0.000060, 0.025000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -3, -1}, 310.091230, 0.000010, 0.038000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -3, 0}, 103.605680, 0.000010, 0.076000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -2, -1}, 310.090950, 0.000180, 0.075000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, -1}, 310.091230, 0.003320, 19.959000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, 0}, 283.605680, 0.000620, 0.075000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 310.110900, 0.000320, 0.076000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 283.605680, 0.000090, 0.038000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 1, -1}, 310.091230, 0.000010, 0.038000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 104.311600, 0.000970, 0.080000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 103.605840, 0.001680, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 105.910660, 0.000300, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 103.605680, 0.000040, 0.019000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 3, -2, -1}, 310.091500, 0.000040, 0.087000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 3, -2, 0}, 283.605680, 0.000020, 0.040000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 3, -1, -1}, 310.091230, 0.000040, 0.041000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 3, -1, 0}, 283.605680, 0.000020, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 4, -3, 0}, 103.605680, 0.000020, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 4, -2, 0}, 103.605680, 0.000070, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 4, -1, 0}, 103.605680, 0.000040, 0.020000},
	{{0, 18, -14, -7, 0, 0, 0, 0, -2, 0, 0}, 223.602510, 0.000010, 0.076000},
	{{0, 18, -14, -7, 0, 0, 0, 0, -2, 1, 0}, 79.415960, 0.000020, 17.893000},
	{{0, 18, -14, -7, 0, 0, 0, 0, -2, 2, 0}, 223.602510, 0.000010, 0.075000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -4, -1, 0}, 180.668750, 0.000020, 0.021000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -4, 0, 0}, 180.668750, 0.000030, 0.029000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -4, 1, 0}, 180.668750, 0.000010, 0.048000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, -2, 0}, 180.668750, 0.000080, 0.028000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 180.668750, 0.000560, 0.044000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 180.666060, 0.000270, 0.106000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 0, -3, 0}, 180.668750, 0.000010, 0.041000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 180.668750, 0.000090, 0.089000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 1.356230, 0.000040, 0.066000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, -2, -2}, 308.111890, 0.000010, 0.075000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 344.830750, 0.000120, 0.074000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 0.668750, 0.000010, 0.037000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, 0, -2}, 308.111890, 0.000010, 0.076000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 308.072550, 0.000040, 0.025000},
	{{0, 18, -14, 0, 0, 3, 0, 0, 2, -1, -2}, 17.165090, 0.000020, 494.047000},
	{{0, 18, -13, -9, 0, 0, 0, 0, -2, 0, 0}, 45.376740, 0.000020, 0.075000},
	{{0, 18, -13, -9, 0, 0, 0, 0, -2, 1, 0}, 101.323340, 0.000050, 133.722000},
	{{0, 18, -13, -9, 0, 0, 0, 0, -2, 2, 0}, 45.376740, 0.000020, 0.075000},
	{{0, 18, -13, -7, 0, 0, 0, 0, -1, 1, -1}, 13.371770, 0.000110, 470.696000},
	{{0, 18, -13, -5, 0, 0, 0, 0, 0, 1, -2}, 4.784150, 0.000010, 85.271000},
	{{0, 18, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 77.731820, 0.000020, 0.046000},
	{{0, 18, -12, -11, 0, 0, 0, 0, -2, 1, 0}, 29.018840, 0.000020, 14.115000},
	{{0, 18, -10, -15, 0, 0, 0, 0, -2, 1, 0}, 328.741870, 0.000010, 5.061000},
	{{0, 18, -10, -13, 0, 0, 0, 0, -1, 0, 0}, 35.983060, 0.000010, 47.117000},
	{{0, 18, -8, -15, 0, 0, 0, 0, 0, -1, 0}, 160.312190, 0.000020, 35.213000},
	{{0, 19, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 109.546920, 0.000010, 0.046000},
	{{0, 19, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 109.546920, 0.000010, 0.215000},
	{{0, 19, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 49.039740, 0.000020, 0.053000},
	{{0, 19, -25, 0, 0, 0, 0, 0, -2, 1, 0}, 229.039740, 0.000020, 0.179000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -4, 0, 0}, 324.027210, 0.000020, 0.023000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -4, 2, 0}, 57.527470, 0.000010, 0.062000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 222.453000, 0.000040, 0.056000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 236.511530, 0.000050, 0.115000},
	{{0, 19, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 129.859200, 0.000020, 0.145000},
	{{0, 19, -24, 0, 1, 0, 0, 0, -2, 0, 0}, 50.154320, 0.000020, 0.056000},
	{{0, 19, -24, 0, 1, 0, 0, 0, -2, 2, 0}, 50.154320, 0.000020, 0.114000},
	{{0, 19, -24, 8, 0, 0, 0, 0, -2, -1, 2}, 87.680550, 0.000030, 101.947000},
	{{0, 19, -24, 9, 0, 0, 0, 0, -2, 1, 0}, 116.208160, 0.000010, 5.309000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -3, -1, 1}, 313.467140, 0.000040, 0.040000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -3, 0, 1}, 313.467140, 0.000040, 0.087000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, -3, 1}, 313.467140, 0.000010, 0.038000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, -2, 1}, 313.467140, 0.000210, 0.075000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, -1, 1}, 313.467140, 0.003750, 4846.835000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, 0, 1}, 313.467140, 0.000210, 0.075000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, 1, 1}, 313.467140, 0.000010, 0.038000},
	{{0, 19, -24, 10, 0, 0, 0, 0, 1, -2, 1}, 313.467140, 0.000040, 0.087000},
	{{0, 19, -24, 10, 0, 0, 0, 0, 1, -1, 1}, 313.467140, 0.000040, 0.040000},
	{{0, 19, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 232.745570, 0.000020, 0.059000},
	{{0, 19, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 51.504900, 0.000030, 0.186000},
	{{0, 19, -22, 0, -1, 0, 0, 0, -2, 0, 0}, 53.119370, 0.000010, 0.063000},
	{{0, 19, -22, 0, -1, 0, 0, 0, -2, 2, 0}, 233.119370, 0.000010, 0.095000},
	{{0, 19, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 325.951290, 0.000020, 0.063000},
	{{0, 19, -22, 5, 0, 0, 0, 0, -2, 1, 0}, 242.779140, 0.000020, 16.228000},
	{{0, 19, -21, 0, -2, 0, 0, 0, -4, 3, 0}, 224.035060, 0.000030, 116.125000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 12.420610, 0.000040, 0.067000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 9.036600, 0.000030, 0.626000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 357.034220, 0.000020, 0.086000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 351.138970, 0.000020, 0.297000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 353.012930, 0.000100, 0.101000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 177.177670, 0.000070, 0.029000},
	{{0, 19, -21, 2, 0, 0, 0, 0, -2, 0, 0}, 179.384410, 0.000030, 0.073000},
	{{0, 19, -21, 2, 0, 0, 0, 0, -2, 2, 0}, 179.384410, 0.000030, 0.079000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -4, 0, 0}, 14.987140, 0.000010, 0.026000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -4, 1, 0}, 14.987140, 0.000090, 0.040000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -4, 2, 0}, 14.573170, 0.000070, 0.087000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, -1, 0}, 14.987140, 0.000030, 0.038000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 0, 0}, 15.302230, 0.000480, 0.075000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 1, -2}, 194.987140, 0.000020, 0.037000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 1, 0}, 14.987140, 0.007750, 573.318000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 1, 2}, 194.987140, 0.000020, 0.037000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 2, 0}, 15.302230, 0.000480, 0.075000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 3, 0}, 14.987140, 0.000030, 0.038000},
	{{0, 19, -21, 3, 0, 0, 0, 0, 0, 0, 0}, 14.573170, 0.000070, 0.087000},
	{{0, 19, -21, 3, 0, 0, 0, 0, 0, 1, 0}, 14.987140, 0.000090, 0.040000},
	{{0, 19, -21, 3, 0, 0, 0, 0, 0, 2, 0}, 14.987140, 0.000010, 0.026000},
	{{0, 19, -21, 4, 0, 0, 0, 0, -2, 1, 0}, 57.631000, 0.000030, 1.887000},
	{{0, 19, -21, 5, 0, 0, 0, 0, -1, 1, -1}, 171.663870, 0.000020, 127.251000},
	{{0, 19, -20, 0, -1, 0, 0, 0, -2, 0, 0}, 336.809230, 0.000030, 0.072000},
	{{0, 19, -20, 0, -1, 0, 0, 0, -2, 1, 0}, 254.109890, 0.000030, 1.468000},
	{{0, 19, -20, 0, -1, 0, 0, 0, -2, 2, 0}, 16.303610, 0.000020, 0.080000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 271.869740, 0.000200, 0.072000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 270.735730, 0.000320, 1.676000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 89.226790, 0.000010, 0.079000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -1, 0, 0}, 91.835550, 0.000010, 0.674000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -1, 1, -1}, 71.918040, 0.000010, 0.606000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 275.132470, 0.000040, 0.422000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 267.836180, 0.000140, 0.092000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, 1, 0}, 95.284880, 0.000020, 0.041000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, 2, 0}, 272.248760, 0.000010, 0.027000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 71.961690, 0.000010, 0.102000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, -1, 0}, 272.277450, 0.000080, 0.045000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 91.270010, 0.000110, 0.028000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 4, 0, 0}, 92.277450, 0.000010, 0.017000},
	{{0, 19, -20, 0, 1, 0, 0, 0, -2, 0, 0}, 131.061440, 0.000070, 0.073000},
	{{0, 19, -20, 0, 1, 0, 0, 0, -2, 1, 0}, 141.487620, 0.000030, 1.951000},
	{{0, 19, -20, 0, 1, 0, 0, 0, 0, 0, 0}, 311.061440, 0.000010, 0.091000},
	{{0, 19, -20, 0, 2, 0, 0, 0, -2, 0, 0}, 237.789600, 0.000010, 0.073000},
	{{0, 19, -20, 0, 2, 0, 0, 0, -2, 1, 0}, 206.954910, 0.000040, 2.335000},
	{{0, 19, -20, 0, 2, 0, 0, 0, -2, 2, 0}, 237.789600, 0.000010, 0.078000},
	{{0, 19, -20, 1, 0, 0, 0, 0, -2, 1, 0}, 145.452470, 0.000020, 15.358000},
	{{0, 19, -20, 3, 0, 0, 0, 0, -1, 1, -1}, 274.484670, 0.000050, 18.015000},
	{{0, 19, -19, -2, 0, 0, 0, 0, -2, 0, 0}, 27.646470, 0.000010, 0.072000},
	{{0, 19, -19, -2, 0, 0, 0, 0, -2, 2, 0}, 27.646470, 0.000010, 0.079000},
	{{0, 19, -19, -1, 0, 0, 0, 0, -2, 1, 0}, 301.986100, 0.000020, 7.783000},
	{{0, 19, -19, 0, -5, 0, 0, 0, -2, 1, 0}, 236.634420, 0.000030, 54.589000},
	{{0, 19, -19, 0, -4, 0, 0, 0, -2, 1, 0}, 241.450760, 0.000050, 15.155000},
	{{0, 19, -19, 0, -3, 0, 0, 0, -2, 0, 0}, 36.247520, 0.000010, 0.076000},
	{{0, 19, -19, 0, -3, 0, 0, 0, -2, 1, 0}, 200.563180, 0.000020, 6.654000},
	{{0, 19, -19, 0, -3, 0, 0, 0, -2, 2, 0}, 216.247520, 0.000010, 0.075000},
	{{0, 19, -19, 0, -2, 0, 0, 0, -2, 1, 0}, 216.253360, 0.000040, 4.263000},
	{{0, 19, -19, 0, -1, 0, 0, 0, -2, 0, 0}, 53.616340, 0.000020, 0.077000},
	{{0, 19, -19, 0, -1, 0, 0, 0, -2, 1, 0}, 265.661060, 0.000010, 3.136000},
	{{0, 19, -19, 0, -1, 0, 0, 0, -2, 2, 0}, 53.616340, 0.000020, 0.074000},
	{{0, 19, -19, 0, -1, 0, 0, 0, 0, -1, 0}, 272.793910, 0.000010, 0.687000},
	{{0, 19, -19, 0, 0, -2, 0, 0, -2, 1, 0}, 201.283630, 0.000020, 2.982000},
	{{0, 19, -19, 0, 0, -1, 0, 0, -2, 1, 0}, 272.147540, 0.000040, 2.708000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -4, 1, 0}, 180.120400, 0.000020, 0.041000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -4, 2, 0}, 181.550540, 0.000020, 0.090000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, -1, 0}, 359.534610, 0.000050, 0.038000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 359.707020, 0.000720, 0.078000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 180.122560, 0.001890, 2.480000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 179.187100, 0.000130, 0.073000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, -1, 0}, 0.077750, 0.000020, 0.073000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, -1, 1}, 16.012920, 0.000050, 3.154000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 0, -1}, 211.349030, 0.000030, 0.072000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 0, 0}, 0.077750, 0.000320, 2.067000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 0, 1}, 31.349030, 0.000020, 0.077000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 1, -1}, 193.744820, 0.000080, 1.537000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 1, 0}, 0.077750, 0.000020, 0.078000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 179.951500, 0.000470, 0.730000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 180.680620, 0.000840, 0.084000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 1, 0}, 180.420950, 0.000090, 0.040000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 1, -1, -1}, 192.302270, 0.000010, 0.412000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, -2, 0}, 179.753460, 0.000010, 0.099000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, -1, 0}, 179.753390, 0.000100, 0.043000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 359.752110, 0.000250, 0.027000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, 1, 0}, 359.753430, 0.000060, 0.020000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 3, -2, 0}, 359.836040, 0.000010, 0.044000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 3, 0, 0}, 359.836040, 0.000010, 0.020000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 4, -1, 0}, 359.753420, 0.000010, 0.021000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 4, 0, 0}, 359.748900, 0.000020, 0.016000},
	{{0, 19, -19, 0, 0, 1, 0, 0, -2, 0, 0}, 267.267270, 0.000010, 0.078000},
	{{0, 19, -19, 0, 0, 1, 0, 0, -2, 1, 0}, 267.044850, 0.000030, 2.288000},
	{{0, 19, -19, 0, 0, 1, 0, 0, -2, 2, 0}, 267.267270, 0.000010, 0.073000},
	{{0, 19, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 163.934990, 0.000030, 0.078000},
	{{0, 19, -19, 0, 2, 0, 0, 0, -2, 1, 0}, 162.783820, 0.000010, 1.749000},
	{{0, 19, -19, 2, 0, 0, 0, 0, 0, -2, 0}, 330.088660, 0.000010, 0.074000},
	{{0, 19, -19, 2, 0, 0, 0, 0, 0, 0, 0}, 330.088660, 0.000010, 0.077000},
	{{0, 19, -18, -3, 0, 0, 0, 0, -2, 0, 0}, 103.519200, 0.000020, 0.074000},
	{{0, 19, -18, -3, 0, 0, 0, 0, -2, 1, 0}, 144.746450, 0.000030, 5.213000},
	{{0, 19, -18, -3, 0, 0, 0, 0, -2, 2, 0}, 103.519200, 0.000020, 0.077000},
	{{0, 19, -18, -2, 0, 0, 0, 0, -2, 0, 0}, 329.184830, 0.000020, 0.077000},
	{{0, 19, -18, -2, 0, 0, 0, 0, -2, 2, 0}, 329.184830, 0.000020, 0.074000},
	{{0, 19, -18, -1, 0, 0, 0, 0, -1, 0, 0}, 0.593010, 0.000030, 64.559000},
	{{0, 19, -18, 0, -4, 0, 0, 0, -1, 1, -1}, 107.474910, 0.000030, 81.835000},
	{{0, 19, -18, 0, -2, 0, 0, 0, -2, 0, 0}, 271.425060, 0.000010, 0.083000},
	{{0, 19, -18, 0, -2, 0, 0, 0, -2, 1, 0}, 93.523590, 0.000030, 0.810000},
	{{0, 19, -18, 0, -2, 0, 0, 0, -2, 2, 0}, 91.425060, 0.000010, 0.069000},
	{{0, 19, -18, 0, 0, -1, 0, 0, 0, -1, 0}, 158.475610, 0.000010, 2.471000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, -1, 1}, 282.892790, 0.000030, 1.464000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 0, -1}, 282.979650, 0.000210, 0.077000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 0, 0}, 279.749050, 0.000020, 1.937000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 1, -1}, 102.972410, 0.000660, 2.862000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 2, -1}, 102.971920, 0.000040, 0.074000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 74.562540, 0.000010, 0.073000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 211.210350, 0.000060, 2.697000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, 0, -1}, 283.027100, 0.000080, 1.860000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 293.803400, 0.000010, 0.078000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 1, -1, -1}, 103.038820, 0.000080, 0.702000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 103.024540, 0.000160, 0.085000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 94.342960, 0.000020, 0.041000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 94.373740, 0.000050, 0.027000},
	{{0, 19, -18, 0, 1, 0, 0, 0, 0, -1, 0}, 23.902900, 0.000030, 3.490000},
	{{0, 19, -17, -3, 0, 0, 0, 0, -2, 0, 0}, 156.029310, 0.000010, 0.080000},
	{{0, 19, -17, -3, 0, 0, 0, 0, -2, 2, 0}, 156.029310, 0.000010, 0.071000},
	{{0, 19, -17, -2, 0, 0, 0, 0, 0, -2, 0}, 180.321890, 0.000010, 0.073000},
	{{0, 19, -17, -2, 0, 0, 0, 0, 0, 0, 0}, 180.321890, 0.000010, 0.078000},
	{{0, 19, -17, -1, 0, 0, 0, 0, 0, -1, 0}, 303.862280, 0.000010, 10.256000},
	{{0, 19, -17, 0, -3, 0, 0, 0, 0, 1, -2}, 190.203300, 0.000010, 23.387000},
	{{0, 19, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 28.936890, 0.000030, 0.092000},
	{{0, 19, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 205.205430, 0.000010, 0.064000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 26.467170, 0.000340, 1.589000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 207.500610, 0.000170, 0.072000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, 1, -2}, 24.942870, 0.000030, 3.382000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 1, -1, -1}, 211.182190, 0.000030, 2.355000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 205.649270, 0.000020, 0.026000},
	{{0, 19, -16, -6, 0, 0, 0, 0, -2, 1, 0}, 45.235370, 0.000030, 4.693000},
	{{0, 19, -16, -4, 0, 0, 0, 0, 0, -1, 0}, 150.540000, 0.000030, 2.010000},
	{{0, 19, -16, -3, 0, 0, 0, 0, 0, -2, 0}, 169.432580, 0.000010, 0.076000},
	{{0, 19, -16, -3, 0, 0, 0, 0, 0, -1, 0}, 311.607670, 0.000060, 29.298000},
	{{0, 19, -16, -3, 0, 0, 0, 0, 0, 0, 0}, 349.432580, 0.000010, 0.075000},
	{{0, 19, -16, 0, 0, 0, 0, 0, 1, -1, -1}, 310.147470, 0.000020, 1.738000},
	{{0, 19, -15, -5, 0, 0, 0, 0, 0, -1, 0}, 354.407550, 0.000070, 34.206000},
	{{0, 19, -15, -3, 0, 0, 0, 0, 1, -1, -1}, 275.495380, 0.000020, 50.937000},
	{{0, 19, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 308.045900, 0.000030, 0.071000},
	{{0, 19, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 308.045900, 0.000030, 0.025000},
	{{0, 19, -14, -10, 0, 0, 0, 0, -2, 1, 0}, 33.804820, 0.000010, 11.580000},
	{{0, 19, -14, -7, 0, 0, 0, 0, 0, -1, 0}, 123.711660, 0.000020, 10.799000},
	{{0, 19, -11, -15, 0, 0, 0, 0, -2, 1, 0}, 336.924770, 0.000010, 2.337000},
	{{0, 19, -7, -20, 0, 0, 0, 0, 0, -1, 0}, 298.017580, 0.000040, 222.268000},
	{{0, 20, -29, 15, 0, 0, 0, 0, -2, 0, 0}, 15.077270, 0.000020, 0.075000},
	{{0, 20, -29, 15, 0, 0, 0, 0, -2, 1, 0}, 339.172940, 0.000060, 250.641000},
	{{0, 20, -29, 15, 0, 0, 0, 0, -2, 2, 0}, 15.077270, 0.000020, 0.075000},
	{{0, 20, -28, 13, 0, 0, 0, 0, -2, 1, 0}, 172.870210, 0.000010, 16.841000},
	{{0, 20, -27, 11, 0, 0, 0, 0, -2, 1, 0}, 116.701710, 0.000010, 8.147000},
	{{0, 20, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 49.342910, 0.000020, 0.055000},
	{{0, 20, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 229.342910, 0.000020, 0.201000},
	{{0, 20, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 226.901940, 0.000040, 0.058000},
	{{0, 20, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 236.640000, 0.000050, 0.108000},
	{{0, 20, -25, 0, 0, 0, 0, 0, 0, -1, 0}, 144.015370, 0.000010, 0.174000},
	{{0, 20, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 126.558890, 0.000020, 0.133000},
	{{0, 20, -25, 0, 0, 0, 0, 0, 0, 1, 0}, 144.015370, 0.000010, 0.048000},
	{{0, 20, -25, 0, 1, 0, 0, 0, -2, 0, 0}, 50.118690, 0.000030, 0.058000},
	{{0, 20, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 51.467370, 0.000020, 0.211000},
	{{0, 20, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 81.872430, 0.000020, 0.029000},
	{{0, 20, -23, 2, 0, 0, 0, 0, -2, 1, 0}, 270.729120, 0.000010, 1.101000},
	{{0, 20, -23, 3, 0, 0, 0, 0, -2, 1, 0}, 94.793920, 0.000020, 2.658000},
	{{0, 20, -23, 7, 0, 0, 0, 0, 0, -1, 0}, 131.743890, 0.000030, 42.551000},
	{{0, 20, -23, 11, 0, 0, 0, 0, 2, -1, -2}, 244.953990, 0.000010, 232.800000},
	{{0, 20, -22, 0, -2, 0, 0, 0, -2, 1, 0}, 51.526380, 0.000010, 0.877000},
	{{0, 20, -22, 0, -1, 0, 0, 0, -3, 1, 1}, 249.201540, 0.000090, 551.702000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -4, 1, 0}, 194.739200, 0.000010, 0.039000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 321.753170, 0.000030, 1.030000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 13.431420, 0.000030, 0.081000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, -1, 0}, 351.665940, 0.000020, 0.364000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 2.926990, 0.000160, 0.095000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, 1, 0}, 14.739200, 0.000090, 0.042000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, 2, 0}, 14.739200, 0.000010, 0.027000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 2, -1, 0}, 157.088930, 0.000010, 0.045000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 177.488200, 0.000060, 0.028000},
	{{0, 20, -22, 0, 1, 0, 0, 0, -2, 0, 0}, 269.801610, 0.000020, 0.071000},
	{{0, 20, -22, 0, 1, 0, 0, 0, -2, 1, 0}, 283.762750, 0.000010, 1.127000},
	{{0, 20, -22, 0, 1, 0, 0, 0, -2, 2, 0}, 89.801610, 0.000020, 0.081000},
	{{0, 20, -22, 1, 0, 0, 0, 0, -2, 1, 0}, 271.282560, 0.000010, 2.275000},
	{{0, 20, -22, 2, 0, 0, 0, 0, -2, 1, 0}, 25.574110, 0.000020, 10.859000},
	{{0, 20, -22, 3, 0, 0, 0, 0, -2, 1, 0}, 6.788030, 0.000010, 1.603000},
	{{0, 20, -22, 5, 0, 0, 0, 0, 0, -1, 0}, 152.744950, 0.000010, 11.512000},
	{{0, 20, -21, 0, -3, 0, 0, 0, -2, 1, 0}, 54.010520, 0.000020, 4.461000},
	{{0, 20, -21, 0, -2, 0, 0, 0, -2, 1, 0}, 283.708830, 0.000040, 7.149000},
	{{0, 20, -21, 0, -1, 0, 0, 0, -2, 0, 0}, 288.285410, 0.000040, 0.075000},
	{{0, 20, -21, 0, -1, 0, 0, 0, -2, 1, 0}, 331.627210, 0.000020, 17.993000},
	{{0, 20, -21, 0, 0, -2, 0, 0, -2, 1, 0}, 229.487480, 0.000050, 25.530000},
	{{0, 20, -21, 0, 0, -1, 0, 0, -2, 0, 0}, 347.796950, 0.000040, 0.075000},
	{{0, 20, -21, 0, 0, -1, 0, 0, -2, 1, 0}, 333.791320, 0.000040, 191.502000},
	{{0, 20, -21, 0, 0, -1, 0, 0, -2, 2, 0}, 78.091490, 0.000010, 0.075000},
	{{0, 20, -21, 0, 0, 0, -3, 0, -2, 1, 0}, 261.382560, 0.000030, 143.271000},
	{{0, 20, -21, 0, 0, 0, -2, 0, -2, 1, 0}, 334.486730, 0.000070, 203.168000},
	{{0, 20, -21, 0, 0, 0, 0, -2, -2, 1, 0}, 98.365990, 0.000030, 60.286000},
	{{0, 20, -21, 0, 0, 0, 0, -1, -2, 1, 0}, 330.071860, 0.000020, 44.137000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -6, 1, 0}, 271.802270, 0.000010, 0.020000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -6, 2, 0}, 271.802270, 0.000030, 0.028000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -6, 3, 0}, 271.802270, 0.000020, 0.044000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, -1, 0}, 271.802270, 0.000010, 0.020000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 0, 0}, 271.926000, 0.000120, 0.026000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 1, 0}, 271.803490, 0.001190, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 2, 0}, 271.503320, 0.001140, 0.087000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -3, 1, 0}, 91.802270, 0.000030, 0.081000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, -2, 0}, 271.802270, 0.000030, 0.025000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, -1, 0}, 272.361870, 0.000220, 0.038000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, -2}, 91.802270, 0.000030, 0.025000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 272.360590, 0.003180, 0.076000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 1}, 82.773050, 0.000010, 5.116000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 2}, 91.802270, 0.000010, 0.073000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, -2}, 91.802270, 0.000210, 0.037000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 271.802270, 0.106510, 34.812000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, 2}, 91.802270, 0.000210, 0.037000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, -2}, 91.802270, 0.000010, 0.074000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 272.079680, 0.006060, 0.075000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, 2}, 91.802270, 0.000030, 0.025000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 3, 0}, 272.079720, 0.000410, 0.038000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 4, 0}, 271.802270, 0.000030, 0.025000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 0, -1}, 88.263840, 0.000030, 0.070000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 0, 0}, 87.170700, 0.000030, 1.165000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 1, -1}, 71.303610, 0.000030, 0.976000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 1, 0}, 91.802270, 0.000030, 0.081000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 2, -1}, 296.897280, 0.000020, 0.082000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 272.129240, 0.000100, 0.573000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 271.384610, 0.001890, 0.087000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 1, 0}, 271.757420, 0.001240, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 2, 0}, 271.894670, 0.000150, 0.026000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 3, 0}, 271.802270, 0.000010, 0.020000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 1, 0, -1}, 296.965210, 0.000020, 0.096000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 1, 1, -1}, 296.965210, 0.000030, 0.042000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 272.162180, 0.000070, 0.043000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 91.470340, 0.000100, 0.028000},
	{{0, 20, -21, 0, 0, 0, 0, 2, -2, 1, 0}, 255.982430, 0.000030, 24.472000},
	{{0, 20, -21, 0, 0, 0, 1, 0, -2, 1, 0}, 219.055480, 0.000030, 24.614000},
	{{0, 20, -21, 0, 0, 0, 2, 0, -2, 1, 0}, 262.593580, 0.000030, 19.037000},
	{{0, 20, -21, 0, 0, 2, 0, 0, -2, 1, 0}, 231.093590, 0.000010, 10.350000},
	{{0, 20, -21, 0, 0, 3, 0, 0, -2, 1, 0}, 161.360500, 0.000010, 7.659000},
	{{0, 20, -21, 0, 1, 0, 0, 0, -2, 0, 0}, 297.247340, 0.000030, 0.076000},
	{{0, 20, -21, 0, 1, 0, 0, 0, -2, 1, 0}, 273.881840, 0.000060, 8.847000},
	{{0, 20, -21, 0, 1, 0, 0, 0, -2, 2, 0}, 178.385480, 0.000020, 0.075000},
	{{0, 20, -21, 0, 2, 0, 0, 0, -2, 0, 0}, 45.850710, 0.000020, 0.077000},
	{{0, 20, -21, 0, 2, 0, 0, 0, -2, 1, 0}, 240.500500, 0.000020, 5.068000},
	{{0, 20, -21, 0, 2, 0, 0, 0, -2, 2, 0}, 45.850710, 0.000020, 0.074000},
	{{0, 20, -21, 3, 0, 0, 0, 0, 0, -1, 0}, 298.691350, 0.000010, 6.656000},
	{{0, 20, -20, -2, 0, 0, 0, 0, -2, 0, 0}, 30.084430, 0.000010, 0.075000},
	{{0, 20, -20, -2, 0, 0, 0, 0, -2, 1, 0}, 226.168970, 0.000050, 28.867000},
	{{0, 20, -20, -2, 0, 0, 0, 0, -2, 2, 0}, 210.084430, 0.000010, 0.076000},
	{{0, 20, -20, 0, -2, 0, 0, 0, -2, 1, 0}, 190.351560, 0.000020, 1.163000},
	{{0, 20, -20, 0, -2, 0, 0, 0, -2, 2, 0}, 190.660350, 0.000020, 0.071000},
	{{0, 20, -20, 0, -2, 0, 0, 0, -1, 0, 0}, 19.605120, 0.000050, 37.187000},
	{{0, 20, -20, 0, -1, 0, 0, 0, -2, 0, 0}, 15.311260, 0.000010, 0.081000},
	{{0, 20, -20, 0, -1, 0, 0, 0, -2, 1, 0}, 200.886210, 0.000040, 1.059000},
	{{0, 20, -20, 0, -1, 0, 0, 0, -2, 2, 0}, 195.311260, 0.000010, 0.070000},
	{{0, 20, -20, 0, -1, 0, 0, 0, -1, 0, 0}, 59.536730, 0.000040, 17.418000},
	{{0, 20, -20, 0, -1, 0, 0, 0, 0, -2, 0}, 92.805410, 0.000010, 0.071000},
	{{0, 20, -20, 0, -1, 0, 0, 0, 0, -1, 0}, 300.971720, 0.000030, 1.205000},
	{{0, 20, -20, 0, -1, 0, 0, 0, 0, 0, 0}, 272.805410, 0.000010, 0.080000},
	{{0, 20, -20, 0, 0, -1, 0, 0, -2, 1, 0}, 92.040540, 0.000010, 1.005000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -5, 2, -1}, 194.028290, 0.000010, 0.028000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -4, 0, 0}, 168.865340, 0.000010, 0.027000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -4, 1, 0}, 168.865340, 0.000090, 0.042000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -4, 2, 0}, 166.266190, 0.000040, 0.096000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 0, -1}, 194.028290, 0.000060, 0.026000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 0, 0}, 0.003840, 0.000030, 0.041000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 1, -1}, 194.010660, 0.000510, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 1, 0}, 0.003840, 0.000030, 0.088000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 2, -1}, 194.059680, 0.000470, 0.087000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 1.623500, 0.000300, 0.082000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -2, 1, -1}, 14.028290, 0.000010, 0.081000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 179.650630, 0.000210, 0.972000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 190.510790, 0.000030, 0.070000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -2, -1}, 194.028290, 0.000010, 0.025000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -1, -1}, 193.806910, 0.000230, 0.038000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -1, 0}, 0.003840, 0.000140, 0.076000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -1, 1}, 15.995220, 0.000040, 3.242000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, -3}, 14.028290, 0.000010, 0.025000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, -1}, 193.806870, 0.003400, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, 0}, 0.003840, 0.002580, 7.056000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, -3}, 14.028290, 0.000090, 0.037000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, -1}, 194.028290, 0.042800, 39.938000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, 0}, 0.003840, 0.000140, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, 1}, 14.028290, 0.000090, 0.037000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 2, -1}, 193.997470, 0.002370, 0.076000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 2, 1}, 14.028290, 0.000010, 0.025000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 3, -1}, 193.997390, 0.000160, 0.038000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 4, -1}, 194.028290, 0.000010, 0.025000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 181.524940, 0.000030, 0.071000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 180.038350, 0.001170, 1.342000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 180.489070, 0.000940, 0.080000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 1, -2}, 179.762620, 0.000010, 0.927000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 1, -1}, 14.028290, 0.000010, 0.081000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 1, 0}, 184.346210, 0.000040, 0.039000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, -1, 0}, 0.003840, 0.000030, 0.086000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 194.607390, 0.000260, 0.087000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 0, 0}, 0.003840, 0.000030, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 1, -1}, 194.046910, 0.000480, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 2, -1}, 194.028290, 0.000060, 0.026000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, -2, 0}, 179.587000, 0.000030, 0.093000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, -1, 0}, 179.862440, 0.000120, 0.042000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 359.346230, 0.000190, 0.027000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, 1, 0}, 359.718440, 0.000030, 0.020000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 3, -2, 0}, 359.802660, 0.000010, 0.043000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 3, 0, -1}, 194.028290, 0.000010, 0.028000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 3, 0, 0}, 359.802660, 0.000010, 0.020000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 4, -1, 0}, 359.715790, 0.000030, 0.021000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 4, 0, 0}, 359.715780, 0.000040, 0.016000},
	{{0, 20, -20, 0, 0, 0, 2, 0, -1, 1, -1}, 152.748940, 0.000030, 809.552000},
	{{0, 20, -20, 0, 0, 1, 0, 0, -1, 1, -1}, 135.290290, 0.000010, 112.250000},
	{{0, 20, -20, 0, 1, 0, 0, 0, -2, 0, 0}, 167.820060, 0.000010, 0.082000},
	{{0, 20, -20, 0, 1, 0, 0, 0, -2, 1, 0}, 347.002140, 0.000030, 0.898000},
	{{0, 20, -20, 0, 1, 0, 0, 0, -2, 2, 0}, 347.820060, 0.000010, 0.070000},
	{{0, 20, -20, 0, 1, 0, 0, 0, 0, -1, 0}, 347.820060, 0.000010, 1.513000},
	{{0, 20, -20, 0, 1, 0, 0, 0, 0, 0, 0}, 170.984370, 0.000020, 0.079000},
	{{0, 20, -20, 2, 0, 0, 0, 0, 0, 1, -2}, 59.261860, 0.000010, 64.783000},
	{{0, 20, -19, -4, 0, 0, 0, 0, -2, 1, 0}, 4.437670, 0.000030, 10.203000},
	{{0, 20, -19, -3, 0, 0, 0, 0, -2, 0, 0}, 123.996060, 0.000030, 0.078000},
	{{0, 20, -19, -3, 0, 0, 0, 0, -2, 1, 0}, 99.327010, 0.000040, 2.306000},
	{{0, 20, -19, -3, 0, 0, 0, 0, -2, 2, 0}, 123.996060, 0.000030, 0.073000},
	{{0, 20, -19, -2, 0, 0, 0, 0, -2, 1, 0}, 101.045860, 0.000010, 1.036000},
	{{0, 20, -19, -2, 0, 0, 0, 0, -1, 0, 0}, 297.013280, 0.000020, 12.764000},
	{{0, 20, -19, -2, 0, 0, 0, 0, -1, 1, -1}, 77.243740, 0.000030, 11.311000},
	{{0, 20, -19, -1, 0, 0, 0, 0, 0, -1, 0}, 180.236810, 0.000020, 3.610000},
	{{0, 20, -19, 0, -4, 0, 0, 0, 0, -1, 0}, 117.498070, 0.000030, 12.120000},
	{{0, 20, -19, 0, -3, 0, 0, 0, 0, -2, 0}, 107.827830, 0.000060, 0.075000},
	{{0, 20, -19, 0, -3, 0, 0, 0, 0, -1, 0}, 116.743970, 0.000470, 556.895000},
	{{0, 20, -19, 0, -3, 0, 0, 0, 0, 0, 0}, 161.265470, 0.000050, 0.075000},
	{{0, 20, -19, 0, -2, 0, 0, 0, 0, -1, 0}, 121.129130, 0.000030, 11.615000},
	{{0, 20, -19, 0, -1, 0, 0, 0, 0, -1, 0}, 0.858920, 0.000010, 5.868000},
	{{0, 20, -19, 0, -1, 0, 0, 0, 0, 0, -1}, 325.939780, 0.000020, 274.159000},
	{{0, 20, -19, 0, 0, -2, 0, 0, 0, -1, 0}, 96.112090, 0.000040, 5.353000},
	{{0, 20, -19, 0, 0, -1, 0, 0, 0, -1, 0}, 339.639490, 0.000010, 4.530000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -3, 1, -1}, 91.091360, 0.000030, 0.042000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -3, 2, -1}, 91.091360, 0.000020, 0.095000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -2, 0, -1}, 282.989350, 0.000020, 0.041000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -2, 1, -1}, 282.989350, 0.000020, 0.088000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, 0, -1}, 296.377710, 0.000040, 0.081000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, 1, -1}, 102.524090, 0.000060, 1.026000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, 2, -1}, 271.017970, 0.000010, 0.070000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, -2, 0}, 252.084800, 0.000010, 0.077000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, -1, -1}, 282.989350, 0.000110, 0.076000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 208.726930, 0.000110, 3.926000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 0, -1}, 282.989350, 0.002000, 11.370000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 261.440880, 0.000020, 0.074000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 1, -2}, 279.791240, 0.000100, 12.690000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 1, -1}, 282.989350, 0.000110, 0.075000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 1, -2, -1}, 103.001820, 0.000010, 0.071000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 1, -1, -1}, 103.001550, 0.000190, 1.251000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 1, 0, -1}, 103.008340, 0.000150, 0.080000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 2, -1, -1}, 282.989350, 0.000020, 0.086000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 2, -1, 0}, 94.485770, 0.000010, 0.040000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 2, 0, -1}, 282.989350, 0.000020, 0.040000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 89.588600, 0.000030, 0.026000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 4, -2, 0}, 94.515410, 0.000010, 0.027000},
	{{0, 20, -19, 0, 1, 0, 0, 0, 0, 1, -2}, 242.342130, 0.000060, 181.839000},
	{{0, 20, -18, -6, 0, 0, 0, 0, -2, 1, 0}, 139.294570, 0.000030, 6.197000},
	{{0, 20, -18, -5, 0, 0, 0, 0, -2, 1, 0}, 214.437860, 0.000020, 2.701000},
	{{0, 20, -18, -4, 0, 0, 0, 0, -1, 0, 0}, 51.314730, 0.000020, 66.754000},
	{{0, 20, -18, -2, 0, 0, 0, 0, -2, 1, 0}, 179.448610, 0.000020, 0.509000},
	{{0, 20, -18, 0, -2, 0, 0, 0, 0, -1, 0}, 359.548440, 0.000030, 0.921000},
	{{0, 20, -18, 0, -2, 0, 0, 0, 1, -1, -1}, 47.011360, 0.000030, 30.927000},
	{{0, 20, -18, 0, -1, 0, 0, 0, 1, -1, -1}, 256.076970, 0.000020, 8.574000},
	{{0, 20, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 20.969950, 0.000020, 0.098000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 153.691350, 0.000010, 0.083000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 28.267340, 0.000050, 0.797000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 199.955260, 0.000080, 0.069000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, -1, -2}, 206.453180, 0.000030, 0.076000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, -1, -1}, 213.568120, 0.000110, 4.977000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, 0, -2}, 206.453180, 0.000630, 29.252000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 5.894530, 0.000020, 0.074000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, 1, -2}, 206.453180, 0.000030, 0.075000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 205.625670, 0.000020, 0.025000},
	{{0, 20, -17, 0, -1, 0, 0, 0, 2, -1, -2}, 232.834950, 0.000010, 15.905000},
	{{0, 20, -17, 0, 0, 0, 0, 0, 2, 0, -3}, 129.735140, 0.000030, 51.076000},
	{{0, 20, -16, -6, 0, 0, 0, 0, 0, -1, 0}, 41.500250, 0.000020, 15.479000},
	{{0, 20, -15, -8, 0, 0, 0, 0, 0, -2, 0}, 127.301240, 0.000030, 0.075000},
	{{0, 20, -15, -8, 0, 0, 0, 0, 0, -1, 0}, 100.593760, 0.000530, 809.761000},
	{{0, 20, -15, -8, 0, 0, 0, 0, 0, 0, 0}, 127.301240, 0.000030, 0.075000},
	{{0, 20, -15, -6, 0, 0, 0, 0, 1, -1, -1}, 77.768650, 0.000020, 92.271000},
	{{0, 20, -15, -4, 0, 0, 0, 0, 2, -1, -2}, 302.156200, 0.000010, 48.923000},
	{{0, 20, -14, -10, 0, 0, 0, 0, 0, -1, 0}, 63.632860, 0.000020, 16.095000},
	{{0, 20, -13, -15, 0, 0, 0, 0, -2, 1, 0}, 222.743640, 0.000010, 18.705000},
	{{0, 20, -12, -17, 0, 0, 0, 0, -2, 1, 0}, 146.773660, 0.000020, 100.952000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -3, 1, -1}, 354.137590, 0.000050, 0.040000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -3, 2, -1}, 354.137590, 0.000050, 0.087000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, -1, -1}, 354.137590, 0.000020, 0.038000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 0, -1}, 354.137590, 0.000220, 0.075000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 1, -1}, 354.137590, 0.004070, 3300.556000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 2, -1}, 354.137590, 0.000220, 0.075000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 3, -1}, 354.137590, 0.000020, 0.038000},
	{{0, 20, -12, -15, 0, 0, 0, 0, 1, 0, -1}, 354.137590, 0.000050, 0.087000},
	{{0, 20, -12, -15, 0, 0, 0, 0, 1, 1, -1}, 354.137590, 0.000050, 0.040000},
	{{0, 21, -29, 15, 0, 0, 0, 0, 0, -1, 0}, 202.989380, 0.000040, 6.920000},
	{{0, 21, -28, 10, 0, 0, 0, 0, -2, 1, 0}, 210.976040, 0.000020, 34.593000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, -1, 0}, 144.002100, 0.000010, 0.033000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 236.747210, 0.000050, 0.060000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 144.002100, 0.000010, 0.299000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 236.747210, 0.000050, 0.101000},
	{{0, 21, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 144.002100, 0.000010, 0.195000},
	{{0, 21, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 100.863750, 0.000010, 0.123000},
	{{0, 21, -26, 0, 0, 0, 0, 0, 0, 1, 0}, 144.002100, 0.000010, 0.047000},
	{{0, 21, -26, 0, 1, 0, 0, 0, -2, 0, 0}, 50.081390, 0.000030, 0.061000},
	{{0, 21, -25, 0, 0, 0, 0, 0, -4, 0, 0}, 231.427770, 0.000030, 0.025000},
	{{0, 21, -25, 0, 0, 0, 0, 0, 0, -1, 0}, 51.427770, 0.000020, 0.243000},
	{{0, 21, -24, 0, -1, 0, 0, 0, -2, 1, 0}, 55.060120, 0.000010, 0.699000},
	{{0, 21, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 299.372230, 0.000010, 0.068000},
	{{0, 21, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 299.372230, 0.000010, 0.084000},
	{{0, 21, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 82.301570, 0.000010, 0.029000},
	{{0, 21, -24, 2, 0, 0, 0, 0, -2, 0, 0}, 270.740620, 0.000010, 0.074000},
	{{0, 21, -24, 2, 0, 0, 0, 0, -2, 1, 0}, 296.451380, 0.000010, 3.541000},
	{{0, 21, -24, 2, 0, 0, 0, 0, -2, 2, 0}, 270.740620, 0.000010, 0.077000},
	{{0, 21, -24, 3, 0, 0, 0, 0, -2, 1, 0}, 99.910110, 0.000020, 4.011000},
	{{0, 21, -24, 6, 0, 0, 0, 0, 0, -1, 0}, 26.694300, 0.000030, 14.217000},
	{{0, 21, -23, 0, -2, 0, 0, 0, -2, 0, 0}, 51.490750, 0.000010, 0.073000},
	{{0, 21, -23, 0, -2, 0, 0, 0, -2, 1, 0}, 230.360010, 0.000020, 1.944000},
	{{0, 21, -23, 0, -2, 0, 0, 0, -2, 2, 0}, 231.490750, 0.000010, 0.078000},
	{{0, 21, -23, 0, -1, 0, 0, 0, -2, 0, 0}, 189.502070, 0.000010, 0.073000},
	{{0, 21, -23, 0, -1, 0, 0, 0, -2, 1, 0}, 339.082540, 0.000030, 2.325000},
	{{0, 21, -23, 0, -1, 0, 0, 0, -2, 2, 0}, 9.502070, 0.000010, 0.078000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, -2, 2}, 169.569120, 0.000040, 0.075000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, -1, 2}, 166.674450, 0.000540, 81.722000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 328.803370, 0.000040, 0.074000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 0, 2}, 169.569120, 0.000040, 0.076000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 344.943250, 0.000210, 2.892000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 166.378430, 0.000020, 0.077000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 351.450860, 0.000020, 0.472000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 352.976490, 0.000080, 0.090000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 2, -1, 0}, 177.817920, 0.000010, 0.044000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 177.773000, 0.000050, 0.028000},
	{{0, 21, -23, 0, 0, 0, 1, 0, -2, -2, 2}, 15.436420, 0.000040, 0.075000},
	{{0, 21, -23, 0, 0, 0, 1, 0, -2, -1, 2}, 15.436420, 0.000810, 2987.643000},
	{{0, 21, -23, 0, 0, 0, 1, 0, -2, 0, 2}, 15.436420, 0.000040, 0.075000},
	{{0, 21, -23, 0, 0, 1, 0, 0, -2, 1, 0}, 265.273880, 0.000020, 3.207000},
	{{0, 21, -23, 0, 1, 0, 0, 0, -2, 0, 0}, 273.666860, 0.000070, 0.074000},
	{{0, 21, -23, 0, 1, 0, 0, 0, -2, 1, 0}, 209.357000, 0.000030, 3.825000},
	{{0, 21, -23, 0, 1, 0, 0, 0, -2, 2, 0}, 89.942700, 0.000020, 0.077000},
	{{0, 21, -23, 0, 2, 0, 0, 0, -2, 1, 0}, 291.820280, 0.000030, 5.645000},
	{{0, 21, -23, 0, 3, 0, 0, 0, -2, 1, 0}, 307.470740, 0.000030, 10.772000},
	{{0, 21, -23, 0, 4, 0, 0, 0, -2, 0, 0}, 340.828820, 0.000020, 0.075000},
	{{0, 21, -23, 0, 4, 0, 0, 0, -2, 1, 0}, 211.965550, 0.000050, 117.194000},
	{{0, 21, -23, 0, 4, 0, 0, 0, -2, 2, 0}, 160.828820, 0.000020, 0.075000},
	{{0, 21, -23, 1, 0, 0, 0, 0, -2, 1, 0}, 92.507930, 0.000010, 5.378000},
	{{0, 21, -23, 2, 0, 0, 0, 0, -2, 0, 0}, 336.461160, 0.000020, 0.080000},
	{{0, 21, -23, 2, 0, 0, 0, 0, -2, 2, 0}, 336.461160, 0.000020, 0.072000},
	{{0, 21, -23, 2, 0, 0, 0, 0, -1, -1, 1}, 178.680740, 0.000090, 379.678000},
	{{0, 21, -23, 4, 0, 0, 0, 0, 0, -1, 0}, 59.687720, 0.000240, 143.494000},
	{{0, 21, -23, 6, 0, 0, 0, 0, 1, -1, -1}, 140.220230, 0.000020, 60.344000},
	{{0, 21, -22, 0, -2, 0, 0, 0, -2, 0, 0}, 296.974630, 0.000010, 0.078000},
	{{0, 21, -22, 0, -2, 0, 0, 0, -2, 2, 0}, 116.974630, 0.000010, 0.073000},
	{{0, 21, -22, 0, -1, 0, 0, 0, -2, 0, 0}, 282.148750, 0.000030, 0.079000},
	{{0, 21, -22, 0, -1, 0, 0, 0, -2, 1, 0}, 288.441850, 0.000040, 1.755000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -4, 2, 0}, 91.785870, 0.000010, 0.092000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 92.094380, 0.000110, 0.079000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 268.747340, 0.000140, 1.528000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 271.785870, 0.000070, 0.072000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -2, 1}, 250.552740, 0.000030, 0.075000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -1, 0}, 91.999590, 0.000020, 0.074000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -1, 1}, 250.553280, 0.000620, 15.151000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, -1}, 70.615120, 0.000030, 0.073000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, 0}, 91.999590, 0.000300, 4.296000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, 1}, 250.570420, 0.000100, 0.076000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 1, -1}, 70.635670, 0.000130, 2.503000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 1, 0}, 91.999590, 0.000020, 0.077000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 0, -1, 0}, 272.372830, 0.000150, 0.893000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 272.573590, 0.000260, 0.082000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 0, 1, 0}, 94.216720, 0.000020, 0.039000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, -3, 0}, 92.250310, 0.000020, 0.346000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, -2, 0}, 280.332240, 0.000020, 0.097000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, -1, 0}, 278.265300, 0.000050, 0.042000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 92.251820, 0.000120, 0.027000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, 1, 0}, 92.252360, 0.000010, 0.020000},
	{{0, 21, -22, 0, 0, 2, 0, 0, -1, -1, 1}, 229.055700, 0.000040, 527.988000},
	{{0, 21, -22, 0, 1, 0, 0, 0, -2, 0, 0}, 21.413850, 0.000040, 0.080000},
	{{0, 21, -22, 0, 1, 0, 0, 0, -2, 1, 0}, 128.467670, 0.000030, 1.354000},
	{{0, 21, -22, 0, 1, 0, 0, 0, -2, 2, 0}, 264.839120, 0.000010, 0.071000},
	{{0, 21, -22, 0, 1, 0, 0, 0, -1, -1, 1}, 171.855140, 0.000030, 54.640000},
	{{0, 21, -22, 0, 1, 0, 0, 0, 0, -1, 0}, 177.890850, 0.000020, 0.966000},
	{{0, 21, -22, 0, 2, 0, 0, 0, -2, 1, 0}, 233.233150, 0.000030, 1.215000},
	{{0, 21, -22, 0, 2, 0, 0, 0, -1, -1, 1}, 264.370050, 0.000020, 9.746000},
	{{0, 21, -22, 0, 2, 0, 0, 0, -1, 0, 0}, 53.233140, 0.000030, 15.589000},
	{{0, 21, -22, 2, 0, 0, 0, 0, 0, -1, 0}, 55.536290, 0.000010, 17.731000},
	{{0, 21, -22, 3, 0, 0, 0, 0, 0, -1, 0}, 236.047810, 0.000010, 2.104000},
	{{0, 21, -21, -3, 0, 0, 0, 0, -2, 0, 0}, 13.848130, 0.000030, 0.076000},
	{{0, 21, -21, -3, 0, 0, 0, 0, -2, 1, 0}, 329.411230, 0.000020, 16.893000},
	{{0, 21, -21, -3, 0, 0, 0, 0, -2, 2, 0}, 13.848130, 0.000030, 0.075000},
	{{0, 21, -21, 0, -2, 0, 0, 0, -2, 1, 0}, 25.124330, 0.000010, 0.673000},
	{{0, 21, -21, 0, -2, 0, 0, 0, 0, -1, 0}, 353.885680, 0.000010, 3.468000},
	{{0, 21, -21, 0, -1, 0, 0, 0, -2, 0, 0}, 102.260060, 0.000020, 0.086000},
	{{0, 21, -21, 0, -1, 0, 0, 0, -2, 1, 0}, 5.488970, 0.000020, 0.637000},
	{{0, 21, -21, 0, -1, 0, 0, 0, -2, 2, 0}, 102.260060, 0.000020, 0.067000},
	{{0, 21, -21, 0, -1, 0, 0, 0, 0, -1, 0}, 282.355940, 0.000040, 4.900000},
	{{0, 21, -21, 0, -1, 0, 0, 0, 0, 0, 0}, 263.745550, 0.000040, 0.077000},
	{{0, 21, -21, 0, 0, -1, 0, 0, 0, -1, 0}, 268.565490, 0.000030, 6.506000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -4, 2, 0}, 1.648130, 0.000010, 0.102000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, -2, 0}, 180.023730, 0.000040, 0.026000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, -1, 0}, 179.971320, 0.000320, 0.040000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 359.994080, 0.000420, 0.086000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 359.919970, 0.000010, 0.605000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 181.655930, 0.000060, 0.067000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -1, 0, -1}, 32.324310, 0.000020, 0.079000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -1, 0, 0}, 357.869430, 0.000060, 1.303000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -1, 1, -1}, 192.938430, 0.000060, 1.665000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -3, 0}, 180.128620, 0.000120, 0.038000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -2, -2}, 359.943930, 0.000010, 0.025000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -2, 0}, 180.128860, 0.001710, 0.075000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -1, -2}, 359.943930, 0.000060, 0.037000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 179.943930, 0.032380, 8.350000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -1, 2}, 359.943930, 0.000060, 0.037000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, -1}, 13.869490, 0.000070, 3.490000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 179.879720, 0.005420, 0.076000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, 2}, 359.943930, 0.000010, 0.025000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 1, -2}, 179.728780, 0.000070, 2.206000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 1, 0}, 179.889160, 0.000340, 0.038000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 1, -1, -1}, 193.502930, 0.000030, 0.852000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, -2, 0}, 179.772770, 0.000380, 0.088000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 179.889140, 0.000490, 0.041000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 359.400500, 0.000060, 0.026000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, 1, 0}, 359.678860, 0.000020, 0.020000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 4, -1, 0}, 359.676100, 0.000010, 0.020000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 4, 0, 0}, 359.676090, 0.000030, 0.016000},
	{{0, 21, -21, 0, 0, 1, 0, 0, 0, -1, 0}, 249.030190, 0.000020, 11.653000},
	{{0, 21, -21, 0, 0, 3, 0, 0, 0, -1, 0}, 245.381560, 0.000030, 55.794000},
	{{0, 21, -21, 0, 1, 0, 0, 0, -2, 1, 0}, 172.303460, 0.000020, 0.575000},
	{{0, 21, -21, 0, 2, 0, 0, 0, 0, -1, 0}, 53.962890, 0.000050, 20.475000},
	{{0, 21, -20, -5, 0, 0, 0, 0, -2, 1, 0}, 302.343360, 0.000100, 239.709000},
	{{0, 21, -20, -3, 0, 0, 0, 0, -1, 1, -1}, 353.611090, 0.000080, 184.128000},
	{{0, 21, -20, -2, 0, 0, 0, 0, 0, -1, 0}, 113.006610, 0.000030, 5.461000},
	{{0, 21, -20, -1, 0, 0, 0, 0, 0, 1, -2}, 0.081610, 0.000010, 66.517000},
	{{0, 21, -20, 0, -2, 0, 0, 0, 0, -1, 0}, 91.260650, 0.000020, 1.405000},
	{{0, 21, -20, 0, -1, 0, 0, 0, 0, -2, 0}, 181.043290, 0.000020, 0.080000},
	{{0, 21, -20, 0, -1, 0, 0, 0, 0, 0, 0}, 1.043290, 0.000020, 0.071000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -2, -1, 0}, 77.007000, 0.000030, 0.042000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 256.806700, 0.000020, 0.094000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -1, -1, -1}, 102.932630, 0.000030, 0.040000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -1, 0, -1}, 283.865020, 0.000060, 0.086000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -1, 1, -1}, 102.898710, 0.000020, 0.625000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 0, 0, -1}, 282.962760, 0.000020, 1.402000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -3, -1}, 102.916030, 0.000010, 0.037000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -3, 0}, 6.551000, 0.000020, 0.075000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -2, -1}, 102.915510, 0.000160, 0.074000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -2, 0}, 6.551000, 0.000340, 147.570000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -1, -1}, 102.932630, 0.002980, 5.763000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -1, 0}, 6.551000, 0.000020, 0.075000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 103.370690, 0.000640, 0.076000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, 1, -1}, 103.377030, 0.000040, 0.038000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 81.250200, 0.000020, 0.026000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 3, -2, -1}, 102.950020, 0.000030, 0.088000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 3, -1, -1}, 102.932630, 0.000030, 0.041000},
	{{0, 21, -20, 0, 2, 0, 0, 0, 1, -1, -1}, 41.146010, 0.000030, 203.061000},
	{{0, 21, -19, -7, 0, 0, 0, 0, -2, 1, 0}, 285.409360, 0.000020, 14.806000},
	{{0, 21, -19, -4, 0, 0, 0, 0, 0, -1, 0}, 219.297430, 0.000020, 4.057000},
	{{0, 21, -19, -3, 0, 0, 0, 0, 0, -1, 0}, 329.176520, 0.000010, 3.507000},
	{{0, 21, -19, -3, 0, 0, 0, 0, 0, 1, -2}, 154.164430, 0.000010, 20.690000},
	{{0, 21, -19, -2, 0, 0, 0, 0, -2, 0, 0}, 359.579000, 0.000010, 0.094000},
	{{0, 21, -19, -2, 0, 0, 0, 0, -2, 2, 0}, 359.579000, 0.000010, 0.063000},
	{{0, 21, -19, -2, 0, 0, 0, 0, 0, -1, 0}, 180.251020, 0.000010, 1.224000},
	{{0, 21, -19, 0, -2, 0, 0, 0, -2, 1, 0}, 179.782490, 0.000010, 0.287000},
	{{0, 21, -19, 0, 0, -3, 0, 0, 2, -3, 0}, 92.432660, 0.000010, 228.825000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 26.465410, 0.000020, 0.532000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 206.467200, 0.000030, 0.066000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 2, -3, 0}, 25.400880, 0.000030, 9.415000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 2, -1, -2}, 25.697860, 0.000030, 4.400000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 163.549670, 0.000020, 0.025000},
	{{0, 21, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 128.026520, 0.000020, 0.065000},
	{{0, 21, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 128.026520, 0.000020, 0.024000},
	{{0, 21, -16, -9, 0, 0, 0, 0, 0, -1, 0}, 53.049040, 0.000050, 10.518000},
	{{0, 21, -15, -11, 0, 0, 0, 0, 0, -1, 0}, 11.243590, 0.000020, 31.541000},
	{{0, 21, -14, -13, 0, 0, 0, 0, 0, -1, 0}, 351.475190, 0.000020, 31.583000},
	{{0, 22, -29, 9, 0, 0, 0, 0, -2, 1, 0}, 179.316360, 0.000020, 15.401000},
	{{0, 22, -28, 7, 0, 0, 0, 0, -2, 0, 0}, 318.169300, 0.000030, 0.075000},
	{{0, 22, -28, 7, 0, 0, 0, 0, -2, 1, 0}, 206.042560, 0.000240, 640.093000},
	{{0, 22, -28, 7, 0, 0, 0, 0, -2, 2, 0}, 318.169300, 0.000030, 0.075000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, -1, 0}, 143.987430, 0.000010, 0.034000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 236.547340, 0.000040, 0.063000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 1, 0}, 170.866520, 0.000020, 0.368000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 2, 0}, 236.547340, 0.000040, 0.095000},
	{{0, 22, -27, 0, 1, 0, 0, 0, -2, 0, 0}, 50.042460, 0.000030, 0.063000},
	{{0, 22, -27, 0, 1, 0, 0, 0, -2, 1, 0}, 50.042460, 0.000010, 0.379000},
	{{0, 22, -27, 5, 0, 0, 0, 0, -2, 1, 0}, 212.496240, 0.000030, 16.180000},
	{{0, 22, -26, 0, -1, 0, 0, 0, -2, 1, 0}, 60.055870, 0.000010, 0.554000},
	{{0, 22, -26, 0, 0, 0, 0, 0, -4, 0, 0}, 231.386140, 0.000020, 0.025000},
	{{0, 22, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 51.386140, 0.000020, 0.286000},
	{{0, 22, -26, 0, 0, 0, 0, 0, 0, 1, 0}, 51.386140, 0.000020, 0.043000},
	{{0, 22, -26, 0, 1, 0, 0, 0, -2, 1, 0}, 218.265200, 0.000010, 0.611000},
	{{0, 22, -26, 3, 0, 0, 0, 0, -2, 1, 0}, 165.760420, 0.000060, 7.989000},
	{{0, 22, -26, 4, 0, 0, 0, 0, -2, 1, 0}, 299.854710, 0.000010, 2.460000},
	{{0, 22, -25, 0, -2, 0, 0, 0, -3, 2, 0}, 353.474300, 0.000030, 547.201000},
	{{0, 22, -25, 0, -1, 0, 0, 0, -2, 0, 0}, 55.015680, 0.000030, 0.071000},
	{{0, 22, -25, 0, -1, 0, 0, 0, -2, 1, 0}, 232.127750, 0.000020, 1.243000},
	{{0, 22, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 107.329150, 0.000010, 0.072000},
	{{0, 22, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 287.329150, 0.000010, 0.080000},
	{{0, 22, -25, 0, 0, 0, 0, 0, 2, 0, 0}, 82.683510, 0.000010, 0.028000},
	{{0, 22, -25, 0, 1, 0, 0, 0, -2, 1, 0}, 325.275170, 0.000030, 1.573000},
	{{0, 22, -25, 0, 2, 0, 0, 0, -2, 1, 0}, 265.710610, 0.000010, 1.813000},
	{{0, 22, -25, 3, 0, 0, 0, 0, -1, 0, 0}, 187.168620, 0.000010, 82.081000},
	{{0, 22, -24, -2, 0, 0, 0, 0, -2, 1, 0}, 234.596890, 0.000010, 1.276000},
	{{0, 22, -24, 0, -4, 0, 0, 0, -2, 1, 0}, 96.696890, 0.000020, 17.408000},
	{{0, 22, -24, 0, -3, 0, 0, 0, -2, 0, 0}, 61.440670, 0.000010, 0.076000},
	{{0, 22, -24, 0, -3, 0, 0, 0, -2, 1, 0}, 22.453660, 0.000040, 37.232000},
	{{0, 22, -24, 0, -3, 0, 0, 0, -2, 2, 0}, 61.440670, 0.000010, 0.075000},
	{{0, 22, -24, 0, -2, 0, 0, 0, -2, 0, 0}, 45.106110, 0.000050, 0.076000},
	{{0, 22, -24, 0, -2, 0, 0, 0, -2, 1, 0}, 350.553130, 0.000030, 8.996000},
	{{0, 22, -24, 0, -2, 0, 0, 0, -2, 2, 0}, 36.903690, 0.000020, 0.075000},
	{{0, 22, -24, 0, -1, 0, 0, 0, -2, 1, 0}, 23.328940, 0.000030, 5.116000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 142.387890, 0.000020, 0.077000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 347.105670, 0.000240, 3.574000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 342.200440, 0.000030, 0.074000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -1, 0, 0}, 168.501680, 0.000010, 1.647000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -1, 1, -1}, 167.041850, 0.000010, 1.292000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 350.886440, 0.000030, 0.669000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 352.565280, 0.000050, 0.085000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 2, -1, 0}, 178.077140, 0.000010, 0.043000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 178.034820, 0.000040, 0.027000},
	{{0, 22, -24, 0, 0, 1, 0, 0, -2, 1, 0}, 265.521500, 0.000010, 3.188000},
	{{0, 22, -24, 0, 1, 0, 0, 0, -2, 0, 0}, 111.028780, 0.000030, 0.078000},
	{{0, 22, -24, 0, 1, 0, 0, 0, -2, 1, 0}, 206.354080, 0.000020, 2.747000},
	{{0, 22, -24, 0, 1, 0, 0, 0, -2, 2, 0}, 18.623820, 0.000010, 0.073000},
	{{0, 22, -24, 3, 0, 0, 0, 0, 0, -1, 0}, 110.309170, 0.000020, 9.920000},
	{{0, 22, -23, -3, 0, 0, 0, 0, -2, 1, 0}, 132.711090, 0.000030, 3.172000},
	{{0, 22, -23, -2, 0, 0, 0, 0, -2, 1, 0}, 243.323760, 0.000010, 4.621000},
	{{0, 22, -23, 0, -3, 0, 0, 0, -1, 1, -1}, 90.681280, 0.000010, 37.167000},
	{{0, 22, -23, 0, -2, 0, 0, 0, -1, 1, -1}, 67.059250, 0.000020, 17.422000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 106.244550, 0.000080, 0.084000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 264.931810, 0.000020, 0.781000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 89.555200, 0.000010, 0.069000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 0, -1}, 249.827420, 0.000030, 0.077000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 0, 0}, 93.288070, 0.000080, 2.546000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 1, -1}, 69.988370, 0.000290, 4.425000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 2, -1}, 69.988340, 0.000020, 0.074000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 272.407720, 0.000590, 2.023000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 272.165850, 0.000310, 0.078000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, 1, 0}, 92.237690, 0.000010, 0.038000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 1, -1, -1}, 69.944160, 0.000010, 0.646000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 92.237140, 0.000090, 0.027000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 2, 1, 0}, 92.237690, 0.000010, 0.020000},
	{{0, 22, -23, 0, 1, 0, 0, 0, 0, -1, 0}, 135.068170, 0.000020, 2.439000},
	{{0, 22, -23, 0, 1, 0, 0, 0, 0, 0, 0}, 177.700940, 0.000030, 0.078000},
	{{0, 22, -23, 0, 2, 0, 0, 0, 0, -1, 0}, 226.386630, 0.000030, 3.071000},
	{{0, 22, -23, 1, 0, 0, 0, 0, 0, -1, 0}, 96.455790, 0.000020, 26.710000},
	{{0, 22, -22, -4, 0, 0, 0, 0, -2, 1, 0}, 40.239330, 0.000030, 6.535000},
	{{0, 22, -22, -3, 0, 0, 0, 0, -1, -1, 1}, 40.267110, 0.000020, 28.144000},
	{{0, 22, -22, -1, 0, 0, 0, 0, 0, -1, 0}, 269.073980, 0.000030, 38.568000},
	{{0, 22, -22, 0, -2, 0, 0, 0, 0, -1, 0}, 199.681060, 0.000040, 2.966000},
	{{0, 22, -22, 0, -2, 0, 0, 0, 0, 1, -2}, 345.169920, 0.000060, 275.284000},
	{{0, 22, -22, 0, -1, 0, 0, 0, -2, 0, 0}, 189.537990, 0.000010, 0.090000},
	{{0, 22, -22, 0, -1, 0, 0, 0, -2, 2, 0}, 9.537990, 0.000010, 0.065000},
	{{0, 22, -22, 0, -1, 0, 0, 0, 0, -2, 0}, 9.537990, 0.000010, 0.078000},
	{{0, 22, -22, 0, -1, 0, 0, 0, 0, -1, 0}, 186.920890, 0.000020, 2.373000},
	{{0, 22, -22, 0, -1, 0, 0, 0, 0, 0, 0}, 189.537990, 0.000010, 0.073000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -2, -1, 0}, 179.796780, 0.000010, 0.041000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 170.709020, 0.000140, 0.091000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 175.719490, 0.000020, 0.439000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 177.064220, 0.000040, 0.064000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -1, 0, 0}, 354.432270, 0.000010, 0.718000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -1, 1, -1}, 193.453150, 0.000010, 0.816000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, -2, 0}, 179.716000, 0.000120, 0.078000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, -1, 0}, 179.799920, 0.001280, 1.977000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 0, -2}, 0.113330, 0.000010, 0.076000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 0, -1}, 13.560990, 0.000040, 2.950000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 2.105290, 0.000420, 0.073000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 1, -2}, 179.545550, 0.000360, 5.806000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 1, 0}, 0.768490, 0.000060, 0.037000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 2, -2}, 179.543870, 0.000020, 0.074000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 2, 0}, 179.634360, 0.000010, 0.025000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 1, -1, -1}, 192.524570, 0.000120, 1.825000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 1, 0, -1}, 192.433940, 0.000050, 0.079000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 2, -1, 0}, 179.668430, 0.000070, 0.040000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 359.634440, 0.000100, 0.026000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 4, 0, 0}, 359.634360, 0.000010, 0.016000},
	{{0, 22, -22, 0, 1, 0, 0, 0, -2, 0, 0}, 350.914830, 0.000010, 0.092000},
	{{0, 22, -22, 0, 1, 0, 0, 0, -2, 2, 0}, 170.914830, 0.000010, 0.064000},
	{{0, 22, -22, 1, 0, 0, 0, 0, 1, -1, -1}, 83.668970, 0.000010, 61.253000},
	{{0, 22, -22, 3, 0, 0, 0, 0, 2, -1, -2}, 266.025020, 0.000020, 148.742000},
	{{0, 22, -21, -6, 0, 0, 0, 0, -2, 1, 0}, 192.113400, 0.000020, 11.153000},
	{{0, 22, -21, -2, 0, 0, 0, 0, 0, -1, 0}, 257.934400, 0.000030, 2.261000},
	{{0, 22, -21, 0, 0, 0, 0, 0, -1, 0, -1}, 102.927730, 0.000030, 0.091000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, -2, -1}, 102.920580, 0.000020, 0.078000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, -1, -1}, 102.920840, 0.000320, 2.212000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, 0, -1}, 282.928800, 0.000110, 0.073000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 2, -2, 0}, 267.178870, 0.000010, 0.077000},
	{{0, 22, -20, -8, 0, 0, 0, 0, -2, 1, 0}, 135.549130, 0.000050, 38.025000},
	{{0, 22, -20, 0, -2, 0, 0, 0, -2, 0, 0}, 359.748580, 0.000010, 0.109000},
	{{0, 22, -20, 0, -2, 0, 0, 0, -2, 2, 0}, 359.748580, 0.000010, 0.058000},
	{{0, 22, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 26.438050, 0.000010, 0.399000},
	{{0, 22, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 25.566070, 0.000020, 0.025000},
	{{0, 22, -19, -6, 0, 0, 0, 0, 0, 1, -2}, 213.125710, 0.000010, 55.980000},
	{{0, 22, -18, 0, 0, 0, 0, 0, 2, -2, 0}, 127.994380, 0.000010, 0.063000},
	{{0, 22, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 127.994380, 0.000010, 0.024000},
	{{0, 22, -14, -16, 0, 0, 0, 0, 0, -1, 0}, 64.724800, 0.000050, 838.533000},
	{{0, 23, -36, 19, 0, 0, 0, 0, -2, 1, 0}, 146.746050, 0.000010, 137.056000},
	{{0, 23, -33, 15, 0, 0, 0, 0, -1, 0, 0}, 252.225540, 0.000020, 155.060000},
	{{0, 23, -31, 13, 0, 0, 0, 0, 0, -1, 0}, 268.392590, 0.000020, 23.163000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 236.648600, 0.000040, 0.065000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 1, 0}, 143.971420, 0.000030, 0.477000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 236.648600, 0.000040, 0.090000},
	{{0, 23, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 57.260020, 0.000020, 0.107000},
	{{0, 23, -28, 0, 1, 0, 0, 0, -2, 0, 0}, 50.001940, 0.000030, 0.066000},
	{{0, 23, -28, 0, 1, 0, 0, 0, -2, 1, 0}, 50.001940, 0.000020, 0.497000},
	{{0, 23, -28, 2, 0, 0, 0, 0, -2, 1, 0}, 94.952200, 0.000010, 0.970000},
	{{0, 23, -28, 3, 0, 0, 0, 0, -2, 1, 0}, 108.224570, 0.000030, 2.001000},
	{{0, 23, -28, 4, 0, 0, 0, 0, -2, 1, 0}, 39.499290, 0.000010, 31.219000},
	{{0, 23, -27, 0, -1, 0, 0, 0, -2, 0, 0}, 60.015360, 0.000010, 0.069000},
	{{0, 23, -27, 0, -1, 0, 0, 0, -2, 2, 0}, 240.015360, 0.000010, 0.083000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -4, 0, 0}, 231.342520, 0.000020, 0.026000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 56.816430, 0.000030, 0.070000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 0, 2}, 231.342520, 0.000020, 0.080000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 1, 0}, 74.651620, 0.000010, 0.914000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 2, 0}, 41.216080, 0.000010, 0.082000},
	{{0, 23, -27, 0, 0, 0, 0, 0, 0, -1, 0}, 51.342520, 0.000010, 0.349000},
	{{0, 23, -27, 0, 0, 0, 0, 0, 0, 1, 0}, 51.342520, 0.000010, 0.042000},
	{{0, 23, -27, 0, 1, 0, 0, 0, -2, 0, 0}, 218.224680, 0.000020, 0.070000},
	{{0, 23, -27, 0, 1, 0, 0, 0, -2, 1, 0}, 38.295730, 0.000030, 0.990000},
	{{0, 23, -27, 0, 2, 0, 0, 0, -2, 1, 0}, 205.180860, 0.000010, 1.080000},
	{{0, 23, -27, 2, 0, 0, 0, 0, -2, 0, 0}, 28.228560, 0.000050, 0.075000},
	{{0, 23, -27, 2, 0, 0, 0, 0, -2, 1, 0}, 302.892150, 0.000040, 31.913000},
	{{0, 23, -27, 2, 0, 0, 0, 0, -2, 2, 0}, 28.228560, 0.000050, 0.076000},
	{{0, 23, -27, 4, 0, 0, 0, 0, -1, 1, -1}, 26.013030, 0.000020, 46.014000},
	{{0, 23, -27, 6, 0, 0, 0, 0, 0, 1, -2}, 175.118910, 0.000010, 82.442000},
	{{0, 23, -26, -2, 0, 0, 0, 0, -2, 1, 0}, 190.770140, 0.000010, 0.864000},
	{{0, 23, -26, 0, -1, 0, 0, 0, -2, 0, 0}, 243.614880, 0.000030, 0.074000},
	{{0, 23, -26, 0, -1, 0, 0, 0, -2, 1, 0}, 91.425370, 0.000010, 5.586000},
	{{0, 23, -26, 0, 0, -2, 0, 0, -2, 1, 0}, 161.451050, 0.000010, 6.150000},
	{{0, 23, -26, 0, 0, -1, 0, 0, -2, 1, 0}, 244.694550, 0.000030, 7.773000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 65.708410, 0.000080, 0.075000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 71.694790, 0.000550, 10.559000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 85.313860, 0.000050, 0.076000},
	{{0, 23, -26, 0, 0, 0, 0, 0, 2, 0, 0}, 83.065640, 0.000010, 0.028000},
	{{0, 23, -26, 0, 0, 2, 0, 0, -2, 1, 0}, 347.158940, 0.000030, 37.303000},
	{{0, 23, -26, 0, 0, 3, 0, 0, -2, 1, 0}, 237.035840, 0.000030, 140.052000},
	{{0, 23, -26, 0, 1, 0, 0, 0, -2, 0, 0}, 272.165120, 0.000070, 0.075000},
	{{0, 23, -26, 0, 1, 0, 0, 0, -2, 1, 0}, 214.480330, 0.000060, 96.157000},
	{{0, 23, -26, 0, 1, 0, 0, 0, -2, 2, 0}, 165.164520, 0.000030, 0.075000},
	{{0, 23, -26, 0, 2, 0, 0, 0, -2, 1, 0}, 84.592940, 0.000030, 13.531000},
	{{0, 23, -26, 0, 2, 0, 0, 0, -2, 2, 0}, 79.508440, 0.000030, 0.075000},
	{{0, 23, -26, 0, 3, 0, 0, 0, -2, 1, 0}, 184.751910, 0.000020, 6.321000},
	{{0, 23, -26, 2, 0, 0, 0, 0, -1, 1, -1}, 304.599950, 0.000010, 11.751000},
	{{0, 23, -26, 4, 0, 0, 0, 0, 0, -1, 0}, 30.448940, 0.000010, 3.876000},
	{{0, 23, -25, -4, 0, 0, 0, 0, -3, -1, 2}, 353.149130, 0.000010, 0.075000},
	{{0, 23, -25, -4, 0, 0, 0, 0, -3, 0, 2}, 353.149130, 0.000190, 1088.552000},
	{{0, 23, -25, -4, 0, 0, 0, 0, -3, 1, 2}, 353.149130, 0.000010, 0.075000},
	{{0, 23, -25, 0, -2, 0, 0, 0, -2, 1, 0}, 51.414510, 0.000010, 1.357000},
	{{0, 23, -25, 0, -2, 0, 0, 0, -1, -1, 1}, 342.745200, 0.000030, 60.846000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, -1, 0}, 168.182450, 0.000020, 0.026000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, 0, 0}, 168.182450, 0.000140, 0.040000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, 1, 0}, 168.182450, 0.000140, 0.087000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 171.205880, 0.000010, 0.081000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 171.205880, 0.000010, 0.071000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, -2, 0}, 168.182450, 0.000050, 0.038000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, -1, 0}, 168.182450, 0.000690, 0.076000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, -1, 1}, 346.825640, 0.000020, 5.404000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, -2}, 348.182450, 0.000020, 0.037000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, -1}, 166.796980, 0.000040, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, 0}, 168.182450, 0.012490, 54.684000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, 2}, 348.182450, 0.000020, 0.037000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 1, -1}, 166.874280, 0.000300, 6.735000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 1, 0}, 168.182450, 0.000690, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 2, -1}, 166.874690, 0.000020, 0.076000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 2, 0}, 168.182450, 0.000050, 0.038000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 0, -1, 0}, 350.435260, 0.000060, 1.151000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 352.916500, 0.000060, 0.081000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, -1, 0}, 168.182450, 0.000140, 0.087000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, 0, 0}, 168.182450, 0.000140, 0.040000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, 1, 0}, 168.182450, 0.000020, 0.026000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 2, 0, 0}, 358.398370, 0.000010, 0.027000},
	{{0, 23, -25, 0, 1, 0, 0, 0, -2, 0, 0}, 90.905540, 0.000010, 0.082000},
	{{0, 23, -25, 0, 1, 0, 0, 0, -2, 1, 0}, 269.861190, 0.000030, 1.011000},
	{{0, 23, -25, 0, 1, 0, 0, 0, -2, 2, 0}, 270.905540, 0.000010, 0.070000},
	{{0, 23, -25, 0, 1, 0, 0, 0, -1, 0, 0}, 90.905540, 0.000010, 9.748000},
	{{0, 23, -25, 2, 0, 0, 0, 0, 0, -1, 0}, 355.038710, 0.000030, 5.138000},
	{{0, 23, -24, -3, 0, 0, 0, 0, -2, 1, 0}, 132.523700, 0.000020, 3.223000},
	{{0, 23, -24, 0, -2, 0, 0, 0, 0, -2, 0}, 320.648550, 0.000010, 0.075000},
	{{0, 23, -24, 0, -2, 0, 0, 0, 0, -1, 0}, 13.681620, 0.000050, 26.788000},
	{{0, 23, -24, 0, -2, 0, 0, 0, 0, 0, 0}, 140.648550, 0.000010, 0.076000},
	{{0, 23, -24, 0, -1, 0, 0, 0, 0, -2, 0}, 205.738440, 0.000020, 0.076000},
	{{0, 23, -24, 0, -1, 0, 0, 0, 0, -1, 0}, 253.375840, 0.000030, 21.289000},
	{{0, 23, -24, 0, -1, 0, 0, 0, 0, 0, 0}, 163.829860, 0.000060, 0.075000},
	{{0, 23, -24, 0, 0, -3, 0, 0, 0, -1, 0}, 22.455960, 0.000020, 33.975000},
	{{0, 23, -24, 0, 0, -1, 0, 0, 0, -1, 0}, 354.690490, 0.000060, 10.274000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, -1, 0}, 272.325840, 0.000080, 0.041000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 0, -1}, 249.195000, 0.000030, 0.040000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 270.234870, 0.000200, 0.088000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 1, -1}, 249.195000, 0.000030, 0.087000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 271.753350, 0.000010, 0.525000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -1, 0, 0}, 91.980730, 0.000010, 0.982000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -1, 1, -1}, 69.114030, 0.000020, 1.174000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -3, 0}, 271.614780, 0.000020, 0.038000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 271.615440, 0.000360, 0.076000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, -2}, 92.281100, 0.000010, 0.037000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, -1}, 249.195000, 0.000140, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 272.281100, 0.006290, 7.618000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, 2}, 92.281100, 0.000010, 0.037000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, -1}, 249.195000, 0.002510, 28.187000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 93.662940, 0.000380, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 1, -2}, 272.159080, 0.000090, 4.945000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 1, -1}, 249.195000, 0.000140, 0.076000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 1, 0}, 93.530590, 0.000030, 0.038000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 1, -1, -1}, 69.148940, 0.000030, 1.084000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, -2, 0}, 272.987550, 0.000070, 0.086000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, -1, -1}, 249.195000, 0.000030, 0.087000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, -1, 0}, 272.222760, 0.000050, 0.040000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, 0, -1}, 249.195000, 0.000030, 0.040000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 92.221670, 0.000090, 0.026000},
	{{0, 23, -24, 0, 1, 0, 0, 0, -2, 0, 0}, 359.013420, 0.000010, 0.089000},
	{{0, 23, -24, 0, 1, 0, 0, 0, -2, 1, 0}, 179.013420, 0.000010, 0.503000},
	{{0, 23, -24, 0, 1, 0, 0, 0, -2, 2, 0}, 179.013420, 0.000010, 0.066000},
	{{0, 23, -24, 0, 1, 0, 0, 0, 0, -2, 0}, 357.281490, 0.000010, 0.077000},
	{{0, 23, -24, 0, 1, 0, 0, 0, 0, -1, 0}, 29.910540, 0.000020, 4.639000},
	{{0, 23, -24, 0, 1, 0, 0, 0, 0, 0, 0}, 357.281490, 0.000010, 0.074000},
	{{0, 23, -24, 0, 1, 0, 0, 0, 0, 1, -2}, 178.393090, 0.000010, 8.480000},
	{{0, 23, -24, 0, 2, 0, 0, 0, 0, -1, 0}, 227.626960, 0.000040, 3.335000},
	{{0, 23, -23, -2, 0, 0, 0, 0, 0, -1, 0}, 214.368480, 0.000020, 14.726000},
	{{0, 23, -23, 0, -1, 0, 0, 0, 1, -1, -1}, 33.504460, 0.000100, 147.246000},
	{{0, 23, -23, 0, 0, -2, 0, 0, 1, -1, -1}, 163.770540, 0.000010, 103.989000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 171.934510, 0.000080, 0.097000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 179.481280, 0.000040, 0.062000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -1, -1, -1}, 192.753450, 0.000050, 0.041000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -1, 0, -1}, 193.227520, 0.000110, 0.088000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, -2, 0}, 190.866900, 0.000010, 0.082000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 179.409500, 0.000190, 0.884000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 1.250320, 0.000110, 0.070000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, 1, 0}, 359.590680, 0.000020, 0.036000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, 2, 0}, 179.586670, 0.000020, 0.024000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -3, -1}, 192.756530, 0.000020, 0.038000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -2, -1}, 192.756860, 0.000240, 0.076000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -2, 0}, 359.861670, 0.000010, 4.094000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -1, -2}, 359.679650, 0.000020, 0.075000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -1, -1}, 192.753450, 0.004430, 12.901000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, -2}, 359.679650, 0.000300, 11.205000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, -1}, 16.142150, 0.000080, 0.075000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 1, -2}, 359.679650, 0.000020, 0.076000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 2, -3, 0}, 0.005090, 0.000010, 1.556000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 2, -1, -2}, 179.590660, 0.000020, 1.024000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 2, -1, 0}, 179.436480, 0.000030, 0.039000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 359.589490, 0.000130, 0.026000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 2, 1, 0}, 359.590680, 0.000020, 0.019000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 3, -2, -1}, 192.749960, 0.000050, 0.087000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 3, -1, -1}, 192.753450, 0.000050, 0.040000},
	{{0, 23, -22, -6, 0, 0, 0, 0, -1, -1, 1}, 287.014820, 0.000020, 197.578000},
	{{0, 23, -22, -4, 0, 0, 0, 0, 0, -1, 0}, 217.190590, 0.000160, 220.195000},
	{{0, 23, -22, -2, 0, 0, 0, 0, 1, -1, -1}, 281.832760, 0.000030, 70.700000},
	{{0, 23, -22, 0, -1, 0, 0, 0, 2, -1, -2}, 180.752070, 0.000010, 16.514000},
	{{0, 23, -22, 0, 0, -1, 0, 0, 2, -1, -2}, 180.655690, 0.000010, 98.033000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 0, -1, -2}, 274.980300, 0.000040, 0.040000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 0, 0, -2}, 274.980300, 0.000030, 0.087000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 1, -1, -1}, 103.430980, 0.000040, 0.928000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 1, 0, -1}, 282.884140, 0.000040, 0.070000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -3, -2}, 274.980300, 0.000010, 0.038000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -2, -2}, 274.981260, 0.000170, 0.076000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -1, -2}, 274.980300, 0.003050, 42.111000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, 0, -2}, 276.692070, 0.000110, 0.075000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, 1, -2}, 274.980300, 0.000010, 0.038000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 4, -2, -2}, 274.980300, 0.000030, 0.087000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 4, -1, -2}, 274.980300, 0.000040, 0.040000},
	{{0, 23, -21, -6, 0, 0, 0, 0, 0, -1, 0}, 49.535660, 0.000030, 16.999000},
	{{0, 23, -21, -2, 0, 0, 0, 0, 2, -1, -2}, 179.786970, 0.000010, 25.239000},
	{{0, 23, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 20.006460, 0.000010, 0.024000},
	{{0, 23, -19, -13, 0, 0, 0, 0, -2, 1, 0}, 95.353900, 0.000050, 151.533000},
	{{0, 23, -19, -11, 0, 0, 0, 0, -1, 1, -1}, 328.060140, 0.000020, 332.942000},
	{{0, 24, -30, 4, 0, 0, 0, 0, -2, 1, 0}, 291.628250, 0.000030, 2.920000},
	{{0, 24, -30, 6, 0, 0, 0, 0, -1, -1, 1}, 347.035190, 0.000090, 1486.561000},
	{{0, 24, -30, 8, 0, 0, 0, 0, 0, -1, 0}, 107.932350, 0.000030, 97.320000},
	{{0, 24, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 318.185700, 0.000030, 0.068000},
	{{0, 24, -29, 0, 0, 0, 0, 0, -2, 1, 0}, 143.954090, 0.000020, 0.681000},
	{{0, 24, -29, 0, 0, 0, 0, 0, -2, 2, 0}, 233.477130, 0.000010, 0.085000},
	{{0, 24, -29, 0, 1, 0, 0, 0, -2, 0, 0}, 49.959900, 0.000030, 0.068000},
	{{0, 24, -29, 0, 1, 0, 0, 0, -2, 1, 0}, 229.910290, 0.000030, 0.722000},
	{{0, 24, -29, 2, 0, 0, 0, 0, -2, 0, 0}, 94.910150, 0.000010, 0.073000},
	{{0, 24, -29, 2, 0, 0, 0, 0, -2, 1, 0}, 115.173340, 0.000010, 2.464000},
	{{0, 24, -29, 2, 0, 0, 0, 0, -2, 2, 0}, 94.910150, 0.000010, 0.078000},
	{{0, 24, -29, 6, 0, 0, 0, 0, 0, -1, 0}, 115.402390, 0.000010, 18.835000},
	{{0, 24, -28, 0, -1, 0, 0, 0, -2, 1, 0}, 21.703370, 0.000020, 1.807000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 97.748090, 0.000010, 0.073000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 1, 0}, 42.480340, 0.000010, 2.131000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 97.748090, 0.000010, 0.078000},
	{{0, 24, -28, 0, 1, 0, 0, 0, -2, 0, 0}, 38.247150, 0.000060, 0.073000},
	{{0, 24, -28, 0, 2, 0, 0, 0, -2, 1, 0}, 290.925540, 0.000030, 3.327000},
	{{0, 24, -28, 0, 2, 0, 0, 0, -2, 2, 0}, 205.727220, 0.000020, 0.077000},
	{{0, 24, -27, -1, 0, 0, 0, 0, -2, 0, 0}, 218.206230, 0.000020, 0.075000},
	{{0, 24, -27, -1, 0, 0, 0, 0, -2, 1, 0}, 218.206230, 0.000280, 1155.779000},
	{{0, 24, -27, -1, 0, 0, 0, 0, -2, 2, 0}, 218.206230, 0.000020, 0.075000},
	{{0, 24, -27, 0, -2, 0, 0, 0, -2, 1, 0}, 356.008630, 0.000010, 2.761000},
	{{0, 24, -27, 0, -1, 0, 0, 0, -2, 0, 0}, 234.923490, 0.000030, 0.078000},
	{{0, 24, -27, 0, -1, 0, 0, 0, -2, 1, 0}, 238.245890, 0.000030, 2.240000},
	{{0, 24, -27, 0, 0, 0, 0, 0, -2, 1, 0}, 75.286940, 0.000020, 1.884000},
	{{0, 24, -27, 0, 0, 0, 0, 0, 0, -1, 0}, 90.238090, 0.000010, 0.804000},
	{{0, 24, -27, 0, 2, 0, 0, 0, -1, -1, 1}, 128.324890, 0.000020, 48.022000},
	{{0, 24, -27, 3, 0, 0, 0, 0, 0, 1, -2}, 147.551310, 0.000020, 54.525000},
	{{0, 24, -26, -4, 0, 0, 0, 0, -2, 1, 0}, 173.263260, 0.000010, 1.678000},
	{{0, 24, -26, -3, 0, 0, 0, 0, -2, 0, 0}, 209.673910, 0.000020, 0.075000},
	{{0, 24, -26, -3, 0, 0, 0, 0, -2, 1, 0}, 12.019060, 0.000070, 15.568000},
	{{0, 24, -26, -3, 0, 0, 0, 0, -2, 2, 0}, 209.673910, 0.000020, 0.076000},
	{{0, 24, -26, 0, -1, 0, 0, 0, 0, -1, 0}, 190.306900, 0.000010, 3.053000},
	{{0, 24, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 164.476160, 0.000040, 0.085000},
	{{0, 24, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 145.956440, 0.000010, 0.068000},
	{{0, 24, -26, 0, 0, 0, 0, 0, -1, 1, -1}, 166.650020, 0.000020, 2.096000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -2, 0}, 352.760500, 0.000050, 0.074000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 350.134900, 0.000550, 4.112000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 351.571390, 0.000170, 0.077000},
	{{0, 24, -26, 0, 1, 0, 0, 0, 0, -2, 0}, 90.909310, 0.000010, 0.075000},
	{{0, 24, -26, 0, 1, 0, 0, 0, 0, -1, 0}, 214.343670, 0.000040, 6.294000},
	{{0, 24, -26, 0, 1, 0, 0, 0, 0, 0, 0}, 270.909310, 0.000010, 0.076000},
	{{0, 24, -26, 0, 2, 0, 0, 0, 0, -1, 0}, 301.438260, 0.000030, 13.407000},
	{{0, 24, -26, 0, 3, 0, 0, 0, 0, -2, 0}, 155.464960, 0.000010, 0.075000},
	{{0, 24, -26, 0, 3, 0, 0, 0, 0, -1, 0}, 155.464960, 0.000190, 102.937000},
	{{0, 24, -26, 0, 3, 0, 0, 0, 0, 0, 0}, 155.464960, 0.000010, 0.075000},
	{{0, 24, -25, -5, 0, 0, 0, 0, -2, 1, 0}, 352.939790, 0.000010, 7.837000},
	{{0, 24, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 272.115200, 0.000030, 0.093000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 0, -1, 0}, 271.657020, 0.000150, 1.321000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 92.076520, 0.000090, 0.071000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 0, 1, -2}, 272.145320, 0.000010, 2.362000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 1, -2, -1}, 68.283100, 0.000010, 0.074000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 1, -2, 0}, 92.274620, 0.000010, 7.680000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 1, -1, -1}, 68.282880, 0.000200, 3.367000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 1, 0, -1}, 68.282890, 0.000070, 0.077000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 2, -1, 0}, 92.204680, 0.000020, 0.039000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 2, 0, 0}, 92.204330, 0.000070, 0.026000},
	{{0, 24, -25, 0, 1, 0, 0, 0, 0, -1, 0}, 178.976110, 0.000010, 1.189000},
	{{0, 24, -24, -7, 0, 0, 0, 0, -2, 1, 0}, 143.722230, 0.000010, 5.236000},
	{{0, 24, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 179.493730, 0.000070, 0.103000},
	{{0, 24, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 179.381780, 0.000010, 0.060000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -4, 0}, 179.431260, 0.000010, 0.026000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -3, 0}, 179.431260, 0.000120, 0.040000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 0.768400, 0.000010, 0.087000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 181.589330, 0.000060, 0.569000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 359.877840, 0.000070, 0.067000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, 1, 0}, 359.545030, 0.000010, 0.035000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 1, -1, -1}, 193.620430, 0.000040, 1.422000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -5, 0}, 179.429790, 0.000040, 0.038000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -4, 0}, 179.429760, 0.000560, 0.075000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -3, -2}, 359.431260, 0.000020, 0.037000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -3, 0}, 179.431260, 0.010170, 58.088000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -3, 2}, 359.431260, 0.000020, 0.037000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -2, 0}, 179.486650, 0.001060, 0.076000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -1, -2}, 179.551850, 0.000110, 2.851000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -1, 0}, 179.482440, 0.000070, 0.038000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 359.543780, 0.000100, 0.025000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, 1, 0}, 359.545020, 0.000010, 0.019000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 4, -4, 0}, 179.432760, 0.000110, 0.087000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 4, -3, 0}, 179.431260, 0.000120, 0.040000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 4, -2, 0}, 179.430320, 0.000010, 0.026000},
	{{0, 24, -23, 0, 0, 0, 0, 0, 1, -1, -1}, 102.838590, 0.000010, 0.587000},
	{{0, 24, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 273.959410, 0.000020, 0.025000},
	{{0, 24, -22, -7, 0, 0, 0, 0, 0, -1, 0}, 259.071430, 0.000030, 28.562000},
	{{0, 24, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 20.461270, 0.000010, 0.024000},
	{{0, 24, -21, -9, 0, 0, 0, 0, 0, -1, 0}, 260.390490, 0.000020, 35.266000},
	{{0, 25, -35, 11, 0, 0, 0, 0, -2, 1, 0}, 125.397580, 0.000020, 205.390000},
	{{0, 25, -33, 7, 0, 0, 0, 0, -2, 1, 0}, 316.694500, 0.000020, 8.206000},
	{{0, 25, -31, 2, 0, 0, 0, 0, -2, 1, 0}, 231.244390, 0.000030, 1.282000},
	{{0, 25, -31, 3, 0, 0, 0, 0, -2, 1, 0}, 132.607310, 0.000010, 4.023000},
	{{0, 25, -31, 4, 0, 0, 0, 0, -2, 1, 0}, 291.590640, 0.000030, 3.533000},
	{{0, 25, -30, 0, -1, 0, 0, 0, -2, 1, 0}, 152.021130, 0.000010, 1.078000},
	{{0, 25, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 293.155530, 0.000030, 0.071000},
	{{0, 25, -30, 0, 0, 0, 0, 0, -2, 2, 0}, 246.809500, 0.000020, 0.081000},
	{{0, 25, -30, 0, 1, 0, 0, 0, -2, 0, 0}, 229.865820, 0.000050, 0.071000},
	{{0, 25, -30, 1, 0, 0, 0, 0, -2, 1, 0}, 50.726700, 0.000010, 3.205000},
	{{0, 25, -30, 2, 0, 0, 0, 0, -2, 0, 0}, 274.866630, 0.000020, 0.077000},
	{{0, 25, -30, 2, 0, 0, 0, 0, -2, 1, 0}, 88.337590, 0.000020, 4.552000},
	{{0, 25, -30, 2, 0, 0, 0, 0, -2, 2, 0}, 274.866630, 0.000020, 0.074000},
	{{0, 25, -30, 5, 0, 0, 0, 0, 0, -1, 0}, 74.256770, 0.000030, 24.543000},
	{{0, 25, -29, 0, -3, 0, 0, 0, -2, 1, 0}, 137.890150, 0.000010, 10.355000},
	{{0, 25, -29, 0, -2, 0, 0, 0, -2, 0, 0}, 312.144820, 0.000060, 0.075000},
	{{0, 25, -29, 0, -2, 0, 0, 0, -2, 1, 0}, 218.682610, 0.000030, 81.524000},
	{{0, 25, -29, 0, -2, 0, 0, 0, -2, 2, 0}, 66.599320, 0.000010, 0.076000},
	{{0, 25, -29, 0, -1, 0, 0, 0, -2, 0, 0}, 186.992790, 0.000030, 0.076000},
	{{0, 25, -29, 0, -1, 0, 0, 0, -2, 1, 0}, 192.257380, 0.000020, 13.882000},
	{{0, 25, -29, 0, -1, 0, 0, 0, -2, 2, 0}, 224.165440, 0.000020, 0.075000},
	{{0, 25, -29, 0, 0, -2, 0, 0, -2, 1, 0}, 245.987000, 0.000010, 11.307000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, -1, 0}, 51.249510, 0.000010, 0.038000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, 0, 2}, 51.249510, 0.000020, 0.073000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, 1, 0}, 105.493360, 0.000030, 6.396000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, 2, 0}, 228.233620, 0.000020, 0.075000},
	{{0, 25, -29, 0, 0, 1, 0, 0, -2, 1, 0}, 139.021380, 0.000010, 5.255000},
	{{0, 25, -29, 0, 1, 0, 0, 0, -2, 0, 0}, 220.294060, 0.000020, 0.077000},
	{{0, 25, -29, 0, 1, 0, 0, 0, -2, 1, 0}, 82.678680, 0.000020, 4.156000},
	{{0, 25, -29, 3, 0, 0, 0, 0, 0, -2, 0}, 358.071890, 0.000010, 0.075000},
	{{0, 25, -29, 3, 0, 0, 0, 0, 0, -1, 0}, 284.286910, 0.000010, 44.205000},
	{{0, 25, -29, 3, 0, 0, 0, 0, 0, 0, 0}, 358.071890, 0.000010, 0.076000},
	{{0, 25, -28, -2, 0, 0, 0, 0, -2, 0, 0}, 190.527670, 0.000020, 0.076000},
	{{0, 25, -28, -2, 0, 0, 0, 0, -2, 2, 0}, 190.527670, 0.000020, 0.075000},
	{{0, 25, -28, 0, -1, 0, 0, 0, -1, 1, -1}, 9.236480, 0.000020, 54.729000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -1, 0, 0}, 253.205800, 0.000010, 3.713000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -1, 1, -1}, 253.368580, 0.000130, 9.749000},
	{{0, 25, -28, 0, 0, 0, 0, 0, 0, -1, 0}, 43.011800, 0.000010, 1.619000},
	{{0, 25, -28, 0, 1, 0, 0, 0, 0, -1, 0}, 283.662960, 0.000010, 1.875000},
	{{0, 25, -27, -4, 0, 0, 0, 0, -2, 0, 0}, 173.139050, 0.000020, 0.076000},
	{{0, 25, -27, -4, 0, 0, 0, 0, -2, 2, 0}, 173.139050, 0.000020, 0.075000},
	{{0, 25, -27, 0, -4, 0, 0, 0, 0, -1, 0}, 72.960860, 0.000010, 22.170000},
	{{0, 25, -27, 0, -3, 0, 0, 0, 0, -1, 0}, 62.265360, 0.000010, 7.727000},
	{{0, 25, -27, 0, -1, 0, 0, 0, 0, -1, 0}, 190.539260, 0.000010, 3.356000},
	{{0, 25, -27, 0, 0, 0, 0, 0, -2, 2, 0}, 176.160320, 0.000020, 0.065000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, -2, 0}, 179.517640, 0.000040, 0.078000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, -1, 0}, 353.094590, 0.000150, 2.616000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 0, -2}, 356.315990, 0.000020, 0.076000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 0, -1}, 346.366520, 0.000020, 4.639000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 0, 0}, 177.211980, 0.000100, 0.073000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 1, -2}, 356.315990, 0.000340, 20.488000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 2, -2}, 356.315990, 0.000020, 0.075000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 1, -1, -1}, 166.599110, 0.000020, 1.489000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 2, -2, 0}, 357.882120, 0.000010, 0.084000},
	{{0, 25, -27, 0, 1, 0, 0, 0, 0, -1, 0}, 270.632280, 0.000030, 2.143000},
	{{0, 25, -26, -2, 0, 0, 0, 0, 0, 1, -2}, 124.389110, 0.000010, 68.695000},
	{{0, 25, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 91.623360, 0.000020, 0.099000},
	{{0, 25, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 91.623360, 0.000020, 0.061000},
	{{0, 25, -26, 0, 0, 0, 0, 0, -1, 1, -3}, 67.085150, 0.000010, 0.040000},
	{{0, 25, -26, 0, 0, 0, 0, 0, -1, 2, -3}, 67.085150, 0.000010, 0.087000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 0, -2, 0}, 91.569070, 0.000010, 0.084000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 276.854990, 0.000020, 0.723000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 91.940760, 0.000050, 0.068000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, -1, -1}, 67.339340, 0.000120, 3.044000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 0, -3}, 67.085150, 0.000050, 0.075000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 0, -2}, 92.293470, 0.000030, 6.180000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 0, -1}, 247.185880, 0.000030, 0.074000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 1, -3}, 67.085150, 0.000940, 201.839000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 2, -3}, 67.085150, 0.000050, 0.075000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 2, -1, -2}, 272.185680, 0.000010, 1.379000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 2, -1, 0}, 92.186050, 0.000020, 0.038000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 2, 0, 0}, 92.185700, 0.000050, 0.025000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 3, 0, -3}, 67.085150, 0.000010, 0.087000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 3, 1, -3}, 67.085150, 0.000010, 0.040000},
	{{0, 25, -25, -8, 0, 0, 0, 0, -2, 1, 0}, 115.838910, 0.000010, 10.295000},
	{{0, 25, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 179.447740, 0.000060, 0.110000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 0, -2, 0}, 359.551430, 0.000030, 0.092000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 359.880130, 0.000050, 0.064000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 2, -2, 0}, 179.679180, 0.000010, 0.072000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 2, -1, -2}, 179.505440, 0.000140, 3.639000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 2, -1, 0}, 359.489100, 0.000010, 0.037000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 2, 0, 0}, 359.496910, 0.000080, 0.025000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 2, 2, 0}, 359.501800, 0.000010, 0.015000},
	{{0, 25, -24, -3, 0, 0, 0, 0, 2, -3, 0}, 123.097360, 0.000010, 75.446000},
	{{0, 25, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 274.799870, 0.000010, 0.024000},
	{{0, 25, -21, -15, 0, 0, 0, 0, -2, 1, 0}, 207.923140, 0.000030, 5.523000},
	{{0, 25, -21, -12, 0, 0, 0, 0, 0, -1, 0}, 302.103640, 0.000050, 473.049000},
	{{0, 25, -18, -21, 0, 0, 0, 0, -2, 1, 0}, 301.595790, 0.000010, 110.782000},
	{{0, 26, -37, 15, 0, 0, 0, 0, 0, -1, 0}, 308.093850, 0.000010, 59.214000},
	{{0, 26, -36, 10, 0, 0, 0, 0, -2, 1, 0}, 167.152050, 0.000010, 10.131000},
	{{0, 26, -35, 8, 0, 0, 0, 0, -2, 1, 0}, 65.160500, 0.000030, 28.298000},
	{{0, 26, -34, 6, 0, 0, 0, 0, -2, 0, 0}, 109.507760, 0.000010, 0.075000},
	{{0, 26, -34, 6, 0, 0, 0, 0, -2, 2, 0}, 109.507760, 0.000010, 0.076000},
	{{0, 26, -33, 4, 0, 0, 0, 0, -2, 0, 0}, 80.748750, 0.000020, 0.075000},
	{{0, 26, -33, 4, 0, 0, 0, 0, -2, 1, 0}, 291.651880, 0.000010, 10.941000},
	{{0, 26, -33, 4, 0, 0, 0, 0, -2, 2, 0}, 80.748750, 0.000020, 0.076000},
	{{0, 26, -32, 0, 1, 0, 0, 0, -2, 1, 0}, 142.001070, 0.000010, 0.882000},
	{{0, 26, -32, 2, 0, 0, 0, 0, -2, 0, 0}, 231.199790, 0.000040, 0.075000},
	{{0, 26, -32, 2, 0, 0, 0, 0, -2, 1, 0}, 208.740740, 0.000040, 6.461000},
	{{0, 26, -32, 2, 0, 0, 0, 0, -2, 2, 0}, 231.199790, 0.000040, 0.076000},
	{{0, 26, -32, 3, 0, 0, 0, 0, -2, 1, 0}, 20.159850, 0.000020, 2.653000},
	{{0, 26, -32, 4, 0, 0, 0, 0, -1, 0, 0}, 109.645010, 0.000010, 46.311000},
	{{0, 26, -31, 0, -1, 0, 0, 0, -2, 0, 0}, 152.014480, 0.000020, 0.074000},
	{{0, 26, -31, 0, -1, 0, 0, 0, -2, 1, 0}, 163.445690, 0.000020, 3.307000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, -2, 2}, 143.915610, 0.000020, 0.076000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, 0, 2}, 143.915610, 0.000020, 0.075000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, 1, 0}, 140.100120, 0.000010, 4.584000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, 2, 0}, 150.462880, 0.000020, 0.077000},
	{{0, 26, -31, 0, 0, 2, 0, 0, -2, 1, 0}, 312.598810, 0.000030, 6.656000},
	{{0, 26, -31, 0, 1, 0, 0, 0, -2, 0, 0}, 109.358860, 0.000070, 0.075000},
	{{0, 26, -31, 0, 3, 0, 0, 0, -2, 0, 0}, 286.320400, 0.000020, 0.076000},
	{{0, 26, -31, 0, 3, 0, 0, 0, -2, 1, 0}, 264.649320, 0.000050, 28.754000},
	{{0, 26, -31, 1, 0, 0, 0, 0, -2, 1, 0}, 50.681760, 0.000010, 3.189000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -2, -1, 0}, 21.862590, 0.000020, 0.039000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 33.932430, 0.000020, 0.080000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -2, 1, 0}, 51.200220, 0.000030, 1.279000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -2, 2, 0}, 51.006430, 0.000010, 0.071000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -1, -1, 1}, 158.662320, 0.000010, 16.230000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -1, 0, 0}, 336.428690, 0.000020, 9.511000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 0, -2, 0}, 357.937670, 0.000030, 0.070000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 0, 0, 0}, 177.937670, 0.000040, 0.082000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 2, -2, 0}, 177.937670, 0.000050, 0.095000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 2, -1, 0}, 177.937670, 0.000080, 0.042000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 2, 0, 0}, 177.937670, 0.000010, 0.027000},
	{{0, 26, -30, 2, 0, 0, 0, 0, 0, -1, 0}, 71.126240, 0.000030, 14.042000},
	{{0, 26, -29, -4, 0, 0, 0, 0, -2, -1, 2}, 265.152960, 0.000030, 88.047000},
	{{0, 26, -29, -4, 0, 0, 0, 0, -2, 1, 0}, 265.304430, 0.000010, 2.900000},
	{{0, 26, -29, -3, 0, 0, 0, 0, -2, 0, 0}, 174.803030, 0.000010, 0.077000},
	{{0, 26, -29, -3, 0, 0, 0, 0, -2, 1, 0}, 125.734110, 0.000040, 5.353000},
	{{0, 26, -29, -3, 0, 0, 0, 0, -2, 2, 0}, 174.803030, 0.000010, 0.074000},
	{{0, 26, -29, -2, 0, 0, 0, 0, -2, 1, 0}, 190.639630, 0.000010, 1.392000},
	{{0, 26, -29, -2, 0, 0, 0, 0, -1, -1, 1}, 138.154850, 0.000020, 569.866000},
	{{0, 26, -29, 0, -1, 0, 0, 0, 0, -1, 0}, 154.671020, 0.000020, 13.080000},
	{{0, 26, -29, 0, 0, -1, 0, 0, 0, -1, 0}, 141.066380, 0.000010, 38.315000},
	{{0, 26, -29, 0, 0, 0, -1, 0, 0, -1, 0}, 270.165050, 0.000010, 246.676000},
	{{0, 26, -29, 0, 0, 0, 0, -2, 0, -1, 0}, 173.111270, 0.000030, 233.097000},
	{{0, 26, -29, 0, 0, 0, 0, -1, 0, -1, 0}, 308.273870, 0.000030, 562.132000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -4, -1, 0}, 75.000740, 0.000010, 0.020000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -4, 0, 0}, 75.000740, 0.000030, 0.028000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -4, 1, 0}, 75.000740, 0.000020, 0.044000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -3, 0}, 75.000740, 0.000010, 0.020000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -2, 0}, 75.000740, 0.000150, 0.026000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -1, 0}, 74.988140, 0.001210, 0.040000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 74.778250, 0.001310, 0.087000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -1, -1, 0}, 255.000740, 0.000030, 0.081000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -4, 0}, 75.000740, 0.000030, 0.025000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -3, 0}, 75.047320, 0.000390, 0.038000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, -2}, 255.000740, 0.000030, 0.025000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, 0}, 75.047260, 0.005790, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, 2}, 255.000740, 0.000010, 0.074000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, -2}, 255.000740, 0.000210, 0.037000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, 0}, 75.000740, 0.104890, 127.422000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, 2}, 255.000740, 0.000210, 0.037000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, -2}, 255.000740, 0.000010, 0.074000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, -1}, 72.646650, 0.000010, 6.293000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, 0}, 75.285200, 0.005050, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, 2}, 255.000740, 0.000030, 0.025000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 1, 0}, 75.285120, 0.000340, 0.038000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 2, 0}, 75.000740, 0.000030, 0.025000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 1, -1, 0}, 255.000740, 0.000030, 0.081000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, -2, 0}, 74.953680, 0.001160, 0.087000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, -1, 0}, 75.013550, 0.001200, 0.040000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, 0, 0}, 75.000740, 0.000150, 0.026000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, 1, 0}, 75.000740, 0.000010, 0.020000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 4, -3, 0}, 75.000740, 0.000020, 0.044000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 4, -2, 0}, 75.000740, 0.000030, 0.028000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 4, -1, 0}, 75.000740, 0.000010, 0.020000},
	{{0, 26, -29, 0, 0, 1, 0, 0, 0, -1, 0}, 336.287010, 0.000030, 23.926000},
	{{0, 26, -29, 0, 1, 0, 0, 0, 0, -1, 0}, 14.102520, 0.000030, 10.852000},
	{{0, 26, -29, 0, 2, 0, 0, 0, 0, -1, 0}, 271.641680, 0.000010, 5.667000},
	{{0, 26, -29, 2, 0, 0, 0, 0, 1, -1, -1}, 49.892040, 0.000020, 57.304000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -2, -2, 0}, 332.063810, 0.000010, 0.027000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -2, -1, 0}, 332.063810, 0.000080, 0.042000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 332.063810, 0.000050, 0.095000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -1, -1, -1}, 166.278270, 0.000040, 0.040000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, -2, 0}, 332.050470, 0.000040, 0.082000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, -1, 0}, 351.425780, 0.000020, 0.992000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 159.942250, 0.000070, 0.070000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -3, -1}, 166.278270, 0.000010, 0.038000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -2, -1}, 166.264390, 0.000170, 0.075000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -1, -1}, 166.278270, 0.003140, 21.779000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, 0, -1}, 166.307760, 0.000310, 0.076000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, 1, -1}, 166.278270, 0.000010, 0.038000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 2, -1, 0}, 152.063810, 0.000010, 0.039000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 2, 0, 0}, 358.968000, 0.000020, 0.026000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 3, -2, -1}, 166.292180, 0.000030, 0.087000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 3, -1, -1}, 166.278270, 0.000040, 0.041000},
	{{0, 26, -28, 0, 0, 1, 0, 0, 1, -1, -1}, 301.761160, 0.000010, 83.548000},
	{{0, 26, -28, 0, 1, 0, 0, 0, 1, -1, -1}, 75.294500, 0.000020, 26.051000},
	{{0, 26, -28, 2, 0, 0, 0, 0, 2, -1, -2}, 179.508590, 0.000010, 27.538000},
	{{0, 26, -27, -7, 0, 0, 0, 0, -2, 1, 0}, 55.963850, 0.000020, 16.646000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 0, -1, 0}, 272.124030, 0.000010, 0.498000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 0, 0, 0}, 92.081590, 0.000010, 0.066000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 1, -1, -1}, 66.311050, 0.000010, 1.048000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, -3, 0}, 272.165640, 0.000020, 4.277000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, -2, -2}, 272.163990, 0.000020, 0.075000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, -1, -2}, 272.163990, 0.000440, 10.032000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, -1, 0}, 92.166170, 0.000010, 0.037000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, 0, -2}, 272.163990, 0.000020, 0.076000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, 0, 0}, 92.165820, 0.000040, 0.025000},
	{{0, 26, -27, 0, 1, 0, 0, 0, 2, -1, -2}, 262.656580, 0.000010, 65.026000},
	{{0, 26, -26, -9, 0, 0, 0, 0, -2, 0, 0}, 206.761760, 0.000020, 0.075000},
	{{0, 26, -26, -9, 0, 0, 0, 0, -2, 1, 0}, 319.165510, 0.000070, 303.701000},
	{{0, 26, -26, -9, 0, 0, 0, 0, -2, 2, 0}, 206.761760, 0.000020, 0.075000},
	{{0, 26, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 359.653600, 0.000020, 0.055000},
	{{0, 26, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 179.752700, 0.000010, 0.332000},
	{{0, 26, -26, 0, 0, 0, 0, 0, 2, -1, 0}, 359.448800, 0.000020, 0.036000},
	{{0, 26, -26, 0, 0, 0, 0, 0, 2, 0, 0}, 359.448080, 0.000070, 0.024000},
	{{0, 26, -26, 0, 0, 0, 0, 0, 3, -2, -2}, 359.561370, 0.000120, 75.143000},
	{{0, 26, -25, 0, -1, 0, 0, 0, -2, 0, 0}, 180.525810, 0.000010, 0.132000},
	{{0, 26, -25, 0, 0, 0, 0, 0, 2, 0, 0}, 274.799750, 0.000010, 0.024000},
	{{0, 26, -24, 0, -2, 0, 0, 0, -2, 0, 0}, 359.596200, 0.000010, 0.151000},
	{{0, 26, -23, -15, 0, 0, 0, 0, -2, 1, 0}, 119.999590, 0.000010, 5.171000},
	{{0, 27, -37, 8, 0, 0, 0, 0, -2, -1, 2}, 50.457680, 0.000010, 177.824000},
	{{0, 27, -36, 7, 0, 0, 0, 0, -2, 1, 0}, 260.293980, 0.000020, 7.741000},
	{{0, 27, -35, 5, 0, 0, 0, 0, -2, 1, 0}, 200.763370, 0.000010, 15.196000},
	{{0, 27, -34, 2, 0, 0, 0, 0, -2, 1, 0}, 323.318390, 0.000020, 1.890000},
	{{0, 27, -34, 3, 0, 0, 0, 0, -2, 1, 0}, 29.440020, 0.000030, 409.620000},
	{{0, 27, -33, 0, 0, 0, 0, 0, -2, 1, 0}, 224.924490, 0.000010, 1.687000},
	{{0, 27, -33, 0, 1, 0, 0, 0, -2, 0, 0}, 141.992570, 0.000030, 0.073000},
	{{0, 27, -33, 0, 2, 0, 0, 0, -2, 1, 0}, 223.373020, 0.000020, 2.359000},
	{{0, 27, -33, 0, 3, 0, 0, 0, -2, -1, 2}, 219.418410, 0.000020, 161.700000},
	{{0, 27, -33, 0, 3, 0, 0, 0, -2, 1, 0}, 41.051980, 0.000030, 2.944000},
	{{0, 27, -33, 0, 7, 0, 0, 0, -2, 1, 0}, 26.590100, 0.000040, 403.129000},
	{{0, 27, -33, 2, 0, 0, 0, 0, -2, 1, 0}, 198.475890, 0.000020, 2.124000},
	{{0, 27, -32, 0, -1, 0, 0, 0, -2, 1, 0}, 203.451610, 0.000020, 3.095000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 69.340220, 0.000030, 0.078000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 2, 0}, 117.227690, 0.000060, 0.073000},
	{{0, 27, -32, 0, 1, 0, 0, 0, -2, 0, 0}, 49.943570, 0.000020, 0.078000},
	{{0, 27, -32, 0, 1, 0, 0, 0, -2, 1, 0}, 109.980050, 0.000030, 2.034000},
	{{0, 27, -32, 0, 1, 0, 0, 0, -2, 2, 0}, 229.690580, 0.000030, 0.073000},
	{{0, 27, -32, 0, 2, 0, 0, 0, -2, 1, 0}, 111.312420, 0.000020, 1.736000},
	{{0, 27, -32, 2, 0, 0, 0, 0, 0, -1, 0}, 94.775340, 0.000010, 3.298000},
	{{0, 27, -32, 3, 0, 0, 0, 0, 0, -1, 0}, 287.983870, 0.000010, 4.378000},
	{{0, 27, -31, -2, 0, 0, 0, 0, -2, 1, 0}, 102.552640, 0.000030, 2.907000},
	{{0, 27, -31, -1, 0, 0, 0, 0, -1, 0, 0}, 143.085600, 0.000010, 88.463000},
	{{0, 27, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 231.149110, 0.000030, 0.084000},
	{{0, 27, -31, 0, 0, 0, 0, 0, 0, -1, 0}, 165.112150, 0.000020, 2.728000},
	{{0, 27, -31, 0, 1, 0, 0, 0, 0, -1, 0}, 38.067260, 0.000030, 3.542000},
	{{0, 27, -31, 0, 4, 0, 0, 0, 0, -1, 0}, 250.538010, 0.000020, 34.001000},
	{{0, 27, -30, -4, 0, 0, 0, 0, -2, 1, 0}, 265.295930, 0.000010, 3.563000},
	{{0, 27, -30, 0, 0, 0, 0, 0, 0, -1, 0}, 70.225830, 0.000010, 1.579000},
	{{0, 27, -30, 0, 0, 0, 0, 0, 1, -1, -1}, 254.639110, 0.000010, 2.379000},
	{{0, 27, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 188.805210, 0.000010, 0.102000},
	{{0, 27, -29, 0, 0, 0, 0, 0, 1, -1, -1}, 166.113620, 0.000020, 1.725000},
	{{0, 27, -29, 0, 0, 0, 0, 0, 2, -3, 0}, 359.383430, 0.000010, 7.110000},
	{{0, 27, -29, 0, 0, 0, 0, 0, 2, 0, 0}, 359.141040, 0.000020, 0.025000},
	{{0, 27, -28, -5, 0, 0, 0, 0, 0, -1, 0}, 173.994080, 0.000020, 39.921000},
	{{0, 27, -28, -3, 0, 0, 0, 0, 1, -1, -1}, 111.109890, 0.000020, 64.739000},
	{{0, 27, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 91.569170, 0.000010, 0.113000},
	{{0, 27, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 91.569170, 0.000010, 0.057000},
	{{0, 27, -28, 0, 0, 0, 0, 0, 2, -2, 0}, 272.142610, 0.000020, 0.071000},
	{{0, 27, -28, 0, 0, 0, 0, 0, 2, -1, -2}, 272.144700, 0.000010, 1.902000},
	{{0, 27, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 179.311920, 0.000020, 0.127000},
	{{0, 27, -27, 0, 0, 0, 0, 0, 0, 0, 0}, 134.802940, 0.000010, 0.059000},
	{{0, 27, -27, 0, 0, 0, 0, 0, 2, -1, 0}, 359.397600, 0.000020, 0.035000},
	{{0, 27, -27, 0, 0, 0, 0, 0, 2, 0, 0}, 359.396880, 0.000050, 0.024000},
	{{0, 27, -25, 0, -2, 0, 0, 0, -2, 0, 0}, 359.554160, 0.000010, 0.166000},
	{{0, 27, -20, -20, 0, 0, 0, 0, 0, -2, 0}, 329.815390, 0.000020, 0.075000},
	{{0, 27, -20, -20, 0, 0, 0, 0, 0, -1, 0}, 329.815390, 0.000310, 3189.335000},
	{{0, 27, -20, -20, 0, 0, 0, 0, 0, 0, 0}, 329.815390, 0.000020, 0.075000},
	{{0, 27, -19, 0, -2, 0, 0, 0, -2, 0, 0}, 72.906330, 0.000030, 58.910000},
	{{0, 28, -42, 15, 0, 0, 0, 0, -2, 1, 0}, 210.602980, 0.000020, 122.320000},
	{{0, 28, -39, 11, 0, 0, 0, 0, -1, 0, 0}, 136.464290, 0.000020, 179.530000},
	{{0, 28, -37, 9, 0, 0, 0, 0, 0, -1, 0}, 166.442720, 0.000020, 22.701000},
	{{0, 28, -36, 4, 0, 0, 0, 0, -2, 1, 0}, 309.955150, 0.000010, 6.264000},
	{{0, 28, -36, 7, 0, 0, 0, 0, 0, -1, 0}, 167.619740, 0.000010, 51.772000},
	{{0, 28, -35, 0, 2, 0, 0, 0, -2, 1, 0}, 323.155730, 0.000010, 1.252000},
	{{0, 28, -35, 2, 0, 0, 0, 0, -2, 0, 0}, 143.308480, 0.000030, 0.076000},
	{{0, 28, -35, 2, 0, 0, 0, 0, -2, 1, 0}, 337.760640, 0.000020, 10.387000},
	{{0, 28, -35, 2, 0, 0, 0, 0, -2, 2, 0}, 143.308480, 0.000030, 0.075000},
	{{0, 28, -35, 5, 0, 0, 0, 0, 0, -1, 0}, 108.570780, 0.000020, 12.094000},
	{{0, 28, -34, 0, -1, 0, 0, 0, -2, 1, 0}, 80.627190, 0.000020, 19.458000},
	{{0, 28, -34, 0, 0, -1, 0, 0, -2, 1, 0}, 106.332500, 0.000160, 964.920000},
	{{0, 28, -34, 0, 0, -1, 0, 0, -2, 2, 0}, 332.646530, 0.000030, 0.075000},
	{{0, 28, -34, 0, 0, 0, -1, 0, -2, 1, 0}, 224.271000, 0.000030, 47.598000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -4, 2, 0}, 242.474350, 0.000020, 0.087000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 62.474350, 0.000080, 0.076000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -2, 2, 0}, 62.474350, 0.000080, 0.075000},
	{{0, 28, -34, 0, 0, 0, 0, 0, 0, 0, 0}, 242.474350, 0.000020, 0.087000},
	{{0, 28, -34, 0, 0, 1, 0, 0, -2, 1, 0}, 139.018180, 0.000020, 14.957000},
	{{0, 28, -34, 0, 0, 2, 0, 0, -2, 1, 0}, 49.610810, 0.000010, 9.920000},
	{{0, 28, -34, 0, 1, 0, 0, 0, -2, 0, 0}, 141.546210, 0.000020, 0.076000},
	{{0, 28, -34, 0, 1, 0, 0, 0, -2, 1, 0}, 304.199520, 0.000020, 8.531000},
	{{0, 28, -34, 0, 1, 0, 0, 0, -2, 2, 0}, 141.546210, 0.000020, 0.075000},
	{{0, 28, -34, 0, 2, 0, 0, 0, -2, 0, 0}, 230.949380, 0.000070, 0.077000},
	{{0, 28, -34, 3, 0, 0, 0, 0, 0, -1, 0}, 20.141210, 0.000010, 6.847000},
	{{0, 28, -33, -2, 0, 0, 0, 0, -2, 0, 0}, 9.671910, 0.000020, 0.075000},
	{{0, 28, -33, -2, 0, 0, 0, 0, -2, 1, 0}, 176.052320, 0.000020, 32.834000},
	{{0, 28, -33, -2, 0, 0, 0, 0, -2, 2, 0}, 9.671910, 0.000020, 0.076000},
	{{0, 28, -33, 0, 0, 0, 0, 0, -1, 1, -1}, 64.923060, 0.000140, 47.954000},
	{{0, 28, -33, 0, 0, 0, 0, 0, 0, -2, 0}, 21.412700, 0.000010, 0.071000},
	{{0, 28, -33, 0, 0, 0, 0, 0, 0, 0, 0}, 201.412700, 0.000010, 0.080000},
	{{0, 28, -33, 0, 1, 0, 0, 0, -2, 1, 0}, 49.777410, 0.000010, 0.895000},
	{{0, 28, -32, -3, 0, 0, 0, 0, -2, 1, 0}, 86.844200, 0.000010, 2.284000},
	{{0, 28, -32, 0, -3, 0, 0, 0, 0, -1, 0}, 181.442960, 0.000050, 167.191000},
	{{0, 28, -32, 0, -2, 0, 0, 0, 0, -1, 0}, 115.516850, 0.000030, 11.076000},
	{{0, 28, -32, 0, -1, 0, 0, 0, 0, -1, 0}, 15.768630, 0.000010, 5.728000},
	{{0, 28, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 231.096260, 0.000020, 0.089000},
	{{0, 28, -32, 0, 0, 0, 0, 0, 0, -1, 0}, 119.610740, 0.000020, 3.863000},
	{{0, 28, -32, 0, 1, 0, 0, 0, 0, -1, 0}, 218.000150, 0.000010, 2.914000},
	{{0, 28, -32, 0, 1, 0, 0, 0, 0, 1, -2}, 200.249250, 0.000010, 103.254000},
	{{0, 28, -31, -4, 0, 0, 0, 0, -1, 0, 0}, 85.285780, 0.000010, 52.176000},
	{{0, 28, -31, -2, 0, 0, 0, 0, 0, -1, 0}, 10.288120, 0.000010, 5.114000},
	{{0, 28, -31, 0, 0, 0, 0, 0, 1, -1, -1}, 254.758860, 0.000040, 4.875000},
	{{0, 28, -31, 0, 0, 0, 0, 0, 1, 0, -2}, 258.064050, 0.000030, 26.061000},
	{{0, 28, -30, -4, 0, 0, 0, 0, 0, -1, 0}, 173.080770, 0.000020, 7.567000},
	{{0, 28, -30, 0, 0, 0, 0, 0, 2, -1, -2}, 359.253040, 0.000040, 6.607000},
	{{0, 28, -30, 0, 0, 0, 0, 0, 2, 0, -3}, 345.932810, 0.000050, 64.963000},
	{{0, 28, -30, 0, 0, 0, 0, 0, 2, 0, 0}, 359.301440, 0.000010, 0.025000},
	{{0, 28, -29, -6, 0, 0, 0, 0, 0, -1, 0}, 144.340120, 0.000010, 14.537000},
	{{0, 28, -29, 0, 0, 0, 0, 0, 0, 0, 0}, 114.154060, 0.000020, 0.061000},
	{{0, 28, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 359.513770, 0.000010, 0.052000},
	{{0, 28, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 179.343880, 0.000020, 0.057000},
	{{0, 28, -28, 0, 0, 0, 0, 0, 2, -1, 0}, 359.343920, 0.000010, 0.034000},
	{{0, 28, -28, 0, 0, 0, 0, 0, 2, 0, 0}, 359.343910, 0.000040, 0.024000},
	{{0, 28, -25, -17, 0, 0, 0, 0, -2, 1, 0}, 337.720250, 0.000010, 174.819000},
	{{0, 29, -41, 10, 0, 0, 0, 0, -2, 1, 0}, 30.907370, 0.000020, 40.450000},
	{{0, 29, -37, 6, 0, 0, 0, 0, 0, -1, 0}, 109.364830, 0.000010, 13.419000},
	{{0, 29, -36, 0, 0, 0, 0, 0, -2, 0, 2}, 136.733460, 0.000020, 0.075000},
	{{0, 29, -36, 0, 2, 0, 0, 0, -2, 1, 0}, 110.608820, 0.000030, 5.782000},
	{{0, 29, -36, 0, 3, 0, 0, 0, -2, 1, 0}, 310.054650, 0.000010, 11.280000},
	{{0, 29, -36, 0, 4, 0, 0, 0, -2, 0, 0}, 226.900540, 0.000030, 0.075000},
	{{0, 29, -36, 0, 4, 0, 0, 0, -2, 1, 0}, 163.968490, 0.000040, 230.025000},
	{{0, 29, -36, 0, 4, 0, 0, 0, -2, 2, 0}, 303.594160, 0.000010, 0.075000},
	{{0, 29, -36, 2, 0, 0, 0, 0, -1, -1, 1}, 14.183800, 0.000010, 644.451000},
	{{0, 29, -36, 4, 0, 0, 0, 0, 0, -2, 0}, 260.605810, 0.000010, 0.076000},
	{{0, 29, -36, 4, 0, 0, 0, 0, 0, -1, 0}, 87.167290, 0.000020, 89.650000},
	{{0, 29, -36, 4, 0, 0, 0, 0, 0, 0, 0}, 260.605810, 0.000010, 0.075000},
	{{0, 29, -35, 0, 0, 0, 0, 0, -2, 0, 0}, 149.404270, 0.000010, 0.079000},
	{{0, 29, -35, 0, 0, 0, 0, 0, -2, 2, 0}, 149.404270, 0.000010, 0.072000},
	{{0, 29, -35, 0, 1, 0, 0, 0, -2, 1, 0}, 141.970570, 0.000020, 1.346000},
	{{0, 29, -35, 0, 2, 0, 0, 0, -2, 1, 0}, 230.901810, 0.000010, 1.209000},
	{{0, 29, -35, 0, 2, 0, 0, 0, -1, 0, 0}, 50.901810, 0.000010, 16.677000},
	{{0, 29, -35, 2, 0, 0, 0, 0, 0, -1, 0}, 245.238610, 0.000020, 19.152000},
	{{0, 29, -34, -3, 0, 0, 0, 0, -2, 1, 0}, 86.678200, 0.000020, 15.778000},
	{{0, 29, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 57.109440, 0.000010, 0.086000},
	{{0, 29, -34, 0, 0, 0, 0, 0, 0, -2, 0}, 237.109440, 0.000050, 0.075000},
	{{0, 29, -34, 0, 0, 0, 0, 0, 0, 0, 0}, 237.109440, 0.000050, 0.076000},
	{{0, 29, -34, 0, 0, 0, 0, 0, 2, -2, 0}, 57.109440, 0.000010, 0.088000},
	{{0, 29, -34, 0, 0, 1, 0, 0, 0, -1, 0}, 230.823610, 0.000030, 12.250000},
	{{0, 29, -34, 0, 0, 2, 0, 0, 0, -1, 0}, 307.045750, 0.000020, 20.971000},
	{{0, 29, -34, 0, 1, 0, 0, 0, 0, -2, 0}, 198.309190, 0.000030, 0.075000},
	{{0, 29, -34, 0, 1, 0, 0, 0, 0, -1, 0}, 244.258430, 0.000020, 31.972000},
	{{0, 29, -34, 0, 1, 0, 0, 0, 0, 0, 0}, 264.886450, 0.000020, 0.076000},
	{{0, 29, -34, 0, 2, 0, 0, 0, 0, -1, 0}, 11.176430, 0.000020, 18.859000},
	{{0, 29, -33, -2, 0, 0, 0, 0, 0, -1, 0}, 282.738770, 0.000010, 5.588000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -3, 0}, 336.271800, 0.000030, 0.075000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -2, 0}, 335.628310, 0.000480, 385.960000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -1, -1}, 340.965310, 0.000010, 5.905000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -1, 0}, 287.135220, 0.000030, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, -1, -1, -1}, 162.705350, 0.000030, 0.040000},
	{{0, 29, -33, 0, 2, 0, 0, 0, -1, 0, -1}, 162.705350, 0.000030, 0.087000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, -2, -1}, 162.705350, 0.000120, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, -1, -1}, 162.705350, 0.002260, 1352.997000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, 0, -1}, 162.705350, 0.000120, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 3, -2, -1}, 162.705350, 0.000030, 0.087000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 3, -1, -1}, 162.705350, 0.000030, 0.040000},
	{{0, 29, -30, 0, 0, 0, 0, 0, 4, -3, -2}, 92.533370, 0.000070, 348.536000},
	{{0, 29, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 179.227880, 0.000010, 0.152000},
	{{0, 29, -29, 0, 0, 0, 0, 0, 2, 0, 0}, 179.272950, 0.000010, 0.023000},
	{{0, 29, -27, -13, 0, 0, 0, 0, 0, -1, 0}, 148.852540, 0.000010, 36.394000},
	{{0, 29, -24, 3, 0, 0, 0, 0, -2, 0, 0}, 128.047730, 0.000030, 441.048000},
	{{0, 30, -41, 7, 0, 0, 0, 0, -2, 1, 0}, 229.643150, 0.000010, 173.980000},
	{{0, 30, -40, 5, 0, 0, 0, 0, -2, 1, 0}, 78.539300, 0.000020, 17.355000},
	{{0, 30, -38, 0, 0, 0, 0, 0, -2, 0, 0}, 41.552960, 0.000020, 0.072000},
	{{0, 30, -38, 3, 0, 0, 0, 0, -1, 0, 0}, 143.313550, 0.000020, 125.038000},
	{{0, 30, -37, 0, 0, 0, 0, 0, -2, 1, 0}, 335.687510, 0.000010, 3.522000},
	{{0, 30, -37, 0, 1, 0, 0, 0, -2, 1, 0}, 49.626830, 0.000010, 2.716000},
	{{0, 30, -37, 0, 2, 0, 0, 0, -2, 1, 0}, 143.134280, 0.000030, 2.210000},
	{{0, 30, -36, 0, 2, 0, 0, 0, 0, -1, 0}, 230.851500, 0.000020, 3.111000},
	{{0, 30, -36, 1, 0, 0, 0, 0, 0, -1, 0}, 322.775640, 0.000040, 24.024000},
	{{0, 30, -35, -1, 0, 0, 0, 0, 0, -1, 0}, 262.198710, 0.000050, 45.992000},
	{{0, 30, -35, 3, 0, 0, 0, 0, 2, -1, -2}, 149.734940, 0.000020, 394.087000},
	{{0, 30, -31, 0, 0, 0, 0, 0, 2, 0, 0}, 272.074740, 0.000020, 0.024000},
	{{0, 30, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 179.179460, 0.000020, 0.167000},
	{{0, 30, -25, 0, -1, 0, 0, 0, -3, 0, 1}, 27.773630, 0.000030, 428.143000},
	{{0, 30, -24, 0, 0, -1, 0, 0, -2, 0, 0}, 300.843570, 0.000060, 174.065000},
	{{0, 30, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 256.670610, 0.000080, 35.458000},
	{{0, 31, -43, 11, 0, 0, 0, 0, 0, -1, 0}, 53.722790, 0.000020, 62.465000},
	{{0, 31, -41, 4, 0, 0, 0, 0, -2, 1, 0}, 77.393500, 0.000010, 27.611000},
	{{0, 31, -40, 2, 0, 0, 0, 0, -2, 1, 0}, 146.218290, 0.000010, 36.833000},
	{{0, 31, -39, 0, 0, 1, 0, 0, -2, 1, 0}, 316.044610, 0.000010, 17.677000},
	{{0, 31, -39, 0, 0, 2, 0, 0, -2, 1, 0}, 217.683540, 0.000030, 44.205000},
	{{0, 31, -39, 0, 0, 3, 0, 0, -2, 1, 0}, 304.059910, 0.000010, 88.294000},
	{{0, 31, -39, 0, 1, 0, 0, 0, -2, 1, 0}, 74.793710, 0.000070, 160.924000},
	{{0, 31, -39, 0, 2, 0, 0, 0, -2, 0, 0}, 230.514420, 0.000010, 0.076000},
	{{0, 31, -39, 0, 2, 0, 0, 0, -2, 1, 0}, 175.366250, 0.000030, 12.806000},
	{{0, 31, -39, 0, 2, 0, 0, 0, -2, 2, 0}, 50.514420, 0.000010, 0.075000},
	{{0, 31, -39, 0, 3, 0, 0, 0, -2, 1, 0}, 40.763150, 0.000010, 6.158000},
	{{0, 31, -38, 2, 0, 0, 0, 0, 0, -1, 0}, 143.327080, 0.000010, 5.029000},
	{{0, 31, -37, 0, -2, 0, 0, 0, 0, -1, 0}, 84.809140, 0.000010, 30.171000},
	{{0, 31, -37, 0, -1, 0, 0, 0, 0, -1, 0}, 299.468690, 0.000050, 19.547000},
	{{0, 31, -37, 0, 0, 0, 0, 0, 0, -1, 0}, 5.271810, 0.000020, 7.382000},
	{{0, 31, -37, 0, 0, 0, 0, 0, 0, 0, 0}, 67.428060, 0.000030, 0.075000},
	{{0, 31, -37, 0, 1, 0, 0, 0, 0, -1, 0}, 321.899530, 0.000030, 4.550000},
	{{0, 31, -37, 0, 2, 0, 0, 0, 0, -1, 0}, 230.800100, 0.000010, 3.289000},
	{{0, 31, -36, -2, 0, 0, 0, 0, 0, -1, 0}, 190.028690, 0.000010, 13.871000},
	{{0, 31, -36, 0, 1, 0, 0, 0, 1, 0, -2}, 229.626790, 0.000120, 1326.246000},
	{{0, 31, -35, 0, 0, 0, 0, 0, 2, -1, -2}, 170.520190, 0.000050, 35.801000},
	{{0, 31, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 326.206270, 0.000020, 0.120000},
	{{0, 31, -32, 0, 0, 0, 0, 0, 2, 0, 0}, 272.049020, 0.000020, 0.023000},
	{{0, 31, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 179.135610, 0.000010, 0.187000},
	{{0, 31, -31, 0, 0, 0, 0, 0, 2, -2, 0}, 179.179910, 0.000010, 0.057000},
	{{0, 31, -31, 0, 0, 0, 0, 0, 2, 0, 0}, 179.171770, 0.000020, 0.023000},
	{{0, 31, -29, 0, -2, 0, 0, 0, -2, 0, 0}, 359.371670, 0.000010, 0.285000},
	{{0, 31, -23, -5, 0, 0, 0, 0, -2, 0, 0}, 181.777440, 0.000010, 213.001000},
	{{0, 32, -43, 8, 0, 0, 0, 0, 0, -1, 0}, 355.174830, 0.000020, 69.152000},
	{{0, 32, -40, -1, 0, 0, 0, 0, -2, 1, 0}, 29.513940, 0.000020, 301.177000},
	{{0, 32, -40, 0, 0, 0, 0, 0, -2, 0, 0}, 222.273590, 0.000020, 0.079000},
	{{0, 32, -39, 0, 0, 0, 0, 0, -2, 0, 0}, 137.498530, 0.000030, 0.085000},
	{{0, 32, -39, 0, 1, 0, 0, 0, 0, -1, 0}, 229.469070, 0.000020, 6.464000},
	{{0, 32, -39, 0, 3, 0, 0, 0, 0, -1, 0}, 166.037630, 0.000040, 71.941000},
	{{0, 32, -33, 0, 0, 0, 0, 0, 2, 0, 0}, 272.022210, 0.000010, 0.023000},
	{{0, 32, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 179.087970, 0.000010, 0.212000},
	{{0, 32, -32, 0, 0, 0, 0, 0, 2, 0, 0}, 179.116330, 0.000020, 0.022000},
	{{0, 32, -31, 7, 0, 0, 0, 0, -2, 0, 0}, 310.804280, 0.000040, 962.299000},
	{{0, 32, -28, 0, -2, 0, 0, 0, -3, 1, 0}, 184.515660, 0.000020, 425.427000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 1, -1}, 140.415620, 0.000020, 0.075000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 2, -1}, 140.415620, 0.000290, 2005.078000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 3, -1}, 140.415620, 0.000020, 0.075000},
	{{0, 32, -27, 0, -3, 0, 0, 0, -2, 0, 0}, 260.755220, 0.000030, 37.971000},
	{{0, 32, -25, 0, -2, 0, 0, 0, 0, 0, -2}, 25.238270, 0.000020, 321.594000},
	{{0, 33, -42, 0, 0, 0, 0, 0, -2, 0, 0}, 109.023290, 0.000020, 0.076000},
	{{0, 33, -42, 0, 0, 0, 0, 0, -2, 2, 0}, 109.023290, 0.000020, 0.075000},
	{{0, 33, -42, 3, 0, 0, 0, 0, 0, -1, 0}, 233.591810, 0.000030, 54.240000},
	{{0, 33, -40, 0, 0, 0, 0, 0, 0, 0, 0}, 137.730180, 0.000020, 0.073000},
	{{0, 33, -39, 0, 0, 0, 0, 0, 1, 1, -3}, 42.031610, 0.000100, 1300.532000},
	{{0, 33, -38, 0, 0, 0, 0, 0, 0, 0, 0}, 323.743860, 0.000020, 0.064000},
	{{0, 33, -37, 0, 0, 0, 0, 0, 0, 0, 0}, 230.807310, 0.000020, 0.060000},
	{{0, 33, -33, 0, 0, 0, 0, 0, -2, 0, 0}, 179.038180, 0.000010, 0.244000},
	{{0, 33, -33, 0, 0, 0, 0, 0, 2, 0, 0}, 179.055310, 0.000010, 0.022000},
	{{0, 33, -30, 0, 0, 0, 0, 0, -3, 0, 1}, 129.702120, 0.000020, 24.119000},
	{{0, 33, -30, 2, 0, 0, 0, 0, -2, 0, 0}, 272.633570, 0.000030, 31.389000},
	{{0, 33, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 53.968380, 0.000070, 10.501000},
	{{0, 33, -29, 0, 1, 0, 0, 0, -2, 0, 0}, 298.539550, 0.000040, 91.552000},
	{{0, 34, -44, 0, 3, 0, 0, 0, -2, 1, 0}, 175.436770, 0.000020, 25.665000},
	{{0, 34, -42, 0, 0, 0, 0, 0, 0, 0, 0}, 263.982470, 0.000020, 0.075000},
	{{0, 34, -40, 0, 0, 0, 0, 0, -2, 0, 0}, 51.804250, 0.000020, 0.106000},
	{{0, 34, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 178.988810, 0.000010, 0.288000},
	{{0, 34, -32, 0, -2, 0, 0, 0, -2, 0, 0}, 359.199750, 0.000020, 0.610000},
	{{0, 34, -30, -1, 0, 0, 0, 0, -2, 0, 0}, 97.605660, 0.000110, 720.298000},
	{{0, 35, -47, 3, 0, 0, 0, 0, -2, 1, 0}, 306.607940, 0.000020, 150.902000},
	{{0, 35, -46, 0, 7, 0, 0, 0, -2, 1, 0}, 316.292870, 0.000030, 586.536000},
	{{0, 35, -40, 0, 0, 0, 0, 0, -2, 0, 0}, 323.685040, 0.000030, 0.127000},
	{{0, 35, -33, 0, 0, 0, 0, 0, -2, 0, 0}, 14.017540, 0.000030, 1.185000},
	{{0, 35, -32, 0, -2, 0, 0, 0, -2, 0, 0}, 25.049190, 0.000070, 78.189000},
	{{0, 35, -32, 0, 0, -3, 0, 0, -2, 0, 0}, 177.308590, 0.000020, 18.528000},
	{{0, 35, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 243.551980, 0.000040, 6.418000},
	{{0, 35, -32, 0, 0, 0, 0, 0, -2, 1, -1}, 308.950200, 0.000010, 91.428000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -3, 0, -1}, 113.915420, 0.000020, 0.040000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -3, 1, -1}, 113.915420, 0.000020, 0.087000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -1, -1, -1}, 113.915420, 0.000070, 0.075000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -1, 0, -1}, 113.915420, 0.001360, 4784.938000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -1, 1, -1}, 113.915420, 0.000070, 0.075000},
	{{0, 35, -31, 0, 0, -3, 0, 0, 1, -1, -1}, 113.915420, 0.000020, 0.087000},
	{{0, 35, -31, 0, 0, -3, 0, 0, 1, 0, -1}, 113.915420, 0.000020, 0.040000},
	{{0, 35, -30, -4, 0, 0, 0, 0, -2, 0, 0}, 173.456570, 0.000030, 34.386000},
	{{0, 36, -41, 0, 0, 0, 0, 0, -2, 0, 0}, 323.654120, 0.000020, 0.139000},
	{{0, 36, -40, 0, 0, 0, 0, 0, -2, 0, 0}, 230.616020, 0.000020, 0.161000},
	{{0, 36, -37, 6, 0, 0, 0, 0, -2, 0, 0}, 112.507010, 0.000020, 35.024000},
	{{0, 36, -36, 4, 0, 0, 0, 0, -2, 0, 0}, 84.318090, 0.000010, 10.879000},
	{{0, 36, -35, 0, 2, 0, 0, 0, -3, 0, 1}, 111.015620, 0.000040, 269.063000},
	{{0, 36, -35, 2, 0, 0, 0, 0, -2, 0, 0}, 66.735440, 0.000010, 6.440000},
	{{0, 36, -34, 0, -3, 0, 0, 0, -2, 0, 0}, 189.188870, 0.000010, 2.121000},
	{{0, 36, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 205.640490, 0.000060, 4.573000},
	{{0, 36, -34, 0, 1, 0, 0, 0, -2, 0, 0}, 13.791020, 0.000030, 7.443000},
	{{0, 36, -34, 0, 2, 0, 0, 0, -2, 0, 0}, 194.215000, 0.000010, 19.981000},
	{{0, 36, -32, 0, 0, 0, 0, 0, 0, -2, 0}, 237.575340, 0.000040, 136.522000},
	{{0, 36, -29, -9, 0, 0, 0, 0, -2, 0, 0}, 176.914970, 0.000030, 262.068000},
	{{0, 37, -37, 3, 0, 0, 0, 0, -2, 0, 0}, 16.503750, 0.000130, 521.324000},
	{{0, 37, -36, 0, -2, 0, 0, 0, -2, 0, 0}, 269.945620, 0.000010, 1.313000},
	{{0, 37, -36, 0, 0, 0, 0, 0, -2, 0, 0}, 294.197200, 0.000010, 1.686000},
	{{0, 37, -35, 0, -5, 0, 0, 0, -2, 0, 0}, 10.844970, 0.000020, 68.230000},
	{{0, 37, -35, 0, -3, 0, 0, 0, -2, 0, 0}, 216.743350, 0.000030, 6.496000},
	{{0, 37, -35, 0, -1, 0, 0, 0, -2, 0, 0}, 39.377250, 0.000010, 3.100000},
	{{0, 38, -45, 15, 0, 0, 0, 0, -2, 0, 0}, 180.042770, 0.000030, 130.682000},
	{{0, 38, -42, 6, 0, 0, 0, 0, -4, 2, 0}, 237.220780, 0.000010, 286.659000},
	{{0, 38, -39, 3, 0, 0, 0, 0, -2, 0, 0}, 55.204450, 0.000010, 2.684000},
	{{0, 38, -38, 0, -1, 0, 0, 0, -3, 0, 1}, 242.389140, 0.000060, 540.584000},
	{{0, 38, -38, 0, 0, 0, 0, 0, -2, 0, 0}, 170.487170, 0.000010, 1.033000},
	{{0, 38, -37, 0, -3, 0, 0, 0, -2, 0, 0}, 281.509480, 0.000030, 4.535000},
	{{0, 38, -37, 0, -2, 0, 0, 0, -2, 0, 0}, 295.974220, 0.000040, 7.341000},
	{{0, 38, -37, 0, -1, 0, 0, 0, -2, 0, 0}, 59.344380, 0.000030, 19.262000},
	{{0, 38, -37, 0, 0, -2, 0, 0, -2, 0, 0}, 289.739040, 0.000010, 28.163000},
	{{0, 38, -37, 0, 0, -1, 0, 0, -2, 0, 0}, 316.818220, 0.000160, 641.251000},
	{{0, 38, -37, 0, 0, 0, -3, 0, -2, 0, 0}, 93.544560, 0.000030, 301.443000},
	{{0, 38, -37, 0, 0, 0, -2, 0, -2, 0, 0}, 279.031230, 0.000040, 116.490000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, -1, 0}, 307.191290, 0.000030, 0.076000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, 0, 0}, 307.191290, 0.000610, 30.876000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, 1, 0}, 307.191290, 0.000030, 0.075000},
	{{0, 38, -37, 0, 1, 0, 0, 0, -2, 0, 0}, 195.084010, 0.000040, 8.570000},
	{{0, 38, -36, -2, 0, 0, 0, 0, -2, 0, 0}, 77.389940, 0.000030, 32.280000},
	{{0, 38, -36, 0, 0, 0, 0, 0, -1, 0, -1}, 39.939140, 0.000040, 46.780000},
	{{0, 38, -35, -4, 0, 0, 0, 0, -2, 0, 0}, 322.555800, 0.000010, 10.599000},
	{{0, 38, -35, 0, -3, 0, 0, 0, 0, -2, 0}, 0.312280, 0.000020, 183.214000},
	{{0, 38, -28, -17, 0, 0, 0, 0, -2, 0, 0}, 193.484640, 0.000050, 160.172000},
	{{0, 39, -41, 4, 0, 0, 0, 0, -2, 0, 0}, 236.794770, 0.000010, 4.644000},
	{{0, 39, -40, 2, 0, 0, 0, 0, -2, 0, 0}, 219.003960, 0.000020, 3.588000},
	{{0, 39, -39, 0, -2, 0, 0, 0, -2, 0, 0}, 198.897730, 0.000010, 1.958000},
	{{0, 39, -39, 0, 0, 0, 0, 0, -2, 0, 0}, 357.339230, 0.000110, 2.923000},
	{{0, 39, -39, 0, 0, 1, 0, 0, -2, 0, 0}, 266.343340, 0.000010, 3.245000},
	{{0, 39, -39, 0, 4, 0, 0, 0, -2, 0, 0}, 255.379270, 0.000040, 205.320000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -4, 0, 0}, 16.248810, 0.000020, 0.040000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -4, 1, 0}, 16.248810, 0.000020, 0.087000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -2, -1, 0}, 16.248810, 0.000100, 0.075000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -2, 0, 0}, 16.248810, 0.001800, 1963.481000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -2, 1, 0}, 16.248810, 0.000100, 0.075000},
	{{0, 39, -36, -5, 0, 0, 0, 0, 0, -1, 0}, 16.248810, 0.000020, 0.087000},
	{{0, 39, -36, -5, 0, 0, 0, 0, 0, 0, 0}, 16.248810, 0.000020, 0.040000},
	{{0, 39, -36, -3, 0, 0, 0, 0, -1, 0, -1}, 218.026840, 0.000050, 109.969000},
	{{0, 40, -45, 9, 0, 0, 0, 0, -2, 0, 0}, 115.252400, 0.000020, 14.579000},
	{{0, 40, -44, 7, 0, 0, 0, 0, -2, 0, 0}, 217.598880, 0.000020, 191.399000},
	{{0, 40, -43, 5, 0, 0, 0, 0, -2, 0, 0}, 237.087870, 0.000030, 17.199000},
	{{0, 40, -41, 0, -2, 0, 0, 0, -3, 1, 0}, 101.613720, 0.000040, 544.976000},
	{{0, 40, -41, 0, 0, 0, 0, 0, -3, 2, -1}, 68.524610, 0.000020, 271.239000},
	{{0, 40, -41, 1, 0, 0, 0, 0, -2, 0, 0}, 358.594640, 0.000010, 5.409000},
	{{0, 40, -40, 0, -4, 0, 0, 0, -2, 0, 0}, 53.895830, 0.000030, 18.594000},
	{{0, 40, -40, 0, -3, 0, 0, 0, -2, 0, 0}, 15.718440, 0.000020, 32.764000},
	{{0, 40, -40, 0, -2, 0, 0, 0, -2, 0, 0}, 17.073950, 0.000030, 8.709000},
	{{0, 40, -40, 0, -1, 0, 0, 0, -2, 0, 0}, 54.202510, 0.000030, 5.022000},
	{{0, 40, -40, 0, 0, -1, 0, 0, -2, 0, 0}, 270.952730, 0.000010, 4.008000},
	{{0, 40, -40, 0, 0, 0, 0, 0, -2, 0, 0}, 354.683500, 0.000070, 3.528000},
	{{0, 40, -39, -3, 0, 0, 0, 0, -2, 0, 0}, 227.690390, 0.000010, 3.209000},
	{{0, 40, -39, -2, 0, 0, 0, 0, -2, 0, 0}, 316.919570, 0.000020, 4.544000},
	{{0, 40, -39, 0, -1, 0, 0, 0, -2, 0, 0}, 179.820300, 0.000010, 0.834000},
	{{0, 40, -39, 0, 0, 0, 0, 0, -1, 0, -1}, 282.062340, 0.000020, 4.354000},
	{{0, 40, -38, -4, 0, 0, 0, 0, -2, 0, 0}, 302.697670, 0.000010, 6.382000},
	{{0, 40, -38, 0, -2, 0, 0, 0, 0, 0, -2}, 351.983100, 0.000040, 137.080000},
	{{0, 40, -37, -6, 0, 0, 0, 0, -2, 0, 0}, 81.440680, 0.000010, 10.715000},
	{{0, 41, -45, 6, 0, 0, 0, 0, -2, 0, 0}, 57.431940, 0.000010, 10.095000},
	{{0, 41, -43, 2, 0, 0, 0, 0, -2, 0, 0}, 351.245480, 0.000040, 36.137000},
	{{0, 41, -42, 0, -1, 0, 0, 0, -2, 0, 0}, 149.472750, 0.000020, 5.703000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, -1, 0}, 91.325960, 0.000030, 0.075000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, 0, 0}, 91.325960, 0.000480, 10.984000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, 1, 0}, 91.325960, 0.000030, 0.076000},
	{{0, 41, -42, 0, 0, 1, 0, 0, -2, 0, 0}, 356.832540, 0.000010, 17.515000},
	{{0, 41, -42, 0, 0, 2, 0, 0, -2, 0, 0}, 62.296440, 0.000040, 43.206000},
	{{0, 41, -42, 0, 2, 0, 0, 0, -2, 0, 0}, 39.591550, 0.000040, 12.892000},
	{{0, 41, -41, 0, 0, 0, 0, 0, -2, 0, 0}, 178.606660, 0.000010, 1.100000},
	{{0, 41, -41, 0, 0, 0, 0, 0, -1, 0, -1}, 13.352680, 0.000030, 6.906000},
	{{0, 41, -35, -13, 0, 0, 0, 0, -2, 0, 0}, 55.389660, 0.000010, 340.508000},
	{{0, 42, -44, 0, 1, 0, 0, 0, -2, 0, 0}, 109.419660, 0.000030, 2.623000},
	{{0, 42, -43, -1, 0, 0, 0, 0, -2, 0, 0}, 17.718090, 0.000020, 357.500000},
	{{0, 42, -43, 0, 0, 0, 0, 0, -2, 0, 0}, 270.961040, 0.000010, 1.871000},
	{{0, 42, -43, 0, 1, 0, 0, 0, -2, 0, 0}, 358.073600, 0.000010, 1.616000},
	{{0, 42, -42, -3, 0, 0, 0, 0, -2, 0, 0}, 30.675880, 0.000040, 16.510000},
	{{0, 43, -51, 11, 0, 0, 0, 0, -2, 0, 0}, 50.505520, 0.000030, 117.217000},
	{{0, 43, -46, 2, 0, 0, 0, 0, -2, 0, 0}, 91.346800, 0.000010, 4.477000},
	{{0, 43, -45, 0, -2, 0, 0, 0, -2, 0, 0}, 187.676920, 0.000060, 116.226000},
	{{0, 43, -45, 0, -1, 0, 0, 0, -2, 0, 0}, 283.243100, 0.000040, 13.210000},
	{{0, 43, -45, 0, 1, 0, 0, 0, -2, 0, 0}, 123.223000, 0.000020, 4.093000},
	{{0, 43, -44, -2, 0, 0, 0, 0, -2, 0, 0}, 157.921120, 0.000020, 10.348000},
	{{0, 43, -44, 0, -1, 0, 0, 0, -1, 0, -1}, 350.865620, 0.000010, 45.591000},
	{{0, 43, -43, -4, 0, 0, 0, 0, -2, 0, 0}, 39.582590, 0.000020, 30.060000},
	{{0, 43, -43, 0, -1, 0, 0, 0, 0, 0, -2}, 92.385160, 0.000020, 31.417000},
	{{0, 43, -43, 0, 0, 0, 0, 0, 0, 0, -2}, 0.778650, 0.000030, 19.058000},
	{{0, 43, -42, -6, 0, 0, 0, 0, -2, 0, 0}, 26.211710, 0.000030, 33.222000},
	{{0, 43, -42, -2, 0, 0, 0, 0, 0, 0, -2}, 101.662310, 0.000020, 91.787000},
	{{0, 43, -42, 0, 0, 0, 0, 0, -1, 0, -3}, 281.555620, 0.000080, 0.040000},
	{{0, 43, -42, 0, 0, 0, 0, 0, -1, 1, -3}, 281.555620, 0.000070, 0.087000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, -2, -3}, 281.555620, 0.000020, 0.038000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, -1, -3}, 281.555620, 0.000360, 0.075000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 0, -5}, 101.555620, 0.000010, 0.037000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 0, -3}, 281.555620, 0.006600, 773.987000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 0, -1}, 101.555620, 0.000010, 0.037000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 1, -3}, 281.555620, 0.000360, 0.075000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 2, -3}, 281.555620, 0.000020, 0.038000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 3, -1, -3}, 281.555620, 0.000070, 0.087000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 3, 0, -3}, 281.555620, 0.000080, 0.040000},
	{{0, 44, -48, 2, 0, 0, 0, 0, -2, 0, 0}, 179.072440, 0.000010, 6.618000},
	{{0, 44, -47, 0, 0, 0, 0, 0, -2, 0, 0}, 123.345830, 0.000010, 4.663000},
	{{0, 44, -47, 0, 2, 0, 0, 0, -2, 0, 0}, 274.197650, 0.000020, 21.804000},
	{{0, 44, -47, 0, 3, 0, 0, 0, -2, 0, 0}, 336.291130, 0.000010, 26.014000},
	{{0, 44, -45, 0, 0, 0, 0, 0, 0, -2, 0}, 271.283170, 0.000070, 86.878000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -4, 0, 0}, 296.452700, 0.000020, 0.040000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -4, 1, 0}, 296.452700, 0.000020, 0.087000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -2, -1, 0}, 296.452700, 0.000100, 0.075000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -2, 0, 0}, 296.452700, 0.001830, 2704.790000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -2, 1, 0}, 296.452700, 0.000100, 0.075000},
	{{0, 44, -42, -9, 0, 0, 0, 0, 0, -1, 0}, 296.452700, 0.000020, 0.087000},
	{{0, 44, -42, -9, 0, 0, 0, 0, 0, 0, 0}, 296.452700, 0.000020, 0.040000},
	{{0, 45, -50, 3, 0, 0, 0, 0, -2, 0, 0}, 276.006100, 0.000050, 163.835000},
	{{0, 45, -48, 0, 0, 0, 0, 0, -2, 0, 0}, 94.866230, 0.000010, 2.433000},
	{{0, 46, -58, 15, 0, 0, 0, 0, -2, 0, 0}, 284.347800, 0.000010, 84.476000},
	{{0, 46, -51, 2, 0, 0, 0, 0, -2, 0, 0}, 94.416900, 0.000030, 10.006000},
	{{0, 46, -50, 0, 0, -1, 0, 0, -2, 0, 0}, 108.841250, 0.000080, 380.797000},
	{{0, 46, -50, 0, 0, 0, 0, 0, -2, -1, 0}, 229.902400, 0.000010, 0.076000},
	{{0, 46, -50, 0, 0, 0, 0, 0, -2, 1, 0}, 229.902400, 0.000010, 0.075000},
	{{0, 46, -50, 0, 1, 0, 0, 0, -2, 0, 0}, 225.499970, 0.000020, 8.273000},
	{{0, 46, -49, 0, 0, 0, 0, 0, -1, 0, -1}, 67.052500, 0.000090, 58.170000},
	{{0, 46, -49, 2, 0, 0, 0, 0, 0, 0, -2}, 26.032270, 0.000010, 131.783000},
	{{0, 46, -48, -4, 0, 0, 0, 0, -2, 0, 0}, 352.041480, 0.000020, 11.091000},
	{{0, 46, -41, -17, 0, 0, 0, 0, -2, 0, 0}, 129.744590, 0.000020, 485.961000},
	{{0, 47, -52, 0, 4, 0, 0, 0, -2, -1, 0}, 259.654280, 0.000040, 0.075000},
	{{0, 47, -52, 0, 4, 0, 0, 0, -2, 0, 0}, 259.654280, 0.000660, 1460.021000},
	{{0, 47, -52, 0, 4, 0, 0, 0, -2, 1, 0}, 259.654280, 0.000040, 0.075000},
	{{0, 47, -50, -3, 0, 0, 0, 0, -2, 0, 0}, 105.955080, 0.000010, 14.916000},
	{{0, 47, -49, 0, 0, 0, 0, 0, 1, -3, 0}, 125.669300, 0.000010, 933.289000},
	{{0, 48, -57, 7, 0, 0, 0, 0, -2, 0, 0}, 78.515790, 0.000010, 106.267000},
	{{0, 49, -57, 4, 0, 0, 0, 0, -2, 0, 0}, 142.758700, 0.000010, 25.075000},
	{{0, 49, -56, 2, 0, 0, 0, 0, -2, 0, 0}, 90.924780, 0.000020, 42.576000},
	{{0, 49, -55, 0, 0, 1, 0, 0, -2, 0, 0}, 322.532670, 0.000010, 18.901000},
	{{0, 49, -55, 0, 0, 2, 0, 0, -2, 0, 0}, 228.155310, 0.000010, 52.744000},
	{{0, 49, -55, 0, 1, 0, 0, 0, -2, 0, 0}, 6.884960, 0.000120, 391.900000},
	{{0, 49, -48, -13, 0, 0, 0, 0, -2, 0, 0}, 237.792040, 0.000010, 800.815000},
	{{0, 50, -56, -1, 0, 0, 0, 0, -2, 0, 0}, 161.893770, 0.000030, 143.211000},
	{{0, 51, -58, 0, -2, 0, 0, 0, -2, 0, 0}, 2.216360, 0.000030, 226.325000},
	{{0, 51, -55, 0, 0, 0, 0, 0, 1, 0, -3}, 162.530030, 0.000020, 345.601000},
	{{0, 52, -60, 0, 2, 0, 0, 0, -2, 0, 0}, 218.728070, 0.000030, 23.994000},
	{{0, 53, -63, 3, 0, 0, 0, 0, -2, 0, 0}, 320.473920, 0.000020, 97.189000},
	{{0, 55, -65, 0, 4, 0, 0, 0, -2, 0, 0}, 92.481350, 0.000050, 285.666000},
	{{0, 59, -58, 0, 1, 0, 0, 0, -2, -1, 0}, 204.336340, 0.000030, 325.228000},
	{{0, 61, -64, 2, 0, 0, 0, 0, -4, 1, 0}, 114.669240, 0.000020, 949.691000},
	{{0, 61, -61, 0, -2, 0, 0, 0, -2, -1, 0}, 9.571990, 0.000050, 202.367000},
	{{1, -51, 54, 0, 0, 0, 0, 0, 2, 0, 0}, 131.054110, 0.000010, 82.651000},
	{{1, -43, 41, 0, 0, 0, 0, 0, 2, 0, 0}, 32.959910, 0.000040, 126.367000},
	{{1, -35, 28, 0, 0, 0, 0, 0, 2, 0, 0}, 288.162340, 0.000070, 268.243000},
	{{1, -33, 38, 0, 0, 0, 0, 0, 2, -1, 0}, 108.334770, 0.000010, 118.531000},
	{{1, -31, 33, 0, 0, 0, 0, 0, 0, 1, 0}, 103.666950, 0.000010, 60.144000},
	{{1, -30, 33, 0, 0, 0, 0, 0, 2, -1, 0}, 113.560210, 0.000030, 7.584000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -4, 1, 2}, 77.182790, 0.000010, 0.040000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -2, 0, 2}, 77.182790, 0.000050, 0.075000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -2, 1, 2}, 77.182790, 0.000880, 1374.129000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -2, 2, 2}, 77.182790, 0.000050, 0.075000},
	{{1, -28, 26, 0, 0, 0, 0, 0, 0, 1, 2}, 77.182790, 0.000010, 0.040000},
	{{1, -28, 30, 0, 0, 0, 0, 0, 2, -1, 0}, 205.274050, 0.000010, 8.391000},
	{{1, -25, 25, 0, 0, 0, 0, 0, 2, -2, 0}, 72.866250, 0.000030, 0.075000},
	{{1, -25, 25, 0, 0, 0, 0, 0, 2, -1, 0}, 135.060250, 0.000030, 235.235000},
	{{1, -25, 25, 0, 0, 0, 0, 0, 2, 0, 0}, 72.866250, 0.000030, 0.075000},
	{{1, -23, 20, 0, 0, 0, 0, 0, 0, 1, 0}, 150.687240, 0.000020, 48.049000},
	{{1, -23, 22, 0, 0, 0, 0, 0, 2, -1, 0}, 345.521790, 0.000020, 4.052000},
	{{1, -21, 19, 0, 0, 0, 0, 0, 2, -1, 0}, 77.344380, 0.000010, 2.009000},
	{{1, -20, 13, 0, 0, 0, 0, 0, -2, 1, 2}, 203.511440, 0.000010, 203.531000},
	{{1, -20, 16, 0, 0, 0, 0, 0, 1, 0, 0}, 67.849510, 0.000040, 96.401000},
	{{1, -20, 17, 0, 0, 0, 0, 0, 2, -1, 0}, 149.792950, 0.000040, 8.106000},
	{{1, -10, 10, 0, 0, 0, 0, 0, -2, 0, 2}, 87.987100, 0.000010, 227.782000},
	{{1, -9, 7, 0, 0, 0, 0, 0, 0, 0, 0}, 76.873470, 0.000010, 0.288000},
	{{1, -8, 6, 0, 0, 0, 0, 0, 0, 0, 0}, 76.867130, 0.000010, 0.351000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 0, -2, 0}, 114.257370, 0.000010, 0.040000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 0, -1, 0}, 114.257370, 0.000010, 0.087000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 2, -3, 0}, 111.330370, 0.000040, 0.075000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 2, -2, 0}, 114.257370, 0.000920, 1698.830000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 2, -1, 0}, 129.453850, 0.000060, 0.075000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 4, -3, 0}, 114.257370, 0.000010, 0.087000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 4, -2, 0}, 114.257370, 0.000010, 0.040000},
	{{1, -6, 4, 0, 0, 0, 0, 0, -2, 1, 0}, 76.901060, 0.000020, 0.076000},
	{{1, -6, 4, 0, 0, 0, 0, 0, -2, 3, 0}, 76.901060, 0.000020, 0.074000},
	{{1, -6, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 348.421150, 0.000020, 1.664000},
	{{1, -5, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 80.059750, 0.000010, 1.025000},
	{{1, -5, 4, 0, 0, 0, 0, 0, -2, 0, 0}, 351.707690, 0.000020, 0.040000},
	{{1, -5, 4, 0, 0, 0, 0, 0, -2, 1, 0}, 351.707690, 0.000020, 0.087000},
	{{1, -5, 4, 0, 0, 0, 0, 0, 0, -1, 0}, 348.536440, 0.000030, 0.076000},
	{{1, -5, 4, 0, 0, 0, 0, 0, 0, 0, 0}, 351.136660, 0.000160, 40.859000},
	{{1, -5, 4, 0, 0, 0, 0, 0, 0, 1, 0}, 348.536440, 0.000030, 0.075000},
	{{1, -5, 4, 0, 0, 0, 0, 0, 2, -1, 0}, 351.751470, 0.000020, 0.087000},
	{{1, -5, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 351.751470, 0.000020, 0.040000},
	{{1, -4, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 174.205180, 0.000010, 1.538000},
	{{1, -3, 0, 0, 0, 0, 0, 0, -1, 2, -1}, 339.277290, 0.000020, 236.591000},
	{{1, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 153.848550, 0.000020, 1.380000},
	{{1, -1, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 336.112430, 0.000020, 1.899000},
	{{1, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 257.135740, 0.000010, 0.655000},
	{{1, 0, -11, 11, 0, 0, 0, 0, 0, 0, 0}, 229.871260, 0.000010, 1.001000},
	{{1, 0, -11, 11, 0, 0, 0, 0, 2, 0, 0}, 229.871260, 0.000010, 0.042000},
	{{1, 0, -10, 11, 0, 0, 0, 0, -2, -1, 0}, 126.934340, 0.000020, 0.026000},
	{{1, 0, -10, 11, 0, 0, 0, 0, -2, 0, 0}, 126.934340, 0.000090, 0.040000},
	{{1, 0, -10, 11, 0, 0, 0, 0, -2, 1, 0}, 126.934340, 0.000190, 0.087000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 0, -1, 0}, 306.934340, 0.000020, 0.075000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 0, 0, 0}, 306.934340, 0.000010, 1618.870000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 0, 1, 0}, 306.934340, 0.000020, 0.075000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 2, -1, 0}, 126.934340, 0.000190, 0.087000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 2, 0, 0}, 126.934340, 0.000090, 0.040000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 2, 1, 0}, 126.934340, 0.000020, 0.026000},
	{{1, 0, -9, 11, 0, 0, 0, 0, -2, 0, 0}, 23.997410, 0.000010, 0.042000},
	{{1, 0, -9, 11, 0, 0, 0, 0, 0, 0, 0}, 23.997410, 0.000010, 0.999000},
	{{1, 0, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 128.873400, 0.000030, 0.075000},
	{{1, 0, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 128.811480, 0.000010, 13.534000},
	{{1, 0, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 128.873400, 0.000030, 0.076000},
	{{1, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 357.075820, 0.000020, 1.179000},
	{{1, 0, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 320.455540, 0.000020, 0.094000},
	{{1, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 320.552050, 0.000030, 0.042000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -4, 1, 0}, 209.549410, 0.000010, 0.028000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 209.549590, 0.000040, 0.026000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 209.611020, 0.000370, 0.041000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 209.075570, 0.000540, 0.088000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 209.657890, 0.000020, 0.519000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 210.837100, 0.000050, 0.038000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 211.767980, 0.000690, 0.076000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 210.627440, 0.003430, 6.575000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 211.981100, 0.000680, 0.075000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 211.765220, 0.000050, 0.038000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 210.157700, 0.000430, 0.086000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 210.472360, 0.000270, 0.040000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 210.327850, 0.000030, 0.026000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 136.662780, 0.000010, 0.029000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 136.636480, 0.000050, 0.027000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 136.636110, 0.000410, 0.042000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 136.686630, 0.000520, 0.097000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 136.716700, 0.000020, 0.342000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 136.852670, 0.000280, 0.083000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 137.555700, 0.001300, 0.868000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 137.140700, 0.000200, 0.069000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 289.950080, 0.000040, 0.076000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 289.922260, 0.000280, 10.170000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 318.136970, 0.000020, 0.074000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 109.588390, 0.000030, 0.037000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 289.950080, 0.000040, 0.075000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 138.681640, 0.000190, 0.079000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 138.629240, 0.000070, 0.039000},
	{{1, 0, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 274.177760, 0.000090, 0.044000},
	{{1, 0, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 268.115490, 0.000110, 0.107000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 255.501520, 0.000020, 0.041000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 257.609110, 0.000210, 0.090000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 68.943170, 0.000190, 0.465000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 64.706200, 0.000030, 0.065000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 33.450540, 0.000020, 0.910000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, -1, -2}, 77.592920, 0.000080, 0.076000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 75.748950, 0.001190, 0.073000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 0, -2}, 76.381840, 0.000700, 22.442000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 259.485780, 0.000100, 0.037000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 1, -2}, 77.592920, 0.000080, 0.075000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 254.293380, 0.000020, 0.025000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 75.675930, 0.000020, 0.040000},
	{{1, 0, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 175.849480, 0.000050, 0.046000},
	{{1, 0, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 176.242090, 0.000030, 0.120000},
	{{1, 0, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 176.957100, 0.000010, 0.055000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 179.167780, 0.000030, 0.099000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 179.454210, 0.000340, 0.317000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 178.834870, 0.000040, 0.061000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 53.926610, 0.000010, 0.477000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 177.494080, 0.000120, 0.068000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 358.033690, 0.000060, 0.036000},
	{{1, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 290.914090, 0.000050, 0.049000},
	{{1, 0, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 293.641880, 0.000020, 0.136000},
	{{1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1}, 313.937380, 0.000010, 0.192000},
	{{1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 289.469800, 0.000120, 0.241000},
	{{1, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 279.211220, 0.000030, 0.064000},
	{{1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 106.530610, 0.000020, 0.035000},
	{{1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 52.926760, 0.000020, 0.194000},
	{{1, 0, 27, -37, 0, 0, 0, 0, -2, 1, 0}, 190.382800, 0.000020, 509.270000},
	{{1, 1, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 342.102630, 0.000030, 0.075000},
	{{1, 1, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 144.399180, 0.000040, 278.019000},
	{{1, 1, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 342.102630, 0.000030, 0.075000},
	{{1, 2, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 256.850550, 0.000010, 0.294000},
	{{1, 3, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 308.595920, 0.000020, 0.076000},
	{{1, 3, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 308.595920, 0.000020, 0.075000},
	{{1, 10, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 188.561560, 0.000030, 13.438000},
	{{1, 13, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 76.704000, 0.000010, 0.835000},
	{{1, 13, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 157.477110, 0.000010, 35.540000},
	{{1, 14, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 76.677420, 0.000010, 0.072000},
	{{1, 14, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 76.677420, 0.000010, 0.079000},
	{{1, 15, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 76.837700, 0.000030, 0.076000},
	{{1, 15, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 76.689840, 0.000020, 18.797000},
	{{1, 15, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 76.837700, 0.000030, 0.075000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -3, 1, -1}, 4.341160, 0.000030, 0.040000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -3, 2, -1}, 4.341160, 0.000030, 0.087000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, -1, -1}, 4.341160, 0.000010, 0.038000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 2.389690, 0.000190, 0.075000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 1, -1}, 4.341160, 0.002800, 1772.175000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 2, -1}, 2.389690, 0.000190, 0.075000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 3, -1}, 4.341160, 0.000010, 0.038000},
	{{1, 15, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 4.341160, 0.000030, 0.087000},
	{{1, 15, -16, 0, 0, 0, 0, 0, 1, 1, -1}, 4.341160, 0.000030, 0.040000},
	{{1, 16, -19, 0, 0, 0, 0, 0, -2, -1, 2}, 162.169570, 0.000010, 81.712000},
	{{1, 16, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 291.950860, 0.000010, 10.494000},
	{{1, 18, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 95.604380, 0.000040, 14.239000},
	{{1, 18, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 257.615730, 0.000020, 6.421000},
	{{1, 21, -25, 0, 0, 0, 0, 0, 0, -1, 0}, 24.614350, 0.000070, 30.938000},
	{{1, 23, -30, 0, 0, 0, 0, 0, -2, 1, 0}, 34.318000, 0.000030, 17.426000},
	{{1, 23, -29, 0, 0, 0, 0, 0, -1, 1, -1}, 296.913000, 0.000030, 276.148000},
	{{1, 26, -35, 0, 0, 0, 0, 0, -2, 1, 0}, 173.281880, 0.000010, 15.142000},
	{{1, 36, -38, 0, 0, 0, 0, 0, -2, 0, 0}, 73.077870, 0.000030, 15.023000},
	{{1, 41, -45, 0, 0, 0, 0, 0, -1, 0, -1}, 272.503880, 0.000010, 137.294000},
	{{2, -56, 58, 0, 0, 0, 0, 0, 2, 0, 0}, 272.070510, 0.000050, 80.804000},
	{{2, -48, 45, 0, 0, 0, 0, 0, 2, 0, 0}, 261.888990, 0.000010, 60.382000},
	{{2, -45, 38, 0, 0, 0, 0, 0, 0, 0, 2}, 10.296630, 0.000020, 1510.143000},
	{{2, -42, 37, 0, 0, 0, 0, 0, 4, -2, 0}, 223.193130, 0.000030, 231.663000},
	{{2, -36, 37, 0, 0, 0, 0, 0, 0, 1, 0}, 357.802690, 0.000020, 24.330000},
	{{2, -33, 32, 0, 0, 0, 0, 0, 0, 1, 0}, 350.920540, 0.000030, 12.147000},
	{{2, -33, 34, 0, 0, 0, 0, 0, 2, -1, 0}, 352.260540, 0.000010, 6.961000},
	{{2, -32, 32, 0, 0, 0, 0, 0, 2, -1, 0}, 78.997470, 0.000010, 4.332000},
	{{2, -30, 29, 0, 0, 0, 0, 0, 2, -2, 0}, 351.367500, 0.000020, 0.076000},
	{{2, -30, 29, 0, 0, 0, 0, 0, 2, -1, 0}, 268.253180, 0.000010, 49.447000},
	{{2, -30, 29, 0, 0, 0, 0, 0, 2, 0, 0}, 351.367500, 0.000020, 0.075000},
	{{2, -28, 24, 0, 0, 0, 0, 0, 0, 1, 0}, 145.004810, 0.000030, 22.081000},
	{{2, -28, 25, 0, 0, 0, 0, 0, 1, 1, -1}, 61.194730, 0.000020, 117.956000},
	{{2, -27, 22, 0, 0, 0, 0, 0, 0, -1, 2}, 223.816760, 0.000030, 231.235000},
	{{2, -27, 24, 0, 0, 0, 0, 0, 2, -1, 0}, 141.205330, 0.000030, 9.689000},
	{{2, -25, 20, 0, 0, 0, 0, 0, 1, 0, 0}, 42.340680, 0.000030, 28.696000},
	{{2, -25, 21, 0, 0, 0, 0, 0, 2, -1, 0}, 144.455510, 0.000010, 6.764000},
	{{2, -24, 19, 0, 0, 0, 0, 0, 2, -2, 0}, 42.292770, 0.000010, 0.074000},
	{{2, -24, 19, 0, 0, 0, 0, 0, 2, 0, 0}, 42.292770, 0.000010, 0.077000},
	{{2, -24, 21, 0, 0, 0, 0, 0, 4, -4, 0}, 27.444290, 0.000030, 0.075000},
	{{2, -24, 21, 0, 0, 0, 0, 0, 4, -3, 0}, 27.444290, 0.000580, 1528.620000},
	{{2, -24, 21, 0, 0, 0, 0, 0, 4, -2, 0}, 27.444290, 0.000030, 0.075000},
	{{2, -22, 16, 0, 0, 0, 0, 0, 2, -1, 0}, 327.814990, 0.000040, 40.968000},
	{{2, -20, 12, 0, 0, 0, 0, 0, 1, 1, -1}, 271.126660, 0.000020, 232.978000},
	{{2, -12, 13, 0, 0, 0, 0, 0, 2, -3, 0}, 185.695810, 0.000010, 0.076000},
	{{2, -12, 13, 0, 0, 0, 0, 0, 2, -2, 0}, 3.110230, 0.000020, 41.866000},
	{{2, -12, 13, 0, 0, 0, 0, 0, 2, -1, 0}, 185.695810, 0.000010, 0.075000},
	{{2, -11, 6, 0, 0, 0, 0, 0, 0, 0, 0}, 222.268790, 0.000010, 0.280000},
	{{2, -10, 8, 0, 0, 0, 0, 0, 0, 0, 0}, 114.979250, 0.000010, 20.429000},
	{{2, -9, 8, 0, 0, 0, 0, 0, 2, -2, 0}, 170.516610, 0.000010, 10.046000},
	{{2, -8, 3, 0, 0, 0, 0, 0, -2, 1, 0}, 42.969540, 0.000010, 0.076000},
	{{2, -8, 3, 0, 0, 0, 0, 0, -2, 2, 0}, 222.226200, 0.000040, 13.511000},
	{{2, -8, 3, 0, 0, 0, 0, 0, -2, 3, 0}, 42.969540, 0.000010, 0.075000},
	{{2, -7, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 146.923330, 0.000050, 13.427000},
	{{2, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 342.146260, 0.000010, 0.555000},
	{{2, -4, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 314.456850, 0.000040, 0.076000},
	{{2, -4, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 136.029910, 0.000030, 35.623000},
	{{2, -4, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 314.456850, 0.000040, 0.075000},
	{{2, -3, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 222.012150, 0.000010, 0.074000},
	{{2, -3, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 222.012150, 0.000010, 0.077000},
	{{2, -2, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 273.699420, 0.000030, 0.074000},
	{{2, -2, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 273.699420, 0.000030, 0.076000},
	{{2, -2, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 296.799100, 0.000020, 0.087000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 113.795420, 0.000150, 0.075000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 105.298890, 0.000710, 1587.748000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 113.795420, 0.000150, 0.075000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 296.799100, 0.000020, 0.087000},
	{{2, -2, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 42.010850, 0.000020, 0.077000},
	{{2, -2, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 42.010850, 0.000020, 0.074000},
	{{2, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 208.869620, 0.000010, 0.303000},
	{{2, 0, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 209.412100, 0.000020, 0.068000},
	{{2, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 29.438480, 0.000010, 0.036000},
	{{2, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 321.338960, 0.000020, 0.232000},
	{{2, 0, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 320.507240, 0.000030, 0.063000},
	{{2, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 140.515260, 0.000030, 0.034000},
	{{2, 0, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 72.795080, 0.000020, 0.051000},
	{{2, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 71.907200, 0.000140, 0.189000},
	{{2, 0, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 70.901650, 0.000060, 0.060000},
	{{2, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 250.901720, 0.000060, 0.033000},
	{{2, 0, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 180.166650, 0.000070, 0.054000},
	{{2, 0, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 180.291430, 0.000050, 0.193000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 180.400640, 0.000050, 0.144000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 180.235900, 0.000320, 0.159000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 180.174300, 0.000030, 0.051000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 179.892260, 0.000100, 0.056000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 359.885080, 0.000100, 0.032000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 359.900590, 0.000030, 0.023000},
	{{2, 0, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 280.263630, 0.000020, 0.239000},
	{{2, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 290.556700, 0.000040, 0.137000},
	{{2, 0, 3, 0, 0, 0, 0, 0, -2, 0, 1}, 243.094090, 0.000020, 92.605000},
	{{2, 0, 3, 0, 0, 0, 0, 0, -2, 1, 0}, 64.564380, 0.000010, 5.632000},
	{{2, 0, 17, -26, 0, 0, 0, 0, -2, 1, 0}, 331.639430, 0.000040, 743.009000},
	{{2, 1, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 93.745010, 0.000020, 0.075000},
	{{2, 1, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 93.745010, 0.000020, 0.076000},
	{{2, 5, -6, 0, 0, 0, 0, 0, -3, 1, 1}, 118.166150, 0.000020, 261.378000},
	{{2, 8, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 291.464230, 0.000020, 19.007000},
	{{2, 8, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 324.369670, 0.000030, 867.364000},
	{{2, 10, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 148.510420, 0.000010, 1.084000},
	{{2, 10, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 216.991300, 0.000020, 12.874000},
	{{2, 11, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 148.485780, 0.000010, 0.074000},
	{{2, 11, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 332.493150, 0.000020, 3.369000},
	{{2, 11, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 148.485780, 0.000010, 0.077000},
	{{2, 11, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 240.994680, 0.000010, 14.121000},
	{{2, 13, -19, 0, 0, 0, 0, 0, -3, 1, 1}, 322.763520, 0.000020, 124.822000},
	{{2, 13, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 39.867550, 0.000030, 0.075000},
	{{2, 13, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 39.867550, 0.000030, 0.076000},
	{{2, 14, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 313.646040, 0.000030, 2.380000},
	{{2, 14, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 221.801210, 0.000030, 1.725000},
	{{2, 14, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 140.841150, 0.000020, 5.148000},
	{{2, 15, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 150.511080, 0.000020, 4.871000},
	{{2, 16, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 56.554300, 0.000020, 5.911000},
	{{2, 16, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 216.895770, 0.000010, 17.606000},
	{{2, 16, -20, 0, 0, 0, 0, 0, 1, -2, -1}, 145.012320, 0.000010, 0.075000},
	{{2, 16, -20, 0, 0, 0, 0, 0, 1, -1, -1}, 145.012320, 0.000180, 329.750000},
	{{2, 16, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 145.012320, 0.000010, 0.075000},
	{{2, 18, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 79.296070, 0.000030, 12.216000},
	{{2, 19, -28, 0, 0, 0, 0, 0, -2, 1, 0}, 93.212360, 0.000020, 3.418000},
	{{2, 19, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 41.530230, 0.000040, 15.008000},
	{{2, 20, -29, 0, 0, 0, 0, 0, -2, 1, 0}, 273.250450, 0.000010, 3.004000},
	{{2, 24, -34, 0, 0, 0, 0, 0, 0, -1, 0}, 185.162470, 0.000010, 16.398000},
	{{2, 31, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 84.868870, 0.000020, 23.758000},
	{{2, 34, -39, 0, 0, 0, 0, 0, -2, 0, 0}, 40.817960, 0.000030, 6.042000},
	{{3, -27, 20, 0, 0, 0, 0, 0, 2, -1, 0}, 119.788250, 0.000020, 20.457000},
	{{3, -9, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 115.896150, 0.000010, 5.766000},
	{{3, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 321.647660, 0.000010, 0.134000},
	{{3, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 141.069070, 0.000020, 0.031000},
	{{3, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 72.904170, 0.000030, 0.061000},
	{{3, 0, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 73.060460, 0.000020, 0.331000},
	{{3, 0, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 72.127710, 0.000010, 0.208000},
	{{3, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 72.266080, 0.000070, 0.118000},
	{{3, 0, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 71.197490, 0.000020, 0.050000},
	{{3, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 251.198170, 0.000030, 0.030000},
	{{3, 0, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 181.153900, 0.000090, 0.065000},
	{{3, 0, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 181.323150, 0.000090, 0.494000},
	{{3, 0, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 181.110430, 0.000040, 0.263000},
	{{3, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 181.625890, 0.000130, 0.106000},
	{{3, 0, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 180.445430, 0.000020, 0.048000},
	{{3, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 0.445730, 0.000050, 0.029000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -3, 1, 1}, 312.755700, 0.000440, 35.335000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -3, 2, 1}, 312.749050, 0.000020, 0.075000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 95.688870, 0.000120, 0.070000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 95.782470, 0.000130, 0.975000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 199.656170, 0.000010, 0.082000},
	{{3, 0, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 98.503620, 0.000020, 0.357000},
	{{3, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 116.686900, 0.000050, 0.096000},
	{{3, 0, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 199.502290, 0.000020, 0.042000},
	{{3, 0, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 283.750960, 0.000020, 0.028000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 96.565360, 0.000040, 0.026000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 1, 0}, 96.565360, 0.000340, 0.040000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 2, 0}, 96.653890, 0.000320, 0.087000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 96.294860, 0.000160, 0.038000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 96.294820, 0.002340, 0.075000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, -2}, 276.565360, 0.000060, 0.037000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 96.565360, 0.029230, 39.271000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, 2}, 276.565360, 0.000060, 0.037000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 96.480440, 0.001640, 0.076000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 96.480360, 0.000110, 0.038000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 95.467380, 0.000180, 0.087000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 96.565360, 0.000340, 0.040000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 2, 0}, 96.565360, 0.000040, 0.026000},
	{{3, 0, 0, 0, -3, 0, 0, 0, -1, -1, 1}, 98.153290, 0.000010, 729.668000},
	{{3, 0, 0, 0, 0, 0, 0, 0, -4, 1, 0}, 353.628430, 0.000020, 0.042000},
	{{3, 0, 0, 0, 0, 0, 0, 0, -4, 2, 0}, 353.628430, 0.000010, 0.095000},
	{{3, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 353.628430, 0.000010, 0.081000},
	{{3, 0, 0, 0, 0, 0, 0, 0, -1, 1, -1}, 49.246340, 0.000050, 12.622000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -4, 1, 0}, 353.962060, 0.000020, 0.040000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -4, 2, 0}, 353.962060, 0.000020, 0.087000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -2, 0, 0}, 353.962060, 0.000090, 0.075000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -2, 1, 0}, 353.962060, 0.001580, 1373.316000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -2, 2, 0}, 353.962060, 0.000090, 0.075000},
	{{3, 0, 7, -15, 0, 0, 0, 0, 0, 0, 0}, 353.962060, 0.000020, 0.087000},
	{{3, 0, 7, -15, 0, 0, 0, 0, 0, 1, 0}, 353.962060, 0.000020, 0.040000},
	{{3, 2, -6, 0, 0, 0, 0, 0, -4, 2, 0}, 239.576240, 0.000020, 0.075000},
	{{3, 2, -6, 0, 0, 0, 0, 0, -4, 3, 0}, 239.576240, 0.000310, 2494.868000},
	{{3, 2, -6, 0, 0, 0, 0, 0, -4, 4, 0}, 239.576240, 0.000020, 0.075000},
	{{3, 6, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 345.576750, 0.000010, 21.579000},
	{{3, 13, -20, 0, 0, 0, 0, 0, 0, 1, -2}, 293.860410, 0.000080, 837.450000},
	{{4, -29, 18, 0, 0, 0, 0, 0, 1, -1, 1}, 342.681850, 0.000030, 270.651000},
	{{4, -29, 19, 0, 0, 0, 0, 0, 2, -1, 0}, 262.734500, 0.000020, 19.972000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -4, 3, 0}, 184.981920, 0.000010, 0.087000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -2, 1, 0}, 10.247060, 0.000100, 0.075000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -2, 2, 0}, 19.566850, 0.000690, 2144.232000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -2, 3, 0}, 10.247060, 0.000100, 0.075000},
	{{4, -15, 6, 0, 0, 0, 0, 0, 0, 1, 0}, 184.981920, 0.000010, 0.087000},
	{{4, -7, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 314.119130, 0.000010, 0.075000},
	{{4, -7, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 314.119130, 0.000010, 0.075000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -4, 1, 0}, 30.689450, 0.000020, 0.040000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -4, 2, 0}, 30.689450, 0.000020, 0.087000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 30.689450, 0.000080, 0.075000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -2, 1, 0}, 30.689450, 0.001520, 1010.649000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -2, 2, 0}, 30.689450, 0.000080, 0.075000},
	{{4, -5, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 30.689450, 0.000020, 0.087000},
	{{4, -5, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 30.689450, 0.000020, 0.040000},
	{{4, 0, -6, 0, 0, 0, 0, 0, -3, 2, 0}, 143.411950, 0.000040, 73.341000},
	{{4, 0, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 322.831540, 0.000020, 0.071000},
	{{4, 0, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 322.876940, 0.000030, 1.145000},
	{{4, 0, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 141.589810, 0.000010, 0.028000},
	{{4, 0, -6, 3, 0, 0, 0, 0, -1, -1, 1}, 4.441880, 0.000020, 700.544000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 73.477260, 0.000030, 0.041000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 73.470110, 0.000030, 0.088000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 253.749230, 0.000010, 0.038000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 253.749170, 0.000190, 0.076000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 73.477260, 0.002810, 7.897000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 73.484080, 0.000160, 0.075000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 73.483980, 0.000010, 0.038000},
	{{4, 0, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 71.059640, 0.000040, 0.607000},
	{{4, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 72.790410, 0.000170, 0.086000},
	{{4, 0, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 73.477260, 0.000030, 0.040000},
	{{4, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 251.685410, 0.000020, 0.028000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -3, 1, -1}, 24.759920, 0.000010, 0.041000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -3, 2, -1}, 24.759420, 0.000010, 0.088000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 2.888900, 0.000120, 0.082000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 183.005040, 0.000070, 0.888000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 205.049240, 0.000010, 2.461000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 205.288990, 0.000020, 0.076000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 2.435960, 0.000110, 4.173000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 24.759920, 0.001140, 13.725000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, 2, -1}, 24.760400, 0.000060, 0.075000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 182.984840, 0.000020, 0.072000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 183.029880, 0.000350, 1.545000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 182.694710, 0.000240, 0.079000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 24.823470, 0.000030, 0.087000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 24.759920, 0.000010, 0.040000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 1.506490, 0.000030, 0.027000},
	{{4, 0, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 99.393110, 0.000020, 0.090000},
	{{4, 0, -3, 0, 0, 0, 0, 0, -2, 1, -2}, 100.631050, 0.000050, 0.040000},
	{{4, 0, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 99.305340, 0.000020, 0.470000},
	{{4, 0, -3, 0, 0, 0, 0, 0, -2, 2, -2}, 100.631050, 0.000050, 0.087000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 99.283390, 0.000040, 0.078000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, -1, -2}, 100.631050, 0.000020, 0.038000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 99.364550, 0.000730, 2.836000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 100.772710, 0.000160, 0.076000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 313.253410, 0.000020, 5.381000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 279.297380, 0.000200, 0.073000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 1, -2}, 100.631050, 0.004270, 52.370000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 2, -2}, 100.735990, 0.000240, 0.075000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 3, -2}, 100.631050, 0.000020, 0.038000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 133.673170, 0.000020, 1.426000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 100.631050, 0.000050, 0.087000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 283.540260, 0.000020, 0.026000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 2, 1, -2}, 100.631050, 0.000050, 0.040000},
	{{4, 0, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 35.960470, 0.000020, 0.739000},
	{{4, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 215.971470, 0.000020, 0.068000},
	{{4, 0, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 52.057620, 0.000040, 3.346000},
	{{4, 3, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 61.209130, 0.000020, 0.075000},
	{{4, 3, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 332.741860, 0.000080, 312.886000},
	{{4, 5, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 191.664720, 0.000030, 661.131000},
	{{4, 6, -11, 0, 0, 0, 0, 0, 2, -1, -2}, 135.175380, 0.000010, 560.934000},
	{{4, 11, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 214.850980, 0.000040, 135.472000},
	{{4, 13, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 22.168160, 0.000020, 374.117000},
	{{4, 17, -31, 0, 0, 0, 0, 0, 0, -1, 0}, 313.522550, 0.000010, 74.095000},
	{{4, 21, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 21.648850, 0.000010, 145.805000},
	{{4, 29, -39, 0, 0, 0, 0, 0, -2, 0, 0}, 271.147640, 0.000020, 90.547000},
	{{5, -32, 18, 0, 0, 0, 0, 0, 0, 1, 0}, 257.068140, 0.000090, 1880.011000},
	{{5, -14, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 335.896700, 0.000010, 319.437000},
	{{5, -12, 12, 0, 0, 0, 0, 0, 0, -1, 0}, 250.868440, 0.000030, 633.672000},
	{{5, -4, -1, 0, 0, 0, 0, 0, 0, -2, 0}, 111.034030, 0.000010, 0.075000},
	{{5, -4, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 111.034030, 0.000210, 383.522000},
	{{5, -4, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 111.034030, 0.000010, 0.075000},
	{{5, 0, -13, 7, 0, 0, 0, 0, -2, 0, 0}, 303.081240, 0.000030, 0.075000},
	{{5, 0, -13, 7, 0, 0, 0, 0, -2, 1, 0}, 303.081240, 0.000530, 1971.354000},
	{{5, 0, -13, 7, 0, 0, 0, 0, -2, 2, 0}, 303.081240, 0.000030, 0.075000},
	{{5, 0, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 214.199780, 0.000020, 2.019000},
	{{5, 0, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 322.551270, 0.000060, 1.981000},
	{{5, 0, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 142.907800, 0.000030, 0.073000},
	{{5, 0, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 73.666320, 0.000020, 0.665000},
	{{5, 0, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 246.333930, 0.000030, 0.068000},
	{{5, 0, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 252.406350, 0.000010, 0.025000},
	{{5, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 3.422250, 0.000010, 0.025000},
	{{5, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 283.798400, 0.000010, 0.024000},
	{{5, 4, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 188.674680, 0.000020, 147.212000},
	{{6, -39, 27, 0, 0, 0, 0, 0, 2, -1, 0}, 18.435780, 0.000060, 892.417000},
	{{6, -31, 14, 0, 0, 0, 0, 0, 2, -1, 0}, 97.575900, 0.000010, 326.268000},
	{{6, 0, -3, 0, 0, 0, 0, 0, -5, 2, 1}, 155.157020, 0.000050, 352.558000},
	{{6, 0, 0, 0, -2, 0, 0, 0, -2, -1, 0}, 231.515270, 0.000010, 0.075000},
	{{6, 0, 0, 0, -2, 0, 0, 0, -2, 0, 0}, 231.515270, 0.000260, 155.167000},
	{{6, 0, 0, 0, -2, 0, 0, 0, -2, 1, 0}, 231.515270, 0.000010, 0.075000},
	{{6, 0, 0, 0, 0, 0, 0, 0, -2, -1, 0}, 235.020940, 0.000010, 0.076000},
	{{6, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 235.020940, 0.000240, 5.713000},
	{{6, 0, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 235.020940, 0.000010, 0.074000},
	{{7, 0, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 280.645240, 0.000020, 0.598000},
	{{7, 0, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 208.705600, 0.000100, 1.486000},
	{{7, 0, -4, 0, -4, 0, 0, 0, -2, 0, 0}, 41.489530, 0.000030, 99.278000},
	{{7, 0, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 138.003810, 0.000010, 0.077000},
	{{7, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 138.003810, 0.000250, 3.057000},
	{{7, 0, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 138.003810, 0.000010, 0.074000},
	{{7, 0, -4, 0, 0, 0, 0, 0, -2, 2, -2}, 137.632690, 0.000020, 157.008000},
	{{7, 0, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 83.200500, 0.000030, 3.658000},
	{{8, -4, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 31.095490, 0.000030, 43.751000},
	{{8, 0, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 261.320950, 0.000020, 1.920000},
	{{8, 0, -9, 1, 0, 0, 0, 0, -2, 0, 0}, 7.569290, 0.000020, 91.577000},
	{{8, 4, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 233.877550, 0.000010, 53.558000},
	{{9, -19, 5, 0, 0, 0, 0, 0, -2, 1, 0}, 104.650470, 0.000020, 467.061000},
	{{9, -3, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 220.495190, 0.000010, 95.129000},
	{{9, -1, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 72.257000, 0.000060, 172.311000},
	{{10, 0, -12, -9, 0, 0, 0, 0, -2, 0, 0}, 352.792540, 0.000010, 574.613000},
	{{11, 0, -22, 2, 0, 0, 0, 0, -2, 0, 0}, 113.754190, 0.000050, 890.800000},
	{{12, 0, -12, 0, 2, 0, 0, 0, -2, -1, 0}, 207.326780, 0.000170, 2204.260000},
	{{17, 0, -22, 0, 0, 0, 0, 0, -5, 1, 0}, 332.538240, 0.000020, 411.722000}
};

static const struct planet_pert plan_pert_elp11 [ELP11_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 179.931970, 0.000680, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1}, 359.928610, 0.000070, 5.997000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1}, 359.977390, 0.000400, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -1}, 359.994840, 0.000030, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1}, 359.973130, 0.000060, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1}, 359.891520, 0.000010, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, -1}, 180.039600, 0.000010, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 356.536300, 0.000020, 1.127000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 1}, 180.039600, 0.000010, 0.080000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 180.017720, 0.000180, 0.949000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 76.409710, 0.000520, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 180.016740, 0.000190, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 45.970980, 0.000070, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -3, 1}, 180.669920, 0.000010, 0.622000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, -1}, 0.067500, 0.000150, 0.066000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, -1}, 0.097880, 0.001430, 0.515000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 1}, 0.107900, 0.001620, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 0.144350, 0.003210, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1}, 0.127990, 0.000810, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, -1}, 0.151480, 0.000210, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1}, 0.141220, 0.000100, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -1, 0}, 34.898150, 0.000070, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 34.898150, 0.000060, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -2, 1}, 0.120970, 0.000030, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -1, -1}, 0.113700, 0.000080, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -1, 1}, 0.109380, 0.000040, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, 0, -1}, 0.115430, 0.000050, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 1}, 0.106700, 0.000010, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -1, -1}, 261.188640, 0.000010, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 1}, 261.188640, 0.000010, 5.786000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 1, -1}, 261.188640, 0.000010, 6.223000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1}, 261.188640, 0.000010, 0.037000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, -1, -1}, 99.715230, 0.000050, 0.037000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, -1, 1}, 102.008920, 0.000050, 6.005000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 0, -1}, 330.599030, 0.000030, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 0, 1}, 330.599030, 0.000030, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 1, -1}, 102.008920, 0.000050, 5.988000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 1, 1}, 99.715230, 0.000050, 0.037000},
	{{0, 0, 0, 0, 0, 0, 1, 0, -2, 0, 1}, 184.372050, 0.000040, 0.088000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, -1, -1}, 236.391870, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 1}, 236.391870, 0.000020, 5.597000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, 1, -1}, 236.391870, 0.000020, 6.458000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1}, 236.391870, 0.000020, 0.037000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 2, 0, -1}, 186.066060, 0.000040, 0.088000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -4, 1, -1}, 267.938170, 0.000010, 0.020000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, -1, -1}, 267.934480, 0.000030, 0.019000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, -1, 1}, 266.912650, 0.000080, 0.041000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, -1}, 267.323230, 0.000210, 0.026000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 1}, 267.415380, 0.001010, 0.089000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 1, -1}, 269.364010, 0.000240, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 1, 1}, 269.571190, 0.000200, 0.506000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 2, 1}, 273.819560, 0.000010, 0.066000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0}, 63.313910, 0.000050, 0.081000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -2, -1}, 261.434130, 0.000040, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -2, 1}, 261.299280, 0.000020, 0.077000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, -1}, 260.896380, 0.000380, 0.038000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 1}, 261.089840, 0.000400, 4.983000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 0, -1}, 77.863130, 0.000070, 0.075000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1}, 78.074590, 0.000070, 0.074000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, -1}, 261.055090, 0.000390, 7.530000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1}, 260.838940, 0.000380, 0.037000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 2, -1}, 261.316330, 0.000020, 0.076000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 1}, 261.442440, 0.000040, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0}, 66.178160, 0.000060, 0.081000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -2, -1}, 273.512830, 0.000010, 0.066000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -1, -1}, 269.412650, 0.000200, 0.524000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -1, 1}, 269.096040, 0.000240, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, -1}, 266.954230, 0.001030, 0.088000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 1}, 267.305200, 0.000200, 0.026000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 1, -1}, 266.452860, 0.000080, 0.041000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 1, 1}, 267.722360, 0.000030, 0.019000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 4, -1, 1}, 267.446960, 0.000010, 0.020000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, 0, -1}, 167.019970, 0.000010, 0.026000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, 0, 1}, 164.851040, 0.000060, 0.089000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -1, 0, 0}, 324.556940, 0.000040, 0.081000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, -1, -1}, 324.489140, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, -1, 1}, 324.489140, 0.000020, 4.262000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 0, -1}, 151.656840, 0.000020, 0.075000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 1}, 151.656840, 0.000020, 0.074000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 1, -1}, 324.489140, 0.000020, 10.115000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 1, 1}, 324.489140, 0.000020, 0.037000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0}, 139.432020, 0.000020, 0.080000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 2, 0, -1}, 168.870910, 0.000040, 0.088000},
	{{0, 0, 0, 0, 1, -5, 0, 0, -2, 0, 1}, 200.353490, 0.000020, 0.088000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 2, 0, -1}, 193.554510, 0.000020, 0.089000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, 0, -1}, 355.569310, 0.000010, 0.026000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, 0, 1}, 355.569230, 0.000070, 0.089000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, -1, -1}, 298.689350, 0.000030, 0.038000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, -1, 1}, 298.689350, 0.000030, 5.460000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 0, -1}, 47.021900, 0.000010, 0.075000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 0, 1}, 47.021900, 0.000010, 0.074000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 1, -1}, 298.689350, 0.000030, 6.651000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 1, 1}, 298.689350, 0.000030, 0.037000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, 0, -1}, 353.653950, 0.000070, 0.088000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, 0, 1}, 353.653950, 0.000010, 0.026000},
	{{0, 0, 0, 0, 1, -1, 0, 0, -2, 0, 1}, 177.145810, 0.000040, 0.089000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 2, 0, -1}, 176.873340, 0.000040, 0.088000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 0, -1}, 351.253420, 0.000040, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 0, 1}, 354.032430, 0.000100, 0.028000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 1, -1}, 354.164630, 0.000080, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 1, 1}, 358.471100, 0.000150, 0.044000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 2, -1}, 0.796760, 0.000060, 0.028000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 2, 1}, 354.865040, 0.000020, 0.106000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -2, -1}, 355.376670, 0.000040, 0.015000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -2, 1}, 344.456850, 0.000030, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, -1}, 347.066460, 0.000240, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, 1}, 349.192480, 0.000500, 0.041000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, -1}, 354.591520, 0.001640, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 1}, 354.873770, 0.008370, 0.089000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 3}, 357.189040, 0.000030, 0.064000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, -1}, 359.578860, 0.002490, 0.040000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, 1}, 358.812360, 0.002080, 0.494000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 2, -1}, 184.957900, 0.000040, 0.086000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 2, 1}, 6.057030, 0.000200, 0.065000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, -1, 0}, 78.883060, 0.000060, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, -1}, 178.575820, 0.000050, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0}, 79.943220, 0.001190, 0.081000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 1}, 176.764520, 0.000050, 0.879000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 1, 0}, 258.883060, 0.000060, 1.030000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -3, -1}, 291.107660, 0.000020, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -2, -1}, 295.124110, 0.000220, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -2, 1}, 293.672930, 0.000100, 0.077000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, -1}, 295.953140, 0.001780, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 1}, 294.283720, 0.001810, 3.983000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1}, 102.392980, 0.000530, 0.075000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1}, 103.214550, 0.000490, 0.074000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, -1}, 294.080480, 0.001810, 12.128000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1}, 294.521120, 0.001800, 0.037000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 2, -1}, 293.154610, 0.000100, 0.076000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 2, 1}, 293.904060, 0.000210, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 3, 1}, 290.195870, 0.000020, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, 0}, 258.389060, 0.000090, 1.246000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, 2}, 257.200400, 0.000010, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, -2}, 78.526810, 0.000010, 0.069000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, -1}, 174.066430, 0.000030, 1.032000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0}, 78.541300, 0.001420, 0.080000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1}, 174.067730, 0.000030, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0}, 78.550350, 0.000080, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -2, -1}, 6.801430, 0.000180, 0.066000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -2, 1}, 154.628650, 0.000030, 0.085000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, -1}, 356.906770, 0.001940, 0.539000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, 1}, 356.398110, 0.002300, 0.040000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, -3}, 346.457260, 0.000010, 0.065000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, -1}, 346.145980, 0.007790, 0.088000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 1}, 346.814780, 0.001430, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, -1}, 343.482590, 0.000470, 0.041000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 1}, 339.265770, 0.000210, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 2, -1}, 325.273060, 0.000020, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 2, 1}, 351.918730, 0.000020, 0.015000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, -1, 0}, 178.445710, 0.000020, 0.042000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -2, -1}, 352.085420, 0.000020, 0.104000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -2, 1}, 357.781400, 0.000060, 0.027000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -1, -1}, 353.410590, 0.000140, 0.044000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -1, 1}, 351.708100, 0.000070, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 0, -1}, 350.540320, 0.000100, 0.028000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 0, 1}, 352.657850, 0.000030, 0.016000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, -1, -1}, 0.043910, 0.000030, 0.037000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, -1, 1}, 0.043910, 0.000020, 5.974000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, 1, -1}, 0.043910, 0.000020, 6.019000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, 1, 1}, 0.043910, 0.000030, 0.037000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 1, 1}, 165.960950, 0.000020, 0.044000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 2, -1}, 165.639730, 0.000010, 0.027000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -2, 1}, 345.159660, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -1, -1}, 333.098420, 0.000050, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -1, 1}, 329.350360, 0.000100, 0.041000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 0, -1}, 251.065820, 0.000080, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 0, 1}, 263.998030, 0.000410, 0.088000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, -1}, 178.133810, 0.000610, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, 1}, 178.938410, 0.000500, 0.516000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 2, 1}, 169.586260, 0.000090, 0.066000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 3, 1}, 166.630730, 0.000010, 0.035000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -3, -1}, 345.960950, 0.000030, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -3, 1}, 345.960950, 0.000010, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, -1}, 346.250390, 0.000370, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, 1}, 346.251890, 0.000190, 0.076000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, -1}, 346.456830, 0.002990, 0.037000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 1}, 346.269780, 0.003050, 6.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, -1}, 161.530010, 0.000860, 0.074000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, 1}, 161.533960, 0.000860, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, -1}, 346.271780, 0.003050, 5.956000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, 1}, 346.459100, 0.002990, 0.037000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, -1}, 346.251330, 0.000190, 0.076000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, 1}, 346.250180, 0.000370, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 3, -1}, 345.960950, 0.000010, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 3, 1}, 345.960950, 0.000030, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 1, 0, 0}, 342.202070, 0.000020, 0.081000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -3, -1}, 166.648330, 0.000010, 0.035000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -2, -1}, 169.567550, 0.000090, 0.066000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, -1}, 178.846860, 0.000500, 0.515000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, 1}, 178.041160, 0.000620, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 0, -1}, 261.348970, 0.000400, 0.088000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 0, 1}, 249.997810, 0.000080, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 1, -1}, 329.118360, 0.000100, 0.041000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 1, 1}, 333.021150, 0.000050, 0.019000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 2, -1}, 345.121840, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, -2, 1}, 165.636380, 0.000010, 0.027000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, -1, -1}, 165.960950, 0.000020, 0.044000},
	{{0, 0, 0, 0, 2, -4, 0, 0, -2, 0, 1}, 250.785510, 0.000020, 0.089000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, 0, -1}, 240.492130, 0.000010, 0.075000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, 0, 1}, 240.492130, 0.000010, 0.074000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 2, 0, -1}, 251.032140, 0.000020, 0.088000},
	{{0, 0, 0, 0, 2, -3, 0, 0, -2, 0, 1}, 300.404270, 0.000030, 0.089000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 2, 0, -1}, 300.369620, 0.000020, 0.088000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, 0, -1}, 359.170330, 0.000020, 0.026000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, 0, 1}, 359.179170, 0.000070, 0.089000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, -1, -1}, 356.924130, 0.000010, 0.038000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, -1, 1}, 356.924130, 0.000010, 3.739000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, 1, -1}, 356.924130, 0.000010, 15.142000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, 1, 1}, 356.924130, 0.000010, 0.037000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, 0, -1}, 358.653920, 0.000070, 0.088000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, 0, 1}, 358.653800, 0.000010, 0.026000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -3, 0, 0}, 336.555810, 0.000020, 0.027000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -3, 1, 0}, 336.555860, 0.000020, 0.042000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 0, -1}, 19.829610, 0.000040, 0.026000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 0, 1}, 14.231820, 0.000160, 0.090000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 1, -1}, 23.795400, 0.000050, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 1, 1}, 20.420490, 0.000050, 0.474000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -1, -1, 0}, 336.555720, 0.000020, 0.039000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -1, 0, 0}, 30.816840, 0.000200, 0.082000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -2, -1}, 320.307220, 0.000020, 0.025000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -2, 1}, 320.307220, 0.000010, 0.077000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -1, -1}, 319.766700, 0.000200, 0.038000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -1, 1}, 320.052160, 0.000190, 2.982000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -2}, 132.889910, 0.000010, 0.037000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -1}, 143.796040, 0.000080, 0.075000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1}, 142.166590, 0.000080, 0.074000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, -2}, 136.638230, 0.000060, 0.075000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, -1}, 319.871480, 0.000200, 540.002000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0}, 132.726940, 0.000100, 0.074000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 1}, 320.120630, 0.000190, 0.037000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 2, -1}, 320.307220, 0.000010, 0.075000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 2, 0}, 132.889910, 0.000010, 0.037000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 2, 1}, 320.307220, 0.000020, 0.025000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0}, 101.536780, 0.000280, 0.080000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -1, -1}, 2.133480, 0.000050, 0.564000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -1, 1}, 356.143730, 0.000050, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 0, -1}, 333.818650, 0.000350, 0.087000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 1}, 336.703380, 0.000060, 0.026000},
	{{0, 0, 0, 0, 3, -5, 0, 0, -2, 0, -1}, 83.977370, 0.000010, 0.026000},
	{{0, 0, 0, 0, 3, -5, 0, 0, -2, 0, 1}, 84.757570, 0.000060, 0.089000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, -1, -1}, 87.882200, 0.000010, 0.038000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, -1, 1}, 87.882200, 0.000010, 4.001000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, 1, -1}, 87.882200, 0.000010, 11.964000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, 1, 1}, 87.882200, 0.000010, 0.037000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, 0, -1}, 84.802110, 0.000050, 0.088000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, 0, 1}, 84.802090, 0.000010, 0.026000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -1, 0, 0}, 24.023890, 0.000010, 0.083000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -1, 0, 2}, 24.023890, 0.000010, 0.068000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, -1, -1}, 314.350810, 0.000010, 0.038000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, -1, 1}, 314.350810, 0.000010, 2.383000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 0, -1}, 134.791080, 0.000010, 0.076000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1}, 134.791080, 0.000010, 0.073000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 1, -1}, 314.350810, 0.000010, 11.607000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 1, 1}, 314.350810, 0.000010, 0.037000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0}, 107.975620, 0.000040, 0.079000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, -1, -1}, 177.394040, 0.000010, 0.037000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, 0, -1}, 181.088710, 0.000010, 0.074000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, 0, 1}, 181.088710, 0.000010, 0.075000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, 1, 1}, 177.394040, 0.000010, 0.037000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, -1}, 38.917510, 0.000050, 0.027000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 1}, 38.652540, 0.000200, 0.093000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 1, -1}, 38.655490, 0.000060, 0.041000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 1, 1}, 38.656750, 0.000060, 0.404000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, -1, 0}, 128.063580, 0.000020, 0.040000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0}, 127.995280, 0.000260, 0.084000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 1, 0}, 308.063580, 0.000020, 0.705000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, -1, -1}, 27.222520, 0.000010, 0.038000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 1}, 27.222520, 0.000010, 1.432000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, -1}, 189.212940, 0.000020, 0.078000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1}, 193.868440, 0.000020, 0.072000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 1, -1}, 27.222520, 0.000010, 2.740000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 1}, 27.222520, 0.000010, 0.037000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, -1, 0}, 308.776630, 0.000050, 2.814000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0}, 128.776800, 0.000870, 0.078000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0}, 128.776630, 0.000050, 0.038000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -1, -1}, 31.074640, 0.000040, 0.710000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -1, 1}, 31.075730, 0.000040, 0.039000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 0, -1}, 27.843410, 0.000110, 0.084000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 0, 1}, 32.691610, 0.000020, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, -1, -1}, 136.608700, 0.000010, 0.020000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 0, -1}, 131.466160, 0.000110, 0.027000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 1}, 132.339480, 0.000380, 0.098000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 1, -1}, 136.423190, 0.000100, 0.042000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 1, 1}, 139.593620, 0.000080, 0.333000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, -1, 0}, 343.756670, 0.000040, 0.041000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 0, -2}, 163.747610, 0.000050, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 0, 0}, 343.884020, 0.001310, 0.088000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 1, -2}, 343.755560, 0.000010, 0.040000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 1, 0}, 343.753110, 0.000380, 0.513000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 2, 0}, 343.754080, 0.000040, 0.066000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -1, -1}, 148.512130, 0.000080, 0.039000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 1}, 145.971820, 0.000050, 0.813000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, -1}, 202.191930, 0.000030, 0.081000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 1}, 207.371320, 0.000030, 0.069000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 1, -1}, 183.477840, 0.000020, 1.115000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 1}, 195.850010, 0.000030, 0.036000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -2, -2}, 163.755580, 0.000070, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -2, 0}, 343.747230, 0.000040, 0.076000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, -2}, 163.761570, 0.000590, 0.037000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, 0}, 343.749960, 0.001630, 5.670000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, -2}, 163.824020, 0.001880, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 0}, 163.750180, 0.038840, 0.074000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 2}, 343.751180, 0.000040, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, -2}, 163.728380, 0.000390, 6.363000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, 0}, 163.749370, 0.002610, 0.037000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 2, -2}, 163.743260, 0.000020, 0.076000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 2, 0}, 163.749210, 0.000190, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, -1}, 277.592530, 0.000070, 0.081000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, 1}, 103.589640, 0.000010, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -1, -2}, 343.804450, 0.000050, 0.518000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -1, 0}, 163.745510, 0.000380, 0.040000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 0, -2}, 163.672710, 0.000130, 0.088000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 0, 0}, 163.746080, 0.000280, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 1, -2}, 163.724930, 0.000020, 0.041000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 1, 0}, 163.744620, 0.000040, 0.019000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 1, 0, 0}, 1.877270, 0.000060, 0.072000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -1, 0, 0}, 145.973630, 0.000020, 0.071000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, -1, 0}, 345.714810, 0.000040, 0.037000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 0, 0}, 345.718130, 0.000780, 0.074000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 0, 2}, 345.883770, 0.000010, 0.075000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 1, 0}, 165.714810, 0.000040, 4.171000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 0, -1}, 25.353640, 0.000010, 0.069000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 0, 1}, 33.717970, 0.000030, 0.081000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 1, 0, 0}, 164.697890, 0.000040, 0.089000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, -1, -1}, 41.031480, 0.000040, 0.326000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, -1, 1}, 41.030830, 0.000040, 0.042000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 0, -1}, 41.002870, 0.000120, 0.098000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 0, 1}, 39.422590, 0.000040, 0.027000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, -1, 0}, 21.081610, 0.000030, 0.038000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 0, 0}, 21.081610, 0.000510, 0.077000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 1, 0}, 201.081610, 0.000030, 3.425000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 0, -1}, 325.412580, 0.000020, 0.071000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 0, 1}, 325.412580, 0.000020, 0.078000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 1, 0, 0}, 23.419950, 0.000160, 0.085000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 0, -1}, 83.584320, 0.000070, 0.093000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 0, 1}, 79.197420, 0.000020, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 0, -1}, 319.402670, 0.000020, 0.016000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 0, 1}, 318.781740, 0.000080, 0.028000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 1, -1}, 318.950580, 0.000060, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 1, 1}, 319.553820, 0.000100, 0.044000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 2, -1}, 321.524190, 0.000030, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 2, 1}, 319.158230, 0.000010, 0.104000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 0, 0}, 273.311230, 0.000020, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 1, 0}, 273.311250, 0.000020, 0.042000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -2, -1}, 319.202740, 0.000020, 0.015000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -2, 1}, 313.437850, 0.000010, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -1, -1}, 318.201840, 0.000190, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -1, 1}, 317.417670, 0.000430, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, -1}, 318.432930, 0.001160, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 1}, 318.176590, 0.006150, 0.088000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 3}, 321.193370, 0.000020, 0.065000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, -1}, 321.351660, 0.001410, 0.040000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, 1}, 321.434610, 0.001130, 0.533000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 2, -1}, 134.414250, 0.000030, 0.085000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 2, 1}, 327.216930, 0.000060, 0.066000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, -1, 0}, 52.992050, 0.000020, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, -1}, 139.116130, 0.000030, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 0}, 52.991740, 0.000380, 0.080000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 1}, 139.467170, 0.000020, 1.010000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 1, 0}, 232.992050, 0.000020, 1.214000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -3, -1}, 313.603740, 0.000040, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -2, -1}, 313.641980, 0.000350, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -2, 1}, 312.978750, 0.000170, 0.076000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, -1}, 314.041030, 0.002970, 0.037000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 1}, 312.908460, 0.002650, 9.672000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, -1}, 324.719160, 0.002580, 0.074000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, 1}, 324.906320, 0.002530, 0.075000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, -1}, 312.905510, 0.002670, 4.346000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, 1}, 314.211890, 0.002990, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, -1}, 313.064610, 0.000170, 0.077000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, 1}, 313.806050, 0.000360, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 3, 1}, 313.716920, 0.000040, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, -1, 0}, 232.668180, 0.000020, 1.052000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, -1}, 137.694160, 0.000030, 0.895000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, 0}, 50.414650, 0.000390, 0.081000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, 1}, 137.809260, 0.000040, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 1, 0}, 52.668180, 0.000020, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -2, -1}, 326.211480, 0.000080, 0.066000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -2, 1}, 142.877790, 0.000020, 0.086000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, -1}, 321.594140, 0.001280, 0.499000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, 1}, 321.816560, 0.001570, 0.040000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, -3}, 319.691520, 0.000020, 0.064000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, -1}, 320.081510, 0.006340, 0.089000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, 1}, 320.137500, 0.001270, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, -1}, 318.606900, 0.000450, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, 1}, 318.610910, 0.000220, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 2, -1}, 313.548000, 0.000010, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 2, 1}, 320.161640, 0.000020, 0.015000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -2, -1}, 319.981620, 0.000010, 0.106000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -2, 1}, 322.392900, 0.000030, 0.028000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -1, -1}, 321.071610, 0.000100, 0.044000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -1, 1}, 319.715840, 0.000060, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, 0, -1}, 319.779610, 0.000090, 0.028000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, 0, 1}, 319.302880, 0.000030, 0.016000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, 0, -1}, 33.824930, 0.000010, 0.026000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, 0, 1}, 33.824930, 0.000050, 0.088000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, -1, -1}, 28.876950, 0.000020, 0.037000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, -1, 1}, 26.573290, 0.000010, 5.838000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 0, -1}, 44.038170, 0.000020, 0.075000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 0, 1}, 44.038170, 0.000020, 0.074000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 1, -1}, 26.573290, 0.000010, 6.164000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 1, 1}, 28.876950, 0.000020, 0.037000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, 0, -1}, 33.774990, 0.000050, 0.088000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, 0, 1}, 33.774990, 0.000010, 0.026000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 0, 0, -1}, 196.888330, 0.000010, 0.075000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 0, 0, 1}, 196.888330, 0.000010, 0.074000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -4, 1, -1}, 0.648030, 0.000010, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, -1, -1}, 0.642870, 0.000050, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, -1, 1}, 0.637620, 0.000080, 0.041000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, -1}, 0.649470, 0.000220, 0.027000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 1}, 0.637910, 0.001020, 0.092000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 1, -1}, 0.686390, 0.000300, 0.041000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 1, 1}, 0.678720, 0.000260, 0.415000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 2, 1}, 0.637810, 0.000030, 0.064000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 0, 0}, 92.495320, 0.000140, 0.084000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -2, -1}, 0.404080, 0.000020, 0.025000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -1, -1}, 0.586250, 0.000170, 0.038000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -1, 1}, 0.483410, 0.000170, 1.575000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, -1}, 2.479870, 0.000090, 0.077000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 1}, 3.472800, 0.000060, 0.072000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 1, -1}, 0.374300, 0.000140, 3.316000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 1, 1}, 0.471120, 0.000130, 0.037000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 2, 1}, 0.401930, 0.000020, 0.025000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, -1, 0}, 274.465150, 0.000020, 2.388000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 0, 0}, 94.465150, 0.000460, 0.078000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 1, 0}, 94.465150, 0.000030, 0.038000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -1, -1}, 0.358030, 0.000160, 0.679000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -1, 1}, 0.361030, 0.000210, 0.039000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, -1}, 0.288390, 0.000710, 0.085000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, 1}, 0.338070, 0.000110, 0.026000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 1, -1}, 0.259300, 0.000030, 0.040000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 1, 1}, 0.304570, 0.000010, 0.019000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 1, 0, 0}, 129.726920, 0.000020, 0.077000},
	{{0, 0, 1, 0, -5, 5, 0, 0, 1, 0, 0}, 328.561070, 0.000030, 0.076000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 0, -1}, 317.013040, 0.000030, 0.027000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 0, 1}, 317.561340, 0.000090, 0.094000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 1, -1}, 317.173490, 0.000030, 0.041000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 1, 1}, 317.174080, 0.000030, 0.384000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -1, 0, 0}, 122.262090, 0.000060, 0.085000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, -1, -1}, 313.455190, 0.000030, 0.038000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, -1, 1}, 313.726190, 0.000020, 1.206000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 0, -1}, 314.679020, 0.000020, 0.078000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 0, 1}, 314.679020, 0.000020, 0.071000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 1, -1}, 313.726190, 0.000020, 2.016000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 1, 1}, 313.455190, 0.000030, 0.037000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, -1, 0}, 300.642030, 0.000020, 4.460000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, 0, 0}, 120.642030, 0.000370, 0.077000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, 1, 0}, 120.642030, 0.000020, 0.038000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 2, 0, -1}, 316.852710, 0.000030, 0.083000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 1, 0, 0}, 101.059210, 0.000050, 0.076000},
	{{0, 0, 1, 0, -4, 5, 0, 0, -1, 0, 0}, 271.814070, 0.000030, 0.087000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 1, 0, 0}, 271.894290, 0.000280, 0.076000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 0, 1}, 309.205860, 0.000020, 0.028000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 1, -1}, 309.303830, 0.000010, 0.020000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, -1, -1}, 308.725300, 0.000040, 0.020000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, -1, 1}, 309.231560, 0.000050, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, -1}, 308.480550, 0.000230, 0.027000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, 1}, 309.024480, 0.000850, 0.095000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 1, -1}, 309.094980, 0.000260, 0.041000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 1, 1}, 309.040540, 0.000230, 0.372000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 2, 1}, 308.377140, 0.000030, 0.063000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, -1, 2}, 290.645720, 0.000020, 0.508000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 0, 0}, 111.641250, 0.000480, 0.086000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 1, 0}, 291.160860, 0.000070, 0.612000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -2, -1}, 305.363120, 0.000030, 0.026000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -2, 1}, 299.785440, 0.000020, 0.081000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -1, -1}, 306.304710, 0.000220, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -1, 1}, 306.109660, 0.000240, 1.094000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 0, -1}, 303.241190, 0.000200, 0.079000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 0, 1}, 304.598410, 0.000220, 0.071000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 1, -1}, 304.881230, 0.000180, 1.723000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 1, 1}, 304.684260, 0.000200, 0.036000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 2, -1}, 305.579960, 0.000010, 0.072000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 2, 1}, 305.396920, 0.000030, 0.025000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -3, 0}, 110.918750, 0.000020, 0.038000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -2, 0}, 110.980780, 0.000350, 0.075000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -2, 2}, 290.622350, 0.000040, 0.074000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -1, 0}, 291.104670, 0.000160, 7.147000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -1, 2}, 110.669700, 0.000120, 0.037000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 0, -2}, 112.975050, 0.000030, 0.073000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 0, 0}, 110.921660, 0.004720, 0.076000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 1, 0}, 110.924070, 0.000250, 0.038000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -2, -1}, 112.986920, 0.000010, 0.069000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -1, -1}, 88.633370, 0.000060, 0.838000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -1, 1}, 88.190200, 0.000070, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 0, -1}, 308.415910, 0.000470, 0.083000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 0, 1}, 323.441470, 0.000030, 0.026000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 1, -1}, 308.678560, 0.000020, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 3, -1, 0}, 110.924130, 0.000050, 0.041000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 3, 0, 0}, 110.924170, 0.000030, 0.026000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -3, 1}, 112.989940, 0.000010, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -2, -1}, 112.956250, 0.000030, 0.097000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -2, 1}, 112.999510, 0.000040, 0.027000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -1, -1}, 113.022740, 0.000030, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -1, 1}, 113.022480, 0.000020, 0.020000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 1, 0, 0}, 109.390310, 0.000020, 0.076000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 0, -1}, 172.567690, 0.000020, 0.027000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 0, 1}, 172.531860, 0.000070, 0.096000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, -1, -1}, 173.001240, 0.000010, 0.039000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, -1, 1}, 173.001240, 0.000010, 0.923000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 0, -1}, 171.137150, 0.000010, 0.080000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 0, 1}, 171.137150, 0.000010, 0.070000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 1, -1}, 173.001240, 0.000010, 1.333000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 1, 1}, 173.001240, 0.000010, 0.036000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 1, 0, 0}, 4.120680, 0.000070, 0.075000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 2, 0, -1}, 172.496000, 0.000020, 0.082000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, -1, 1}, 305.976720, 0.000020, 0.021000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 0, -1}, 305.255290, 0.000030, 0.016000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 0, 1}, 305.623100, 0.000080, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 1, -1}, 305.627450, 0.000070, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 1, 1}, 306.190340, 0.000110, 0.046000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 2, -1}, 305.595880, 0.000050, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 2, 1}, 305.487060, 0.000010, 0.115000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 0, 0}, 100.506350, 0.000030, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 1, 0}, 100.506350, 0.000050, 0.043000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -2, -1}, 305.794550, 0.000040, 0.016000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -2, 1}, 306.029650, 0.000020, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -1, -1}, 304.737940, 0.000260, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -1, 1}, 305.087450, 0.000430, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, -1}, 305.953430, 0.001690, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 1}, 305.983160, 0.006630, 0.095000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 3}, 306.681800, 0.000020, 0.061000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, -1}, 305.739830, 0.002010, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, 1}, 305.708390, 0.001680, 0.361000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 2, -1}, 131.186680, 0.000020, 0.092000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 2, 1}, 306.220140, 0.000160, 0.062000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 3, 1}, 305.799720, 0.000020, 0.034000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -1, 0}, 100.501910, 0.000150, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -1, 2}, 280.525280, 0.000030, 0.487000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, -1}, 125.851430, 0.000110, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 0}, 100.506730, 0.003490, 0.087000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 1}, 125.828520, 0.000100, 0.530000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 2}, 100.504440, 0.000040, 0.065000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, -2}, 101.296850, 0.000010, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, 0}, 280.508590, 0.000860, 0.582000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 2, 0}, 280.509780, 0.000080, 0.067000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -3, -1}, 302.368150, 0.000010, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -2, -1}, 300.184840, 0.000220, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -2, 1}, 302.143700, 0.000100, 0.082000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, -1}, 300.775140, 0.001770, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, 1}, 300.695380, 0.001470, 1.002000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, -1}, 300.489410, 0.001150, 0.079000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 1}, 300.945760, 0.001480, 0.070000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 3}, 149.836710, 0.000010, 0.024000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, -1}, 301.645910, 0.001340, 1.505000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, 1}, 301.427280, 0.001390, 0.036000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 2, -1}, 302.054720, 0.000060, 0.072000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 2, 1}, 301.021480, 0.000150, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 3, 1}, 301.474190, 0.000010, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -3, 0}, 100.524700, 0.000040, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, -1}, 305.519490, 0.000020, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, 0}, 100.526680, 0.000610, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, 2}, 280.544440, 0.000020, 0.074000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, -2}, 101.133420, 0.000090, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, -1}, 306.259830, 0.000060, 0.074000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 0}, 280.506980, 0.002660, 17.980000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 1}, 308.304070, 0.000030, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 2}, 100.526330, 0.000190, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, -2}, 103.093510, 0.000380, 0.073000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, -1}, 306.090160, 0.000300, 4.497000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 0}, 100.507520, 0.049640, 0.076000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 1}, 306.060970, 0.000320, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 2}, 280.499720, 0.000030, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, -2}, 99.692070, 0.000060, 2.570000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, -1}, 306.090160, 0.000020, 0.077000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, 0}, 100.507940, 0.002790, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, 1}, 306.090150, 0.000040, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 2, 0}, 100.507130, 0.000160, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -2, -1}, 289.415740, 0.000030, 0.070000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -2, 1}, 144.185970, 0.000020, 0.080000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, -1}, 301.806750, 0.000630, 0.901000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, 1}, 301.290000, 0.000830, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, -3}, 304.878710, 0.000010, 0.068000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, -1}, 305.890910, 0.003380, 0.082000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, 1}, 302.435160, 0.000510, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 1, -1}, 305.728420, 0.000230, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 1, 1}, 305.401540, 0.000080, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -2, 0}, 280.524700, 0.000020, 0.088000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -1, 0}, 100.507700, 0.000540, 0.041000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 0, -2}, 99.252230, 0.000030, 0.090000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 0, 0}, 100.508010, 0.000320, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 1, 0}, 100.507310, 0.000040, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -3, 1}, 103.448470, 0.000010, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -2, -1}, 100.756560, 0.000010, 0.096000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -2, 1}, 289.321770, 0.000060, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -1, -1}, 290.796640, 0.000130, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -1, 1}, 285.657330, 0.000070, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, 0, -1}, 306.056640, 0.000020, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, 0, 1}, 130.717380, 0.000020, 0.016000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 1, 0, 0}, 111.743460, 0.000090, 0.075000},
	{{0, 0, 1, 0, -2, 3, 0, 0, 1, 0, 0}, 108.190190, 0.000240, 0.075000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 0, 0, -1}, 350.556370, 0.000010, 0.080000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 0, 0, 1}, 350.556370, 0.000010, 0.069000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 1, 0, 0}, 188.558820, 0.000090, 0.075000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 0, -1}, 179.225820, 0.000010, 0.027000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 0, 1}, 188.001810, 0.000040, 0.097000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 1, -1}, 271.102120, 0.000020, 0.042000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 1, 1}, 271.102120, 0.000020, 0.340000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, -1, -1}, 91.102120, 0.000020, 0.039000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, -1, 1}, 91.102120, 0.000010, 0.856000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 1, -1}, 271.102120, 0.000010, 1.199000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 1, 1}, 271.102120, 0.000010, 0.036000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 1, -1, 0}, 86.298980, 0.000060, 8.763000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 1, 0, 0}, 266.299360, 0.001050, 0.075000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 1, 1, 0}, 266.299360, 0.000060, 0.038000},
	{{0, 0, 1, 0, -2, 6, 0, 0, 1, 0, 0}, 270.458390, 0.000080, 0.075000},
	{{0, 0, 1, 0, -1, -5, 0, 0, 1, 0, 0}, 110.435730, 0.000030, 0.076000},
	{{0, 0, 1, 0, -1, -2, 0, 0, 1, 0, 0}, 271.708950, 0.000030, 0.076000},
	{{0, 0, 1, 0, -1, -1, 0, 0, 1, 0, 0}, 293.883070, 0.000030, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 1, -1}, 1.762680, 0.000010, 0.014000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 1, 1}, 1.762680, 0.000010, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 3, -1}, 1.664250, 0.000010, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -1, -1}, 0.829990, 0.000030, 0.013000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -1, 1}, 1.381880, 0.000060, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 0, -1}, 0.474730, 0.000170, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 0, 1}, 1.215670, 0.000410, 0.028000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 1, -1}, 1.548230, 0.000370, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 1, 1}, 1.672710, 0.000620, 0.046000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 2, -1}, 1.727420, 0.000210, 0.028000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 2, 1}, 1.491300, 0.000030, 0.116000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, 0, -1}, 2.018870, 0.000020, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -2, -1}, 1.598430, 0.000150, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -2, 1}, 1.686890, 0.000160, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -1, -1}, 1.575000, 0.001140, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -1, 1}, 1.666070, 0.001820, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, -1}, 1.795850, 0.008040, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 1}, 1.779970, 0.030560, 0.096000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 3}, 2.897940, 0.000090, 0.061000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, -1}, 1.644130, 0.009160, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, 1}, 1.618730, 0.007650, 0.350000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, -1}, 183.335680, 0.000050, 0.093000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, 1}, 1.746680, 0.000680, 0.062000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 3, 1}, 1.846660, 0.000070, 0.034000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -1, -1}, 0.705710, 0.000090, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -1, 0}, 96.047690, 0.000030, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -1, 1}, 0.579560, 0.000070, 0.089000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, -1}, 0.625860, 0.000430, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, 0}, 95.308810, 0.000260, 0.087000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, 1}, 0.629700, 0.000330, 0.508000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 1, 0}, 276.602590, 0.000100, 0.555000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 1, 1}, 0.794430, 0.000090, 0.066000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -3, -1}, 1.241280, 0.000080, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -3, 1}, 0.799970, 0.000020, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -2, -1}, 1.311370, 0.000770, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -2, 1}, 1.089660, 0.000330, 0.082000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, -3}, 1.100920, 0.000010, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, -1}, 1.269140, 0.006570, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, 1}, 1.396300, 0.005540, 0.924000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, 3}, 0.985040, 0.000030, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, -1}, 1.420050, 0.004500, 0.080000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 1}, 1.302190, 0.005910, 0.070000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 3}, 181.407020, 0.000020, 0.024000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, -3}, 2.033880, 0.000010, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, -1}, 1.121100, 0.005110, 1.335000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, 1}, 1.097750, 0.005300, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 2, -1}, 0.730300, 0.000290, 0.071000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 2, 1}, 1.134810, 0.000640, 0.024000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 3, -1}, 1.039680, 0.000020, 0.037000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 3, 1}, 1.084220, 0.000060, 0.018000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -2, -1}, 1.537220, 0.000010, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -2, 0}, 97.388320, 0.000030, 0.076000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -2, 1}, 181.027950, 0.000050, 5.117000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, -1}, 1.082440, 0.000510, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, 0}, 276.810580, 0.000430, 34.860000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, 1}, 1.056070, 0.000760, 0.074000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, -2}, 83.853800, 0.000040, 0.074000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, -1}, 180.712710, 0.003010, 7.243000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 0}, 96.812860, 0.008020, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 1}, 180.707160, 0.002970, 0.037000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, -1}, 180.710190, 0.000190, 0.076000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, 0}, 96.810340, 0.000430, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, 1}, 180.710690, 0.000370, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 2, 0}, 96.810310, 0.000030, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 2, 1}, 180.710190, 0.000040, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -3, -1}, 181.839720, 0.000020, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -2, -1}, 1.393150, 0.000030, 0.070000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -2, 1}, 170.523610, 0.000030, 0.080000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -1, -1}, 1.065330, 0.001700, 0.976000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -1, 1}, 0.846630, 0.002340, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, -3}, 0.784480, 0.000060, 0.068000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, -1}, 0.454260, 0.014090, 0.082000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, 1}, 0.593780, 0.001630, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 1, -1}, 0.693080, 0.000900, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 1, 1}, 1.454790, 0.000280, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 2, -1}, 0.757880, 0.000070, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 2, 1}, 1.201670, 0.000040, 0.015000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -2, -1}, 0.745830, 0.000010, 0.523000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -2, 1}, 0.713840, 0.000040, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -1, -1}, 0.397570, 0.000030, 0.088000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -1, 0}, 96.810020, 0.000090, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -1, 1}, 180.715630, 0.000050, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 0, -1}, 180.710180, 0.000100, 0.041000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 0, 0}, 96.809790, 0.000050, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 0, 1}, 180.710080, 0.000050, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -2, -1}, 0.975760, 0.000020, 0.096000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -2, 1}, 0.852420, 0.000060, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -1, -1}, 0.517880, 0.000210, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -1, 1}, 0.930030, 0.000060, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 0, -1}, 0.738570, 0.000140, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 0, 1}, 1.343950, 0.000030, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 5, -2, -1}, 0.711040, 0.000010, 0.044000},
	{{0, 0, 1, 0, -1, 1, 0, 0, 1, 0, 0}, 269.905170, 0.000050, 0.075000},
	{{0, 0, 1, 0, -1, 2, 0, 0, 1, 0, 0}, 68.966820, 0.000030, 0.075000},
	{{0, 0, 1, 0, -1, 3, 0, 0, 1, 0, 0}, 87.554730, 0.000100, 0.075000},
	{{0, 0, 1, 0, -1, 5, 0, 0, 1, 0, 0}, 103.144010, 0.000060, 0.074000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, 0, -1}, 314.819200, 0.000010, 0.027000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, 0, 1}, 314.864710, 0.000030, 0.095000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -1, 0, 0}, 109.268830, 0.000030, 0.087000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 1, 0, 0}, 108.155440, 0.000270, 0.076000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 1, 0, 0}, 299.235140, 0.000150, 0.076000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 0, -1}, 16.615920, 0.000020, 0.027000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 0, 1}, 16.909390, 0.000060, 0.096000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -1, 0, 0}, 206.565740, 0.000070, 0.087000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, -1, -1}, 16.764530, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, -1, 1}, 16.933390, 0.000010, 0.939000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 0, -1}, 15.180550, 0.000020, 0.080000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 0, 1}, 15.180550, 0.000020, 0.070000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 1, -1}, 16.933390, 0.000010, 1.367000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 1, 1}, 16.764530, 0.000020, 0.036000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, -1, 0}, 26.522780, 0.000090, 89.713000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, -2}, 206.520810, 0.000010, 0.074000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, -1}, 197.014560, 0.000020, 6.426000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, 0}, 206.522770, 0.001720, 0.075000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, 1}, 197.014690, 0.000020, 0.037000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 1, 0}, 206.522780, 0.000090, 0.038000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 2, 0, -1}, 17.083340, 0.000020, 0.082000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 3, -1, 0}, 206.522780, 0.000020, 0.040000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, -1, -1}, 285.818740, 0.000020, 0.020000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, -1, 1}, 285.831450, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 0, -1}, 285.695470, 0.000120, 0.027000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 0, 1}, 286.106700, 0.000460, 0.096000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 1, -1}, 285.955220, 0.000150, 0.042000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 1, 1}, 286.003240, 0.000130, 0.348000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, -1, 0}, 113.922040, 0.000020, 0.040000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 0, 0}, 113.922050, 0.000440, 0.087000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 1, 0}, 293.922190, 0.000220, 0.550000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, -1, -1}, 285.668750, 0.000130, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, -1, 1}, 285.859350, 0.000110, 0.910000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 0, -1}, 284.299610, 0.000130, 0.080000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 0, 1}, 284.196210, 0.000120, 0.070000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 1, -1}, 285.804220, 0.000100, 1.307000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 1, 1}, 285.538210, 0.000090, 0.036000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -2, 0}, 113.922330, 0.000040, 0.076000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, -2}, 113.922180, 0.000020, 0.037000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, 0}, 293.922210, 0.000870, 22.176000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, 2}, 113.922200, 0.000020, 0.037000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, -2}, 113.922220, 0.000090, 0.074000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, -1}, 106.272760, 0.000030, 8.220000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 0}, 113.922210, 0.016380, 0.075000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 1}, 106.272950, 0.000030, 0.037000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 2}, 293.922210, 0.000020, 0.025000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 1, -2}, 113.922160, 0.000020, 3.467000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 1, 0}, 113.922210, 0.000910, 0.038000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 2, 0}, 113.922210, 0.000050, 0.025000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, -1, -1}, 288.499150, 0.000010, 0.991000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, -1, 1}, 287.317490, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, 0, -1}, 286.326770, 0.000190, 0.082000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, 0, 1}, 286.115600, 0.000020, 0.026000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 3, -1, 0}, 113.922210, 0.000170, 0.040000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 3, 0, 0}, 113.922210, 0.000100, 0.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 0, -1}, 180.837850, 0.000020, 0.016000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 0, 1}, 0.450930, 0.000010, 0.029000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 1, -1}, 0.666250, 0.000010, 0.021000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, -1, -1}, 0.668320, 0.000070, 0.020000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, -1, 1}, 0.700370, 0.000100, 0.042000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 0, -1}, 0.640520, 0.000480, 0.027000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 0, 1}, 0.675740, 0.001730, 0.097000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 1, -1}, 0.678730, 0.000520, 0.042000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 1, 1}, 0.670450, 0.000460, 0.344000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 2, 1}, 0.695690, 0.000060, 0.062000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -1, 0, 0}, 169.152610, 0.000040, 0.088000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -1, 1, 0}, 350.123120, 0.000040, 0.540000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -2, -1}, 0.453350, 0.000050, 0.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -2, 1}, 0.440230, 0.000020, 0.082000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -1, -1}, 0.488070, 0.000400, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -1, 1}, 0.467830, 0.000370, 0.883000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 0, -1}, 0.717050, 0.000300, 0.080000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 1}, 0.620540, 0.000370, 0.070000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 1, -1}, 0.405730, 0.000280, 1.251000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 1, 1}, 0.418540, 0.000320, 0.036000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 2, -1}, 0.442810, 0.000020, 0.071000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 2, 1}, 0.395030, 0.000040, 0.024000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -1, 0}, 350.123120, 0.000250, 12.652000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, -2}, 170.127080, 0.000020, 0.074000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, -1}, 180.318300, 0.000070, 11.401000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 0}, 170.123140, 0.004590, 0.075000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 1}, 180.318360, 0.000070, 0.037000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 1, 0}, 170.123120, 0.000250, 0.038000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, -1, -1}, 0.325770, 0.000070, 1.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, -1, 1}, 0.294590, 0.000110, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 0, -1}, 0.239220, 0.000770, 0.081000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 0, 1}, 0.482070, 0.000080, 0.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 1, -1}, 0.185420, 0.000030, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 3, -1, 0}, 170.123120, 0.000050, 0.040000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 3, 0, 0}, 170.123120, 0.000030, 0.026000},
	{{0, 0, 1, 0, 0, 0, -3, 0, 1, 0, 0}, 247.936510, 0.000040, 0.075000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 1, -1, 0}, 254.075090, 0.000020, 11.213000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 1, 0, 0}, 74.075090, 0.000380, 0.075000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 1, 1, 0}, 74.075090, 0.000020, 0.038000},
	{{0, 0, 1, 0, 0, 0, -1, 0, -2, 0, -1}, 353.683910, 0.000010, 0.027000},
	{{0, 0, 1, 0, 0, 0, -1, 0, -2, 0, 1}, 353.624430, 0.000040, 0.097000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 1, 0, 0}, 287.950450, 0.000040, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 1, -1, 0}, 311.785130, 0.000030, 9.916000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 1, 0, 0}, 131.785130, 0.000610, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 1, 1, 0}, 131.785130, 0.000030, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -3, 0, 0}, 272.782380, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -3, 1, 0}, 266.259510, 0.000020, 0.044000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -1, -1}, 63.461860, 0.000020, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -1, 1}, 61.885410, 0.000040, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, -1}, 67.375330, 0.000140, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 1}, 64.113150, 0.000530, 0.097000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 1, -1}, 64.153890, 0.000180, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 1, 1}, 61.691120, 0.000130, 0.340000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -1, 0}, 273.704470, 0.000180, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, -2}, 108.004910, 0.000010, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 269.832540, 0.002370, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, 0}, 109.423280, 0.001860, 0.530000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 2, 0}, 109.155170, 0.000170, 0.066000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -2, -1}, 81.971680, 0.000010, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, -1}, 90.022550, 0.000170, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 103.353140, 0.000020, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 1}, 82.300970, 0.000150, 0.857000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 94.966120, 0.000200, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 291.961190, 0.000040, 1.000000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 92.285430, 0.000210, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3}, 80.818280, 0.000010, 0.024000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, -1}, 87.974480, 0.000110, 1.200000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 282.353400, 0.000030, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1}, 91.524500, 0.000120, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 1}, 81.319060, 0.000010, 0.024000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, -2}, 273.816920, 0.000050, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 0}, 111.957830, 0.007770, 8.850000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, -2}, 305.931590, 0.000080, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 264.803250, 0.000050, 18.600000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 291.982000, 0.140730, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1}, 264.803030, 0.000050, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 2}, 112.555950, 0.000150, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, -2}, 283.208490, 0.000060, 4.535000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0}, 291.857520, 0.007760, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 2}, 112.185660, 0.000020, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 2, 0}, 291.961240, 0.000470, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 3, 0}, 291.961240, 0.000030, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -1, -1}, 2.687840, 0.000090, 1.063000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -1, 1}, 16.455980, 0.000110, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -3}, 261.478720, 0.000010, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -1}, 45.605520, 0.000400, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 111.961170, 0.000040, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 1}, 37.868580, 0.000040, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 1, -1}, 42.615360, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -1, 0}, 291.961220, 0.001510, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, 0, -2}, 293.130690, 0.000010, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 0}, 291.790120, 0.000900, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, 1, 0}, 291.961210, 0.000110, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 5, -2, 0}, 291.961210, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 5, -1, 0}, 291.961200, 0.000020, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0}, 187.933340, 0.000020, 0.075000},
	{{0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0}, 110.454070, 0.000100, 0.075000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, 0, -1}, 165.745010, 0.000020, 0.027000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, 0, 1}, 165.927030, 0.000070, 0.097000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, -1, 0}, 334.189860, 0.000020, 0.041000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 0, 0}, 334.312220, 0.000310, 0.088000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 1, 0}, 334.189750, 0.000120, 0.521000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -2, 0}, 334.189270, 0.000020, 0.076000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -1, -2}, 333.716210, 0.000050, 0.037000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -1, 0}, 334.187590, 0.000740, 6.806000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 0, -2}, 331.285630, 0.000150, 0.074000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0}, 154.188090, 0.012830, 0.075000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 1, -2}, 334.925540, 0.000030, 5.360000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0}, 154.188520, 0.000660, 0.038000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 2, 0}, 154.189640, 0.000040, 0.025000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 3, -1, 0}, 154.189800, 0.000140, 0.040000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 3, 0, 0}, 154.189930, 0.000080, 0.026000},
	{{0, 0, 1, 0, 0, 2, 0, 0, -1, 0, 0}, 55.590560, 0.000020, 0.088000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, -1, 0}, 55.592210, 0.000040, 5.528000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 0, -2}, 219.046120, 0.000030, 0.075000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 0, 0}, 235.628010, 0.000770, 0.074000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 1, 0}, 235.589450, 0.000040, 0.037000},
	{{0, 0, 1, 0, 0, 3, 0, 0, 1, 0, 0}, 139.641950, 0.000020, 0.074000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 0, -1}, 11.698980, 0.000020, 0.027000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 0, 1}, 11.684450, 0.000080, 0.096000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 1, -1}, 11.661020, 0.000030, 0.042000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 1, 1}, 11.661030, 0.000030, 0.350000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, -1, -1}, 11.611950, 0.000020, 0.039000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, -1, 1}, 11.914310, 0.000010, 0.925000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 0, -1}, 12.612650, 0.000010, 0.080000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 0, 1}, 12.612650, 0.000010, 0.070000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 1, -1}, 11.914310, 0.000010, 1.337000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 1, 1}, 11.611950, 0.000020, 0.036000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 1, 0, -2}, 87.496960, 0.000010, 0.074000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 1, 0, 0}, 87.496960, 0.000010, 0.075000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 2, 0, -1}, 10.265660, 0.000030, 0.082000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 1, 0, 0}, 136.661120, 0.000110, 0.075000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, 0, -1}, 183.195860, 0.000020, 0.027000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, 0, 1}, 183.243950, 0.000080, 0.097000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, -1, -1}, 182.337770, 0.000010, 0.039000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, -1, 1}, 182.337770, 0.000010, 0.845000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 0, -1}, 181.355780, 0.000020, 0.081000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 0, 1}, 181.355780, 0.000020, 0.069000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 1, -1}, 182.337770, 0.000010, 1.177000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 1, 1}, 182.337770, 0.000010, 0.036000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 1, 0, 0}, 258.996940, 0.000270, 0.075000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -1, 0, 0}, 274.308040, 0.000050, 0.088000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, -1, -2}, 273.979520, 0.000050, 0.037000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, -1, 0}, 274.224790, 0.000100, 6.122000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 0, -2}, 274.317460, 0.000140, 0.074000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 0, 0}, 94.417690, 0.001150, 0.075000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 1, -2}, 273.803080, 0.000030, 5.877000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 1, 0}, 95.235920, 0.000020, 0.037000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, 1, -1}, 245.090950, 0.000010, 0.021000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, -1, -1}, 244.131390, 0.000030, 0.020000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, -1, 1}, 245.167980, 0.000050, 0.043000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, -1}, 245.271840, 0.000190, 0.027000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, 1}, 245.202230, 0.000710, 0.098000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 1, -1}, 248.177650, 0.000180, 0.042000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 1, 1}, 247.695300, 0.000160, 0.331000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, -1, 0}, 255.775080, 0.000090, 0.041000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 0, -2}, 75.928190, 0.000020, 0.026000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 0, 0}, 255.789930, 0.001710, 0.089000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 1, 0}, 255.382100, 0.000280, 0.507000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 2, 0}, 255.508750, 0.000030, 0.066000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, -1, -1}, 232.639540, 0.000100, 0.039000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, -1, 1}, 234.850590, 0.000110, 0.799000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 0, -1}, 239.223840, 0.000060, 0.081000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1}, 239.357930, 0.000060, 0.069000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 1, -1}, 237.973750, 0.000040, 1.090000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 1}, 236.936580, 0.000040, 0.036000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -2, -2}, 75.763530, 0.000030, 0.025000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -2, 0}, 255.376510, 0.000080, 0.077000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -1, -2}, 75.916700, 0.000230, 0.038000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -1, 0}, 255.499580, 0.001710, 5.069000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, -2}, 77.440640, 0.000770, 0.075000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0}, 75.508530, 0.034800, 0.074000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 2}, 255.507860, 0.000030, 0.025000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 1, -2}, 75.062450, 0.000150, 7.341000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 1, 0}, 75.513770, 0.002100, 0.037000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 2, 0}, 75.519060, 0.000140, 0.025000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, -1, 1}, 55.909160, 0.000010, 0.038000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, 0, -1}, 109.929130, 0.000030, 0.081000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, -1, -2}, 256.372100, 0.000020, 0.524000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, -1, 0}, 75.498190, 0.000360, 0.040000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 0, -2}, 74.495150, 0.000050, 0.088000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 0, 0}, 75.505750, 0.000230, 0.026000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 1, 0}, 75.509020, 0.000030, 0.019000},
	{{0, 0, 1, 0, 2, -8, 0, 0, 1, 0, 0}, 35.542630, 0.000030, 0.075000},
	{{0, 0, 1, 0, 2, -7, 0, 0, 1, 0, 0}, 302.601110, 0.000220, 0.075000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, 0, -1}, 190.860720, 0.000010, 0.080000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, 0, 1}, 190.860720, 0.000010, 0.070000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 1, 0, 0}, 209.747910, 0.000030, 0.075000},
	{{0, 0, 1, 0, 2, -6, 3, 0, 1, 0, 0}, 67.397470, 0.000040, 0.075000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 0, 1}, 66.917870, 0.000020, 0.029000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 1, -1}, 66.960980, 0.000010, 0.021000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, -1, -1}, 66.854560, 0.000030, 0.020000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, -1, 1}, 67.000780, 0.000060, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, -1}, 66.829610, 0.000200, 0.027000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, 1}, 66.982360, 0.000740, 0.097000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 1, -1}, 66.526740, 0.000260, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 1, 1}, 66.566320, 0.000220, 0.340000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 2, 1}, 66.968880, 0.000020, 0.062000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -1, 0, 0}, 59.080970, 0.000070, 0.088000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -1, 1, 0}, 59.058840, 0.000150, 0.530000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -2, -1}, 65.756600, 0.000020, 0.026000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -1, -1}, 66.263590, 0.000180, 0.039000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -1, 1}, 66.167990, 0.000160, 0.858000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 0, -1}, 67.062630, 0.000140, 0.080000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 0, 1}, 66.676700, 0.000180, 0.069000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 1, -1}, 65.254820, 0.000130, 1.202000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 1, 1}, 65.235170, 0.000140, 0.036000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 2, 1}, 65.765760, 0.000020, 0.024000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, -1, 0}, 59.059360, 0.000760, 8.940000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, -2}, 239.062080, 0.000020, 0.074000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, -1}, 245.351870, 0.000020, 18.216000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, 0}, 239.059350, 0.013980, 0.075000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, 1}, 245.351950, 0.000020, 0.037000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 1, 0}, 239.059360, 0.000760, 0.038000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 2, 0}, 239.059360, 0.000050, 0.025000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, -1, -1}, 65.909810, 0.000030, 1.062000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, -1, 1}, 65.838090, 0.000040, 0.039000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 0, -1}, 64.523370, 0.000290, 0.081000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 0, 1}, 64.305640, 0.000030, 0.026000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 3, -1, 0}, 239.059360, 0.000150, 0.040000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 3, 0, 0}, 239.059360, 0.000090, 0.026000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, -1, 0}, 323.192130, 0.000020, 6.858000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, 0, 0}, 143.192130, 0.000370, 0.075000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, 1, 0}, 143.192130, 0.000020, 0.038000},
	{{0, 0, 1, 0, 2, -3, 0, 0, 1, 0, 0}, 27.605120, 0.000130, 0.074000},
	{{0, 0, 1, 0, 2, -2, 0, 0, 1, 0, 0}, 94.963740, 0.000280, 0.074000},
	{{0, 0, 1, 0, 2, 0, 0, 0, -1, 0, 0}, 258.764290, 0.000020, 0.089000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 1, 0, 0}, 81.748840, 0.000230, 0.074000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 1, 0, 0}, 173.324580, 0.000250, 0.074000},
	{{0, 0, 1, 0, 4, -10, 0, 0, 1, 0, 0}, 70.721050, 0.000130, 0.075000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -1, 0, 0}, 139.574140, 0.000020, 0.092000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0}, 335.172690, 0.000160, 0.072000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -1, 0, 0}, 237.933770, 0.000060, 0.097000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -1, 1, 0}, 240.814880, 0.000010, 0.339000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, 0, 0}, 14.885030, 0.000040, 0.069000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, -1, -1}, 132.697570, 0.000010, 0.254000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, -1, 1}, 132.697570, 0.000010, 0.044000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, 0, -1}, 132.694340, 0.000060, 0.107000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, 0, 1}, 132.691490, 0.000020, 0.028000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -1, 0, 0}, 309.171010, 0.000060, 0.074000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 0, 0}, 351.697570, 0.000260, 0.077000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 1, 0, 0}, 352.003900, 0.000090, 0.085000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, 0, -1}, 15.650560, 0.000020, 0.094000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 0, -1}, 121.180450, 0.000020, 0.016000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 2, -1}, 301.908360, 0.000010, 0.027000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -1, -1}, 301.094940, 0.000070, 0.019000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -1, 1}, 300.619600, 0.000130, 0.040000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, -1}, 301.849760, 0.000350, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, 1}, 301.095020, 0.001880, 0.087000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 1, -1}, 302.881500, 0.000450, 0.040000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 1, 1}, 303.005740, 0.000370, 0.551000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 2, 1}, 304.471770, 0.000030, 0.066000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -1, 0, 0}, 21.995590, 0.000200, 0.080000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -2, -1}, 297.422540, 0.000080, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -2, 1}, 297.372410, 0.000040, 0.076000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, -1}, 298.296320, 0.000810, 0.037000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, 1}, 297.835060, 0.000730, 24.988000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, -1}, 303.600680, 0.000770, 0.074000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, 1}, 303.689180, 0.000770, 0.075000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, -1}, 297.849930, 0.000740, 3.407000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, 1}, 298.330060, 0.000820, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 2, -1}, 297.213090, 0.000040, 0.077000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 2, 1}, 297.608210, 0.000090, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, 0, 0}, 24.872990, 0.000240, 0.082000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -2, -1}, 304.760040, 0.000050, 0.065000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, -1}, 303.346980, 0.000480, 0.484000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, 1}, 303.430990, 0.000570, 0.040000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, -3}, 302.886870, 0.000010, 0.064000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, -1}, 302.461540, 0.002150, 0.089000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, 1}, 302.351630, 0.000440, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 1, -1}, 301.863880, 0.000150, 0.041000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 1, 1}, 301.635620, 0.000080, 0.019000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, -2, 1}, 302.438340, 0.000010, 0.028000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, -1, -1}, 302.662070, 0.000030, 0.044000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, -1, 1}, 302.667160, 0.000010, 0.020000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, 0, -1}, 302.688870, 0.000020, 0.028000},
	{{0, 0, 2, -4, 2, 0, 0, 0, -2, 0, 1}, 0.614610, 0.000040, 0.089000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, -1, -1}, 359.059840, 0.000010, 0.038000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, -1, 1}, 359.059840, 0.000010, 4.793000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 0, -1}, 0.296100, 0.000030, 0.075000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 0, 1}, 0.296100, 0.000030, 0.074000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 1, -1}, 359.059840, 0.000010, 8.008000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 1, 1}, 359.059840, 0.000010, 0.037000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 2, 0, -1}, 0.508940, 0.000030, 0.088000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, 1, -1}, 330.788550, 0.000010, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, -1, -1}, 330.803500, 0.000060, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, -1, 1}, 330.831870, 0.000100, 0.041000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, -1}, 330.741430, 0.000370, 0.026000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, 1}, 330.893670, 0.001630, 0.092000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 1, -1}, 330.916050, 0.000470, 0.041000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 1, 1}, 330.879040, 0.000410, 0.426000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 2, 1}, 331.099970, 0.000040, 0.064000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 0, 0}, 52.830400, 0.000180, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -2, -1}, 329.958470, 0.000050, 0.025000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -2, 1}, 329.733040, 0.000020, 0.079000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, -1}, 329.821660, 0.000390, 0.038000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, 1}, 329.749020, 0.000360, 1.749000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, -1}, 330.496720, 0.000300, 0.077000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, 1}, 330.395220, 0.000350, 0.072000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, -1}, 329.747030, 0.000330, 4.198000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, 1}, 329.793220, 0.000370, 0.037000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 2, -1}, 329.733290, 0.000020, 0.074000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 2, 1}, 329.555630, 0.000040, 0.025000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, -1, 0}, 233.397300, 0.000040, 2.074000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 0, 0}, 53.397540, 0.000760, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 1, 0}, 53.397300, 0.000040, 0.038000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -2, -1}, 330.900880, 0.000020, 0.068000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -1, -1}, 330.906240, 0.000240, 0.651000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -1, 1}, 330.880990, 0.000290, 0.040000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, -1}, 330.538890, 0.001170, 0.085000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, 1}, 330.586530, 0.000200, 0.026000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 1, -1}, 330.489220, 0.000090, 0.040000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 1, 1}, 330.590310, 0.000030, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, -1, -1}, 358.599730, 0.000010, 0.013000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, -1, 1}, 358.810770, 0.000020, 0.021000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 0, -1}, 0.768110, 0.000050, 0.016000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 0, 1}, 359.648970, 0.000110, 0.028000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 1, -1}, 359.188560, 0.000100, 0.021000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 1, 1}, 359.010860, 0.000150, 0.046000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 2, -1}, 358.895330, 0.000070, 0.028000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 2, 1}, 358.799280, 0.000020, 0.116000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -2, -1}, 358.783180, 0.000040, 0.016000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -2, 1}, 358.785040, 0.000030, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -1, -1}, 359.111540, 0.000340, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -1, 1}, 358.977870, 0.000530, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, -1}, 358.497800, 0.002230, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 1}, 358.628150, 0.008500, 0.096000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 3}, 358.709950, 0.000020, 0.061000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, -1}, 358.924680, 0.002570, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, 1}, 359.137600, 0.002160, 0.348000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 2, -1}, 177.048980, 0.000020, 0.093000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 2, 1}, 358.844900, 0.000210, 0.062000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 3, 1}, 358.944500, 0.000020, 0.034000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, -1, -1}, 0.230700, 0.000010, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 0, -1}, 0.616030, 0.000050, 0.040000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 0, 0}, 98.285210, 0.000130, 0.087000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 0, 1}, 0.835470, 0.000030, 0.502000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 1, 0}, 279.408970, 0.000050, 0.548000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -3, -1}, 359.724290, 0.000020, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -2, -1}, 359.652620, 0.000220, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -2, 1}, 359.772070, 0.000100, 0.082000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, -1}, 359.367810, 0.001940, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, 1}, 359.409990, 0.001590, 0.906000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, -1}, 359.587770, 0.001410, 0.080000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 1}, 359.729650, 0.001870, 0.070000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, -1}, 359.909780, 0.001540, 1.299000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, 1}, 0.121400, 0.001600, 0.036000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 2, -1}, 0.623490, 0.000070, 0.071000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 2, 1}, 359.944390, 0.000170, 0.024000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 3, 1}, 359.971250, 0.000010, 0.018000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -2, -1}, 180.433650, 0.000010, 0.038000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, -1}, 0.406850, 0.000040, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, 0}, 279.409350, 0.000330, 20.152000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, 1}, 0.216430, 0.000080, 0.074000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, -2}, 89.017440, 0.000030, 0.074000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, -1}, 180.234880, 0.000540, 8.537000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 0}, 99.413070, 0.006150, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 1}, 180.234890, 0.000550, 0.037000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, -1}, 180.234880, 0.000030, 0.076000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, 0}, 99.409150, 0.000330, 0.038000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, 1}, 180.234890, 0.000070, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 2, 0}, 99.409130, 0.000020, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -2, 1}, 181.567720, 0.000030, 0.079000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -1, -1}, 359.518070, 0.000410, 0.996000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -1, 1}, 359.945240, 0.000590, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, -3}, 1.216150, 0.000010, 0.069000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, -1}, 0.813830, 0.004040, 0.082000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, 1}, 0.406490, 0.000480, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 1, -1}, 0.298780, 0.000280, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 1, 1}, 359.315920, 0.000090, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, -1, 0}, 99.408890, 0.000070, 0.040000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, -1, 1}, 180.230700, 0.000010, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, 0, 0}, 99.408700, 0.000040, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -2, 1}, 359.886420, 0.000020, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -1, -1}, 0.486190, 0.000050, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -1, 1}, 0.394300, 0.000020, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, 0, -1}, 0.264570, 0.000020, 0.027000},
	{{0, 0, 2, -2, 2, 0, 0, 0, 1, 0, 0}, 135.932580, 0.000030, 0.074000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 0, -1}, 255.152600, 0.000020, 0.027000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 0, 1}, 256.822370, 0.000070, 0.102000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 1, -1}, 257.706480, 0.000010, 0.043000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 1, 1}, 257.706480, 0.000010, 0.293000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -1, 0, 0}, 128.959290, 0.000020, 0.092000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 0, -1}, 227.742770, 0.000010, 0.084000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 0, 1}, 227.742770, 0.000010, 0.067000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, -1, 0}, 128.959300, 0.000030, 1.720000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 0, 0}, 308.960800, 0.000490, 0.072000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 1, 0}, 308.959290, 0.000030, 0.037000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -1, -1}, 37.076810, 0.000020, 2.117000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -1, 1}, 37.074930, 0.000020, 0.038000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, 0, -1}, 37.601130, 0.000020, 0.078000},
	{{0, 0, 2, 0, -5, 0, 0, 0, -2, 0, -1}, 209.190480, 0.000020, 0.027000},
	{{0, 0, 2, 0, -5, 0, 0, 0, -2, 0, 1}, 209.156630, 0.000040, 0.103000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 1, 0, 0}, 298.559590, 0.000040, 0.072000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, -1, -1}, 29.465090, 0.000030, 2.760000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, -1, 1}, 29.465100, 0.000030, 0.038000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, 0, -1}, 30.325270, 0.000030, 0.078000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, -1, -1}, 54.217290, 0.000030, 0.040000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, -1, 1}, 54.216960, 0.000030, 0.522000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -2, -1}, 234.125630, 0.000060, 0.074000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -2, 1}, 234.125630, 0.000060, 0.075000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -1, -1}, 234.216810, 0.000170, 5.193000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -1, 1}, 234.218170, 0.000190, 0.038000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, 0, -1}, 238.504230, 0.000040, 0.077000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, 0, 1}, 234.217240, 0.000020, 0.025000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, -1, -1}, 199.879410, 0.000020, 0.020000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, -1, 1}, 199.783620, 0.000020, 0.044000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 0, -1}, 199.942240, 0.000110, 0.027000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 0, 1}, 199.788340, 0.000360, 0.104000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 1, -1}, 199.801730, 0.000120, 0.043000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 1, 1}, 199.835640, 0.000100, 0.278000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -1, 0, 0}, 295.247830, 0.000030, 0.093000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -2, -1}, 199.908840, 0.000010, 0.026000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -1, -1}, 200.223730, 0.000200, 0.040000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -1, 1}, 200.276920, 0.000170, 0.547000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 0, -1}, 200.724770, 0.000060, 0.085000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 0, 1}, 200.645090, 0.000070, 0.066000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 1, -1}, 200.771570, 0.000060, 0.668000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 1, 1}, 200.655100, 0.000070, 0.035000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 1, 0, 0}, 289.145730, 0.000230, 0.071000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -3, -1}, 19.860910, 0.000010, 0.037000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -2, -1}, 19.823860, 0.000090, 0.074000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -2, 1}, 19.440190, 0.000050, 0.075000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, -1}, 19.951870, 0.000570, 3.597000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, 1}, 19.950340, 0.000590, 0.038000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, 0, -1}, 20.581580, 0.000320, 0.077000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, 0, 1}, 20.032900, 0.000090, 0.025000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -2, 1}, 19.938070, 0.000010, 0.026000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -1, -1}, 19.939970, 0.000020, 0.041000},
	{{0, 0, 2, 0, -4, 2, 0, 0, -2, 0, -1}, 182.702230, 0.000010, 0.027000},
	{{0, 0, 2, 0, -4, 2, 0, 0, -2, 0, 1}, 182.702140, 0.000010, 0.104000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, -1, -1}, 182.384210, 0.000030, 0.040000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, -1, 1}, 182.383860, 0.000020, 0.527000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, 0, -1}, 182.143140, 0.000010, 0.086000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, 0, 1}, 182.143140, 0.000010, 0.066000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -2, -1}, 2.291320, 0.000030, 0.074000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -2, 1}, 2.291320, 0.000030, 0.075000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -1, -1}, 2.383700, 0.000130, 4.760000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -1, 1}, 2.384140, 0.000130, 0.038000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, 0, -1}, 1.228810, 0.000030, 0.077000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, -2, 1}, 57.328020, 0.000010, 0.088000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, -1, -1}, 237.101390, 0.000030, 0.040000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, -1, 1}, 237.147350, 0.000030, 0.518000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -3, -1}, 54.921680, 0.000020, 0.037000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -2, -1}, 57.397560, 0.000170, 0.074000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -2, 1}, 57.397560, 0.000170, 0.075000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -1, -1}, 57.153680, 0.000210, 5.677000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -1, 1}, 57.172900, 0.000230, 0.037000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, 0, 1}, 57.146880, 0.000020, 0.025000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 4, -2, -1}, 57.328020, 0.000010, 0.088000},
	{{0, 0, 2, 0, -4, 4, -2, 0, 2, -2, -1}, 174.859960, 0.000020, 0.075000},
	{{0, 0, 2, 0, -4, 4, -2, 0, 2, -2, 1}, 174.859960, 0.000020, 0.074000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 0, -1}, 351.226590, 0.000030, 0.028000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 0, 1}, 351.228740, 0.000060, 0.105000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 1, -1}, 351.228470, 0.000010, 0.043000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 1, 1}, 351.228470, 0.000010, 0.265000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, -1, -1}, 171.214840, 0.000060, 0.040000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, -1, 1}, 171.214420, 0.000050, 0.500000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -2, -1}, 170.228810, 0.000020, 0.075000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -2, 1}, 170.228810, 0.000020, 0.074000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -1, -1}, 351.214240, 0.000290, 9.238000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -1, 1}, 351.214750, 0.000290, 0.037000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, 0, -1}, 169.536800, 0.000120, 0.076000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, 0, 1}, 351.214780, 0.000040, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 0, -1}, 189.867530, 0.000020, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 0, 1}, 190.149710, 0.000050, 0.029000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 1, -1}, 190.390160, 0.000020, 0.021000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 1, 1}, 190.331250, 0.000020, 0.048000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 2, -1}, 190.406300, 0.000010, 0.029000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -2, -1}, 190.241630, 0.000030, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -2, 1}, 190.104620, 0.000020, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -1, -1}, 190.252150, 0.000180, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -1, 1}, 190.215340, 0.000280, 0.044000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, -1}, 190.364290, 0.000910, 0.027000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, 1}, 190.290940, 0.002530, 0.105000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, -1}, 190.369570, 0.000770, 0.043000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, 1}, 190.409030, 0.000670, 0.271000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 2, 1}, 190.351350, 0.000070, 0.059000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, 0, 0}, 296.396800, 0.000090, 0.094000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -3, 1}, 10.078900, 0.000040, 0.041000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, -1}, 190.239040, 0.000330, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, 1}, 10.013950, 0.000540, 0.088000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, -1}, 190.170800, 0.004080, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 1}, 190.178370, 0.003550, 0.523000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, -1}, 190.740700, 0.000350, 0.086000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 1}, 190.349010, 0.001030, 0.066000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, -3}, 10.778380, 0.000010, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, -1}, 190.723400, 0.000380, 0.633000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, 1}, 190.591200, 0.000450, 0.035000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 2, -1}, 190.729660, 0.000020, 0.067000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 2, 1}, 190.743660, 0.000050, 0.024000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, -1, 0}, 97.942350, 0.000050, 1.163000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 0, 0}, 277.902500, 0.000880, 0.071000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 1, 0}, 277.942340, 0.000050, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -4, -1}, 10.118690, 0.000070, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -4, 1}, 10.248940, 0.000010, 0.076000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, -1}, 10.094130, 0.000800, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, 1}, 10.546340, 0.000090, 7.152000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, -3}, 190.041310, 0.000010, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, -1}, 10.027150, 0.006810, 0.074000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 1}, 10.033670, 0.005100, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 3}, 190.041310, 0.000010, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, -3}, 10.084140, 0.000050, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, -1}, 10.080590, 0.019170, 5.163000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 1}, 10.085260, 0.020120, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 3}, 190.085760, 0.000020, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, -1}, 10.519920, 0.004360, 0.077000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, 1}, 10.022840, 0.002510, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 1, -1}, 10.513490, 0.000270, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 1, 1}, 10.066160, 0.000260, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 2, 1}, 10.096820, 0.000020, 0.015000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -3, -1}, 9.977610, 0.000110, 0.508000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -3, 1}, 10.000260, 0.000240, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, -1}, 10.052800, 0.000750, 0.089000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, 1}, 10.069110, 0.000660, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, -1}, 10.112910, 0.000730, 0.041000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, 1}, 10.080530, 0.000370, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, 0, -1}, 10.214470, 0.000100, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, 0, 1}, 10.085680, 0.000060, 0.015000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -3, -1}, 10.022160, 0.000010, 0.044000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -2, -1}, 10.082790, 0.000020, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -2, 1}, 10.082790, 0.000010, 0.016000},
	{{0, 0, 2, 0, -3, 0, 2, 0, 2, -2, -1}, 349.757140, 0.000010, 0.074000},
	{{0, 0, 2, 0, -3, 0, 2, 0, 2, -2, 1}, 349.757140, 0.000010, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -2, 1}, 181.297670, 0.000020, 0.088000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -1, -1}, 181.412150, 0.000060, 0.040000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -1, 1}, 181.438130, 0.000040, 0.513000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -3, -1}, 180.405120, 0.000030, 0.037000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -2, -1}, 181.218170, 0.000220, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -2, 1}, 181.218170, 0.000220, 0.074000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -1, -1}, 1.443610, 0.000220, 6.260000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -1, 1}, 1.470460, 0.000200, 0.037000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, 0, 1}, 1.438310, 0.000030, 0.025000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -3, 1}, 181.659500, 0.000010, 0.040000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -2, -1}, 181.297670, 0.000020, 0.088000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -2, -1}, 10.191560, 0.000020, 0.075000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -2, 1}, 10.191560, 0.000020, 0.074000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -1, -1}, 191.442540, 0.000050, 7.950000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -1, 1}, 191.443400, 0.000050, 0.037000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -2, -1}, 165.076840, 0.000030, 0.074000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -2, 1}, 165.076840, 0.000030, 0.075000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -1, -1}, 165.661410, 0.000040, 5.641000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -1, 1}, 165.662230, 0.000040, 0.037000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 0, -1}, 179.721180, 0.000080, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 0, 1}, 180.347260, 0.000180, 0.029000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 1, -1}, 180.713990, 0.000190, 0.021000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 1, 1}, 180.795180, 0.000260, 0.048000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 2, -1}, 180.826980, 0.000090, 0.029000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 2, 1}, 180.902550, 0.000020, 0.130000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -2, -1}, 181.390000, 0.000040, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -2, 1}, 181.627740, 0.000040, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -1, -1}, 180.986500, 0.000400, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -1, 1}, 181.344340, 0.000400, 0.044000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, -1}, 181.014200, 0.003910, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 1}, 180.919960, 0.012300, 0.105000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 3}, 182.051250, 0.000030, 0.058000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, -1}, 180.808830, 0.003800, 0.043000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, 1}, 180.762250, 0.003280, 0.265000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 2, 1}, 180.859140, 0.000330, 0.059000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 3, 1}, 180.802720, 0.000040, 0.033000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 0, -1}, 0.179070, 0.000070, 0.042000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 0, 0}, 352.674980, 0.000140, 0.095000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 0, 1}, 0.178490, 0.000070, 0.347000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 1, 0}, 177.570250, 0.000020, 0.368000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -3, -1}, 0.061820, 0.000130, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -3, 1}, 0.115880, 0.000070, 0.041000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -2, -1}, 359.997910, 0.001070, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -2, 1}, 0.020690, 0.000740, 0.089000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, -1}, 359.959290, 0.007780, 0.040000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, 1}, 359.965040, 0.006570, 0.500000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, -1}, 180.271070, 0.002340, 0.086000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, 1}, 181.146860, 0.000570, 0.066000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 1, -1}, 180.442570, 0.001990, 0.601000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 1, 1}, 180.503930, 0.001480, 0.035000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 2, -1}, 180.368020, 0.000130, 0.067000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 2, 1}, 180.504520, 0.000170, 0.024000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 3, 1}, 180.333020, 0.000010, 0.018000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, -1, -1}, 0.320900, 0.000020, 0.080000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 0, -1}, 0.162530, 0.000080, 1.286000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 0, 0}, 195.946480, 0.000300, 0.070000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 0, 1}, 0.162530, 0.000080, 0.036000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -4, -1}, 0.055480, 0.000040, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -4, 1}, 0.079380, 0.000010, 0.077000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -3, -1}, 0.017150, 0.000310, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -3, 1}, 359.754870, 0.000020, 4.462000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, -3}, 180.108030, 0.000030, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, -1}, 359.951300, 0.001750, 0.075000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, 1}, 0.095590, 0.006230, 0.074000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, -3}, 180.139500, 0.000180, 0.037000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, -1}, 180.119610, 0.052230, 9.142000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, 1}, 180.121380, 0.050690, 0.037000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, 3}, 0.121830, 0.000050, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, -3}, 0.116060, 0.000060, 0.073000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, -1}, 0.031230, 0.021940, 0.076000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, 1}, 180.148860, 0.005880, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, -3}, 180.129980, 0.000020, 2.258000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, -1}, 359.998190, 0.001080, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, 1}, 180.177470, 0.000570, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 2, -1}, 0.091610, 0.000080, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 2, 1}, 180.077150, 0.000040, 0.015000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, -1, -1}, 0.121830, 0.000030, 0.082000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, -1, 1}, 0.121830, 0.000030, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -4, -1}, 0.099590, 0.000010, 0.066000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -3, -1}, 0.105930, 0.000130, 0.531000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -3, 1}, 0.093390, 0.000270, 0.040000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -2, -1}, 0.071910, 0.000340, 0.088000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -2, 1}, 180.127830, 0.001050, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -1, -1}, 180.134390, 0.001400, 0.041000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -1, 1}, 180.126630, 0.000840, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 0, -1}, 181.335800, 0.000010, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 0, 1}, 180.123640, 0.000150, 0.015000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 1, -1}, 180.121830, 0.000020, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 1, 1}, 180.121830, 0.000020, 0.013000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -3, 1}, 180.123020, 0.000020, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -2, -1}, 180.121980, 0.000040, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -2, 1}, 180.121980, 0.000030, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -1, -1}, 180.121850, 0.000030, 0.020000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, -1, -1}, 198.973530, 0.000030, 0.040000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, -1, 1}, 198.973000, 0.000030, 0.523000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -2, -1}, 18.408950, 0.000050, 0.074000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -2, 1}, 18.408950, 0.000050, 0.075000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -1, -1}, 18.972760, 0.000150, 5.133000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -1, 1}, 18.952840, 0.000170, 0.038000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, 0, -3}, 197.673420, 0.000010, 0.073000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, 0, -1}, 17.673420, 0.000010, 0.077000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, 0, 1}, 18.973440, 0.000020, 0.025000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 2, -1, -1}, 349.907060, 0.000020, 10.756000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 2, -1, 1}, 349.908640, 0.000020, 0.037000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 0, 1}, 263.003020, 0.000060, 0.029000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 1, -1}, 263.574030, 0.000030, 0.021000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -2, -1}, 264.861200, 0.000020, 0.016000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -1, -1}, 264.098850, 0.000120, 0.020000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -1, 1}, 264.389480, 0.000130, 0.044000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, -1}, 264.570440, 0.000770, 0.028000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, 1}, 264.506700, 0.002240, 0.106000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 1, -1}, 264.978460, 0.000650, 0.044000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 1, 1}, 264.976730, 0.000560, 0.259000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 2, 1}, 264.964110, 0.000070, 0.058000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 0, -1}, 257.773260, 0.000030, 0.042000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 0, 0}, 280.680480, 0.000060, 0.096000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 0, 1}, 257.773260, 0.000020, 0.337000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -2, -1}, 242.098650, 0.000020, 0.026000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -1, -1}, 248.880120, 0.000240, 0.040000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -1, 1}, 248.799830, 0.000190, 0.480000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 0, -1}, 300.089340, 0.000070, 0.087000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 0, 1}, 267.767840, 0.000110, 0.065000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 1, -1}, 271.642760, 0.000140, 0.572000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 1, 1}, 275.813760, 0.000110, 0.035000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 2, 1}, 269.721030, 0.000020, 0.024000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, -2, -1}, 77.774110, 0.000010, 0.039000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, -1, 0}, 77.657330, 0.000040, 0.972000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, 0}, 257.625280, 0.000790, 0.070000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 1, 0}, 257.657320, 0.000040, 0.036000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -2, -1}, 271.956190, 0.000050, 0.075000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -2, 1}, 170.907420, 0.000030, 0.074000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, -1}, 309.844040, 0.000620, 39.875000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, 1}, 306.650230, 0.000600, 0.037000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 0, -1}, 168.559320, 0.000800, 0.076000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 0, 1}, 287.813970, 0.000080, 0.025000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 1, -1}, 165.825360, 0.000040, 0.038000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 4, -2, 1}, 305.562600, 0.000010, 0.026000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 4, -1, -1}, 305.667850, 0.000020, 0.040000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 0, -1}, 186.597220, 0.000030, 0.028000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 0, 1}, 188.100380, 0.000070, 0.105000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 1, -1}, 189.098210, 0.000010, 0.043000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 1, 1}, 189.098210, 0.000010, 0.265000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, -1, -1}, 7.665270, 0.000060, 0.040000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, -1, 1}, 7.665380, 0.000050, 0.501000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -2, -1}, 5.640150, 0.000020, 0.075000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -2, 1}, 5.640150, 0.000020, 0.074000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -1, -1}, 187.665430, 0.000300, 9.049000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -1, 1}, 187.665290, 0.000310, 0.037000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, 0, -1}, 8.537390, 0.000120, 0.076000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, 0, 1}, 187.665290, 0.000040, 0.025000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, 0, -1}, 7.723150, 0.000010, 0.087000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, 0, 1}, 7.723150, 0.000010, 0.065000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, -1, -1}, 6.186310, 0.000040, 13.061000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, -1, 1}, 6.184230, 0.000040, 0.037000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, 0, -1}, 185.484270, 0.000030, 0.076000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 0, -1}, 273.090630, 0.000040, 0.028000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 0, 1}, 272.884740, 0.000090, 0.106000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 1, -1}, 272.742700, 0.000020, 0.043000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 1, 1}, 272.742700, 0.000020, 0.260000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, -1, -1}, 92.925990, 0.000030, 0.040000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, -1, 1}, 92.942300, 0.000020, 0.484000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 0, -1}, 274.548090, 0.000010, 0.087000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 0, 1}, 274.548090, 0.000010, 0.065000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 1, -1}, 272.747940, 0.000010, 0.578000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 1, 1}, 272.747940, 0.000010, 0.035000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 1, 0, 0}, 294.420210, 0.000050, 0.070000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, -1, -1}, 272.871540, 0.000210, 23.464000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, -1, 1}, 272.871120, 0.000210, 0.037000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, 0, -1}, 92.718310, 0.000300, 0.076000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, 0, 1}, 272.871100, 0.000030, 0.025000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, -1, -1}, 180.204690, 0.000030, 0.020000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, -1, 1}, 180.213150, 0.000020, 0.044000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 0, -1}, 180.199860, 0.000160, 0.028000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 0, 1}, 180.210170, 0.000500, 0.107000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 1, -1}, 180.213510, 0.000140, 0.044000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 1, 1}, 180.211440, 0.000140, 0.258000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -1, 0, 0}, 9.519600, 0.000010, 0.096000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -2, -1}, 0.047010, 0.000020, 0.026000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -1, -1}, 359.817600, 0.000060, 0.040000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -1, 1}, 359.727290, 0.000040, 0.476000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 0, -1}, 180.070160, 0.000130, 0.087000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 0, 1}, 180.195240, 0.000030, 0.065000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 1, -1}, 180.129210, 0.000080, 0.566000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 1, 1}, 180.128310, 0.000090, 0.035000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 1, 0, 0}, 189.945080, 0.000060, 0.070000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -2, -1}, 180.045350, 0.000040, 0.075000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -2, 1}, 359.922200, 0.000020, 0.074000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, -1}, 180.030320, 0.000930, 115.334000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, 1}, 180.033130, 0.000830, 0.037000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 0, -1}, 0.004270, 0.001870, 0.075000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 0, 1}, 180.048240, 0.000060, 0.025000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 1, -1}, 0.005540, 0.000100, 0.038000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, -2, 1}, 180.043570, 0.000020, 0.026000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, -1, -1}, 180.034430, 0.000030, 0.040000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 0, -1}, 258.505860, 0.000050, 0.028000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 0, 1}, 258.472790, 0.000120, 0.107000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 1, -1}, 258.491720, 0.000040, 0.044000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 1, 1}, 258.491700, 0.000040, 0.256000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, -1, -1}, 258.926790, 0.000010, 0.040000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, -1, 1}, 258.926790, 0.000010, 0.469000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 0, -1}, 258.647250, 0.000030, 0.087000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 0, 1}, 258.923630, 0.000010, 0.065000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 1, -1}, 258.926790, 0.000010, 0.556000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 1, 1}, 258.926790, 0.000010, 0.035000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 1, 0, 0}, 246.322320, 0.000050, 0.070000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, -1, -1}, 262.425100, 0.000040, 39.561000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, -1, 1}, 262.425110, 0.000040, 0.037000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, 0, -1}, 87.712060, 0.000060, 0.075000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 2, 0, -1}, 359.986930, 0.000050, 0.075000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 0, -1}, 3.703770, 0.000030, 0.028000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 0, 1}, 6.356260, 0.000070, 0.107000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 1, -1}, 1.784930, 0.000010, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 1, 1}, 1.784930, 0.000010, 0.254000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, -1, 0}, 192.098080, 0.000020, 0.042000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 0, 0}, 192.309540, 0.000350, 0.096000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 1, 0}, 9.889230, 0.000110, 0.346000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, -1}, 20.811650, 0.000050, 0.088000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1}, 20.783220, 0.000050, 0.065000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 1, -1}, 15.745850, 0.000010, 0.545000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 1}, 18.273850, 0.000030, 0.035000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0}, 7.655480, 0.000940, 0.070000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 1, 0}, 8.310410, 0.000090, 0.036000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, -2}, 187.377380, 0.000010, 0.075000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, -1}, 22.611570, 0.000110, 16.885000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 187.377380, 0.000010, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, 1}, 23.041520, 0.000090, 0.037000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, -3}, 330.786960, 0.000010, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, -1}, 200.470850, 0.000340, 0.075000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 1, -1}, 200.470880, 0.000020, 0.038000},
	{{0, 0, 2, 0, 0, 1, 0, 0, -1, 0, 0}, 231.252680, 0.000020, 0.097000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -2, 0, -1}, 139.244980, 0.000010, 0.028000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -2, 0, 1}, 139.585690, 0.000030, 0.108000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -1, 0, 0}, 152.771590, 0.000080, 0.097000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 1, 0, 0}, 333.463230, 0.000030, 0.069000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, 0, -3}, 164.916200, 0.000050, 0.074000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, 0, -1}, 304.765700, 0.000030, 0.075000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 2, 0, -3}, 188.748780, 0.000020, 0.074000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 2, 0, -1}, 188.748780, 0.000020, 0.075000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 0, -1}, 323.292020, 0.000020, 0.028000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 0, 1}, 323.356450, 0.000050, 0.107000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 1, 0, 0}, 316.119100, 0.000020, 0.070000},
	{{0, 0, 2, 0, 2, 0, 0, 0, 2, 0, -3}, 127.918400, 0.000020, 0.075000},
	{{0, 0, 2, 0, 2, 0, 0, 0, 2, 0, -1}, 307.918400, 0.000020, 0.074000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 1, 0, 0}, 7.790260, 0.000020, 0.067000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 0, -1}, 209.654210, 0.000020, 0.026000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 0, 1}, 209.517230, 0.000230, 0.081000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 1, 1}, 209.685400, 0.000020, 1.064000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -1, 0, 0}, 188.173820, 0.000120, 0.075000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, -1, -1}, 31.296050, 0.000050, 0.036000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, -1, 1}, 31.338690, 0.000050, 1.199000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 0, -1}, 29.826290, 0.000060, 0.069000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 0, 1}, 29.836220, 0.000080, 0.081000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 1, -1}, 29.261260, 0.000150, 0.857000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 1, 1}, 29.232770, 0.000170, 0.039000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 2, 1}, 28.846580, 0.000020, 0.026000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -2, -1}, 30.178270, 0.000040, 0.062000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -1, -1}, 29.958550, 0.000350, 0.340000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -1, 1}, 29.964670, 0.000420, 0.042000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, -1}, 29.677230, 0.001610, 0.097000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, 1}, 29.684620, 0.000430, 0.027000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 1, -1}, 29.467730, 0.000100, 0.042000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 1, 1}, 29.635020, 0.000070, 0.020000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, -1, 1}, 29.732360, 0.000010, 0.021000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, 0, -1}, 29.740230, 0.000030, 0.029000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, 0, 1}, 209.726190, 0.000010, 0.016000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 2, -2}, 144.439170, 0.000020, 0.026000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 2, 0}, 143.711710, 0.000050, 0.088000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 3, -2}, 144.157280, 0.000030, 0.040000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 0, 0}, 322.470390, 0.000140, 0.076000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 1, -2}, 317.359750, 0.000020, 0.037000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 1, 0}, 324.060970, 0.000040, 6.053000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, -2}, 146.770260, 0.000360, 0.074000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, 0}, 152.935520, 0.000130, 0.075000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 3, -2}, 142.307760, 0.000020, 5.942000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 3, 0}, 145.516520, 0.000050, 0.037000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 0, 0}, 324.255350, 0.000030, 0.086000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 1, 0}, 144.157280, 0.000030, 0.040000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 2, -2}, 143.711710, 0.000050, 0.088000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 2, 0}, 144.439170, 0.000020, 0.026000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 0, -1}, 272.835120, 0.000060, 0.026000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 0, 1}, 271.880970, 0.000310, 0.087000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 1, -1}, 273.722300, 0.000080, 0.040000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 1, 1}, 274.014490, 0.000070, 0.571000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -1, 0, 0}, 352.486640, 0.000100, 0.080000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -2, -1}, 268.750120, 0.000010, 0.025000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -1, -1}, 269.738740, 0.000160, 0.037000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -1, 1}, 269.173900, 0.000140, 42.830000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, -1}, 274.403270, 0.000160, 0.073000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, 1}, 274.752380, 0.000140, 0.076000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 1, -1}, 269.173900, 0.000140, 2.802000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 1, 1}, 269.738740, 0.000160, 0.038000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 2, 1}, 268.666920, 0.000010, 0.025000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 1, 0, 0}, 354.667250, 0.000120, 0.082000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -1, -1}, 275.612710, 0.000090, 0.469000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -1, 1}, 275.148100, 0.000120, 0.040000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 0, -1}, 274.302380, 0.000400, 0.090000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 0, 1}, 274.155390, 0.000090, 0.026000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 1, 1}, 274.660530, 0.000010, 0.020000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 0, -1}, 331.159550, 0.000020, 0.026000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 0, 1}, 331.159560, 0.000100, 0.088000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 1, -1}, 331.157150, 0.000040, 0.040000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 1, 1}, 331.157150, 0.000040, 0.521000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, -1, -1}, 330.238070, 0.000050, 0.037000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, -1, 1}, 329.937930, 0.000040, 6.884000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 0, -1}, 333.369760, 0.000040, 0.074000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 0, 1}, 333.369760, 0.000040, 0.075000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 1, -1}, 329.937930, 0.000040, 5.312000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 1, 1}, 330.238070, 0.000050, 0.038000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, -1, -1}, 331.229760, 0.000040, 0.510000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, -1, 1}, 331.229750, 0.000040, 0.040000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, 0, -1}, 331.227720, 0.000110, 0.089000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, 0, 1}, 331.214280, 0.000020, 0.026000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, -1, -1}, 301.645500, 0.000030, 0.020000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, -1, 1}, 301.806880, 0.000060, 0.041000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, -1}, 301.489210, 0.000170, 0.026000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, 1}, 301.691990, 0.000780, 0.091000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 1, -1}, 301.786780, 0.000220, 0.041000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 1, 1}, 301.774940, 0.000190, 0.438000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 2, 1}, 301.708640, 0.000020, 0.064000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -1, 0, 0}, 22.867690, 0.000120, 0.083000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -2, -1}, 300.320480, 0.000030, 0.025000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -1, -1}, 300.281860, 0.000200, 0.038000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -1, 1}, 300.114400, 0.000190, 1.967000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 0, -1}, 301.719690, 0.000190, 0.076000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 0, 1}, 301.687490, 0.000170, 0.073000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, -1}, 299.985590, 0.000160, 5.720000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, 1}, 300.089350, 0.000170, 0.037000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 2, -1}, 120.885700, 0.000040, 0.074000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 2, 1}, 300.313430, 0.000030, 0.025000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, -1, 0}, 203.021770, 0.000020, 1.833000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 0, 0}, 23.021770, 0.000440, 0.079000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 1, 0}, 23.021770, 0.000020, 0.039000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -1, -1}, 301.736220, 0.000110, 0.625000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -1, 1}, 301.642340, 0.000160, 0.040000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 0, -1}, 301.285480, 0.000580, 0.086000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 0, 1}, 301.304640, 0.000100, 0.026000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 1, -1}, 301.350850, 0.000020, 0.040000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 1, 1}, 301.390440, 0.000010, 0.019000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 0, 1}, 329.517770, 0.000030, 0.028000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 1, -1}, 328.979310, 0.000020, 0.021000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 1, 1}, 328.923530, 0.000020, 0.046000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 2, -1}, 328.728490, 0.000010, 0.028000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, -1, -1}, 328.777640, 0.000080, 0.020000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, -1, 1}, 328.736480, 0.000140, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, -1}, 328.894350, 0.000540, 0.027000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, 1}, 328.518620, 0.002060, 0.096000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 1, -1}, 328.685090, 0.000620, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 1, 1}, 328.728360, 0.000550, 0.355000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 2, 1}, 328.577350, 0.000060, 0.062000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, -1, 0}, 54.634340, 0.000010, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, -1, 1}, 331.154100, 0.000030, 0.088000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, -1}, 151.232470, 0.000080, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, 0}, 54.431360, 0.000150, 0.087000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, 1}, 151.235590, 0.000080, 0.519000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 1, 0}, 234.804040, 0.000040, 0.568000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -2, -1}, 329.851410, 0.000070, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -2, 1}, 330.139590, 0.000020, 0.082000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, -1}, 329.734200, 0.000480, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, 1}, 329.793560, 0.000420, 0.962000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 0, -1}, 328.459710, 0.000340, 0.080000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 0, 1}, 329.203610, 0.000450, 0.070000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 1, -1}, 330.184430, 0.000360, 1.415000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 1, 1}, 330.211710, 0.000380, 0.036000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 2, -1}, 330.112000, 0.000020, 0.072000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 2, 1}, 330.352060, 0.000050, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -2, -1}, 331.586120, 0.000040, 0.037000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -2, 0}, 54.800550, 0.000020, 0.075000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -2, 1}, 331.478260, 0.000010, 6.536000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, -1}, 331.590850, 0.000270, 0.074000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 0}, 234.838110, 0.000230, 72.752000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 1}, 331.717660, 0.000240, 0.075000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, -2}, 54.850160, 0.000030, 0.074000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, -1}, 331.224970, 0.000480, 5.540000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 0}, 54.838010, 0.004210, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 1}, 331.248120, 0.000510, 0.038000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, -1}, 331.235600, 0.000030, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, 0}, 54.838110, 0.000230, 0.038000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, 1}, 331.235630, 0.000060, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -2, 1}, 151.561300, 0.000010, 0.080000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -1, -1}, 330.386210, 0.000150, 0.937000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -1, 1}, 330.782670, 0.000210, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, -1}, 331.323920, 0.001090, 0.082000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, 1}, 329.421140, 0.000120, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 1, -1}, 331.214300, 0.000070, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 1, 1}, 330.166240, 0.000010, 0.019000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -2, 1}, 331.146350, 0.000020, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -1, -1}, 331.154100, 0.000030, 0.088000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -1, 0}, 54.838110, 0.000040, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -1, 1}, 331.236700, 0.000020, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, 0, 0}, 54.838110, 0.000030, 0.026000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -4, 1, -1}, 187.422890, 0.000010, 0.021000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, -1, -1}, 187.009350, 0.000030, 0.020000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, -1, 1}, 187.577010, 0.000050, 0.043000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 0, -1}, 186.448600, 0.000180, 0.027000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 0, 1}, 187.167950, 0.000620, 0.101000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 1, -1}, 186.883100, 0.000190, 0.043000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 1, 1}, 187.039590, 0.000160, 0.299000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -2, -1}, 183.534290, 0.000010, 0.026000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -1, -1}, 183.344540, 0.000220, 0.040000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -1, 1}, 183.413210, 0.000200, 0.636000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 0, -1}, 184.978720, 0.000120, 0.083000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 0, 1}, 184.492400, 0.000130, 0.067000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 1, -1}, 182.965380, 0.000100, 0.808000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 1, 1}, 182.522950, 0.000100, 0.036000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 2, 1}, 183.861740, 0.000010, 0.024000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, -1, 0}, 97.404170, 0.000020, 1.931000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, 0, 0}, 277.404160, 0.000390, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, 1, 0}, 277.404160, 0.000020, 0.037000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -2, -1}, 0.960960, 0.000030, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -2, 1}, 0.963890, 0.000030, 0.077000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -1, -1}, 0.750210, 0.000290, 1.866000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -1, 1}, 0.677400, 0.000280, 0.038000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, -1}, 0.258620, 0.000240, 0.079000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, 1}, 359.216920, 0.000050, 0.025000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, 1, -1}, 256.766660, 0.000010, 0.021000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, -1, -1}, 256.803070, 0.000030, 0.020000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, -1, 1}, 256.829570, 0.000050, 0.044000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, -1}, 256.600980, 0.000210, 0.028000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, 1}, 256.745100, 0.000620, 0.107000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 1, -1}, 256.975230, 0.000160, 0.044000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 1, 1}, 257.002650, 0.000150, 0.258000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 2, 1}, 256.866010, 0.000010, 0.058000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -1, -1}, 256.033490, 0.000080, 0.040000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -1, 1}, 256.788400, 0.000090, 0.475000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, -1}, 254.090500, 0.000070, 0.087000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, 1}, 253.436400, 0.000060, 0.065000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 1, -1}, 256.621080, 0.000060, 0.565000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 1, 1}, 255.730330, 0.000030, 0.035000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, -1, 0}, 127.569230, 0.000020, 0.953000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, 0, 0}, 307.569230, 0.000280, 0.070000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, 1, 0}, 307.569230, 0.000020, 0.036000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, -2}, 127.914410, 0.000010, 0.074000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, -1}, 258.980990, 0.000100, 241.391000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, 0}, 129.331410, 0.000070, 0.075000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, 1}, 259.190070, 0.000090, 0.037000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, -1}, 225.087940, 0.000030, 0.075000},
	{{0, 0, 3, -2, 2, 0, 0, 0, 2, 0, -1}, 264.077860, 0.000020, 0.075000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 1, 0, 0}, 339.045350, 0.000050, 0.067000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 2, 0, -1}, 210.641880, 0.000040, 0.072000},
	{{0, 0, 3, 0, -5, 0, 0, 0, -2, 0, -1}, 194.082180, 0.000020, 0.028000},
	{{0, 0, 3, 0, -5, 0, 0, 0, -2, 0, 1}, 193.997560, 0.000030, 0.114000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 1, 0, 0}, 290.761280, 0.000060, 0.067000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, -1, -1}, 199.587520, 0.000050, 1.568000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, -1, 1}, 199.587530, 0.000050, 0.036000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, 0, -1}, 200.685870, 0.000260, 0.072000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, 0, 1}, 20.634680, 0.000010, 0.025000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 2, 0, -1}, 181.111190, 0.000020, 0.072000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, 0, -1}, 348.351450, 0.000050, 0.071000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, -1, -1}, 182.183580, 0.000020, 0.021000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 0, -1}, 182.599090, 0.000090, 0.028000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 0, 1}, 182.274240, 0.000210, 0.116000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 1, -1}, 182.491800, 0.000070, 0.045000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 1, 1}, 182.490820, 0.000070, 0.217000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 0, -1}, 13.840710, 0.000030, 0.093000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 0, 1}, 187.132420, 0.000010, 0.062000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 1, -1}, 185.433330, 0.000020, 0.401000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 1, 1}, 185.761590, 0.000040, 0.034000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 1, 0, 0}, 280.403740, 0.000190, 0.067000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -2, -1}, 189.359110, 0.000020, 0.080000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -1, -1}, 189.317830, 0.000190, 1.385000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -1, 1}, 189.641820, 0.000270, 0.036000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 0, -1}, 190.576040, 0.001460, 0.072000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 0, 1}, 9.979550, 0.000030, 0.024000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 1, -1}, 190.553620, 0.000080, 0.037000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 1, 1}, 10.087360, 0.000010, 0.018000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -4, -1}, 14.531050, 0.000020, 0.037000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -3, -1}, 14.702520, 0.000090, 0.075000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -3, 1}, 14.702520, 0.000090, 0.074000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -2, -1}, 194.004340, 0.000030, 6.061000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 0, 1}, 165.787240, 0.000020, 0.030000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 1, -1}, 165.506460, 0.000020, 0.021000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, -1, -1}, 166.591680, 0.000050, 0.021000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, -1, 1}, 165.895850, 0.000040, 0.046000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, -1}, 166.718900, 0.000290, 0.028000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, 1}, 165.911560, 0.000740, 0.117000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 1, -1}, 165.727760, 0.000230, 0.045000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 1, 1}, 166.066820, 0.000220, 0.213000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 2, 1}, 165.309760, 0.000020, 0.056000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -3, -1}, 13.604990, 0.000010, 0.020000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -2, -1}, 38.855730, 0.000010, 0.027000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -2, 1}, 267.722590, 0.000030, 0.097000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -1, -1}, 72.300100, 0.000180, 0.042000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -1, 1}, 89.178240, 0.000160, 0.343000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 0, -1}, 0.741990, 0.000150, 0.094000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 0, 1}, 153.670340, 0.000080, 0.062000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 1, -1}, 166.422710, 0.000050, 0.388000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 1, 1}, 174.474190, 0.000130, 0.034000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 2, 1}, 174.647060, 0.000020, 0.023000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 1, 0, 0}, 261.763800, 0.000030, 0.066000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -2, -1}, 178.507000, 0.000070, 0.080000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -2, 1}, 64.869010, 0.000010, 0.069000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -1, -1}, 171.071970, 0.000680, 1.240000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -1, 1}, 173.510130, 0.000970, 0.036000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, -3}, 180.561500, 0.000030, 0.078000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, -1}, 180.133180, 0.005180, 0.071000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, 1}, 13.661090, 0.000100, 0.024000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 1, -1}, 180.205760, 0.000270, 0.037000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 1, 1}, 359.688880, 0.000050, 0.018000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -2, -1}, 36.533630, 0.000010, 0.081000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -2, 1}, 178.999280, 0.000020, 0.026000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -1, -1}, 170.425430, 0.000100, 0.039000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, 0, -1}, 180.569920, 0.000020, 0.026000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, 0, 1}, 180.035150, 0.000010, 0.015000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 0, -1}, 256.752360, 0.000030, 0.017000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 0, 1}, 74.829170, 0.000010, 0.030000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 1, -1}, 76.713460, 0.000020, 0.021000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, -1, -1}, 74.430090, 0.000040, 0.021000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, -1, 1}, 70.344920, 0.000020, 0.046000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 0, -1}, 75.662360, 0.000390, 0.028000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 0, 1}, 75.754020, 0.000960, 0.118000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 1, -1}, 75.564200, 0.000280, 0.045000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 1, 1}, 75.445210, 0.000250, 0.210000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 2, 1}, 76.366070, 0.000020, 0.055000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -2, -1}, 257.720890, 0.000070, 0.027000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -2, 1}, 257.082820, 0.000050, 0.097000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -1, -1}, 256.819320, 0.000350, 0.042000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -1, 1}, 258.684780, 0.000270, 0.334000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 0, -1}, 87.639210, 0.000050, 0.094000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 0, 1}, 240.476300, 0.000020, 0.062000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 1, -1}, 71.430230, 0.000060, 0.375000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 1, 1}, 70.774310, 0.000050, 0.034000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 1, 0, 0}, 259.546840, 0.000170, 0.066000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -2, 1}, 262.134490, 0.000020, 0.069000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -1, -1}, 269.645590, 0.000220, 1.123000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -1, 1}, 268.816640, 0.000230, 0.036000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, 0, -1}, 321.905830, 0.000230, 0.071000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, 0, 1}, 245.911380, 0.000080, 0.024000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -2, -2}, 75.571230, 0.000030, 0.075000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -2, 0}, 262.117410, 0.000040, 0.074000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, -2}, 257.285550, 0.000020, 6.129000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, 0}, 257.286170, 0.000020, 0.037000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, -2, 1}, 257.185050, 0.000010, 0.025000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, -1, -1}, 257.184900, 0.000040, 0.039000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, 0, -1}, 188.729790, 0.000050, 0.071000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 0, -1}, 166.225460, 0.000050, 0.028000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 0, 1}, 165.777330, 0.000100, 0.119000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 1, -1}, 165.852110, 0.000020, 0.045000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 1, 1}, 165.852110, 0.000020, 0.206000},
	{{0, 0, 3, 0, 0, -4, 0, 0, 2, 0, -1}, 272.727680, 0.000030, 0.071000},
	{{0, 0, 3, 0, 0, -3, 0, 0, -2, 0, -1}, 176.806990, 0.000010, 0.028000},
	{{0, 0, 3, 0, 0, -3, 0, 0, -2, 0, 1}, 176.807310, 0.000010, 0.119000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, -1, -1}, 179.900090, 0.000020, 1.045000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, -1, 1}, 179.900090, 0.000020, 0.036000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, 0, -1}, 180.007340, 0.000120, 0.070000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, 0, 1}, 179.994190, 0.000010, 0.024000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, 0, -1}, 76.915830, 0.000020, 0.028000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, 0, 1}, 76.944660, 0.000030, 0.119000},
	{{0, 0, 3, 0, 0, 0, 0, 0, -1, 0, 0}, 120.950540, 0.000080, 0.107000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0}, 306.373350, 0.000100, 0.065000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, -3}, 49.937050, 0.000010, 0.080000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, -1}, 229.937050, 0.000010, 0.070000},
	{{0, 0, 4, -9, 0, 0, 0, 0, -1, 0, 0}, 293.278500, 0.000080, 0.076000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 0, 1}, 242.339880, 0.000050, 0.086000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -1, 0, 0}, 323.293920, 0.000040, 0.079000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -1, -1}, 241.303700, 0.000040, 0.037000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -1, 1}, 240.066560, 0.000030, 11.532000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 0, -1}, 250.154780, 0.000030, 0.073000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 0, 1}, 250.154780, 0.000030, 0.076000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 1, -1}, 240.066560, 0.000030, 2.380000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 1, 1}, 241.303700, 0.000040, 0.038000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 1, 0, 0}, 324.986850, 0.000050, 0.083000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, -1, -1}, 247.039340, 0.000020, 0.456000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, -1, 1}, 247.039080, 0.000020, 0.041000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 0, -1}, 247.063070, 0.000070, 0.090000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 0, 1}, 246.887480, 0.000020, 0.026000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 0, -1}, 279.173350, 0.000030, 0.026000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 0, 1}, 279.103970, 0.000150, 0.088000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 1, -1}, 279.173450, 0.000050, 0.040000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 1, 1}, 279.173450, 0.000050, 0.515000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, -1, -1}, 277.200770, 0.000070, 0.037000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, -1, 1}, 276.913250, 0.000060, 5.976000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 0, -1}, 279.713150, 0.000060, 0.075000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 0, 1}, 279.713150, 0.000060, 0.074000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 1, -1}, 276.913250, 0.000060, 6.017000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 1, 1}, 277.200770, 0.000070, 0.037000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, -1, -1}, 279.170110, 0.000050, 0.515000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, -1, 1}, 279.170110, 0.000050, 0.040000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, 0, -1}, 279.100990, 0.000150, 0.088000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, 0, 1}, 279.170210, 0.000030, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 3, -1}, 286.782000, 0.000010, 0.021000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, -1, 1}, 286.781910, 0.000020, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 0, -1}, 286.675060, 0.000100, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 0, 1}, 286.711000, 0.000270, 0.028000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, -1}, 286.845230, 0.000230, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, 1}, 286.872480, 0.000460, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 2, -1}, 287.087540, 0.000150, 0.027000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 2, 1}, 286.782650, 0.000040, 0.105000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 0, -1}, 286.780610, 0.000010, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 0, 1}, 286.780610, 0.000010, 0.042000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -2, -1}, 286.310020, 0.000100, 0.015000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -2, 1}, 286.316400, 0.000130, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, -1}, 286.419780, 0.000700, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, 1}, 286.400260, 0.001500, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, -1}, 286.697180, 0.004530, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 1}, 286.684170, 0.023460, 0.088000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 3}, 286.640970, 0.000090, 0.064000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, -1}, 287.112610, 0.006180, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, 1}, 287.109650, 0.005030, 0.515000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, -1}, 110.004080, 0.000010, 0.086000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, 1}, 287.777810, 0.000370, 0.066000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 3, 1}, 288.239890, 0.000040, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 0, -1}, 106.704420, 0.000110, 0.039000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 0, 1}, 106.705240, 0.000120, 0.949000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -3, -1}, 284.963360, 0.000090, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -3, 1}, 284.432070, 0.000020, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, -1}, 285.032350, 0.000950, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 1}, 284.903450, 0.000460, 0.076000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, -1}, 285.104060, 0.008040, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 1}, 284.850890, 0.007100, 6.017000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 3}, 284.851720, 0.000020, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, -1}, 287.229300, 0.007620, 0.074000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, 1}, 287.229510, 0.007620, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, -3}, 284.851840, 0.000020, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, -1}, 284.850970, 0.007100, 5.977000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, 1}, 285.104330, 0.008040, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, -1}, 284.900240, 0.000460, 0.076000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, 1}, 285.032680, 0.000950, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 3, -1}, 284.432440, 0.000020, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 3, 1}, 284.963790, 0.000090, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, 0, -1}, 106.705300, 0.000120, 0.948000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, 0, 1}, 106.704500, 0.000110, 0.039000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -3, -1}, 288.241070, 0.000040, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, -1}, 287.778880, 0.000370, 0.066000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, 1}, 110.073670, 0.000010, 0.086000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, -1}, 287.111090, 0.005030, 0.515000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 1}, 287.114270, 0.006190, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, -3}, 286.643440, 0.000090, 0.064000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, -1}, 286.686580, 0.023480, 0.088000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, 1}, 286.698670, 0.004530, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, -1}, 286.402420, 0.001510, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, 1}, 286.421340, 0.000700, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 2, -1}, 286.318440, 0.000130, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 2, 1}, 286.311690, 0.000100, 0.015000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, 0, -1}, 286.784360, 0.000010, 0.042000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, 0, 1}, 286.784360, 0.000010, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -2, -1}, 286.783630, 0.000040, 0.105000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -2, 1}, 287.089100, 0.000150, 0.027000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, -1}, 286.874720, 0.000460, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, 1}, 286.846900, 0.000230, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 0, -1}, 286.713350, 0.000270, 0.028000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 0, 1}, 286.678050, 0.000100, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 1, -1}, 286.783910, 0.000020, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, -3, 1}, 286.783620, 0.000010, 0.021000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, -1, -1}, 272.685210, 0.000010, 0.020000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 0, -1}, 272.663880, 0.000090, 0.026000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 0, 1}, 272.679880, 0.000420, 0.091000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 1, -1}, 272.749890, 0.000120, 0.041000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 1, 1}, 272.821710, 0.000100, 0.451000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 0, 0}, 353.558770, 0.000060, 0.083000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -1, -1}, 271.005380, 0.000120, 0.038000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -1, 1}, 270.803910, 0.000110, 2.247000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, -1}, 272.590850, 0.000090, 0.076000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, 1}, 272.515900, 0.000110, 0.073000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 1, -1}, 270.641730, 0.000100, 8.973000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 1, 1}, 270.881110, 0.000110, 0.037000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 1, 0, 0}, 353.416900, 0.000210, 0.079000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -1, -1}, 272.619230, 0.000080, 0.601000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -1, 1}, 272.534950, 0.000090, 0.040000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 0, -1}, 272.133010, 0.000300, 0.086000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 0, 1}, 272.299950, 0.000050, 0.026000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, -1, -1}, 300.527490, 0.000030, 0.020000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, -1, 1}, 300.505270, 0.000050, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, -1}, 300.577660, 0.000160, 0.027000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, 1}, 300.550610, 0.000640, 0.095000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 1, -1}, 300.510510, 0.000190, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 1, 1}, 300.469920, 0.000160, 0.364000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, 0, 0}, 23.778480, 0.000080, 0.087000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -2, -1}, 301.038700, 0.000010, 0.026000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -1, -1}, 300.896230, 0.000150, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -1, 1}, 301.023360, 0.000150, 1.024000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 0, -1}, 300.219690, 0.000130, 0.079000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 0, 1}, 300.594180, 0.000160, 0.070000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 1, -1}, 301.230260, 0.000100, 1.555000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 1, 1}, 301.214000, 0.000100, 0.036000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 2, 1}, 301.030550, 0.000010, 0.025000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -2, 0}, 24.024440, 0.000020, 0.075000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, -1}, 301.284500, 0.000010, 0.074000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, 0}, 204.014810, 0.000090, 12.968000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, 1}, 301.284500, 0.000010, 0.075000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, -2}, 24.022280, 0.000010, 0.073000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, -1}, 302.241170, 0.000030, 4.101000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, 0}, 24.014880, 0.001710, 0.076000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, 1}, 302.241040, 0.000030, 0.038000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 1, 0}, 24.014800, 0.000090, 0.038000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -1, -1}, 301.846890, 0.000060, 0.884000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -1, 1}, 298.942530, 0.000100, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, -1}, 302.039970, 0.000380, 0.082000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, 1}, 301.747100, 0.000050, 0.026000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 1, -1}, 302.157570, 0.000020, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 3, -1, 0}, 24.014800, 0.000020, 0.041000},
	{{0, 0, 4, -6, 2, 0, 0, 0, 1, 0, 0}, 256.799400, 0.000020, 0.075000},
	{{0, 0, 4, -6, 3, 0, 0, 0, 1, 0, 0}, 56.805190, 0.000020, 0.074000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, -1, -1}, 155.912150, 0.000020, 0.020000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, -1, 1}, 156.244530, 0.000020, 0.043000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 0, -1}, 155.448850, 0.000120, 0.027000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 0, 1}, 156.038220, 0.000410, 0.100000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 1, -1}, 155.958540, 0.000130, 0.042000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 1, 1}, 156.130250, 0.000120, 0.305000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -1, 0, 0}, 56.047270, 0.000020, 0.091000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -1, -1}, 153.302490, 0.000140, 0.039000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -1, 1}, 153.359860, 0.000130, 0.663000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 0, -1}, 154.250720, 0.000090, 0.083000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 0, 1}, 154.040560, 0.000080, 0.068000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 1, -1}, 153.483930, 0.000080, 0.851000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 1, 1}, 152.987840, 0.000080, 0.036000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, -1, 0}, 56.047270, 0.000040, 2.200000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 0, 0}, 236.047930, 0.000710, 0.073000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 1, 0}, 236.047270, 0.000040, 0.037000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -2, -1}, 331.696250, 0.000020, 0.072000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -2, 1}, 331.694660, 0.000020, 0.077000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -1, -1}, 331.394220, 0.000170, 1.669000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -1, 1}, 331.336420, 0.000160, 0.038000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, -1}, 331.591440, 0.000160, 0.079000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, 1}, 330.998380, 0.000030, 0.025000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, -1, -1}, 204.594300, 0.000010, 0.020000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 0, -1}, 203.709810, 0.000070, 0.028000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 0, 1}, 205.402550, 0.000230, 0.106000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 1, -1}, 204.677920, 0.000080, 0.043000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 1, 1}, 204.441280, 0.000070, 0.262000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -1, 0, 0}, 96.846820, 0.000010, 0.095000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -1, 0, 2}, 276.846820, 0.000010, 0.061000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -2, -1}, 2.170950, 0.000020, 0.026000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -1, -1}, 354.335100, 0.000110, 0.040000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -1, 1}, 355.646720, 0.000110, 0.490000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 0, -1}, 189.616650, 0.000070, 0.087000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 1, -1}, 194.139560, 0.000030, 0.586000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 1, 1}, 192.912710, 0.000060, 0.035000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 1, 0, 0}, 278.785530, 0.000200, 0.070000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -2, -1}, 191.360360, 0.000010, 0.075000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -2, 1}, 358.564780, 0.000060, 0.074000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, -1}, 181.906650, 0.000960, 14.813000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, 1}, 182.007910, 0.000890, 0.037000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, -1}, 0.579280, 0.001050, 0.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, 1}, 182.620040, 0.000080, 0.025000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 1, -1}, 0.663350, 0.000060, 0.038000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -2, 1}, 181.960630, 0.000020, 0.026000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -1, -1}, 181.974310, 0.000030, 0.041000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, 0, -1}, 76.194260, 0.000020, 0.028000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, 0, 1}, 76.690600, 0.000040, 0.112000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -1, 0, 0}, 128.563160, 0.000020, 0.100000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 1, 0, 0}, 310.148090, 0.000180, 0.068000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, 0, -1}, 20.932960, 0.000060, 0.073000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, 0, -1}, 154.688660, 0.000010, 0.028000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, 0, 1}, 154.689170, 0.000010, 0.119000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 1, 0, 0}, 338.132390, 0.000020, 0.065000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 2, 0, -1}, 200.628850, 0.000060, 0.068000},
	{{0, 0, 4, 0, -5, 0, 0, 0, -2, 0, -1}, 183.496450, 0.000010, 0.029000},
	{{0, 0, 4, 0, -5, 0, 0, 0, -2, 0, 1}, 183.497340, 0.000010, 0.129000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, 0, -1}, 6.741770, 0.000010, 0.102000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, 0, 1}, 6.741770, 0.000010, 0.059000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 1, 0, 0}, 279.548520, 0.000040, 0.063000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, -1, -1}, 190.266070, 0.000050, 0.611000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, -1, 1}, 190.266480, 0.000050, 0.035000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, 0, -1}, 190.341140, 0.000210, 0.067000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, 0, 1}, 10.286360, 0.000030, 0.024000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 0, -1}, 166.887220, 0.000040, 0.029000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 0, 1}, 166.754430, 0.000070, 0.131000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 1, -1}, 166.741510, 0.000020, 0.047000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 1, 1}, 166.741510, 0.000020, 0.178000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, -1, -1}, 5.677600, 0.000010, 0.043000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 0, -1}, 5.441480, 0.000010, 0.102000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 1, -1}, 172.796840, 0.000010, 0.286000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 1, 1}, 172.865970, 0.000010, 0.033000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, -1, -1}, 179.015520, 0.000110, 0.581000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, -1, 1}, 179.146280, 0.000140, 0.035000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 0, -1}, 179.835240, 0.000610, 0.067000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 0, 1}, 359.340270, 0.000050, 0.024000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 1, -1}, 179.780450, 0.000040, 0.035000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 1, 1}, 359.487280, 0.000010, 0.018000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 0, -1}, 64.136280, 0.000040, 0.029000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 0, 1}, 64.039330, 0.000060, 0.132000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 1, -1}, 64.058780, 0.000020, 0.047000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 1, 1}, 64.058780, 0.000020, 0.176000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 1, 0, 0}, 259.109150, 0.000030, 0.062000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, -1, -1}, 27.723850, 0.000020, 0.554000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, -1, 1}, 27.723740, 0.000020, 0.035000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, 0, -1}, 357.853230, 0.000040, 0.066000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, 0, 1}, 209.840840, 0.000010, 0.024000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 0, -1}, 331.115560, 0.000030, 0.029000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 0, 1}, 331.203800, 0.000050, 0.134000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 1, -1}, 331.225810, 0.000010, 0.047000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 1, 1}, 331.225810, 0.000010, 0.173000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -1, 0, 0}, 263.618350, 0.000040, 0.076000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 1, 0, 0}, 295.526570, 0.000020, 0.083000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 0, -1}, 243.821600, 0.000060, 0.026000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 0, 1}, 243.681080, 0.000230, 0.090000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 1, -1}, 244.127500, 0.000060, 0.041000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 1, 1}, 244.055800, 0.000060, 0.464000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -1, 0, 0}, 324.409200, 0.000020, 0.082000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -1, -1}, 241.559020, 0.000070, 0.038000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -1, 1}, 241.144940, 0.000060, 2.621000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 0, -1}, 244.771030, 0.000070, 0.076000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 0, 1}, 244.813960, 0.000070, 0.073000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 1, -1}, 241.144940, 0.000060, 20.797000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 1, 1}, 241.559020, 0.000070, 0.037000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 1, 0, 0}, 324.000250, 0.000090, 0.079000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -1, -1}, 243.524800, 0.000050, 0.579000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -1, 1}, 243.601740, 0.000050, 0.040000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 0, -1}, 243.048970, 0.000180, 0.087000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 0, 1}, 243.270340, 0.000030, 0.026000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 0, -1}, 271.978920, 0.000060, 0.027000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 0, 1}, 271.976080, 0.000200, 0.095000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 1, -1}, 271.980890, 0.000070, 0.041000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 1, 1}, 271.980910, 0.000070, 0.372000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -1, 0, 0}, 354.134810, 0.000040, 0.086000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, -1, -1}, 271.929070, 0.000060, 0.039000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, -1, 1}, 271.812800, 0.000030, 1.095000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 0, -1}, 272.037770, 0.000060, 0.079000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 0, 1}, 272.042120, 0.000050, 0.071000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 1, -1}, 271.812800, 0.000030, 1.725000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 1, 1}, 271.929070, 0.000060, 0.036000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -2, 0}, 354.276750, 0.000040, 0.075000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -1, 0}, 174.306350, 0.000040, 7.118000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, 0, 0}, 354.306350, 0.000660, 0.076000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, 1, 0}, 354.306350, 0.000040, 0.038000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -1, -1}, 273.097710, 0.000030, 0.837000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -1, 1}, 273.097810, 0.000030, 0.039000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 0, -1}, 273.034440, 0.000130, 0.083000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 0, 1}, 273.149990, 0.000020, 0.026000},
	{{0, 0, 5, -8, 2, 0, 0, 0, 1, 0, -2}, 60.911910, 0.000010, 0.074000},
	{{0, 0, 5, -8, 2, 0, 0, 0, 1, 0, 0}, 240.911910, 0.000010, 0.075000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 0, -1}, 4.559700, 0.000030, 0.016000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 0, 1}, 184.568660, 0.000020, 0.029000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 1, -1}, 184.440310, 0.000020, 0.021000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, -1, -1}, 184.726490, 0.000070, 0.020000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, -1, 1}, 184.511670, 0.000100, 0.042000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, -1}, 184.849870, 0.000430, 0.027000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, 1}, 184.825890, 0.001570, 0.097000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 1, -1}, 185.295480, 0.000420, 0.042000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 1, 1}, 185.295290, 0.000350, 0.340000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 2, 1}, 185.809330, 0.000040, 0.062000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -2, -1}, 184.407400, 0.000020, 0.026000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -1, -1}, 185.781610, 0.000160, 0.039000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -1, 1}, 185.682030, 0.000170, 0.858000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 0, -1}, 188.405410, 0.000080, 0.080000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 0, 1}, 188.680260, 0.000070, 0.069000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 1, -1}, 191.242970, 0.000040, 1.201000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 1, 1}, 191.690220, 0.000050, 0.036000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 1, 0, 0}, 8.173540, 0.000120, 0.075000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, -1, -1}, 4.824150, 0.000040, 1.062000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, -1, 1}, 3.137580, 0.000020, 0.039000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, 0, -1}, 1.241200, 0.000220, 0.081000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, -1, -1}, 126.450310, 0.000010, 0.020000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 0, -1}, 126.414980, 0.000080, 0.027000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 0, 1}, 126.534170, 0.000240, 0.100000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 1, -1}, 126.462740, 0.000080, 0.042000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 1, 1}, 126.425030, 0.000070, 0.311000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -1, 0, 0}, 24.429660, 0.000020, 0.090000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, -1, -1}, 124.361410, 0.000060, 0.039000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, -1, 1}, 124.386060, 0.000060, 0.692000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 0, -1}, 124.004210, 0.000070, 0.082000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 0, 1}, 123.802530, 0.000060, 0.068000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 1, -1}, 124.053580, 0.000050, 0.900000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 1, 1}, 124.061830, 0.000050, 0.036000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, -1, 0}, 24.429660, 0.000040, 2.556000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, 0, 0}, 204.430170, 0.000680, 0.073000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, 1, 0}, 204.429660, 0.000040, 0.037000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -1, -1}, 302.074740, 0.000070, 1.509000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -1, 1}, 302.074630, 0.000070, 0.038000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, -1}, 303.131870, 0.000090, 0.079000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, 1}, 303.159680, 0.000010, 0.025000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 0, -1}, 165.466410, 0.000040, 0.028000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 0, 1}, 166.525590, 0.000110, 0.105000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 1, -1}, 165.973310, 0.000040, 0.043000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 1, 1}, 165.975100, 0.000040, 0.267000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -1, 0, 0}, 57.818240, 0.000010, 0.095000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -1, 0, 2}, 237.818240, 0.000010, 0.061000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -2, -1}, 331.758980, 0.000060, 0.026000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -2, 1}, 331.666570, 0.000050, 0.089000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -1, -1}, 331.217900, 0.000370, 0.040000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -1, 1}, 331.319890, 0.000300, 0.506000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 0, -1}, 158.375370, 0.000050, 0.086000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 0, 1}, 329.448760, 0.000050, 0.066000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 1, -1}, 157.844080, 0.000020, 0.609000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 1, 1}, 157.265170, 0.000030, 0.035000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, -1, 0}, 57.267990, 0.000020, 1.084000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, 0, 0}, 237.267990, 0.000300, 0.071000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, 1, 0}, 237.267990, 0.000020, 0.036000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -3, -1}, 332.461990, 0.000040, 0.038000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, -1}, 332.234970, 0.000230, 0.075000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, 1}, 331.945510, 0.000380, 0.074000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, -1}, 151.743030, 0.001950, 7.641000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, 1}, 151.740100, 0.001900, 0.037000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, -1}, 331.603070, 0.000580, 0.076000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, 1}, 151.714440, 0.000220, 0.025000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 1, -1}, 331.614690, 0.000040, 0.038000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 1, 1}, 151.741730, 0.000020, 0.019000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -3, 1}, 331.478290, 0.000020, 0.040000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -2, -1}, 331.507460, 0.000030, 0.088000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -2, 1}, 151.786600, 0.000030, 0.026000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -1, -1}, 151.741950, 0.000070, 0.041000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -1, 1}, 151.743270, 0.000030, 0.019000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 0, -1}, 141.056370, 0.000010, 0.028000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 0, 1}, 133.211270, 0.000030, 0.111000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -1, -1}, 5.143270, 0.000020, 0.041000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -1, 1}, 7.052450, 0.000010, 0.399000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 0, -1}, 1.931020, 0.000020, 0.090000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 1, 1}, 171.140680, 0.000010, 0.034000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 1, 0, 0}, 282.354540, 0.000130, 0.068000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -1, -1}, 178.567710, 0.000070, 2.495000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -1, 1}, 179.552230, 0.000130, 0.037000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 0, -1}, 180.913570, 0.000960, 0.073000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 0, 1}, 0.277080, 0.000020, 0.025000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 1, -1}, 180.897820, 0.000050, 0.037000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 1, 0, 0}, 309.949980, 0.000110, 0.066000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, 0, -1}, 26.458930, 0.000040, 0.070000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, 0, -1}, 190.051690, 0.000040, 0.063000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, 0, 1}, 10.051680, 0.000010, 0.023000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, -1, -1}, 178.910200, 0.000020, 0.379000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, -1, 1}, 178.911650, 0.000020, 0.034000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, 0, -1}, 179.156380, 0.000100, 0.063000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, 0, 1}, 359.089140, 0.000030, 0.023000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -1, 0, 0}, 234.199700, 0.000030, 0.075000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 0, -1}, 186.110800, 0.000010, 0.072000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 0, 1}, 186.110800, 0.000010, 0.077000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 0, -1}, 214.832770, 0.000030, 0.026000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 0, 1}, 214.759070, 0.000150, 0.090000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 1, -1}, 214.852340, 0.000050, 0.040000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 1, 1}, 214.852340, 0.000050, 0.478000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -1, -1}, 212.315830, 0.000050, 0.038000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -1, 1}, 211.818210, 0.000040, 3.142000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 0, -1}, 216.520980, 0.000050, 0.075000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 0, 1}, 216.520980, 0.000050, 0.074000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 1, -1}, 211.818210, 0.000040, 65.431000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 1, 1}, 212.315830, 0.000050, 0.037000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 1, 0, 0}, 298.077630, 0.000030, 0.080000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, -1, -1}, 214.261670, 0.000040, 0.559000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, -1, 1}, 214.261720, 0.000040, 0.040000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 0, -1}, 214.176820, 0.000120, 0.087000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 0, 1}, 214.303180, 0.000020, 0.026000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 0, -1}, 243.253340, 0.000020, 0.027000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 0, 1}, 243.255310, 0.000070, 0.094000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 1, -1}, 243.254200, 0.000030, 0.041000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 1, 1}, 243.254210, 0.000030, 0.381000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -1, 0, 0}, 324.862000, 0.000010, 0.086000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -1, 0, 2}, 324.862000, 0.000010, 0.066000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, -1, -1}, 242.652430, 0.000020, 0.038000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, -1, 1}, 242.372400, 0.000010, 1.177000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 0, -1}, 243.672490, 0.000020, 0.078000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 0, 1}, 243.672490, 0.000020, 0.071000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 1, -1}, 242.372400, 0.000010, 1.937000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 1, 1}, 242.652430, 0.000020, 0.037000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 1, 0, 0}, 324.934690, 0.000260, 0.077000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, 0, -1}, 243.815770, 0.000030, 0.083000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 0, -1}, 97.365610, 0.000040, 0.027000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 0, 1}, 97.490620, 0.000120, 0.099000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 1, -1}, 97.484850, 0.000040, 0.042000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 1, 1}, 97.484940, 0.000040, 0.317000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -1, 0, 0}, 175.775720, 0.000010, 0.090000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -1, 0, 2}, 355.775720, 0.000010, 0.064000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, -1, -1}, 95.035410, 0.000040, 0.039000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, -1, 1}, 95.246870, 0.000020, 0.724000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 0, -1}, 96.112250, 0.000050, 0.082000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 0, 1}, 96.113600, 0.000050, 0.068000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 1, -1}, 95.246870, 0.000020, 0.954000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 1, 1}, 95.035410, 0.000040, 0.036000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, -1, 0}, 354.335380, 0.000030, 3.050000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 0, 0}, 174.335920, 0.000530, 0.074000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 1, 0}, 174.335380, 0.000030, 0.037000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -1, -1}, 273.035700, 0.000030, 1.378000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -1, 1}, 273.035320, 0.000030, 0.038000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, 0, -1}, 274.880690, 0.000030, 0.080000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 0, -1}, 132.106330, 0.000020, 0.027000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 0, 1}, 132.780900, 0.000050, 0.105000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -2, -1}, 122.352400, 0.000020, 0.026000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -2, 1}, 302.364300, 0.000040, 0.088000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -1, -1}, 122.545000, 0.000270, 0.040000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -1, 1}, 122.566540, 0.000250, 0.523000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 0, -1}, 125.898440, 0.000010, 0.086000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 0, 1}, 123.048550, 0.000050, 0.066000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 1, -1}, 127.235060, 0.000010, 0.633000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 1, 1}, 127.235060, 0.000010, 0.035000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 1, 0, 0}, 205.888970, 0.000270, 0.071000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -3, -1}, 301.871580, 0.000050, 0.037000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, -1}, 302.351570, 0.000490, 0.074000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, 1}, 302.319680, 0.000370, 0.075000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, -1}, 302.335990, 0.001420, 5.148000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, 1}, 302.336920, 0.001500, 0.038000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, -1}, 302.400190, 0.000430, 0.077000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, 1}, 302.348520, 0.000200, 0.025000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 1, -1}, 302.413940, 0.000020, 0.038000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 1, 1}, 302.336220, 0.000020, 0.019000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -3, 1}, 302.577270, 0.000020, 0.040000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -2, -1}, 302.360930, 0.000060, 0.089000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -2, 1}, 302.355120, 0.000050, 0.026000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -1, -1}, 302.336570, 0.000050, 0.041000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -1, 1}, 302.338670, 0.000020, 0.019000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 0, -1}, 82.727500, 0.000020, 0.028000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 0, 1}, 82.643250, 0.000060, 0.107000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 1, -1}, 82.660590, 0.000010, 0.044000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 1, 1}, 82.660590, 0.000010, 0.254000},
	{{0, 0, 6, -8, 3, 0, 0, 0, 0, 0, -1}, 83.916210, 0.000010, 0.088000},
	{{0, 0, 6, -8, 3, 0, 0, 0, 0, 0, 1}, 83.916210, 0.000010, 0.065000},
	{{0, 0, 6, -7, -2, 0, 0, 0, 2, 0, -1}, 97.563900, 0.000020, 0.074000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 0, -1}, 123.012170, 0.000010, 0.028000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 0, 1}, 123.040110, 0.000010, 0.111000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, -1, -1}, 333.920530, 0.000020, 0.041000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, -1, 1}, 334.914370, 0.000010, 0.409000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 0, -1}, 332.587450, 0.000030, 0.090000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 1, 0, 0}, 239.884610, 0.000180, 0.068000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -1, -1}, 149.488780, 0.000050, 2.964000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -1, 1}, 150.688720, 0.000120, 0.037000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, -1}, 151.691990, 0.001170, 0.074000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 1, -1}, 151.686110, 0.000060, 0.037000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -1, -1}, 228.804810, 0.000020, 0.042000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -1, 1}, 228.804830, 0.000010, 0.336000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 1, 0, 0}, 283.255880, 0.000080, 0.066000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -1, -1}, 179.909020, 0.000050, 1.151000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -1, 1}, 179.909030, 0.000050, 0.036000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 0, -1}, 180.609830, 0.000240, 0.071000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 0, 1}, 0.558310, 0.000020, 0.024000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 1, 0, 0}, 309.731580, 0.000070, 0.064000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, 0, -1}, 28.640650, 0.000030, 0.068000},
	{{0, 0, 6, 0, -6, 0, 0, 0, 2, 0, -1}, 178.117150, 0.000020, 0.059000},
	{{0, 0, 7, -16, 4, 5, 0, 0, -2, 0, 1}, 175.617360, 0.000010, 0.081000},
	{{0, 0, 7, -16, 4, 5, 0, 0, -2, 0, 3}, 355.617360, 0.000010, 0.069000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, -1, -1}, 355.617360, 0.000010, 0.036000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, -1, 1}, 355.617360, 0.000010, 1.200000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 0, -1}, 355.617360, 0.000020, 0.069000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 0, 1}, 355.617360, 0.000020, 0.081000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 1, -1}, 355.617360, 0.000010, 0.857000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 1, 1}, 355.617360, 0.000010, 0.039000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, -1, -1}, 355.617360, 0.000050, 0.340000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, -1, 1}, 355.617360, 0.000050, 0.042000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, 0, -1}, 355.617360, 0.000150, 0.097000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, 0, 1}, 355.617360, 0.000040, 0.027000},
	{{0, 0, 7, -15, 0, 0, 0, 0, -1, 0, 0}, 204.392740, 0.000070, 0.075000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, 0, -1}, 258.205140, 0.000040, 0.097000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, 0, 1}, 257.643060, 0.000010, 0.027000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 0, -1}, 185.846060, 0.000030, 0.026000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 0, 1}, 185.846090, 0.000140, 0.089000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 1, -1}, 185.858290, 0.000050, 0.040000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 1, 1}, 185.858260, 0.000050, 0.493000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, -1, -1}, 183.228920, 0.000060, 0.038000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, -1, 1}, 182.795350, 0.000050, 3.924000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, -1}, 186.982800, 0.000050, 0.075000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, 1}, 186.982800, 0.000050, 0.074000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 1, -1}, 182.795350, 0.000050, 12.714000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 1, 1}, 183.228920, 0.000060, 0.037000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -1, -1}, 185.335810, 0.000040, 0.540000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -1, 1}, 185.335630, 0.000040, 0.040000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 0, -1}, 185.389900, 0.000130, 0.088000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 0, 1}, 185.405280, 0.000030, 0.026000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, 0, 1}, 214.455790, 0.000030, 0.094000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 1, 0, 0}, 295.713170, 0.000100, 0.077000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 0, -1}, 68.925680, 0.000030, 0.027000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 0, 1}, 68.991950, 0.000080, 0.098000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 1, -1}, 68.944800, 0.000030, 0.042000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 1, 1}, 68.944890, 0.000030, 0.323000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, -1, -1}, 66.389550, 0.000020, 0.039000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, -1, 1}, 66.630610, 0.000010, 0.759000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 0, -1}, 67.691590, 0.000020, 0.081000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 0, 1}, 67.691590, 0.000020, 0.069000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 1, -1}, 66.630610, 0.000010, 1.016000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 1, 1}, 66.389550, 0.000020, 0.036000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, -1, 0}, 324.577250, 0.000020, 3.781000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 0, 0}, 144.577910, 0.000380, 0.074000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 1, 0}, 144.577250, 0.000020, 0.037000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, -1, -1}, 93.126700, 0.000040, 0.040000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, -1, 1}, 93.126700, 0.000040, 0.541000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 1, 0, 0}, 175.084890, 0.000190, 0.071000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -2, -1}, 273.625060, 0.000030, 0.074000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -2, 1}, 273.625060, 0.000030, 0.075000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -1, -1}, 273.126700, 0.000220, 3.882000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -1, 1}, 273.126700, 0.000220, 0.038000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 0, -1}, 273.471530, 0.000140, 0.077000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 0, 1}, 273.126700, 0.000030, 0.025000},
	{{0, 0, 7, -10, 1, 0, 0, 0, 2, -2, -1}, 124.265950, 0.000010, 0.074000},
	{{0, 0, 7, -10, 1, 0, 0, 0, 2, -2, 1}, 124.265950, 0.000010, 0.075000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, -1, -1}, 301.733960, 0.000020, 0.041000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 0, -1}, 303.123840, 0.000040, 0.089000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 1, 0, 0}, 206.606430, 0.000160, 0.069000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -1, -1}, 119.505670, 0.000030, 3.649000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -1, 1}, 121.733920, 0.000090, 0.037000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, -1}, 122.637810, 0.001160, 0.074000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, 1}, 302.283130, 0.000010, 0.025000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 1, -1}, 122.635440, 0.000060, 0.037000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 1, 0, 0}, 241.335750, 0.000110, 0.066000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, -1, -1}, 151.124320, 0.000040, 1.241000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, -1, 1}, 151.222400, 0.000060, 0.036000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 0, -1}, 151.497050, 0.000270, 0.071000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 0, 1}, 331.386450, 0.000020, 0.024000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 1, -1}, 151.489930, 0.000020, 0.037000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 0, -1}, 177.985940, 0.000010, 0.099000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 0, 1}, 177.985940, 0.000010, 0.060000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 1, 0, 0}, 283.884300, 0.000060, 0.064000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -1, -1}, 180.072570, 0.000030, 0.748000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -1, 1}, 180.072570, 0.000030, 0.035000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 0, -1}, 180.417660, 0.000100, 0.069000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 0, 1}, 0.416270, 0.000010, 0.024000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 1, 0, 0}, 309.351990, 0.000040, 0.062000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, 0, -1}, 29.841110, 0.000020, 0.066000},
	{{0, 0, 8, -19, 0, 0, 0, 0, -2, 0, 1}, 208.123270, 0.000010, 0.075000},
	{{0, 0, 8, -19, 0, 0, 0, 0, -2, 0, 3}, 28.123270, 0.000010, 0.074000},
	{{0, 0, 8, -17, 0, 0, 0, 0, -1, 0, 0}, 354.861580, 0.000080, 0.075000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 0, 1}, 252.680440, 0.000030, 0.028000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 1, -1}, 252.680440, 0.000010, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 1, 1}, 252.680440, 0.000040, 0.044000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 2, -1}, 252.680440, 0.000010, 0.027000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -1, -1}, 252.680440, 0.000060, 0.019000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -1, 1}, 252.680440, 0.000140, 0.041000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 0, -1}, 252.680440, 0.000430, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 0, 1}, 252.680440, 0.002280, 0.088000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 1, -1}, 252.680440, 0.000740, 0.040000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 1, 1}, 252.680440, 0.000640, 0.515000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 2, -1}, 72.680440, 0.000010, 0.086000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 2, 1}, 252.680440, 0.000070, 0.066000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -2, -1}, 72.680440, 0.000030, 0.025000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -1, -1}, 72.680440, 0.000090, 0.037000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -1, 1}, 72.680440, 0.000070, 5.996000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 0, -1}, 72.680440, 0.000130, 0.075000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 0, 1}, 72.680440, 0.000130, 0.075000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 1, -1}, 72.680440, 0.000070, 5.997000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 1, 1}, 72.680440, 0.000090, 0.037000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 2, 1}, 72.680440, 0.000030, 0.025000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -2, -1}, 252.680440, 0.000070, 0.066000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -2, 1}, 72.680440, 0.000010, 0.086000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -1, -1}, 252.680440, 0.000640, 0.515000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -1, 1}, 252.680440, 0.000740, 0.040000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 0, -1}, 252.680440, 0.002280, 0.088000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 0, 1}, 252.680440, 0.000430, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 1, -1}, 252.680440, 0.000140, 0.041000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 1, 1}, 252.680440, 0.000060, 0.019000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, -2, 1}, 252.680440, 0.000010, 0.027000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, -1, -1}, 252.680440, 0.000040, 0.044000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, -1, 1}, 252.680440, 0.000010, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, 0, -1}, 252.680440, 0.000030, 0.028000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, -1, -1}, 156.854540, 0.000020, 0.019000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, -1, 1}, 156.826740, 0.000040, 0.041000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, -1}, 156.619610, 0.000140, 0.026000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, 1}, 156.644350, 0.000690, 0.089000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 1, -1}, 157.352570, 0.000180, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 1, 1}, 157.339760, 0.000160, 0.509000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -2, -1}, 154.163770, 0.000030, 0.025000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -2, 1}, 153.440890, 0.000010, 0.077000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, -1}, 154.027350, 0.000250, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, 1}, 153.758280, 0.000220, 5.222000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, -1}, 156.783020, 0.000220, 0.075000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, 1}, 156.764910, 0.000220, 0.074000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, -1}, 153.713820, 0.000220, 7.041000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, 1}, 153.984440, 0.000240, 0.037000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 2, -1}, 153.447100, 0.000010, 0.076000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 2, 1}, 154.164530, 0.000030, 0.025000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -1, -1}, 157.207320, 0.000150, 0.522000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -1, 1}, 157.218690, 0.000180, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, -1}, 156.494980, 0.000670, 0.088000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, 1}, 156.478160, 0.000140, 0.026000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 1, -1}, 156.664460, 0.000040, 0.041000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 1, 1}, 156.692750, 0.000020, 0.019000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 0, -1}, 184.334930, 0.000010, 0.078000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 0, 1}, 184.334930, 0.000010, 0.072000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 1, 0, 0}, 266.736510, 0.000030, 0.077000},
	{{0, 0, 8, -13, 0, -1, 0, 0, 1, 0, -2}, 191.194710, 0.000020, 0.075000},
	{{0, 0, 8, -13, 0, -1, 0, 0, 1, 0, 0}, 220.333190, 0.000030, 0.075000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 0, -1}, 41.649840, 0.000020, 0.027000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 0, 1}, 41.739680, 0.000060, 0.098000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, 0, -1}, 38.608940, 0.000010, 0.081000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, 0, 1}, 38.608940, 0.000010, 0.069000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 1, 0, -2}, 111.852630, 0.000010, 0.075000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 1, 0, 0}, 113.381730, 0.000240, 0.074000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 1, 0, 0}, 145.603830, 0.000120, 0.071000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -1, -1}, 244.181600, 0.000060, 3.115000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -1, 1}, 244.181740, 0.000060, 0.038000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, 0, -1}, 243.035670, 0.000060, 0.077000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, 0, -1}, 276.039270, 0.000040, 0.089000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, 0, 1}, 86.948180, 0.000010, 0.064000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 1, 0, 0}, 175.955720, 0.000110, 0.069000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, -1}, 275.379460, 0.000030, 4.746000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, 1}, 92.850990, 0.000050, 0.037000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, -3}, 91.399860, 0.000030, 0.075000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, -1}, 93.689830, 0.001520, 0.074000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 1, -1}, 93.694170, 0.000080, 0.037000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 1, 0, 0}, 207.572600, 0.000100, 0.066000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -1, -1}, 122.398710, 0.000040, 1.347000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -1, 1}, 122.398710, 0.000040, 0.036000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, -1}, 122.443350, 0.000200, 0.071000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, 1}, 302.410140, 0.000010, 0.024000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 1, 0, 0}, 242.902130, 0.000070, 0.064000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -1, -1}, 151.381630, 0.000030, 0.785000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -1, 1}, 151.381690, 0.000030, 0.036000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, -1}, 151.411610, 0.000130, 0.069000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, 1}, 331.140740, 0.000010, 0.024000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 1, 0, 0}, 284.293590, 0.000040, 0.062000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, 0, -1}, 180.063900, 0.000070, 0.066000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, 0, 1}, 180.063810, 0.000010, 0.024000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 1, 0, 0}, 308.788180, 0.000030, 0.060000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, 0, -1}, 30.574600, 0.000020, 0.064000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, 0, -1}, 174.224180, 0.000010, 0.069000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, 0, 1}, 174.224180, 0.000010, 0.081000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 2, 0, -1}, 174.224220, 0.000030, 0.097000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 0, -1}, 127.720020, 0.000020, 0.026000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 0, 1}, 127.720060, 0.000090, 0.088000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 1, -1}, 127.705570, 0.000020, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 1, 1}, 127.705570, 0.000020, 0.526000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -1, -1}, 125.742730, 0.000040, 0.037000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -1, 1}, 125.040590, 0.000040, 7.805000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 0, -1}, 131.681330, 0.000040, 0.074000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 0, 1}, 131.681330, 0.000040, 0.075000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 1, -1}, 125.040590, 0.000040, 4.869000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 1, 1}, 125.742730, 0.000040, 0.038000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -1, -1}, 128.043980, 0.000030, 0.505000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -1, 1}, 128.043990, 0.000030, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 0, -1}, 128.034770, 0.000090, 0.089000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 0, 1}, 128.034770, 0.000020, 0.026000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 0, -1}, 149.743510, 0.000040, 0.027000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 0, 1}, 149.743510, 0.000150, 0.097000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 1, -1}, 149.743510, 0.000050, 0.042000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 1, 1}, 149.743510, 0.000050, 0.340000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, -1, -1}, 149.743510, 0.000010, 0.039000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, -1, 1}, 149.743510, 0.000010, 0.857000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 0, -1}, 149.743510, 0.000020, 0.081000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 0, 1}, 149.743510, 0.000020, 0.069000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 1, -1}, 149.743510, 0.000010, 1.200000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 1, 1}, 149.743510, 0.000010, 0.036000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 2, 0, -1}, 329.743510, 0.000020, 0.081000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 0, -1}, 21.125070, 0.000030, 0.027000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 0, 1}, 21.872000, 0.000110, 0.097000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 1, -1}, 21.270290, 0.000040, 0.042000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 1, 1}, 21.272070, 0.000040, 0.337000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, -1, -1}, 13.844560, 0.000030, 0.039000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, -1, 1}, 14.415680, 0.000010, 0.839000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 0, -1}, 18.396010, 0.000040, 0.081000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 0, 1}, 18.399110, 0.000040, 0.069000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 1, -1}, 14.415680, 0.000010, 1.166000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 1, 1}, 13.844560, 0.000030, 0.036000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, -1, 0}, 267.679030, 0.000050, 7.261000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, 0}, 87.677990, 0.000920, 0.075000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 1, 0}, 87.677990, 0.000050, 0.038000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 2, 0, -1}, 359.677740, 0.000020, 0.081000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 1, 0, 0}, 116.235870, 0.000070, 0.072000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, -1, -1}, 215.887090, 0.000020, 2.602000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, -1, 1}, 215.887090, 0.000020, 0.038000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, 0, -1}, 215.536600, 0.000020, 0.078000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 0, -1}, 64.591880, 0.000060, 0.088000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 1, 0, 0}, 146.118020, 0.000070, 0.069000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, -1}, 64.419470, 0.000120, 6.788000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, 1}, 63.923270, 0.000030, 0.037000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, -3}, 50.697620, 0.000020, 0.074000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, -1}, 244.587400, 0.001630, 0.075000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 1, -1}, 244.592120, 0.000090, 0.038000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 4, -1, -1}, 244.592910, 0.000020, 0.040000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 1, 0, 0}, 176.572490, 0.000070, 0.067000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -1, -1}, 93.426880, 0.000020, 1.473000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -1, 1}, 93.426880, 0.000020, 0.036000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 0, -1}, 93.432550, 0.000130, 0.072000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 1, 0, 0}, 208.566030, 0.000060, 0.064000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, -1, -1}, 122.364830, 0.000020, 0.826000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, -1, 1}, 122.364830, 0.000020, 0.036000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 0, -1}, 122.420250, 0.000100, 0.069000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 0, 1}, 301.999170, 0.000010, 0.024000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 1, 0, 0}, 244.373190, 0.000040, 0.062000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -1, -1}, 151.204050, 0.000020, 0.574000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -1, 1}, 151.204050, 0.000020, 0.035000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, 0, -1}, 151.110340, 0.000070, 0.067000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, 0, 1}, 331.951150, 0.000010, 0.024000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 1, 0, 0}, 284.518040, 0.000020, 0.060000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 2, 0, -1}, 179.471040, 0.000030, 0.064000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 4, 0, -5}, 190.061540, 0.000040, 0.075000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 4, 0, -3}, 190.061540, 0.000040, 0.075000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 1, 0, 0}, 308.002190, 0.000020, 0.058000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, 0, -1}, 98.020060, 0.000010, 0.074000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, 0, 1}, 98.020060, 0.000010, 0.075000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, -1, -1}, 71.287350, 0.000010, 0.019000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, -1, 1}, 71.287350, 0.000020, 0.041000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 0, -1}, 71.287350, 0.000070, 0.026000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 0, 1}, 71.287350, 0.000450, 0.088000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 1, -1}, 71.287350, 0.000150, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 1, 1}, 71.287350, 0.000120, 0.515000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, -1, -1}, 251.287200, 0.000010, 0.037000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, 1, 1}, 251.287420, 0.000010, 0.037000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -1, -1}, 71.287270, 0.000120, 0.515000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -1, 1}, 71.287270, 0.000150, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 0, -1}, 71.287270, 0.000450, 0.088000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 0, 1}, 71.287270, 0.000070, 0.026000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 1, -1}, 71.287270, 0.000020, 0.041000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 1, 1}, 71.287270, 0.000010, 0.019000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 1, 0, 0}, 238.126390, 0.000210, 0.075000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 1, 0, 0}, 87.104810, 0.000040, 0.072000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 1, 0, 0}, 116.631730, 0.000040, 0.069000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -1, -1}, 32.383060, 0.000020, 11.910000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -1, 1}, 32.383030, 0.000020, 0.037000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, 0, -1}, 215.491350, 0.000180, 0.075000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 1, 0, 0}, 146.546020, 0.000040, 0.067000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, 0, -1}, 64.439230, 0.000080, 0.072000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 1, 0, 0}, 177.215900, 0.000050, 0.065000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, 0, -1}, 93.383540, 0.000070, 0.069000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 1, 0, 0}, 209.571060, 0.000040, 0.063000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, -1, -1}, 122.619400, 0.000020, 0.596000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, -1, 1}, 122.619400, 0.000020, 0.035000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, 0, -1}, 122.279510, 0.000060, 0.067000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 1, 0, 0}, 245.725760, 0.000030, 0.061000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, 0, -1}, 150.996770, 0.000040, 0.065000},
	{{0, 0, 11, -21, 2, 0, 0, 0, -2, 0, 1}, 128.400610, 0.000020, 0.088000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 2, 0, -1}, 128.369400, 0.000020, 0.088000},
	{{0, 0, 11, -19, 0, 0, 0, 0, 1, 0, 0}, 208.846210, 0.000030, 0.075000},
	{{0, 0, 11, -19, 0, 3, 0, 0, -2, 0, 1}, 328.350410, 0.000030, 0.097000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, 0, -1}, 328.350440, 0.000010, 0.080000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, 0, 1}, 328.350440, 0.000010, 0.069000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 1, 0, 0}, 57.958100, 0.000020, 0.072000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 2, 0, -1}, 186.534680, 0.000050, 0.075000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 1, 0, 0}, 116.945880, 0.000020, 0.067000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, 0, -1}, 35.458030, 0.000040, 0.072000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 1, 0, 0}, 146.993910, 0.000030, 0.065000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 2, 0, -1}, 64.394380, 0.000040, 0.070000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 1, 0, 0}, 177.878950, 0.000030, 0.063000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, 0, -1}, 93.308610, 0.000040, 0.067000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 1, 0, 0}, 210.573130, 0.000030, 0.061000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, 0, -1}, 122.136770, 0.000030, 0.065000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 1, 0, 0}, 246.944650, 0.000020, 0.059000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, 0, -1}, 150.679080, 0.000040, 0.063000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, 0, -1}, 6.487070, 0.000020, 0.073000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 1, 0, 0}, 117.275280, 0.000020, 0.065000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, 0, -1}, 35.412500, 0.000020, 0.070000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 1, 0, 0}, 147.457430, 0.000020, 0.063000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, 0, -1}, 64.331780, 0.000020, 0.068000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 1, 0, 0}, 178.555040, 0.000020, 0.061000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, 0, -1}, 93.204700, 0.000030, 0.065000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 1, 0, 0}, 211.558780, 0.000020, 0.059000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, 0, -1}, 121.946750, 0.000040, 0.063000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 2, 0, -1}, 150.254210, 0.000020, 0.061000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 2, 0, -1}, 64.248430, 0.000020, 0.065000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, 0, -1}, 121.703930, 0.000020, 0.061000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 0, -2, 1}, 98.664130, 0.000010, 0.088000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -3, -1}, 98.140170, 0.000020, 0.037000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, -1}, 98.496150, 0.000160, 0.074000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, 1}, 98.496150, 0.000160, 0.075000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -1, -1}, 98.692300, 0.000060, 5.899000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -1, 1}, 98.649450, 0.000080, 0.037000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 4, -2, -1}, 98.664130, 0.000010, 0.088000},
	{{0, 0, 17, -28, 0, 0, 0, 0, 2, 0, -1}, 220.608900, 0.000020, 0.074000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 1, -1}, 327.067010, 0.000070, 0.075000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 1, 1}, 327.067010, 0.000070, 0.074000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 1, -1}, 28.796190, 0.000020, 0.075000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 1, 1}, 28.796190, 0.000020, 0.074000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 1, -1}, 305.758940, 0.000020, 0.074000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 1, 1}, 305.758940, 0.000020, 0.075000},
	{{0, 1, -6, 0, 1, 0, 0, 0, -2, 0, 1}, 230.469310, 0.000010, 0.064000},
	{{0, 1, -6, 0, 1, 0, 0, 0, -2, 0, 3}, 50.469310, 0.000010, 0.089000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 191.774770, 0.000010, 0.073000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 3}, 191.774770, 0.000010, 0.076000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 237.792780, 0.000130, 0.068000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 60.607680, 0.000100, 0.100000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -3, 0, 0}, 165.507500, 0.000020, 0.026000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -3, 1, 0}, 165.507300, 0.000030, 0.040000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 334.489670, 0.000050, 0.079000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 1, -1}, 337.678690, 0.000040, 0.038000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 1, 1}, 337.676300, 0.000040, 1.766000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 165.507020, 0.000170, 0.037000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 165.490940, 0.003080, 0.073000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 2}, 170.273250, 0.000030, 0.076000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, 0}, 345.506810, 0.000170, 2.051000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 159.827040, 0.000030, 0.036000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 163.531350, 0.000010, 0.828000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 148.041290, 0.000030, 0.068000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 148.041290, 0.000030, 0.083000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 163.531350, 0.000010, 0.649000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 1, 1}, 159.827040, 0.000030, 0.040000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 169.594640, 0.000040, 0.442000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 346.827530, 0.000870, 0.091000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 346.769010, 0.000040, 0.041000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 155.664940, 0.000020, 0.101000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 0, 1}, 155.667310, 0.000020, 0.027000},
	{{0, 1, -3, 0, 1, 0, 0, 0, -1, 0, 0}, 245.434080, 0.000020, 0.073000},
	{{0, 1, -3, 0, 1, 0, 0, 0, -1, 0, 2}, 65.434080, 0.000020, 0.076000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -3, 0, 0}, 256.612170, 0.000040, 0.027000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -3, 1, 0}, 256.612090, 0.000070, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, -1, 1}, 122.897860, 0.000020, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, -1}, 124.396360, 0.000060, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 122.530140, 0.000510, 0.086000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 1, -1}, 207.635080, 0.000060, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 1, 1}, 234.827960, 0.000060, 0.638000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -2, 0}, 256.611980, 0.000020, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, 0}, 256.612460, 0.000390, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, 2}, 256.070910, 0.000010, 1.182000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 256.609190, 0.006490, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 2}, 260.382090, 0.000040, 0.071000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, -2}, 76.621360, 0.000030, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, 0}, 76.622340, 0.000560, 1.951000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, 0}, 76.622820, 0.000110, 0.073000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -2, -1}, 106.948470, 0.000050, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, -1}, 107.477200, 0.000430, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 256.619930, 0.000110, 0.073000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 1}, 108.267950, 0.000360, 4.814000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, -3}, 90.341000, 0.000010, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 103.324360, 0.000390, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 103.126210, 0.000340, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, -1}, 107.791870, 0.000360, 1.848000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 76.621540, 0.000040, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 1}, 107.223850, 0.000410, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 2, -1}, 107.384330, 0.000020, 0.079000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 2, 1}, 106.676240, 0.000050, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -2, 0}, 76.675620, 0.000070, 0.069000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 76.669300, 0.000650, 0.793000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 2}, 76.447270, 0.000020, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, -2}, 256.805370, 0.000060, 0.067000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 256.662000, 0.007530, 0.083000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 2}, 83.954090, 0.000010, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 1, 0}, 256.677610, 0.000460, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 2, 0}, 256.671480, 0.000020, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -1, -1}, 221.168380, 0.000070, 0.432000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -1, 1}, 215.410310, 0.000060, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 234.657400, 0.000290, 0.091000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, 1}, 220.603440, 0.000050, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 1, 1}, 253.812840, 0.000010, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 3, -1, 0}, 256.671490, 0.000080, 0.043000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 3, 0, -2}, 76.680320, 0.000010, 0.101000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 3, 0, 0}, 256.670630, 0.000060, 0.027000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 1, 0, -2}, 76.961640, 0.000020, 0.072000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 1, 0, 0}, 256.961640, 0.000020, 0.077000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 0, -1}, 179.989990, 0.000100, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 0, 1}, 179.986890, 0.000250, 0.028000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 1, -1}, 179.989300, 0.000240, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 1, 1}, 179.985600, 0.000390, 0.045000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 2, -1}, 179.976640, 0.000140, 0.028000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 2, 1}, 179.956840, 0.000030, 0.112000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 0, -1}, 179.974140, 0.000010, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 0, 1}, 179.974210, 0.000010, 0.043000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -2, -1}, 179.998280, 0.000110, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -2, 1}, 179.994090, 0.000140, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -1, -1}, 179.989810, 0.000740, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -1, 1}, 179.989950, 0.001300, 0.042000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, -1}, 179.986230, 0.004890, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 1}, 179.985250, 0.020080, 0.094000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 3}, 179.978270, 0.000060, 0.062000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, -1}, 179.982230, 0.005750, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, 1}, 179.982460, 0.004750, 0.390000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 2, 1}, 179.982780, 0.000390, 0.063000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 3, 1}, 179.969350, 0.000040, 0.034000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, -1, -1}, 0.019610, 0.000010, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 0.007960, 0.000300, 0.040000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 168.236170, 0.000110, 0.085000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 0.007010, 0.000260, 0.596000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 1, -1}, 359.998400, 0.000020, 0.084000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 1, 1}, 359.998400, 0.000020, 0.067000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -3, -1}, 180.010330, 0.000080, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -3, 1}, 180.016860, 0.000020, 0.039000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -2, -1}, 180.010280, 0.000850, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -2, 1}, 180.016060, 0.000380, 0.080000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, -1}, 180.009570, 0.007240, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 1}, 180.012180, 0.005940, 1.262000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 3}, 180.006090, 0.000010, 0.036000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, -1}, 179.987780, 0.007080, 0.078000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 1}, 179.993250, 0.008300, 0.071000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, -3}, 180.068120, 0.000020, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, -1}, 180.012820, 0.005600, 2.180000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, 1}, 180.012280, 0.006160, 0.037000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 2, -1}, 180.041290, 0.000320, 0.073000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 2, 1}, 180.016270, 0.000740, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 3, -1}, 180.022460, 0.000020, 0.037000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 3, 1}, 180.017810, 0.000070, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -2, -1}, 180.070080, 0.000020, 0.037000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 180.013230, 0.000050, 0.073000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, 0}, 206.368910, 0.000050, 3.824000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, 1}, 179.999340, 0.000020, 0.076000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 180.020510, 0.000540, 2.335000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 26.153150, 0.000940, 0.077000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 180.020610, 0.000540, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 2}, 191.860020, 0.000010, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, -1}, 180.021510, 0.000030, 0.078000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, 0}, 26.368940, 0.000050, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, 1}, 180.021510, 0.000060, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -3, -1}, 359.730740, 0.000010, 0.036000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -2, -1}, 359.980240, 0.000080, 0.069000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, -1}, 179.844100, 0.000290, 0.760000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, 1}, 179.946270, 0.000660, 0.039000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, -3}, 179.026500, 0.000020, 0.067000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 180.018930, 0.008120, 0.084000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, 1}, 179.982070, 0.001140, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 1, -1}, 180.019470, 0.000640, 0.040000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 1, 1}, 180.000000, 0.000250, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 2, -1}, 180.040420, 0.000030, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 2, 1}, 180.043610, 0.000030, 0.015000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 3, -1, 1}, 180.019610, 0.000010, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -2, 1}, 179.834420, 0.000010, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -1, -1}, 180.003360, 0.000070, 0.043000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -1, 1}, 179.973990, 0.000030, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, 0, -3}, 180.073950, 0.000020, 0.102000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, 0, -1}, 180.006410, 0.000080, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, 0, 1}, 179.995040, 0.000030, 0.016000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 1, 0, -2}, 102.706980, 0.000020, 0.073000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 1, 0, 0}, 282.706980, 0.000020, 0.076000},
	{{0, 1, 0, 0, -2, 0, 0, 0, 1, 0, -2}, 275.315410, 0.000030, 0.077000},
	{{0, 1, 0, 0, -2, 0, 0, 0, 1, 0, 0}, 95.315410, 0.000030, 0.072000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 0, 1}, 77.657750, 0.000020, 0.029000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 1, -1}, 77.390070, 0.000020, 0.021000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 0, 0}, 283.320410, 0.000040, 0.028000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 1, 0}, 283.336170, 0.000060, 0.045000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -1, -1}, 76.922450, 0.000070, 0.020000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -1, 1}, 77.209260, 0.000070, 0.044000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, -1}, 77.087690, 0.000450, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 1}, 77.046790, 0.001350, 0.103000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 1, -1}, 77.175990, 0.000380, 0.043000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 1, 1}, 76.888780, 0.000320, 0.280000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 2, 1}, 76.032090, 0.000040, 0.059000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -2, 0}, 283.336170, 0.000020, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -1, 0}, 283.333200, 0.000430, 0.042000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, -2}, 103.336520, 0.000020, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 283.336560, 0.007440, 0.093000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 2}, 283.431230, 0.000050, 0.062000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 1, 0}, 103.330260, 0.000370, 0.398000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 2, 0}, 98.738340, 0.000020, 0.063000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -2, -1}, 78.261640, 0.000020, 0.026000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -1, -1}, 81.653420, 0.000310, 0.040000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 1}, 81.351610, 0.000270, 0.558000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -3}, 264.396950, 0.000020, 0.026000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1}, 81.590780, 0.000140, 0.085000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 83.487460, 0.000140, 0.066000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 1, -1}, 81.180040, 0.000090, 0.686000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1}, 83.108760, 0.000080, 0.035000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 283.331010, 0.000170, 0.080000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, -2}, 103.334340, 0.000070, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 283.340420, 0.001170, 1.354000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 2}, 283.338160, 0.000040, 0.036000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, -2}, 103.331770, 0.000260, 0.078000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 103.337790, 0.027360, 0.071000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 2}, 283.325810, 0.000010, 0.024000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 1, -2}, 103.336180, 0.000050, 2.469000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 103.338500, 0.001530, 0.037000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0}, 103.337850, 0.000090, 0.025000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -2, -1}, 265.354310, 0.000060, 0.074000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -2, 1}, 265.327850, 0.000060, 0.075000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, -1}, 270.143320, 0.000360, 3.172000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 103.337460, 0.000060, 0.076000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, 1}, 270.365320, 0.000350, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 292.451480, 0.000120, 0.077000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 1}, 278.458240, 0.000040, 0.025000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, -1, 0}, 103.337730, 0.000300, 0.039000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, 0, -2}, 103.334950, 0.000020, 0.084000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 103.339870, 0.000170, 0.026000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, 1, 0}, 103.337850, 0.000020, 0.019000},
	{{0, 1, 1, -3, 0, 0, 0, 0, 1, 0, 0}, 240.883120, 0.000030, 0.075000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 0, -1}, 359.528200, 0.000040, 0.028000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 0, 1}, 356.833220, 0.000090, 0.115000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 1, -1}, 357.169130, 0.000020, 0.045000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 1, 1}, 357.169130, 0.000020, 0.219000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, -1, 0}, 189.438120, 0.000020, 0.043000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 188.763070, 0.000470, 0.103000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 1, 0}, 9.709340, 0.000040, 0.285000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, -1, -1}, 19.411580, 0.000020, 0.042000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, -1, 1}, 16.305350, 0.000010, 0.358000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 17.763940, 0.000050, 0.093000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 17.736570, 0.000050, 0.062000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 1, -1}, 16.305350, 0.000010, 0.407000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1}, 19.411580, 0.000020, 0.034000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, -1, 0}, 192.120600, 0.000030, 0.575000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 12.079390, 0.000500, 0.067000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0}, 12.119270, 0.000030, 0.035000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -1, -1}, 24.142340, 0.000030, 1.460000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -1, 1}, 24.139070, 0.000030, 0.036000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, 0, -1}, 26.277790, 0.000100, 0.072000},
	{{0, 1, 2, 0, 0, 0, 0, 0, -1, 0, 0}, 122.430200, 0.000060, 0.114000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 1, 0, 0}, 305.050260, 0.000080, 0.063000},
	{{0, 1, 43, -59, 0, 0, 0, 0, 0, -1, -1}, 97.328560, 0.000010, 0.075000},
	{{0, 1, 43, -59, 0, 0, 0, 0, 0, -1, 1}, 97.328560, 0.000010, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -4, 2, 1}, 295.930280, 0.000010, 0.088000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 1, -1}, 300.916420, 0.000020, 0.037000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 2, -1}, 300.400650, 0.000190, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 2, 1}, 300.400650, 0.000190, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 3, 1}, 300.916420, 0.000020, 0.037000},
	{{0, 2, -13, 15, 0, 0, 0, 0, 0, 2, -1}, 295.930280, 0.000010, 0.088000},
	{{0, 2, -7, 0, 1, 0, 0, 0, -2, 0, 1}, 230.468020, 0.000010, 0.067000},
	{{0, 2, -7, 0, 1, 0, 0, 0, -2, 0, 3}, 50.468020, 0.000010, 0.084000},
	{{0, 2, -6, 0, -1, 0, 0, 0, -2, 0, 1}, 240.481430, 0.000010, 0.071000},
	{{0, 2, -6, 0, -1, 0, 0, 0, -2, 0, 3}, 60.481430, 0.000010, 0.079000},
	{{0, 2, -6, 0, 1, 0, 0, 0, -2, 0, 1}, 38.690760, 0.000020, 0.072000},
	{{0, 2, -6, 0, 1, 0, 0, 0, -2, 0, 3}, 218.690760, 0.000020, 0.078000},
	{{0, 2, -5, 0, -1, 0, 0, 0, -2, 0, 1}, 55.789120, 0.000020, 0.076000},
	{{0, 2, -5, 0, -1, 0, 0, 0, -2, 0, 3}, 235.789120, 0.000020, 0.073000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 1, -1}, 67.589130, 0.000090, 0.038000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 1, 1}, 67.591420, 0.000090, 5.213000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 2, -1}, 68.360400, 0.000030, 0.075000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 2, 1}, 68.360400, 0.000030, 0.074000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 235.974600, 0.000230, 0.071000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, 1, 1}, 247.588740, 0.000020, 0.040000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 60.432540, 0.000120, 0.094000},
	{{0, 2, -4, 0, -3, 0, 0, 0, -1, 0, 0}, 280.301850, 0.000050, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 199.014050, 0.000090, 0.083000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 1, -1}, 350.174520, 0.000020, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 1, 1}, 350.176270, 0.000020, 0.839000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 353.990360, 0.000030, 0.038000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 158.339570, 0.000020, 0.038000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 354.184380, 0.000450, 0.076000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 158.337450, 0.000020, 3.281000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, -2}, 352.643390, 0.000030, 0.037000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 2, 0}, 352.600040, 0.000080, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -1, -1}, 139.644390, 0.000040, 0.036000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -1, 1}, 132.494690, 0.000020, 1.718000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 137.303960, 0.000050, 0.071000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 136.237330, 0.000050, 0.079000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 1, -1}, 48.615380, 0.000030, 1.092000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 1, 1}, 84.772150, 0.000040, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 169.594890, 0.000050, 0.611000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, -1, 2}, 349.234570, 0.000010, 0.040000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 349.740700, 0.000650, 0.086000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 349.737250, 0.000030, 0.040000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -1, -1}, 21.343040, 0.000090, 0.372000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -1, 1}, 20.081850, 0.000120, 0.041000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 17.072850, 0.000430, 0.095000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, 1}, 18.940050, 0.000090, 0.027000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 1, 1}, 19.698520, 0.000010, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -6, 2, -1}, 91.822390, 0.000010, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, -1, -1}, 271.816240, 0.000010, 0.013000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 0, -1}, 271.038700, 0.000050, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 0, 1}, 271.149820, 0.000110, 0.028000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 1, -1}, 271.058590, 0.000090, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 1, 1}, 271.435890, 0.000170, 0.044000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 2, -1}, 271.110930, 0.000070, 0.028000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 2, 1}, 270.990080, 0.000020, 0.108000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 0, 0}, 256.702950, 0.000020, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 1, 0}, 256.702950, 0.000030, 0.042000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -2, -1}, 271.101300, 0.000040, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -2, 1}, 271.450620, 0.000050, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, -1}, 271.117170, 0.000330, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, 1}, 270.770630, 0.000610, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 271.364670, 0.002100, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 271.401790, 0.009860, 0.090000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 3}, 271.855760, 0.000030, 0.063000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, -1}, 271.507620, 0.002720, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 1}, 271.445490, 0.002220, 0.456000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 2, -1}, 93.706590, 0.000040, 0.088000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 2, 1}, 272.017820, 0.000180, 0.065000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 3, 1}, 270.526390, 0.000020, 0.035000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 256.713810, 0.000150, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 90.909800, 0.000070, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 256.725650, 0.002490, 0.083000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 90.910760, 0.000060, 0.766000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 2}, 256.898940, 0.000020, 0.068000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, 0}, 76.652880, 0.000370, 0.879000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 2, 0}, 76.678100, 0.000040, 0.069000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -3, -1}, 268.702030, 0.000030, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -2, -1}, 268.714780, 0.000340, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -2, 1}, 268.610580, 0.000160, 0.078000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 268.890560, 0.002880, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 77.800120, 0.000050, 0.077000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 268.330110, 0.002370, 2.394000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 257.339280, 0.000040, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 271.419790, 0.003300, 0.076000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 257.339230, 0.000040, 3.983000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 271.299330, 0.003500, 0.073000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 268.430610, 0.002340, 11.864000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 256.576510, 0.000260, 0.074000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 1}, 268.792560, 0.002700, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, -1}, 268.484530, 0.000150, 0.075000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, 1}, 268.931900, 0.000300, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 3, 1}, 268.575400, 0.000030, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, 0}, 76.706070, 0.000170, 0.072000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, -2}, 256.574420, 0.000030, 0.036000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 76.581130, 0.000960, 1.572000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, 2}, 76.588850, 0.000040, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, -2}, 256.559800, 0.000120, 0.070000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 256.572520, 0.013880, 0.079000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 2}, 78.556090, 0.000010, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 256.578740, 0.000820, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 2, 0}, 256.574900, 0.000040, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -2, -1}, 272.729910, 0.000070, 0.067000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -2, 1}, 89.433910, 0.000030, 0.084000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, -1}, 271.241910, 0.001220, 0.592000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, 1}, 270.969400, 0.001520, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -3}, 270.010930, 0.000020, 0.065000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 270.038870, 0.006350, 0.086000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, 1}, 270.086040, 0.001120, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, -1}, 269.888230, 0.000470, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, 1}, 270.102680, 0.000200, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 2, 1}, 270.470810, 0.000010, 0.015000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, -1, 0}, 256.574900, 0.000140, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, 0, 0}, 256.587520, 0.000110, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -2, 1}, 270.667360, 0.000030, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -1, -1}, 270.733600, 0.000120, 0.043000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -1, 1}, 270.887060, 0.000050, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 0, -1}, 270.751590, 0.000090, 0.028000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 0, 1}, 271.980090, 0.000020, 0.016000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 0, -1}, 359.362370, 0.000010, 0.076000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 0, 1}, 359.362370, 0.000010, 0.073000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 2, -3}, 178.465200, 0.000030, 0.075000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 2, -1}, 358.465200, 0.000030, 0.074000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 2, 0, -3}, 178.720300, 0.000010, 0.066000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 2, 0, -1}, 358.720300, 0.000010, 0.086000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 1, 0, -2}, 268.613550, 0.000030, 0.071000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 1, 0, 0}, 88.613550, 0.000030, 0.078000},
	{{0, 2, -2, -1, 0, 0, 0, 0, 1, -2, 0}, 166.282350, 0.000010, 0.074000},
	{{0, 2, -2, -1, 0, 0, 0, 0, 1, -2, 2}, 166.282350, 0.000010, 0.075000},
	{{0, 2, -2, 0, -3, 0, 0, 0, 1, 0, 0}, 100.301560, 0.000040, 0.075000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 1, 0, -2}, 257.843480, 0.000020, 0.075000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 1, 0, 0}, 77.843480, 0.000020, 0.074000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -6, 1, 1}, 0.323430, 0.000010, 0.022000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, -2, -1}, 0.365050, 0.000010, 0.011000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, -1, -1}, 359.943250, 0.000030, 0.013000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, -1, 1}, 0.194360, 0.000040, 0.021000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 0, -1}, 359.833500, 0.000120, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 0, 1}, 0.126020, 0.000290, 0.029000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 1, -1}, 0.261370, 0.000310, 0.021000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 1, 1}, 0.294660, 0.000480, 0.046000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 2, -1}, 0.328490, 0.000150, 0.028000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 2, 1}, 0.345060, 0.000020, 0.121000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, 0, -1}, 0.448030, 0.000020, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, 0, 3}, 180.415510, 0.000010, 0.227000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -2, -1}, 0.288470, 0.000110, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -2, 1}, 0.324390, 0.000110, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -1, -1}, 0.275520, 0.000900, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -1, 1}, 0.308400, 0.001260, 0.043000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, -1}, 0.388350, 0.006430, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 0.360090, 0.022540, 0.099000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 3}, 0.338190, 0.000070, 0.060000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, -1}, 0.294480, 0.006950, 0.042000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, 1}, 0.260510, 0.005870, 0.313000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, -1}, 180.707850, 0.000050, 0.096000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, 1}, 0.279960, 0.000560, 0.061000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 3, 1}, 0.254720, 0.000060, 0.034000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, -1, 0}, 4.085760, 0.000030, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 180.056610, 0.000090, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 4.034520, 0.000850, 0.090000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 180.056380, 0.000090, 0.434000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 1, 0}, 6.014120, 0.000050, 0.468000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -3, -1}, 0.360060, 0.000030, 0.019000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, -1}, 0.365900, 0.000310, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, 1}, 0.266800, 0.000130, 0.084000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, -1}, 0.507210, 0.002520, 0.039000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, 1}, 0.437260, 0.002160, 0.705000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 0.286270, 0.001410, 0.082000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 0.283110, 0.002500, 0.068000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 1, -1}, 0.202100, 0.002370, 0.922000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 1, 1}, 0.132930, 0.002450, 0.036000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 2, -1}, 0.133360, 0.000110, 0.070000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 2, 1}, 0.224520, 0.000280, 0.024000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 3, 1}, 0.205050, 0.000030, 0.018000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, -2}, 186.653100, 0.000030, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 5.812450, 0.000470, 2.747000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, -2}, 183.001770, 0.000100, 0.076000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 359.943470, 0.000070, 5.069000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 185.888100, 0.009000, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 359.943550, 0.000080, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -3}, 359.655160, 0.000010, 0.075000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -2}, 188.526760, 0.000020, 32.762000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 359.999390, 0.000170, 0.074000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, 0}, 185.960830, 0.000520, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 2, 0}, 185.894530, 0.000030, 0.025000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -3, -1}, 0.267070, 0.000040, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, -1}, 359.905100, 0.000360, 0.072000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, 1}, 179.590690, 0.000070, 0.078000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, -1}, 0.025860, 0.005040, 1.450000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, 1}, 0.016350, 0.006030, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, -3}, 359.993420, 0.000080, 0.070000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 0.000730, 0.019930, 0.080000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, 1}, 0.105300, 0.001980, 0.025000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 1, -1}, 0.024840, 0.001140, 0.039000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 1, 1}, 0.155340, 0.000300, 0.019000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 2, -1}, 359.990260, 0.000060, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 2, 1}, 0.075780, 0.000020, 0.015000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, -1, 0}, 185.894410, 0.000100, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, 0, 0}, 185.894320, 0.000060, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -2, -1}, 0.104700, 0.000040, 0.093000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -2, 1}, 0.032950, 0.000140, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -1, -1}, 359.996040, 0.000380, 0.042000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -1, 1}, 0.033910, 0.000130, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, 0, -1}, 0.010140, 0.000220, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, 0, 1}, 0.016800, 0.000030, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 6, -3, 1}, 0.019000, 0.000010, 0.020000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 2, 0, -3}, 346.943040, 0.000010, 0.070000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 2, 0, -1}, 166.943040, 0.000010, 0.079000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 2, 0, -3}, 170.199840, 0.000040, 0.074000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 2, 0, -1}, 350.199840, 0.000040, 0.075000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, 0, -3}, 349.137340, 0.000020, 0.075000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, 0, -1}, 169.137340, 0.000020, 0.074000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 0, 1}, 257.003100, 0.000050, 0.030000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 1, -1}, 257.059680, 0.000020, 0.021000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 0, 0}, 283.288520, 0.000030, 0.029000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 1, 0}, 283.219700, 0.000040, 0.046000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -1, -1}, 257.100560, 0.000100, 0.020000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -1, 1}, 257.030970, 0.000100, 0.045000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, -1}, 257.054050, 0.000630, 0.028000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 1}, 257.082450, 0.001680, 0.110000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, -1}, 257.070060, 0.000510, 0.044000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, 1}, 257.178510, 0.000450, 0.239000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 2, 1}, 257.082460, 0.000060, 0.057000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, -1, 0}, 283.252060, 0.000290, 0.043000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, -2}, 103.223130, 0.000020, 0.027000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 283.227440, 0.004970, 0.099000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, 2}, 283.211620, 0.000030, 0.060000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, 0}, 103.216140, 0.000360, 0.319000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 2, 0}, 103.309690, 0.000030, 0.061000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -2, -1}, 255.927350, 0.000020, 0.027000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -1, -1}, 256.814670, 0.000140, 0.041000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -1, 1}, 256.724080, 0.000120, 0.414000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, -1}, 83.466850, 0.000040, 0.090000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, 1}, 249.602390, 0.000080, 0.064000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 1, -1}, 254.335340, 0.000080, 0.480000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 1, 1}, 252.909270, 0.000070, 0.035000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -2, 0}, 283.315350, 0.000090, 0.084000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, -2}, 103.239140, 0.000030, 0.039000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, 0}, 283.297480, 0.000460, 0.733000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, 2}, 283.425970, 0.000020, 0.035000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, -2}, 103.034650, 0.000120, 0.082000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 103.298090, 0.013500, 0.068000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 2}, 103.298110, 0.000010, 0.024000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 1, -2}, 103.360000, 0.000020, 0.970000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 1, 0}, 103.295750, 0.000740, 0.036000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 2, 0}, 103.298760, 0.000050, 0.024000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -2, -1}, 256.486220, 0.000010, 0.077000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -2, 1}, 256.389980, 0.000010, 0.072000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -1, -1}, 238.669650, 0.000040, 3.223000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 283.337950, 0.000070, 0.073000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -1, 1}, 243.144020, 0.000090, 0.037000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 246.065750, 0.000960, 0.074000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 1, -1}, 245.759480, 0.000050, 0.037000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, -2, 0}, 283.317160, 0.000020, 0.078000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, -1, 0}, 103.298750, 0.000150, 0.038000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, 0, 0}, 103.292230, 0.000090, 0.025000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 0, -1}, 117.009350, 0.000030, 0.029000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 0, 1}, 124.921040, 0.000060, 0.124000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 1, -1}, 124.841770, 0.000010, 0.046000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 1, 1}, 124.841770, 0.000010, 0.193000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 188.423180, 0.000290, 0.110000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 0, -1}, 47.255040, 0.000030, 0.098000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 47.327050, 0.000030, 0.060000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 12.832440, 0.000290, 0.064000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -1, -1}, 31.213910, 0.000020, 0.763000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -1, 1}, 31.219730, 0.000020, 0.036000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 25.976610, 0.000060, 0.069000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, 0, 1}, 207.657040, 0.000010, 0.024000},
	{{0, 2, 1, -4, 0, 0, 0, 0, 2, 0, -1}, 104.910350, 0.000020, 0.074000},
	{{0, 2, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 123.704310, 0.000050, 0.123000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 306.217360, 0.000070, 0.060000},
	{{0, 3, -8, 0, 1, 0, 0, 0, -2, 0, 1}, 50.746510, 0.000010, 0.070000},
	{{0, 3, -8, 0, 1, 0, 0, 0, -2, 0, 3}, 230.746510, 0.000010, 0.080000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, 0, -1}, 249.811340, 0.000050, 0.097000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, 0, 1}, 249.735860, 0.000010, 0.027000},
	{{0, 3, -7, 0, -1, 0, 0, 0, -2, 0, 1}, 211.314900, 0.000010, 0.074000},
	{{0, 3, -7, 0, -1, 0, 0, 0, -2, 0, 3}, 101.313640, 0.000020, 0.075000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 0, 1}, 301.662650, 0.000040, 0.074000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 0, 3}, 264.383590, 0.000010, 0.075000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 328.854220, 0.000020, 0.069000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 148.754380, 0.000020, 0.098000},
	{{0, 3, -7, 0, 0, 0, 1, 0, -2, 0, 1}, 238.388840, 0.000010, 0.074000},
	{{0, 3, -7, 0, 0, 0, 1, 0, -2, 0, 3}, 58.388840, 0.000010, 0.075000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 0, 1}, 177.847740, 0.000050, 0.075000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 0, 3}, 357.847740, 0.000050, 0.074000},
	{{0, 3, -7, 2, 0, 0, 0, 0, -1, 0, 0}, 342.191570, 0.000030, 0.074000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, -1, -1}, 147.640870, 0.000030, 0.019000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, -1, 1}, 147.640860, 0.000060, 0.041000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 0, -1}, 147.730320, 0.000180, 0.026000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 0, 1}, 147.714990, 0.000870, 0.088000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 1, -1}, 147.314850, 0.000230, 0.040000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 1, 1}, 147.338110, 0.000200, 0.514000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 2, 1}, 147.640120, 0.000020, 0.066000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -2, -1}, 149.137060, 0.000040, 0.025000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -2, 1}, 149.735510, 0.000010, 0.076000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -1, -1}, 149.273630, 0.000280, 0.037000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -1, 1}, 149.484620, 0.000260, 5.880000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 0, -1}, 146.951990, 0.000290, 0.075000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 0, 1}, 146.952610, 0.000290, 0.074000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 1, -1}, 149.488530, 0.000260, 6.118000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 1, 1}, 149.278080, 0.000280, 0.037000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 2, -1}, 149.734530, 0.000010, 0.076000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 2, 1}, 149.136890, 0.000040, 0.025000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, -2, -1}, 147.651060, 0.000020, 0.066000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, -1, -1}, 147.347860, 0.000200, 0.516000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, -1, 1}, 147.324180, 0.000230, 0.040000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 0, -1}, 147.723840, 0.000870, 0.088000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 0, 1}, 147.738950, 0.000180, 0.026000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 1, -1}, 147.650360, 0.000060, 0.041000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 1, 1}, 147.650350, 0.000030, 0.019000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -3, 0, 0}, 239.013640, 0.000030, 0.026000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -3, 1, 0}, 239.013080, 0.000040, 0.040000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 1}, 269.739950, 0.000010, 0.080000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 3}, 269.739950, 0.000010, 0.069000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, 0}, 239.016210, 0.000240, 0.037000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, 2}, 236.577000, 0.000010, 10.300000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 239.008080, 0.004160, 0.074000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, 2}, 248.610630, 0.000060, 0.075000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, 0}, 58.998200, 0.000210, 4.230000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, 2}, 240.867540, 0.000020, 0.038000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -1, -1}, 91.690310, 0.000010, 0.036000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -1, 1}, 91.690310, 0.000010, 1.045000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 94.097900, 0.000020, 0.069000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 0, 1}, 93.470970, 0.000030, 0.081000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 1, -1}, 91.690310, 0.000010, 0.775000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 1, 1}, 91.690310, 0.000010, 0.039000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 59.012860, 0.000040, 0.497000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 59.930610, 0.000360, 0.089000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -1, -1}, 90.188410, 0.000070, 0.326000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -1, 1}, 90.188480, 0.000070, 0.042000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 89.134870, 0.000230, 0.098000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 0, 1}, 90.187170, 0.000060, 0.027000},
	{{0, 3, -6, 0, 0, 2, 0, 0, -1, 0, 0}, 309.739050, 0.000020, 0.074000},
	{{0, 3, -6, 0, 0, 2, 0, 0, -1, 0, 2}, 129.739050, 0.000020, 0.075000},
	{{0, 3, -6, 4, 0, 0, 0, 0, -2, 0, 1}, 50.343160, 0.000030, 0.097000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 0, 1}, 344.977080, 0.000030, 0.028000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 1, -1}, 345.278890, 0.000010, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 1, 1}, 344.711280, 0.000050, 0.044000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 2, -1}, 345.740670, 0.000020, 0.027000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -1, -1}, 344.883440, 0.000090, 0.019000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -1, 1}, 343.949570, 0.000200, 0.040000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, -1}, 344.340870, 0.000540, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 344.172130, 0.002950, 0.087000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 3}, 329.446880, 0.000010, 0.065000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, -1}, 346.268040, 0.000850, 0.040000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, 1}, 346.326490, 0.000730, 0.550000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 2, -1}, 165.054790, 0.000010, 0.085000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 2, 1}, 346.435950, 0.000070, 0.066000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, -1, 0}, 349.961070, 0.000030, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 350.110930, 0.000500, 0.080000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 1, 0}, 169.961080, 0.000030, 1.310000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -2, -1}, 338.118180, 0.000070, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -2, 1}, 337.520580, 0.000030, 0.076000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, -1}, 339.301320, 0.000690, 0.037000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 167.972890, 0.000060, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 1}, 337.806090, 0.000610, 23.081000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 351.294900, 0.000790, 0.074000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 351.329680, 0.000760, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, -1}, 337.798940, 0.000620, 3.446000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, 1}, 339.767760, 0.000720, 0.038000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 2, -1}, 335.744760, 0.000030, 0.077000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 2, 1}, 338.889240, 0.000080, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 167.691960, 0.000080, 0.990000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 347.073350, 0.001160, 0.082000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 347.076630, 0.000060, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -2, -1}, 347.604550, 0.000080, 0.065000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -2, 1}, 169.132230, 0.000020, 0.087000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, -1}, 346.614470, 0.000820, 0.484000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, 1}, 346.778340, 0.000990, 0.040000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, -3}, 346.676400, 0.000010, 0.064000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 346.409630, 0.003540, 0.089000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, 1}, 346.514330, 0.000710, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 1, -1}, 345.630460, 0.000230, 0.041000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 1, 1}, 345.457970, 0.000110, 0.019000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 2, 1}, 346.491730, 0.000020, 0.015000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, -2, 1}, 346.149630, 0.000020, 0.028000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, -1, -1}, 346.265690, 0.000070, 0.044000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, -1, 1}, 346.231560, 0.000020, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, 0, -1}, 346.007590, 0.000040, 0.028000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, 0, 1}, 345.346130, 0.000010, 0.016000},
	{{0, 3, -5, 0, 1, 0, 0, 0, -2, 0, 1}, 82.527180, 0.000020, 0.088000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, 0, -1}, 78.491330, 0.000020, 0.074000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, 0, 1}, 78.491330, 0.000020, 0.075000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 2, 0, -1}, 82.847230, 0.000020, 0.089000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 0, -1}, 179.007370, 0.000030, 0.026000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 0, 1}, 178.979160, 0.000130, 0.089000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 1, -1}, 178.971170, 0.000040, 0.040000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 1, 1}, 178.971170, 0.000040, 0.504000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, -1, -1}, 179.746980, 0.000060, 0.038000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, -1, 1}, 180.643760, 0.000050, 4.719000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 0, -1}, 173.040040, 0.000060, 0.075000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 0, 1}, 173.040040, 0.000060, 0.074000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 1, -1}, 180.643760, 0.000050, 8.225000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 1, 1}, 179.746980, 0.000060, 0.037000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, -1, -1}, 178.966300, 0.000040, 0.528000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, -1, 1}, 178.966300, 0.000040, 0.040000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, 0, -1}, 178.959890, 0.000120, 0.088000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, 0, 1}, 178.933920, 0.000020, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 0, -1}, 271.451780, 0.000040, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 0, 1}, 270.915830, 0.000110, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 1, -1}, 270.700210, 0.000070, 0.021000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 1, 1}, 270.658190, 0.000120, 0.046000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 2, -1}, 270.563280, 0.000050, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 0, 0}, 76.615080, 0.000030, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 1, 0}, 76.622390, 0.000030, 0.044000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -2, -1}, 270.585360, 0.000040, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, -1}, 270.651020, 0.000250, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, 1}, 270.639810, 0.000430, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, -1}, 270.636530, 0.001760, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 270.620940, 0.006830, 0.096000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 3}, 270.735300, 0.000030, 0.061000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, -1}, 270.603050, 0.001990, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, 1}, 270.605510, 0.001680, 0.355000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 2, -1}, 89.187020, 0.000020, 0.093000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 2, 1}, 270.682980, 0.000160, 0.062000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -2, 1}, 270.164730, 0.000010, 0.041000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 76.596170, 0.000210, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 270.347350, 0.000230, 0.088000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 90.350740, 0.000500, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 76.593300, 0.003570, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 90.363290, 0.000460, 0.518000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 2}, 76.617280, 0.000030, 0.065000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, 0}, 256.808190, 0.000150, 0.567000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 90.281900, 0.000080, 0.066000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 2, 0}, 256.583160, 0.000020, 0.067000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -3, -1}, 270.927690, 0.000010, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -2, -1}, 270.873680, 0.000230, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -2, 1}, 270.955330, 0.000090, 0.082000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, -1}, 271.122890, 0.001840, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 1}, 271.055240, 0.001540, 0.958000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 270.357290, 0.001380, 0.080000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 270.742340, 0.001740, 0.070000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, -1}, 270.899130, 0.001350, 1.409000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 256.501200, 0.000020, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 1}, 270.910590, 0.001430, 0.036000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 2, -1}, 270.979430, 0.000090, 0.072000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 2, 1}, 271.033820, 0.000160, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 3, 1}, 271.035020, 0.000010, 0.018000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -3, -1}, 270.114640, 0.000040, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, -1}, 270.098800, 0.000290, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 255.708570, 0.000020, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 1}, 269.327610, 0.000070, 6.397000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 270.425080, 0.002030, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 76.303210, 0.000520, 95.796000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 270.275100, 0.001780, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -2}, 255.173200, 0.000090, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 270.285130, 0.002770, 5.644000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 256.315670, 0.010180, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 270.289910, 0.003000, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 270.281930, 0.000170, 0.076000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 256.311260, 0.000550, 0.038000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, 1}, 270.290060, 0.000370, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 2, 0}, 256.310620, 0.000030, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 2, 1}, 270.281880, 0.000030, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -2, -1}, 87.408690, 0.000040, 0.070000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -2, 1}, 93.425110, 0.000020, 0.080000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, -1}, 286.157190, 0.000110, 0.940000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 78.143950, 0.000020, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, 1}, 280.114720, 0.000230, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 271.227560, 0.001900, 0.082000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, 1}, 272.616330, 0.000270, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 1, -1}, 271.140360, 0.000150, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 1, 1}, 270.658590, 0.000060, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -2, -1}, 270.660970, 0.000040, 0.513000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -2, 1}, 270.517120, 0.000080, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 270.342310, 0.000270, 0.088000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, 0}, 256.310560, 0.000110, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, 1}, 270.330040, 0.000140, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 0, -1}, 270.292630, 0.000110, 0.041000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 0, 0}, 256.310520, 0.000060, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 0, 1}, 270.300940, 0.000060, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -2, 1}, 282.967350, 0.000040, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -1, -1}, 282.872660, 0.000030, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -1, 1}, 282.918260, 0.000040, 0.020000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 1, 0, -2}, 202.559550, 0.000020, 0.074000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 1, 0, 0}, 22.559550, 0.000020, 0.075000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 1, 0, -2}, 82.495770, 0.000040, 0.074000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 1, 0, 0}, 276.045360, 0.000080, 0.075000},
	{{0, 3, -4, 0, 3, 0, 0, 0, 1, 0, -2}, 117.668530, 0.000010, 0.075000},
	{{0, 3, -4, 0, 3, 0, 0, 0, 1, 0, 0}, 297.668530, 0.000010, 0.074000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -2, -1}, 188.730960, 0.000010, 0.075000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -2, 1}, 8.730960, 0.000010, 0.074000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, 0, -3}, 186.824010, 0.000020, 0.073000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, 0, -1}, 6.824010, 0.000020, 0.076000},
	{{0, 3, -3, 0, 0, -3, 0, 0, 2, -2, -1}, 122.063660, 0.000030, 0.075000},
	{{0, 3, -3, 0, 0, -3, 0, 0, 2, -2, 1}, 122.063660, 0.000030, 0.074000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 0, -1}, 357.830550, 0.000010, 0.016000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 0, 1}, 1.534450, 0.000050, 0.029000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 1, -1}, 2.676270, 0.000020, 0.021000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 1, 1}, 2.719600, 0.000020, 0.048000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -2, -1}, 0.074240, 0.000020, 0.016000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -2, 1}, 0.102630, 0.000020, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -1, -1}, 1.218130, 0.000190, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -1, 1}, 1.012930, 0.000320, 0.044000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 3.036720, 0.000770, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 3.123840, 0.001950, 0.106000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, -1}, 2.493380, 0.000640, 0.043000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, 1}, 2.390000, 0.000560, 0.262000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, 3}, 181.989230, 0.000010, 0.033000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 2, -1}, 181.923250, 0.000010, 0.102000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 2, 1}, 2.490420, 0.000070, 0.059000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 354.769460, 0.000020, 0.042000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 337.365630, 0.000010, 0.042000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 355.478820, 0.000560, 0.095000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 347.345020, 0.000020, 0.341000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -3, -1}, 0.026960, 0.000070, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -3, 1}, 0.224320, 0.000030, 0.041000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, -1}, 0.095840, 0.000680, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, 1}, 0.097240, 0.000310, 0.089000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 0.105660, 0.005330, 0.040000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 0.137930, 0.004550, 0.489000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 179.929270, 0.002070, 0.087000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 3.148780, 0.000080, 0.065000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 179.553100, 0.000790, 0.585000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, 1}, 179.157650, 0.000300, 0.035000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 2, -1}, 179.756760, 0.000060, 0.067000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 2, 1}, 178.887410, 0.000050, 0.024000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 4.433170, 0.000120, 1.011000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, -2}, 184.475970, 0.000020, 0.079000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 0.030220, 0.000090, 1.215000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 184.375760, 0.002160, 0.070000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 0.030140, 0.000090, 0.036000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 184.433170, 0.000120, 0.036000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -4, -1}, 1.463340, 0.000010, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -3, -1}, 8.481300, 0.000020, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, -3}, 179.986160, 0.000010, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, -1}, 179.508180, 0.000310, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, 1}, 0.028540, 0.002270, 0.074000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, 3}, 359.986280, 0.000010, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, -3}, 179.986740, 0.000110, 0.037000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, -1}, 179.987340, 0.030940, 15.575000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 190.487840, 0.000040, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 1}, 179.981670, 0.028620, 0.037000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 3}, 359.980950, 0.000030, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -3}, 0.042960, 0.000130, 0.073000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 0.056800, 0.042160, 0.076000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, 1}, 179.948700, 0.002890, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, -3}, 180.010420, 0.000030, 2.514000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, -1}, 0.055780, 0.002250, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, 1}, 179.939580, 0.000250, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 2, -1}, 0.050560, 0.000150, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 2, 1}, 179.904580, 0.000010, 0.015000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, -2, 1}, 180.016420, 0.000010, 0.039000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, -1, 0}, 184.433160, 0.000020, 0.039000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -3, -1}, 359.414850, 0.000050, 0.544000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -3, 1}, 359.665080, 0.000090, 0.040000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -2, -1}, 0.253780, 0.000030, 0.088000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -2, 1}, 179.978880, 0.000640, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -1, -1}, 179.913870, 0.000480, 0.041000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -1, 1}, 179.981190, 0.000480, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, 0, -1}, 0.086600, 0.000210, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, 0, 1}, 179.968210, 0.000070, 0.015000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, 1, -1}, 0.050640, 0.000030, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -3, 1}, 180.024060, 0.000010, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -2, -1}, 179.986280, 0.000020, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -2, 1}, 179.986280, 0.000020, 0.016000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 1, 0, -2}, 274.351400, 0.000010, 0.080000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 1, 0, 0}, 94.351400, 0.000010, 0.070000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, 0, -3}, 128.940410, 0.000020, 0.074000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, 0, -1}, 308.940410, 0.000020, 0.075000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -3, 1, 0}, 283.162050, 0.000030, 0.048000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, -1}, 256.086520, 0.000070, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 257.098720, 0.000190, 0.119000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 1, -1}, 256.939120, 0.000060, 0.045000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 1, 1}, 256.810900, 0.000050, 0.208000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, -1, 0}, 283.209010, 0.000170, 0.044000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, -2}, 103.158580, 0.000020, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 283.174930, 0.003260, 0.105000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, 2}, 283.143820, 0.000020, 0.058000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 1, 0}, 103.210860, 0.000280, 0.266000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -2, -1}, 256.909920, 0.000030, 0.027000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -1, -1}, 256.955770, 0.000270, 0.042000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -1, 1}, 256.939570, 0.000220, 0.329000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 81.834550, 0.000090, 0.095000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 224.037870, 0.000010, 0.061000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -2, 0}, 283.325110, 0.000040, 0.089000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 283.266450, 0.000220, 0.503000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, -2}, 102.020280, 0.000080, 0.086000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 103.292450, 0.008330, 0.066000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, 2}, 103.303020, 0.000010, 0.024000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 1, -2}, 103.678890, 0.000010, 0.604000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 1, 0}, 103.289860, 0.000450, 0.035000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 2, 0}, 103.294050, 0.000030, 0.024000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -2, 1}, 257.365650, 0.000020, 0.069000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -1, -1}, 256.140700, 0.000170, 1.069000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 283.342590, 0.000020, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -1, 1}, 256.175480, 0.000180, 0.036000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 255.487430, 0.000280, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, 1}, 258.453320, 0.000030, 0.024000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -3, 0}, 283.312780, 0.000020, 4.640000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -2, 0}, 103.314140, 0.000330, 0.074000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -1, -2}, 103.296670, 0.000110, 8.477000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -1, 0}, 103.292330, 0.000220, 0.037000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, 0, -2}, 103.464940, 0.000020, 0.076000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, 0, 0}, 103.283640, 0.000050, 0.025000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 4, -1, -1}, 257.043910, 0.000020, 0.039000},
	{{0, 3, -1, -3, 0, 0, 0, 0, 2, 0, -3}, 338.412750, 0.000010, 0.075000},
	{{0, 3, -1, -3, 0, 0, 0, 0, 2, 0, -1}, 338.412750, 0.000010, 0.074000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 0, -1}, 38.165820, 0.000020, 0.029000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 0, 1}, 38.120740, 0.000020, 0.134000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 188.815020, 0.000160, 0.118000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, 0, -1}, 29.121320, 0.000030, 0.105000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, 0, 1}, 29.116290, 0.000030, 0.058000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 12.847140, 0.000180, 0.062000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -1, -1}, 28.690340, 0.000020, 0.517000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -1, 1}, 28.697860, 0.000020, 0.035000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 30.989600, 0.000040, 0.066000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, 0, 1}, 204.364450, 0.000010, 0.024000},
	{{0, 3, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 124.718750, 0.000040, 0.133000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 307.123330, 0.000060, 0.058000},
	{{0, 3, 7, -19, 0, 0, 0, 0, 2, -2, -1}, 311.204880, 0.000010, 0.075000},
	{{0, 3, 7, -19, 0, 0, 0, 0, 2, -2, 1}, 311.204880, 0.000010, 0.074000},
	{{0, 4, -15, 14, 0, 0, 0, 0, -1, 0, 0}, 286.279690, 0.000010, 0.074000},
	{{0, 4, -15, 14, 0, 0, 0, 0, -1, 0, 2}, 286.279690, 0.000010, 0.075000},
	{{0, 4, -10, 0, 2, 0, 0, 0, -2, 0, 1}, 51.634110, 0.000010, 0.068000},
	{{0, 4, -10, 0, 2, 0, 0, 0, -2, 0, 3}, 231.634110, 0.000010, 0.082000},
	{{0, 4, -8, 0, -1, 0, 0, 0, -2, 0, 1}, 60.474210, 0.000010, 0.078000},
	{{0, 4, -8, 0, -1, 0, 0, 0, -2, 0, 3}, 240.474210, 0.000010, 0.072000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 51.950760, 0.000020, 0.078000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 327.162880, 0.000040, 0.072000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 149.472900, 0.000020, 0.092000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 61.441960, 0.000110, 0.078000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 64.372010, 0.000180, 0.084000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 84.154270, 0.000030, 0.092000},
	{{0, 4, -7, 0, 2, 0, 0, 0, -1, 0, 0}, 112.127840, 0.000010, 0.079000},
	{{0, 4, -7, 0, 2, 0, 0, 0, -1, 0, 2}, 292.127840, 0.000010, 0.071000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, -1, -1}, 345.253340, 0.000020, 0.020000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, -1, 1}, 345.847370, 0.000040, 0.042000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 0, -1}, 344.772310, 0.000170, 0.027000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 0, 1}, 345.528500, 0.000650, 0.092000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 1, -1}, 345.669570, 0.000190, 0.041000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 1, 1}, 345.693200, 0.000140, 0.409000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, -2}, 168.132070, 0.000010, 0.026000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 329.569980, 0.000020, 0.084000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 1, 0}, 169.361110, 0.000020, 0.720000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -2, -1}, 344.026880, 0.000030, 0.025000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -2, 1}, 345.985110, 0.000010, 0.079000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -1, -1}, 343.163620, 0.000260, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -1, 1}, 342.905510, 0.000230, 1.495000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 344.812890, 0.000300, 0.077000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, 1}, 344.783100, 0.000290, 0.072000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 1, -1}, 342.447050, 0.000180, 2.982000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 1, 1}, 342.771840, 0.000210, 0.037000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 2, -1}, 342.828930, 0.000010, 0.074000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 2, 1}, 342.970000, 0.000030, 0.025000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -2, 0}, 170.607820, 0.000050, 0.073000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 169.323760, 0.000170, 2.598000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 0, -2}, 349.439570, 0.000020, 0.072000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 349.358070, 0.002830, 0.078000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 1, 0}, 349.361110, 0.000150, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 344.792490, 0.000230, 0.085000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 0, 1}, 344.811760, 0.000040, 0.026000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 3, -1, 0}, 349.361110, 0.000030, 0.041000},
	{{0, 4, -6, 3, 0, 0, 0, 0, 2, 0, -3}, 181.396050, 0.000020, 0.074000},
	{{0, 4, -6, 3, 0, 0, 0, 0, 2, 0, -1}, 181.396050, 0.000020, 0.075000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -3, 1, 0}, 256.546180, 0.000020, 0.045000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, -1, -1}, 93.598870, 0.000030, 0.020000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, -1, 1}, 93.538820, 0.000020, 0.043000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, -1}, 93.692070, 0.000160, 0.027000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 93.362330, 0.000550, 0.102000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, 3}, 273.529720, 0.000010, 0.059000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 1, -1}, 93.485670, 0.000160, 0.043000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 1, 1}, 93.449270, 0.000170, 0.290000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, -1, 0}, 256.534670, 0.000200, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 256.536710, 0.003460, 0.092000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 2}, 256.512510, 0.000020, 0.063000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 2, 0}, 256.513190, 0.000020, 0.064000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -3, -1}, 271.615080, 0.000010, 0.019000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -2, -1}, 271.642550, 0.000030, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -1, -1}, 271.300520, 0.000230, 0.040000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -1, 1}, 271.236740, 0.000190, 0.599000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 268.838900, 0.000060, 0.084000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 264.458760, 0.000020, 0.067000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 1, -1}, 92.655090, 0.000020, 0.749000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -2, 0}, 256.515190, 0.000150, 0.079000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, -2}, 76.631710, 0.000070, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 256.512520, 0.001350, 1.626000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, 2}, 256.520390, 0.000030, 0.036000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, -2}, 77.085260, 0.000280, 0.077000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 76.514400, 0.028840, 0.072000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 2}, 254.587100, 0.000020, 0.025000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, -2}, 76.335260, 0.000050, 3.552000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 76.513200, 0.001640, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 2, 0}, 76.513170, 0.000100, 0.025000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -3, 1}, 274.256370, 0.000010, 9.509000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -2, -1}, 91.412930, 0.000120, 0.073000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, -1}, 91.332360, 0.001170, 2.280000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 78.120300, 0.000050, 0.077000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, 1}, 91.376880, 0.001330, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 92.105660, 0.002400, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, 1}, 91.658660, 0.000260, 0.025000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 1, -1}, 92.143900, 0.000140, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 1, 1}, 92.041060, 0.000020, 0.019000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, -1, 0}, 76.513120, 0.000320, 0.039000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 0, -2}, 76.262500, 0.000020, 0.085000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 0, 0}, 76.513210, 0.000180, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 1, 0}, 76.513220, 0.000020, 0.019000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -2, 1}, 91.412470, 0.000030, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -1, -1}, 91.782820, 0.000070, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -1, 1}, 91.615080, 0.000010, 0.020000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 1, 0, -2}, 88.609500, 0.000020, 0.078000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 1, 0, 0}, 268.609500, 0.000020, 0.071000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 2, 0, -3}, 6.768460, 0.000020, 0.076000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 2, 0, -1}, 186.768460, 0.000020, 0.073000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -4, 1, -1}, 359.231440, 0.000010, 0.021000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, -1, -1}, 359.154830, 0.000030, 0.020000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, -1, 1}, 359.691970, 0.000050, 0.045000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 0, -1}, 359.164440, 0.000180, 0.028000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 359.468750, 0.000550, 0.113000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 1, -1}, 359.173640, 0.000160, 0.045000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 1, 1}, 359.139150, 0.000150, 0.225000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 2, 1}, 358.991130, 0.000010, 0.057000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 27.317880, 0.000190, 0.101000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -2, -1}, 0.142500, 0.000040, 0.027000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -1, -1}, 0.045880, 0.000430, 0.041000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -1, 1}, 0.067690, 0.000350, 0.375000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 359.867490, 0.000430, 0.092000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 180.174210, 0.000560, 0.063000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, -1}, 180.374500, 0.000170, 0.428000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, 1}, 180.204290, 0.000350, 0.034000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 2, -1}, 180.031230, 0.000020, 0.064000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 2, 1}, 180.093450, 0.000040, 0.024000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 0.371210, 0.000010, 0.085000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 10.536580, 0.000050, 0.619000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 0.371210, 0.000010, 0.067000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, -2}, 184.372290, 0.000020, 0.084000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 0.122220, 0.000050, 0.690000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 190.359130, 0.001150, 0.067000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 0.122230, 0.000050, 0.035000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 190.337340, 0.000070, 0.036000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -3, -1}, 180.259950, 0.000020, 0.039000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -2, -1}, 180.024930, 0.000220, 0.079000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -2, 1}, 0.072460, 0.000070, 0.071000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, -3}, 180.014490, 0.000020, 0.038000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, -1}, 180.023460, 0.002440, 1.782000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, 1}, 180.029130, 0.003710, 0.036000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, -3}, 180.011090, 0.000140, 0.077000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 180.038600, 0.023590, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, 1}, 0.266900, 0.000160, 0.025000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 1, -1}, 180.038110, 0.001270, 0.037000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 1, 1}, 0.100440, 0.000030, 0.019000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 2, -1}, 180.050960, 0.000080, 0.025000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 2, 1}, 359.977730, 0.000010, 0.015000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -1, -3}, 180.064520, 0.000010, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 180.064520, 0.000010, 0.077000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -2, -1}, 180.024540, 0.000020, 0.083000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -2, 1}, 180.028090, 0.000090, 0.026000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -1, -1}, 180.036850, 0.000370, 0.040000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -1, 1}, 180.044010, 0.000060, 0.019000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 0, -1}, 180.044240, 0.000090, 0.026000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 0, 1}, 0.027220, 0.000020, 0.015000},
	{{0, 4, -4, 0, 1, 0, 0, 0, 2, 0, -3}, 166.935820, 0.000010, 0.077000},
	{{0, 4, -4, 0, 1, 0, 0, 0, 2, 0, -1}, 346.935820, 0.000010, 0.072000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -3, 1, 0}, 283.312770, 0.000020, 0.049000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 250.619710, 0.000020, 0.029000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 253.806170, 0.000050, 0.128000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 1, -1}, 253.241840, 0.000010, 0.047000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 1, 1}, 253.241840, 0.000010, 0.184000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 283.308200, 0.000120, 0.045000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 283.315930, 0.002200, 0.113000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 1, 0}, 103.300730, 0.000220, 0.228000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 257.093630, 0.000040, 0.043000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 257.093630, 0.000030, 0.273000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 243.424680, 0.000020, 0.101000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, -2, 0}, 283.325850, 0.000030, 0.094000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 283.342730, 0.000110, 0.382000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, -2}, 103.329060, 0.000050, 0.091000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 103.329080, 0.005660, 0.063000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 103.329450, 0.000300, 0.034000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 2, 0}, 103.329120, 0.000020, 0.024000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -1, -1}, 259.411590, 0.000040, 0.640000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -1, 1}, 259.360430, 0.000040, 0.035000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 259.845770, 0.000180, 0.067000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, -2, 0}, 103.322940, 0.000020, 0.071000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, -1, 0}, 103.329120, 0.000060, 0.037000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, 0, 0}, 103.330320, 0.000030, 0.025000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 0, -1}, 30.377830, 0.000020, 0.030000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 30.358570, 0.000020, 0.147000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 187.763590, 0.000110, 0.127000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 27.147250, 0.000030, 0.112000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 27.140930, 0.000030, 0.056000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 10.693640, 0.000120, 0.059000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 25.922410, 0.000030, 0.063000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, 0, 1}, 206.237510, 0.000010, 0.023000},
	{{0, 4, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 125.531190, 0.000030, 0.146000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 307.806500, 0.000050, 0.056000},
	{{0, 5, -10, 0, 1, 0, 0, 0, -2, 2, -1}, 230.450170, 0.000030, 0.074000},
	{{0, 5, -10, 0, 1, 0, 0, 0, -2, 2, 1}, 50.450170, 0.000030, 0.075000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 324.283140, 0.000020, 0.076000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 150.977740, 0.000020, 0.087000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 173.679210, 0.000020, 0.096000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, -1, -1}, 71.786810, 0.000020, 0.019000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, -1, 1}, 72.241240, 0.000020, 0.041000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, -1}, 71.610390, 0.000110, 0.026000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 71.940750, 0.000560, 0.089000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 1, -1}, 72.369590, 0.000160, 0.040000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 1, 1}, 72.480880, 0.000110, 0.483000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 24.631740, 0.000030, 0.082000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -2, -1}, 69.141750, 0.000030, 0.025000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -1, -1}, 69.758790, 0.000210, 0.038000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -1, 1}, 69.388870, 0.000180, 3.397000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 72.189620, 0.000260, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, 1}, 72.179230, 0.000260, 0.074000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 1, -1}, 69.159250, 0.000160, 25.549000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 1, 1}, 69.583830, 0.000190, 0.037000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 2, 1}, 69.746440, 0.000030, 0.025000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 247.839020, 0.000020, 1.317000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 67.838280, 0.000340, 0.080000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, 1, 0}, 67.838270, 0.000020, 0.039000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -1, -1}, 72.651840, 0.000080, 0.552000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -1, 1}, 72.310580, 0.000120, 0.040000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 71.410160, 0.000450, 0.087000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 0, 1}, 71.279740, 0.000080, 0.026000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 1, -1}, 71.644020, 0.000020, 0.040000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 1, 1}, 71.632160, 0.000010, 0.019000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 3, -1, 0}, 272.219330, 0.000020, 0.042000},
	{{0, 5, -7, 0, -1, 0, 0, 0, 1, 0, -2}, 249.321330, 0.000010, 0.074000},
	{{0, 5, -7, 0, -1, 0, 0, 0, 1, 0, 0}, 69.321330, 0.000010, 0.075000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, -1, -1}, 168.763450, 0.000020, 0.020000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, -1, 1}, 168.430430, 0.000040, 0.043000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 0, -1}, 168.939510, 0.000130, 0.027000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 0, 1}, 168.530280, 0.000520, 0.098000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 1, -1}, 168.473160, 0.000150, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 1, 1}, 168.488320, 0.000130, 0.326000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, -1, 0}, 349.199400, 0.000100, 0.041000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, -2}, 169.471350, 0.000020, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 349.194350, 0.001910, 0.089000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 1, -2}, 169.288050, 0.000010, 0.040000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 1, 0}, 349.326580, 0.000290, 0.496000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 2, 0}, 349.282400, 0.000030, 0.065000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -1, -1}, 170.209780, 0.000080, 0.039000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -1, 1}, 170.023790, 0.000070, 0.773000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 0, -1}, 144.036370, 0.000040, 0.081000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 0, 1}, 169.802730, 0.000080, 0.069000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 1, -1}, 169.394260, 0.000060, 1.041000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 1, 1}, 169.501960, 0.000060, 0.036000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -2, 0}, 349.239760, 0.000100, 0.077000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, -2}, 169.532160, 0.000150, 0.038000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, 0}, 349.278050, 0.001880, 4.156000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, -2}, 170.218140, 0.000520, 0.075000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 169.281980, 0.037120, 0.074000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, 2}, 349.282230, 0.000040, 0.025000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 1, -2}, 169.121610, 0.000100, 10.764000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 1, 0}, 169.286990, 0.002160, 0.037000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 2, 0}, 169.292930, 0.000130, 0.025000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, -1}, 162.996850, 0.000100, 1.230000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, 1}, 165.705670, 0.000130, 0.038000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 166.735250, 0.000450, 0.080000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 0, 1}, 166.164440, 0.000040, 0.025000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 1, -1}, 83.342350, 0.000010, 0.039000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, -1, -2}, 349.849620, 0.000010, 0.536000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, -1, 0}, 169.276050, 0.000390, 0.040000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 0, -2}, 166.353970, 0.000030, 0.088000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 0, 0}, 169.281510, 0.000240, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 1, 0}, 169.282480, 0.000030, 0.019000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, -1, -1}, 15.243250, 0.000030, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, 0, -1}, 15.243260, 0.000030, 0.027000},
	{{0, 5, -7, 0, 1, 0, 0, 0, 1, 0, -2}, 255.039190, 0.000020, 0.075000},
	{{0, 5, -7, 0, 1, 0, 0, 0, 1, 0, 0}, 75.039190, 0.000020, 0.074000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 0, -1}, 9.412150, 0.000020, 0.026000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 0, 1}, 9.412150, 0.000080, 0.088000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 1, -1}, 9.412660, 0.000020, 0.040000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 1, 1}, 9.412660, 0.000020, 0.515000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, -1, -1}, 6.460780, 0.000030, 0.037000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, -1, 1}, 4.239690, 0.000020, 5.965000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 0, -1}, 13.204480, 0.000050, 0.075000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 0, 1}, 13.204480, 0.000050, 0.074000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 1, -1}, 4.239690, 0.000020, 6.029000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 1, 1}, 6.460780, 0.000030, 0.037000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, -1, -1}, 9.399700, 0.000020, 0.516000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, -1, 1}, 9.399700, 0.000020, 0.040000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, 0, -1}, 9.400210, 0.000080, 0.088000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, 0, 1}, 9.400210, 0.000020, 0.026000},
	{{0, 5, -6, 0, -1, 0, 0, 0, 2, 0, -3}, 278.019870, 0.000020, 0.074000},
	{{0, 5, -6, 0, -1, 0, 0, 0, 2, 0, -1}, 98.019870, 0.000020, 0.075000},
	{{0, 5, -6, 0, 0, -1, 0, 0, 2, 0, -3}, 3.576450, 0.000010, 0.074000},
	{{0, 5, -6, 0, 0, -1, 0, 0, 2, 0, -1}, 183.576450, 0.000010, 0.075000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 0, -1}, 85.537320, 0.000060, 0.028000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 0, 1}, 86.601880, 0.000180, 0.109000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 1, -1}, 86.997830, 0.000070, 0.044000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 1, 1}, 84.435790, 0.000050, 0.246000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, -1, 0}, 256.285960, 0.000080, 0.043000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 255.934320, 0.001680, 0.098000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 1, 0}, 76.256890, 0.000070, 0.332000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -3, -1}, 91.847480, 0.000010, 0.020000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -2, -1}, 91.847480, 0.000030, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, -1}, 91.777990, 0.000270, 0.041000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, 1}, 91.489000, 0.000140, 0.436000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, -3}, 272.351420, 0.000040, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 92.354370, 0.002070, 0.089000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, 1}, 99.336900, 0.000010, 0.064000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, -1}, 92.268280, 0.000600, 0.510000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, 1}, 273.301890, 0.000030, 0.035000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 2, -1}, 92.327770, 0.000050, 0.066000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -2, 0}, 256.418930, 0.000050, 0.083000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -1, -2}, 76.226680, 0.000020, 0.039000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 256.367580, 0.000360, 0.806000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, -2}, 75.651660, 0.000080, 0.081000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 76.384590, 0.009280, 0.069000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 1, -2}, 76.599880, 0.000010, 1.102000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 1, 0}, 76.380360, 0.000520, 0.036000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 2, 0}, 76.382130, 0.000030, 0.024000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, -3}, 272.338520, 0.000050, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, -1}, 93.669690, 0.000030, 0.077000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, 1}, 93.593560, 0.000030, 0.073000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -3}, 272.359240, 0.000420, 0.038000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -1}, 92.534660, 0.002280, 5.352000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 256.369440, 0.000100, 0.073000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, 1}, 271.768450, 0.000980, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -3}, 272.531400, 0.001640, 0.075000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 272.305970, 0.066630, 0.074000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, 1}, 93.251890, 0.000030, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -3}, 272.233840, 0.000250, 6.818000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -1}, 272.306440, 0.003980, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, 1}, 92.150300, 0.000020, 0.019000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 2, -3}, 272.274470, 0.000010, 0.076000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 2, -1}, 272.306750, 0.000260, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, -1, 0}, 76.382100, 0.000100, 0.038000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, 0, 0}, 76.382070, 0.000060, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -2, 1}, 272.063120, 0.000030, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -1, -3}, 92.449360, 0.000030, 0.521000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -1, -1}, 272.281060, 0.000740, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -1, 1}, 271.847480, 0.000010, 0.019000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 0, -3}, 272.174030, 0.000110, 0.088000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 0, -1}, 272.305290, 0.000450, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 1, -1}, 272.306350, 0.000050, 0.019000},
	{{0, 5, -6, 0, 1, 0, 0, 0, 2, 0, -3}, 278.705450, 0.000010, 0.075000},
	{{0, 5, -6, 0, 1, 0, 0, 0, 2, 0, -1}, 98.705450, 0.000010, 0.074000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 0, -1}, 358.344540, 0.000060, 0.029000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 359.361710, 0.000130, 0.122000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 1, -1}, 359.250610, 0.000050, 0.046000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 1, 1}, 359.331710, 0.000070, 0.197000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 17.561000, 0.000170, 0.108000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -1, -1}, 0.552900, 0.000060, 0.042000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -1, 1}, 0.439590, 0.000090, 0.304000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -1, 3}, 179.983930, 0.000010, 0.033000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 351.799370, 0.000150, 0.097000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 180.163120, 0.000470, 0.060000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 1, -1}, 181.540010, 0.000190, 0.338000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 1, 1}, 180.105260, 0.000270, 0.034000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 2, -1}, 180.007150, 0.000020, 0.062000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 2, 1}, 180.052990, 0.000030, 0.023000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 10.335190, 0.000030, 0.446000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 0.304790, 0.000030, 0.482000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 190.264620, 0.000830, 0.065000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 0.303630, 0.000030, 0.035000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 190.259630, 0.000050, 0.035000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -2, -1}, 179.978750, 0.000140, 0.083000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, -1}, 180.201920, 0.001280, 0.843000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, 1}, 180.038800, 0.001710, 0.036000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, -3}, 177.506540, 0.000040, 0.081000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 180.065380, 0.007960, 0.069000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, 1}, 359.999370, 0.000300, 0.024000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 1, -3}, 171.968050, 0.000010, 1.172000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 1, -1}, 180.567940, 0.000360, 0.036000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 1, 1}, 0.020320, 0.000070, 0.018000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 2, -1}, 180.063760, 0.000030, 0.024000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 2, 1}, 359.965090, 0.000010, 0.015000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, -1, -1}, 0.064880, 0.000100, 0.074000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, 0, -2}, 194.507080, 0.000030, 0.075000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -2, -1}, 180.086310, 0.000010, 0.079000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -2, 1}, 180.054700, 0.000050, 0.025000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -1, -1}, 180.036800, 0.000140, 0.039000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -1, 1}, 180.065490, 0.000010, 0.019000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, 0, 1}, 0.016780, 0.000020, 0.015000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 283.290800, 0.000100, 0.047000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 0, -2}, 103.266440, 0.000020, 0.029000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 283.296720, 0.001510, 0.121000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 1, 0}, 103.289230, 0.000190, 0.199000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, -1, -1}, 257.099470, 0.000020, 0.044000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 87.191770, 0.000010, 0.108000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 283.325120, 0.000020, 0.100000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 283.354310, 0.000040, 0.309000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, -2}, 103.327570, 0.000040, 0.097000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 103.326210, 0.003980, 0.061000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 103.326510, 0.000220, 0.034000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -1, -1}, 267.003100, 0.000020, 0.457000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -1, 1}, 267.002250, 0.000020, 0.034000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 262.438330, 0.000130, 0.065000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, 1}, 89.815290, 0.000010, 0.024000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 3, -1, 0}, 103.326470, 0.000050, 0.036000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 29.247760, 0.000020, 0.030000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 29.247450, 0.000020, 0.162000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 185.742210, 0.000060, 0.138000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 25.779880, 0.000030, 0.121000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 25.773590, 0.000030, 0.054000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 8.063230, 0.000070, 0.057000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 29.200580, 0.000030, 0.061000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, 0, 1}, 210.118420, 0.000010, 0.023000},
	{{0, 5, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 126.190040, 0.000020, 0.160000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 308.320670, 0.000040, 0.054000},
	{{0, 6, -12, 0, 2, 0, 0, 0, -2, 0, 1}, 23.131900, 0.000030, 0.075000},
	{{0, 6, -12, 0, 2, 0, 0, 0, -2, 0, 3}, 203.131900, 0.000030, 0.074000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 0, 1}, 299.105660, 0.000010, 0.080000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 0, 3}, 119.105660, 0.000010, 0.070000},
	{{0, 6, -11, 0, 1, 0, 0, 0, -2, 0, 1}, 50.446150, 0.000010, 0.080000},
	{{0, 6, -11, 0, 1, 0, 0, 0, -2, 0, 3}, 230.446150, 0.000010, 0.070000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 148.481460, 0.000020, 0.079000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 149.378720, 0.000030, 0.082000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 0, -1}, 293.079240, 0.000020, 0.026000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 0, 1}, 293.079240, 0.000090, 0.088000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 1, -1}, 293.079590, 0.000020, 0.040000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 1, 1}, 293.079590, 0.000020, 0.514000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, -1, -1}, 291.211760, 0.000040, 0.037000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, -1, 1}, 290.170030, 0.000020, 5.787000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 0, -1}, 291.583940, 0.000030, 0.075000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 0, 1}, 291.583940, 0.000030, 0.074000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 1, -1}, 290.170030, 0.000020, 6.223000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 1, 1}, 291.211760, 0.000040, 0.037000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, -1, -1}, 293.070460, 0.000020, 0.517000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, -1, 1}, 293.070460, 0.000020, 0.040000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, 0, -1}, 293.070830, 0.000090, 0.088000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, 0, 1}, 293.070830, 0.000020, 0.026000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 0, -1}, 68.470530, 0.000020, 0.027000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 0, 1}, 71.327570, 0.000070, 0.095000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 247.079990, 0.000030, 0.086000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, -1, -1}, 71.273340, 0.000030, 0.039000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, -1, 1}, 71.347550, 0.000020, 1.087000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 0, -1}, 72.485270, 0.000020, 0.079000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 0, 1}, 72.485270, 0.000020, 0.071000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 1, -1}, 71.347550, 0.000020, 1.705000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 1, 1}, 71.273340, 0.000030, 0.036000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -2, 0}, 65.917800, 0.000060, 0.075000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 247.079990, 0.000040, 7.470000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 67.076060, 0.000790, 0.076000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 1, 0}, 67.079980, 0.000040, 0.038000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, -1, -1}, 270.183170, 0.000020, 0.842000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, -1, 1}, 270.183170, 0.000020, 0.039000},
	{{0, 6, -9, 0, 3, 0, 0, 0, 1, 0, -2}, 246.288300, 0.000020, 0.074000},
	{{0, 6, -9, 0, 3, 0, 0, 0, 1, 0, 0}, 66.288300, 0.000020, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, -1, 1}, 347.245650, 0.000020, 0.044000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 172.069410, 0.000030, 0.105000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 348.495130, 0.000280, 0.094000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -1, 1, 0}, 349.118720, 0.000020, 0.379000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -2, -1}, 347.278730, 0.000040, 0.026000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -2, 1}, 167.115540, 0.000120, 0.088000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -1, -1}, 347.195740, 0.000610, 0.040000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -1, 1}, 347.182390, 0.000530, 0.521000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 341.954270, 0.000030, 0.086000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 0, 1}, 345.504120, 0.000110, 0.066000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 349.139900, 0.000120, 1.155000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 0, -2}, 169.319550, 0.000020, 0.079000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 169.121400, 0.002460, 0.071000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 1, 0}, 169.118710, 0.000140, 0.037000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -4, -1}, 168.073840, 0.000020, 0.025000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -3, -1}, 168.109640, 0.000150, 0.037000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -3, 1}, 180.258540, 0.000010, 6.855000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -2, -1}, 167.258130, 0.001380, 0.074000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -2, 1}, 166.942780, 0.001070, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, -1}, 167.227390, 0.003290, 5.330000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 170.641010, 0.000020, 0.076000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 1}, 167.241290, 0.003490, 0.038000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 168.484590, 0.000900, 0.077000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, 1}, 167.227680, 0.000450, 0.025000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 1, -1}, 168.919020, 0.000040, 0.038000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 1, 1}, 167.246320, 0.000040, 0.019000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 3, -1, 0}, 169.118720, 0.000030, 0.039000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -3, -1}, 166.064060, 0.000020, 0.510000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -3, 1}, 166.558420, 0.000050, 0.040000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -2, -1}, 167.138400, 0.000160, 0.089000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -2, 1}, 167.173440, 0.000120, 0.026000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -1, -1}, 167.235880, 0.000120, 0.041000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -1, 1}, 167.224790, 0.000070, 0.019000},
	{{0, 6, -8, 0, 1, 0, 0, 0, 2, 0, -3}, 269.872400, 0.000010, 0.073000},
	{{0, 6, -8, 0, 1, 0, 0, 0, 2, 0, -1}, 89.872400, 0.000010, 0.076000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 0, -1}, 87.968390, 0.000010, 0.028000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 0, 1}, 89.688610, 0.000040, 0.117000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, -1, 0}, 256.245290, 0.000040, 0.044000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 256.255020, 0.000930, 0.104000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 1, 0}, 76.269230, 0.000070, 0.275000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -1, -1}, 182.096310, 0.000010, 0.042000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -1, 1}, 141.454580, 0.000010, 0.342000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, -1}, 92.825320, 0.000050, 0.094000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, 1}, 272.474540, 0.000030, 0.062000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 1, -1}, 270.353050, 0.000020, 0.387000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 1, 1}, 270.988890, 0.000030, 0.034000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -2, 0}, 260.796370, 0.000030, 0.088000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, 0}, 256.277980, 0.000130, 0.536000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, -2}, 76.246990, 0.000050, 0.085000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 76.286670, 0.004710, 0.066000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 1, 0}, 76.286730, 0.000240, 0.035000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -2, -1}, 270.419980, 0.000030, 0.080000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, -1}, 270.039090, 0.000260, 1.231000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 258.237080, 0.000020, 0.070000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, 1}, 270.516150, 0.000360, 0.036000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, -3}, 278.502420, 0.000010, 0.078000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 272.160150, 0.001910, 0.071000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, 1}, 92.040300, 0.000040, 0.024000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 1, -1}, 272.156640, 0.000110, 0.037000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 1, 1}, 92.202580, 0.000020, 0.018000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -2, 0}, 256.216620, 0.000110, 0.075000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -1, -2}, 256.217580, 0.000030, 4.143000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -1, 0}, 76.405220, 0.000020, 0.038000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, 0, 0}, 76.287770, 0.000030, 0.025000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, -1, -1}, 272.156800, 0.000020, 0.039000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 0, -1}, 177.780970, 0.000010, 0.029000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 0, 1}, 359.944300, 0.000030, 0.132000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 15.294010, 0.000150, 0.116000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -3, -1}, 0.063430, 0.000010, 0.020000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -2, 1}, 179.655070, 0.000010, 0.107000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 182.723120, 0.000030, 0.103000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, 1}, 180.188000, 0.000370, 0.058000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 1, -1}, 180.039180, 0.000160, 0.279000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 1, 1}, 180.074470, 0.000190, 0.033000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 2, -1}, 179.975550, 0.000010, 0.059000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 2, 1}, 179.993390, 0.000010, 0.023000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 10.733190, 0.000020, 0.349000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, -2}, 194.136180, 0.000010, 0.093000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 0.019650, 0.000030, 0.370000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 190.603550, 0.000630, 0.062000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 0.019650, 0.000030, 0.034000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 1, 0}, 190.592960, 0.000040, 0.034000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -2, -1}, 180.034580, 0.000070, 0.087000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, -1}, 180.023820, 0.000770, 0.552000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, 1}, 180.023760, 0.000980, 0.035000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, -3}, 180.050260, 0.000030, 0.085000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 180.026960, 0.004160, 0.066000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, 1}, 0.025540, 0.000310, 0.024000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 1, -1}, 180.024770, 0.000180, 0.035000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 1, 1}, 0.025500, 0.000090, 0.018000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -2, 1}, 180.020900, 0.000030, 0.025000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -1, -1}, 180.024080, 0.000080, 0.038000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, 0, -1}, 0.032270, 0.000020, 0.025000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, 0, 1}, 0.026760, 0.000020, 0.015000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, -1, 0}, 283.277250, 0.000070, 0.048000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, -2}, 103.284050, 0.000020, 0.029000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 283.280870, 0.001060, 0.131000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 1, 0}, 103.278650, 0.000160, 0.177000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -2, 0}, 283.321540, 0.000020, 0.107000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, -2}, 103.324370, 0.000030, 0.103000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 103.322260, 0.002820, 0.058000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 103.322630, 0.000160, 0.033000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 264.363130, 0.000090, 0.062000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, 1}, 92.716800, 0.000010, 0.023000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 3, -1, 0}, 103.322600, 0.000030, 0.035000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 3, 0, 0}, 103.322600, 0.000020, 0.024000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 0, -1}, 27.682580, 0.000020, 0.031000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 27.682760, 0.000020, 0.180000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 184.295940, 0.000040, 0.151000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 25.629080, 0.000020, 0.130000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 25.622500, 0.000020, 0.052000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 3.304940, 0.000040, 0.055000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 23.188080, 0.000020, 0.059000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, 0, 1}, 212.325800, 0.000010, 0.023000},
	{{0, 6, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 126.731280, 0.000020, 0.178000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 308.711400, 0.000040, 0.052000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 0, 1}, 38.659130, 0.000010, 0.077000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 0, 3}, 218.659130, 0.000010, 0.072000},
	{{0, 7, -13, 0, 2, 0, 0, 0, -2, 0, 1}, 231.609110, 0.000010, 0.078000},
	{{0, 7, -13, 0, 2, 0, 0, 0, -2, 0, 3}, 51.609110, 0.000010, 0.071000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 0, -1}, 57.882990, 0.000010, 0.071000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 0, 1}, 57.882990, 0.000010, 0.078000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 149.304290, 0.000060, 0.078000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 67.061230, 0.000080, 0.091000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, -1, 0}, 68.379610, 0.000050, 2.034000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 0, -2}, 248.446410, 0.000010, 0.076000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 248.380340, 0.001020, 0.073000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 1, 0}, 248.379610, 0.000060, 0.037000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -1, -1}, 254.251070, 0.000030, 1.779000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -1, 1}, 254.252870, 0.000030, 0.038000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, 0, -1}, 253.343450, 0.000050, 0.079000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 348.370450, 0.000140, 0.100000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, -1, -1}, 168.550970, 0.000020, 0.041000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, -1, 1}, 168.550830, 0.000020, 0.393000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 0, -1}, 171.321880, 0.000020, 0.091000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 348.977960, 0.000060, 0.670000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, -2}, 168.992580, 0.000010, 0.083000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 168.979910, 0.001110, 0.068000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 1, 0}, 168.977960, 0.000060, 0.036000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -1, -1}, 347.217850, 0.000060, 2.284000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -1, 1}, 348.478110, 0.000100, 0.037000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, -3}, 174.639910, 0.000010, 0.076000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 350.084040, 0.000830, 0.073000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, 1}, 168.953970, 0.000020, 0.025000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 1, -1}, 350.052720, 0.000050, 0.037000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, -1, 0}, 256.099950, 0.000020, 0.045000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 256.111060, 0.000580, 0.111000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 1, 0}, 76.125110, 0.000060, 0.234000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, -1, 1}, 92.131550, 0.000010, 0.282000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 263.047250, 0.000010, 0.100000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 0, 1}, 269.272500, 0.000040, 0.060000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 1, 1}, 271.236740, 0.000020, 0.033000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 254.693500, 0.000050, 0.401000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, -2}, 76.335490, 0.000020, 0.090000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 76.145820, 0.002740, 0.064000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 1, 0}, 76.145420, 0.000140, 0.034000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -2, 1}, 92.338800, 0.000010, 0.067000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -1, -1}, 271.675210, 0.000150, 0.695000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -1, 1}, 271.807620, 0.000180, 0.035000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 272.354370, 0.000870, 0.068000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, 1}, 92.355180, 0.000050, 0.024000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 1, -1}, 272.338010, 0.000050, 0.036000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 1, 1}, 92.309580, 0.000020, 0.018000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 3, -1, 0}, 76.146260, 0.000030, 0.037000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 3, 0, 0}, 76.146270, 0.000020, 0.025000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 0, -1}, 181.413790, 0.000020, 0.030000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 0, 1}, 182.168200, 0.000020, 0.144000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 1, -1}, 180.421750, 0.000020, 0.049000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 3, -1}, 0.146860, 0.000010, 0.167000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 15.000680, 0.000120, 0.125000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, -1, -1}, 180.187190, 0.000020, 0.045000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, -1}, 180.947260, 0.000030, 0.111000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, 1}, 180.093030, 0.000280, 0.056000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 1, -1}, 180.064770, 0.000120, 0.237000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 1, 1}, 180.097480, 0.000100, 0.032000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 2, 1}, 180.102550, 0.000020, 0.023000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, -1, 0}, 10.757200, 0.000030, 0.286000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 190.760730, 0.000480, 0.060000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 1, 0}, 190.757440, 0.000030, 0.033000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -2, -1}, 180.118850, 0.000050, 0.092000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, -1}, 180.031570, 0.000490, 0.410000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, 1}, 180.029860, 0.000600, 0.034000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, -3}, 180.028990, 0.000010, 0.090000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 180.030450, 0.002460, 0.064000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, 1}, 359.997920, 0.000270, 0.024000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 1, -1}, 180.031140, 0.000100, 0.035000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 1, 1}, 0.010840, 0.000070, 0.018000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, -2, 1}, 179.970210, 0.000020, 0.025000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, -1, -1}, 180.026800, 0.000070, 0.037000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, -1, 1}, 0.019550, 0.000020, 0.019000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, 0, -1}, 0.018110, 0.000040, 0.025000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, -1, 0}, 283.262900, 0.000050, 0.049000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 283.267100, 0.000740, 0.143000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 1, 0}, 103.266850, 0.000130, 0.160000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, -1, 0}, 103.276510, 0.000020, 0.223000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, -2}, 103.301480, 0.000030, 0.110000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 103.316720, 0.002010, 0.056000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 1, 0}, 103.316660, 0.000110, 0.032000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 266.061820, 0.000070, 0.060000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, 1}, 93.501350, 0.000010, 0.023000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 3, -1, 0}, 103.316600, 0.000020, 0.034000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 0, -1}, 26.839230, 0.000020, 0.031000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 26.838650, 0.000020, 0.203000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 182.692430, 0.000020, 0.167000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 353.745680, 0.000020, 0.053000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 22.651340, 0.000020, 0.057000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 309.012390, 0.000030, 0.051000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 0, 1}, 160.566290, 0.000060, 0.081000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 131.574670, 0.000140, 0.075000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, -1, -1}, 340.982850, 0.000040, 0.036000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, -1, 1}, 341.596240, 0.000020, 1.206000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 0, -1}, 338.066030, 0.000020, 0.069000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 0, 1}, 338.377980, 0.000030, 0.080000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 1, -1}, 339.665050, 0.000050, 0.860000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 1, 1}, 339.460260, 0.000060, 0.039000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, -1, -1}, 340.946710, 0.000100, 0.341000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, -1, 1}, 340.763670, 0.000120, 0.042000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 0, -1}, 340.473350, 0.000420, 0.097000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 0, 1}, 339.992230, 0.000110, 0.027000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 1, 1}, 340.284220, 0.000010, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 0, -1}, 236.481310, 0.000030, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 0, 1}, 237.043310, 0.000080, 0.028000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 1, -1}, 237.280500, 0.000050, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 1, 1}, 237.693150, 0.000100, 0.044000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 2, -1}, 236.714550, 0.000050, 0.027000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 2, 1}, 234.920680, 0.000010, 0.105000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -2, -1}, 237.537970, 0.000020, 0.015000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, -1}, 236.754730, 0.000190, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, 1}, 236.637480, 0.000400, 0.041000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, -1}, 237.402160, 0.001220, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 1}, 237.289010, 0.006260, 0.088000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 3}, 237.992950, 0.000020, 0.064000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, -1}, 237.977580, 0.001710, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, 1}, 238.020340, 0.001400, 0.514000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 2, -1}, 52.064300, 0.000020, 0.086000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 2, 1}, 241.178820, 0.000100, 0.066000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 3, 1}, 238.638830, 0.000010, 0.035000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 55.674980, 0.000030, 0.039000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, 0, 1}, 55.674730, 0.000030, 0.945000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -3, -1}, 233.342440, 0.000020, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -2, -1}, 233.464950, 0.000220, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -2, 1}, 232.937620, 0.000100, 0.076000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, -1}, 233.770030, 0.001870, 0.037000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 1}, 233.096980, 0.001590, 5.850000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, -1}, 237.868410, 0.002180, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 1}, 237.864370, 0.002180, 0.074000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, -1}, 233.093720, 0.001590, 6.151000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 1}, 233.769300, 0.001870, 0.037000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 2, -1}, 233.226070, 0.000100, 0.076000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 2, 1}, 233.574510, 0.000220, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 3, 1}, 233.468320, 0.000020, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 57.883310, 0.000030, 0.953000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, 0, 1}, 57.883310, 0.000030, 0.039000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -3, -1}, 237.456610, 0.000010, 0.035000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -2, -1}, 239.566010, 0.000100, 0.066000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -2, 1}, 58.841380, 0.000020, 0.086000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, -1}, 237.960240, 0.001390, 0.516000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, 1}, 237.926510, 0.001700, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, -3}, 237.962850, 0.000020, 0.064000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 237.230990, 0.006230, 0.088000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, 1}, 237.227710, 0.001210, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, -1}, 236.486430, 0.000400, 0.041000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, 1}, 236.417950, 0.000190, 0.019000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 2, 1}, 237.386100, 0.000020, 0.015000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -2, -1}, 237.382060, 0.000010, 0.105000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -2, 1}, 237.379040, 0.000050, 0.027000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -1, -1}, 237.647830, 0.000100, 0.044000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -1, 1}, 237.226200, 0.000050, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, 0, -1}, 236.931720, 0.000080, 0.028000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, 0, 1}, 236.333040, 0.000030, 0.016000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 0, -1}, 104.235590, 0.000060, 0.027000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 0, 1}, 103.400460, 0.000180, 0.097000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 1, -1}, 83.144710, 0.000040, 0.042000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 1, 1}, 74.098720, 0.000040, 0.340000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -1, -1, 0}, 333.476070, 0.000020, 0.041000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 332.890540, 0.000110, 0.088000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -1, 1, 0}, 333.476070, 0.000100, 0.529000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, -1, -1}, 3.332820, 0.000040, 0.039000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, -1, 1}, 20.808250, 0.000020, 0.854000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 0, -1}, 10.583260, 0.000030, 0.081000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 0, 1}, 16.113280, 0.000030, 0.069000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 1, -1}, 350.694180, 0.000030, 1.194000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 1, 1}, 351.535240, 0.000050, 0.036000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, -2, 0}, 333.476070, 0.000020, 0.076000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, -1, 0}, 333.476070, 0.000600, 8.534000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 153.476500, 0.011070, 0.075000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 1, 0}, 153.476070, 0.000600, 0.038000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 2, 0}, 153.476070, 0.000040, 0.025000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, 0, -1}, 327.225650, 0.000160, 0.081000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, 0, 1}, 330.416200, 0.000010, 0.026000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 3, -1, 0}, 153.476070, 0.000120, 0.040000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 3, 0, 0}, 153.476070, 0.000070, 0.026000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 82.629810, 0.000010, 0.096000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 1, -1, 0}, 68.204310, 0.000020, 0.895000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 248.204310, 0.000300, 0.070000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 1, 1, 0}, 248.204310, 0.000020, 0.036000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -1, -1}, 75.545050, 0.000060, 15.770000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -1, 1}, 76.015790, 0.000040, 0.037000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 254.437040, 0.000350, 0.075000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 1, -1}, 254.437040, 0.000020, 0.038000},
	{{0, 8, -11, 0, 0, 3, 0, 0, 2, 0, -3}, 358.612390, 0.000010, 0.074000},
	{{0, 8, -11, 0, 0, 3, 0, 0, 2, 0, -1}, 178.612390, 0.000010, 0.075000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 348.325460, 0.000090, 0.107000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, -1, 0}, 348.867210, 0.000040, 0.472000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, -2}, 168.957270, 0.000010, 0.087000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 168.865480, 0.000640, 0.065000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 1, 0}, 168.867220, 0.000040, 0.035000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -1, -1}, 350.837420, 0.000050, 0.940000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -1, 1}, 350.837120, 0.000050, 0.036000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, -1}, 351.091190, 0.000230, 0.070000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, 1}, 170.310950, 0.000020, 0.024000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 3, -1, -1}, 169.991550, 0.000060, 0.074000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 255.940600, 0.000380, 0.120000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 1, 0}, 75.934320, 0.000030, 0.204000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 0, -1}, 270.844460, 0.000010, 0.106000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 0, 1}, 271.842590, 0.000020, 0.057000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 255.962580, 0.000010, 0.321000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, -2}, 75.837970, 0.000020, 0.095000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 75.976870, 0.001710, 0.061000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 1, 0}, 75.976530, 0.000080, 0.034000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -1, -1}, 272.392620, 0.000100, 0.485000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -1, 1}, 272.476030, 0.000120, 0.035000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 272.550130, 0.000520, 0.065000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, 1}, 93.740930, 0.000070, 0.024000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 1, -1}, 272.667870, 0.000030, 0.035000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 1, 1}, 93.192570, 0.000010, 0.018000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 3, -1, 0}, 75.977150, 0.000020, 0.036000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 0, -1}, 180.617520, 0.000020, 0.030000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 180.198680, 0.000050, 0.158000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 15.486700, 0.000080, 0.136000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -1, -1}, 179.909890, 0.000020, 0.046000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -1, 1}, 179.591420, 0.000030, 0.193000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 183.564970, 0.000030, 0.119000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 0, 1}, 180.464640, 0.000230, 0.054000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 1, -1}, 179.984700, 0.000110, 0.207000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 1, 1}, 180.106180, 0.000090, 0.032000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 2, 1}, 179.609450, 0.000010, 0.022000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 10.976910, 0.000020, 0.243000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 190.976920, 0.000380, 0.058000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 1, 0}, 190.976910, 0.000020, 0.033000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -2, -1}, 180.326330, 0.000030, 0.098000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, -1}, 180.040370, 0.000300, 0.326000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, 1}, 180.014880, 0.000380, 0.033000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 179.934980, 0.001580, 0.061000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, 1}, 359.996070, 0.000230, 0.023000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 1, -1}, 179.889750, 0.000060, 0.034000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 1, 1}, 0.005210, 0.000060, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, -2, 1}, 179.844080, 0.000010, 0.024000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, -1, -1}, 179.951190, 0.000020, 0.036000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, -1, 1}, 0.024040, 0.000010, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, 0, -1}, 0.010340, 0.000030, 0.024000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, -1, 0}, 283.246780, 0.000040, 0.051000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 283.251480, 0.000520, 0.157000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, 1, 0}, 103.258010, 0.000110, 0.145000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, -1, 0}, 103.290610, 0.000050, 0.195000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, -2}, 103.309210, 0.000020, 0.118000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 103.308190, 0.001450, 0.054000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 1, 0}, 103.308310, 0.000070, 0.032000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 267.408830, 0.000050, 0.058000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 0, 1}, 94.459700, 0.000010, 0.023000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 3, -1, 0}, 103.308020, 0.000020, 0.033000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -2, 0, -1}, 26.480640, 0.000020, 0.032000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 23.301020, 0.000010, 0.055000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 309.247470, 0.000030, 0.049000},
	{{0, 9, -17, 0, 3, 0, 0, 0, -2, 0, 1}, 146.356610, 0.000010, 0.074000},
	{{0, 9, -17, 0, 3, 0, 0, 0, -2, 0, 3}, 326.356610, 0.000010, 0.075000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, 0, -1}, 57.846580, 0.000010, 0.078000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, 0, 1}, 57.846580, 0.000010, 0.071000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 229.853160, 0.000020, 0.077000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 333.100970, 0.000070, 0.071000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 249.648460, 0.000150, 0.067000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, 0, -1}, 75.073820, 0.000070, 0.072000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 348.122200, 0.000050, 0.114000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, -1, 0}, 348.635700, 0.000020, 0.365000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 168.618220, 0.000400, 0.063000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 1, 0}, 168.636360, 0.000020, 0.034000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, -1, -1}, 352.181500, 0.000030, 0.592000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, -1, 1}, 352.181500, 0.000030, 0.035000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 352.017050, 0.000120, 0.067000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, 1}, 170.993370, 0.000020, 0.024000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 255.739720, 0.000250, 0.129000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 1, 0}, 75.751250, 0.000020, 0.181000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, -1, 1}, 272.199070, 0.000020, 0.208000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 75.777420, 0.001110, 0.059000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 1, 0}, 75.777880, 0.000070, 0.033000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -1, -1}, 272.479790, 0.000070, 0.372000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -1, 1}, 272.451970, 0.000080, 0.034000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, -1}, 272.188470, 0.000330, 0.063000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, 1}, 92.968510, 0.000060, 0.023000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 1, -1}, 272.311060, 0.000020, 0.034000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 1, 1}, 92.712950, 0.000010, 0.018000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 0, -1}, 180.529850, 0.000020, 0.031000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 0, 1}, 180.279880, 0.000040, 0.176000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 15.279500, 0.000060, 0.148000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, -1, -1}, 180.309510, 0.000030, 0.048000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, -1, 1}, 180.172770, 0.000040, 0.173000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 0, -1}, 181.195680, 0.000020, 0.128000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 0, 1}, 180.093270, 0.000170, 0.052000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 1, -1}, 180.212640, 0.000050, 0.183000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 1, 1}, 180.166580, 0.000070, 0.031000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 11.192310, 0.000020, 0.211000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 191.192310, 0.000290, 0.056000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 1, 0}, 191.192310, 0.000020, 0.032000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -2, -1}, 180.009230, 0.000020, 0.105000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -1, -1}, 180.000120, 0.000200, 0.271000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -1, 1}, 179.997780, 0.000250, 0.033000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 179.997110, 0.001020, 0.059000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, 1}, 0.007780, 0.000190, 0.023000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 1, -1}, 179.994480, 0.000040, 0.033000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 1, 1}, 0.003950, 0.000060, 0.018000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, 0, 1}, 180.007700, 0.000010, 0.015000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, -1, 0}, 283.232430, 0.000020, 0.053000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 283.233420, 0.000370, 0.174000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 1, 0}, 103.242050, 0.000070, 0.133000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, -1, 0}, 103.281950, 0.000050, 0.174000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, -2}, 103.297880, 0.000010, 0.127000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 103.296850, 0.001050, 0.053000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 1, 0}, 103.296990, 0.000050, 0.031000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 268.773450, 0.000040, 0.056000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 0, 1}, 93.333680, 0.000010, 0.022000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 24.347900, 0.000010, 0.053000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 309.433370, 0.000020, 0.048000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 52.332720, 0.000030, 0.073000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 332.182170, 0.000030, 0.068000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 2, 0, -1}, 157.213340, 0.000040, 0.074000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 250.306340, 0.000100, 0.064000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 76.030010, 0.000030, 0.069000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 348.092360, 0.000030, 0.123000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 168.763120, 0.000270, 0.060000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, -1, -1}, 353.456870, 0.000020, 0.432000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, -1, 1}, 353.458010, 0.000020, 0.034000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, 0, -1}, 352.918880, 0.000070, 0.064000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, 0, 1}, 171.896520, 0.000020, 0.024000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 255.507190, 0.000170, 0.141000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 1, 0}, 75.519730, 0.000020, 0.163000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, -1, -1}, 272.221720, 0.000010, 0.047000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, -1, 1}, 272.221720, 0.000010, 0.184000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, -1, 0}, 75.554220, 0.000010, 0.229000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 75.553810, 0.000740, 0.057000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 1, 0}, 75.553970, 0.000050, 0.032000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -1, -1}, 272.344610, 0.000070, 0.302000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -1, 1}, 272.345290, 0.000050, 0.033000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 272.261730, 0.000220, 0.060000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, 1}, 92.531780, 0.000050, 0.023000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 1, 1}, 92.447050, 0.000010, 0.018000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 0, -1}, 180.214640, 0.000040, 0.031000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 0, 1}, 180.214160, 0.000040, 0.198000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 1, -1}, 180.126280, 0.000010, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 1, 1}, 180.126280, 0.000010, 0.122000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 15.359080, 0.000030, 0.164000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, -1, -1}, 179.991590, 0.000050, 0.049000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, -1, 1}, 179.979650, 0.000020, 0.156000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 0, -1}, 181.598840, 0.000010, 0.140000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 0, 1}, 180.093410, 0.000130, 0.051000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 1, 1}, 180.034710, 0.000050, 0.030000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 191.380230, 0.000230, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -2, -1}, 180.205180, 0.000010, 0.112000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -1, -1}, 179.991020, 0.000150, 0.232000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -1, 1}, 179.991630, 0.000180, 0.032000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, -1}, 179.986660, 0.000660, 0.057000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, 1}, 0.016130, 0.000150, 0.023000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 1, -1}, 179.987400, 0.000030, 0.032000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 1, 1}, 359.998560, 0.000040, 0.017000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, -1, 1}, 359.997770, 0.000020, 0.018000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, 0, 1}, 179.990970, 0.000020, 0.014000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 283.213130, 0.000270, 0.196000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 1, 0}, 103.223830, 0.000060, 0.123000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, -1, 0}, 103.579050, 0.000050, 0.157000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 103.282940, 0.000760, 0.051000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 1, 0}, 103.282730, 0.000050, 0.030000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 269.503400, 0.000030, 0.054000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, 0, 1}, 94.203780, 0.000010, 0.022000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 309.581860, 0.000020, 0.046000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -2, -1, 1}, 256.242440, 0.000020, 0.081000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, -2, -1}, 256.242440, 0.000010, 0.036000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 76.242440, 0.000020, 0.039000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -2, 1}, 76.242440, 0.000020, 0.042000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -1, -1}, 76.242440, 0.000040, 0.097000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -1, 1}, 76.242440, 0.000030, 0.027000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, -1, 1}, 333.305510, 0.000020, 0.028000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, 0, -1}, 333.305510, 0.000020, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, 0, 1}, 333.305510, 0.000020, 0.044000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -3, -1}, 333.305510, 0.000010, 0.015000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -2, -1}, 333.305510, 0.000080, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -2, 1}, 333.305510, 0.000090, 0.041000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, -1}, 333.305510, 0.000480, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, 1}, 333.398530, 0.000860, 0.088000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 333.305510, 0.000540, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 1, 1}, 153.305510, 0.000020, 0.066000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -1, -1, -1}, 153.305510, 0.000010, 0.039000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -4, -1}, 333.305510, 0.000020, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -3, -1}, 333.305510, 0.000250, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -3, 1}, 333.305510, 0.000040, 0.076000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, -1}, 333.258170, 0.002740, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, 1}, 341.158400, 0.000020, 6.016000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, -3}, 153.305510, 0.000030, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 333.188830, 0.024920, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 333.231680, 0.024910, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 3}, 153.305510, 0.000030, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 341.158400, 0.000020, 5.978000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 333.258170, 0.002740, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 333.305510, 0.000040, 0.076000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 1, 1}, 333.305510, 0.000250, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 2, 1}, 333.305510, 0.000020, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 153.305510, 0.000010, 0.039000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -3, -1}, 153.305510, 0.000020, 0.066000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -2, 1}, 333.305510, 0.000540, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, -1}, 333.398530, 0.000860, 0.088000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, 1}, 333.305510, 0.000480, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 333.305510, 0.000090, 0.041000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 0, 1}, 333.305510, 0.000080, 0.019000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 1, 1}, 333.305510, 0.000010, 0.015000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -2, -1}, 333.305510, 0.000020, 0.044000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -2, 1}, 333.305510, 0.000020, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -1, -1}, 333.305510, 0.000020, 0.028000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, -1, -1}, 230.368580, 0.000030, 0.027000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, -1, 1}, 230.368580, 0.000040, 0.097000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, 0, -1}, 230.368580, 0.000020, 0.042000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, -2, -1}, 230.368580, 0.000020, 0.039000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 50.368580, 0.000010, 0.036000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 2, -1, -1}, 50.368580, 0.000020, 0.081000},
	{{0, 11, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 334.429790, 0.000020, 0.066000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 250.891010, 0.000070, 0.062000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 2, 0, -1}, 76.772960, 0.000020, 0.066000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 348.185520, 0.000030, 0.134000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 168.688500, 0.000190, 0.058000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 353.660210, 0.000050, 0.062000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, 0, 1}, 172.900280, 0.000010, 0.023000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 255.244580, 0.000120, 0.154000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, -1, -1}, 275.485970, 0.000010, 0.048000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, -1, 1}, 275.485970, 0.000010, 0.165000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 1, -1}, 275.485970, 0.000010, 0.175000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 1, 1}, 275.485970, 0.000010, 0.031000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, -1, 0}, 75.297330, 0.000010, 0.200000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 75.297380, 0.000490, 0.055000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 1, 0}, 75.297560, 0.000030, 0.032000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, -1, -1}, 272.490910, 0.000050, 0.254000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, -1, 1}, 272.554490, 0.000040, 0.032000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, -1}, 272.014730, 0.000160, 0.058000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, 1}, 93.393800, 0.000040, 0.023000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 0, -1}, 180.187110, 0.000040, 0.032000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 0, 1}, 180.186590, 0.000030, 0.226000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 1, -1}, 180.079980, 0.000010, 0.055000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 1, 1}, 180.079980, 0.000010, 0.113000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 14.824200, 0.000030, 0.182000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, -1, -1}, 179.992170, 0.000040, 0.051000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, -1, 1}, 179.968110, 0.000020, 0.142000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 0, 1}, 180.148790, 0.000080, 0.049000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 1, 1}, 180.083430, 0.000020, 0.030000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 191.544250, 0.000180, 0.052000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -1, -1}, 179.971390, 0.000110, 0.202000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -1, 1}, 179.974780, 0.000120, 0.031000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 179.958560, 0.000450, 0.055000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, 1}, 0.047560, 0.000100, 0.022000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 1, 1}, 359.998140, 0.000040, 0.017000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 4, -1, 1}, 359.989350, 0.000010, 0.018000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 283.187580, 0.000190, 0.223000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 1, 0}, 103.203530, 0.000050, 0.114000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, -1, 0}, 103.287010, 0.000040, 0.143000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 103.234320, 0.000550, 0.049000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 1, 0}, 103.240110, 0.000040, 0.030000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, 0, -1}, 270.109530, 0.000020, 0.052000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 251.411100, 0.000050, 0.059000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 348.130890, 0.000020, 0.146000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 168.605730, 0.000140, 0.056000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, 0, -1}, 354.320710, 0.000030, 0.059000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, 0, 1}, 173.716820, 0.000010, 0.023000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 254.939010, 0.000070, 0.171000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, -1, 0}, 75.009570, 0.000010, 0.178000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 75.009800, 0.000340, 0.053000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 1, 0}, 75.010010, 0.000020, 0.031000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -1, -1}, 272.896220, 0.000030, 0.219000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -1, 1}, 272.892640, 0.000030, 0.032000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 272.185030, 0.000090, 0.056000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, 1}, 92.557310, 0.000050, 0.022000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 0, -1}, 180.208330, 0.000030, 0.033000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 0, 1}, 180.207740, 0.000030, 0.263000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 1, -1}, 180.110010, 0.000010, 0.057000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 1, 1}, 180.110010, 0.000010, 0.106000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 14.406320, 0.000020, 0.206000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, -1, -1}, 179.923650, 0.000020, 0.052000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, -1, 1}, 179.914490, 0.000020, 0.130000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 0, -1}, 180.259700, 0.000030, 0.169000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 0, 1}, 180.127900, 0.000050, 0.048000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 191.687640, 0.000140, 0.050000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -1, -1}, 179.949400, 0.000060, 0.180000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -1, 1}, 179.953200, 0.000080, 0.031000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, -1}, 179.953310, 0.000290, 0.053000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, 1}, 359.960210, 0.000120, 0.022000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 1, 1}, 359.956900, 0.000030, 0.017000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 4, -1, 1}, 359.950740, 0.000010, 0.017000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 283.160900, 0.000130, 0.259000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 1, 0}, 103.181200, 0.000040, 0.106000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, -1, 0}, 103.244660, 0.000040, 0.131000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 103.246500, 0.000400, 0.048000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 1, 0}, 103.246490, 0.000030, 0.029000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 271.240070, 0.000020, 0.050000},
	{{0, 12, -8, 0, 0, 0, -2, 0, -2, 1, -1}, 272.382580, 0.000020, 0.075000},
	{{0, 12, -8, 0, 0, 0, -2, 0, -2, 1, 1}, 272.382580, 0.000020, 0.074000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 1, -1}, 228.508390, 0.000030, 0.026000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 1, 1}, 228.508390, 0.000050, 0.089000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 2, -1}, 228.508390, 0.000030, 0.040000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, -1, -1}, 228.508390, 0.000020, 0.025000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 0, -1}, 228.373250, 0.000140, 0.038000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 49.084040, 0.000030, 5.228000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, -1}, 228.508390, 0.001560, 0.075000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, 1}, 228.508390, 0.001560, 0.074000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 2, 1}, 228.564750, 0.000170, 0.037000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 3, 1}, 228.508390, 0.000020, 0.025000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 0, 1}, 228.508390, 0.000030, 0.040000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 1, -1}, 228.508390, 0.000050, 0.088000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 1, 1}, 228.508390, 0.000030, 0.026000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 1, -2}, 149.227960, 0.000040, 0.074000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 1, 0}, 149.227960, 0.000040, 0.075000},
	{{0, 12, -6, 0, 1, 0, 0, 0, 0, 1, -3}, 278.686710, 0.000010, 0.075000},
	{{0, 12, -6, 0, 1, 0, 0, 0, 0, 1, -1}, 278.686710, 0.000010, 0.074000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 251.874080, 0.000030, 0.057000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 168.514300, 0.000100, 0.054000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, 0, -1}, 354.938270, 0.000020, 0.057000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, 0, 1}, 174.343830, 0.000010, 0.023000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 254.611620, 0.000050, 0.191000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 0, 1}, 92.276260, 0.000020, 0.049000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 74.689460, 0.000230, 0.051000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, -1, -1}, 272.379260, 0.000020, 0.193000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, -1, 1}, 272.378320, 0.000020, 0.031000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 0, -1}, 271.772340, 0.000060, 0.054000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 0, 1}, 93.128570, 0.000040, 0.022000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 0, -1}, 180.168150, 0.000030, 0.033000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 0, 1}, 180.167510, 0.000030, 0.314000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 1, -1}, 180.024480, 0.000010, 0.060000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 1, 1}, 180.024480, 0.000010, 0.099000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 14.335920, 0.000020, 0.236000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -1, -1}, 179.908720, 0.000030, 0.054000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -1, 1}, 179.908610, 0.000030, 0.121000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 0, -1}, 180.048940, 0.000030, 0.189000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 0, 1}, 180.464310, 0.000040, 0.046000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 191.813250, 0.000100, 0.049000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -1, -1}, 180.047630, 0.000060, 0.162000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -1, 1}, 180.053770, 0.000060, 0.030000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 179.936350, 0.000200, 0.051000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 0, 1}, 359.925080, 0.000090, 0.022000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 1, -1}, 359.927370, 0.000020, 0.031000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 1, 1}, 359.927760, 0.000020, 0.017000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 283.127320, 0.000090, 0.309000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 1, 0}, 103.156900, 0.000040, 0.100000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, -1, 0}, 103.223440, 0.000030, 0.121000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 103.225070, 0.000290, 0.047000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 1, 0}, 103.225060, 0.000020, 0.029000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 1, -1}, 25.963230, 0.000010, 0.068000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 1, 1}, 25.963230, 0.000010, 0.083000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, -1, 1}, 102.345190, 0.000020, 0.074000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, -1, 3}, 102.345190, 0.000020, 0.075000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 1, -1}, 280.363780, 0.000010, 0.073000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 1, 1}, 280.363780, 0.000010, 0.076000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 1, 0, 0}, 252.286390, 0.000030, 0.055000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 167.650300, 0.000080, 0.052000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, 0, -1}, 355.491140, 0.000020, 0.055000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -1, 0, 0}, 254.253300, 0.000020, 0.217000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 74.334510, 0.000160, 0.050000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, -1, -1}, 272.152690, 0.000010, 0.172000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, -1, 1}, 272.155220, 0.000010, 0.031000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 0, -1}, 271.589240, 0.000060, 0.052000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 0, 1}, 93.621770, 0.000030, 0.022000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 0, -1}, 179.955420, 0.000010, 0.034000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 0, 1}, 179.955420, 0.000010, 0.391000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 1, -1}, 180.088300, 0.000010, 0.062000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 1, 1}, 180.088300, 0.000010, 0.093000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 2, -1}, 359.955420, 0.000010, 0.346000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 2, 1}, 359.955420, 0.000010, 0.042000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, -1, -1}, 179.887680, 0.000030, 0.056000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, -1, 1}, 179.887590, 0.000030, 0.112000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, 0, -1}, 180.860210, 0.000040, 0.214000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, 0, 1}, 181.128600, 0.000030, 0.045000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 191.923460, 0.000080, 0.047000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, -1, -1}, 179.904020, 0.000050, 0.147000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, -1, 1}, 179.909150, 0.000030, 0.030000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 0, -1}, 179.866120, 0.000140, 0.050000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 0, 1}, 359.997730, 0.000070, 0.021000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 1, 1}, 359.955460, 0.000010, 0.017000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 283.098090, 0.000060, 0.383000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 1, 0}, 103.130690, 0.000040, 0.094000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, -1, 0}, 103.200220, 0.000050, 0.113000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 103.201220, 0.000210, 0.045000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 272.309880, 0.000010, 0.047000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, 0, 1}, 272.309880, 0.000010, 0.021000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -3, 3, -2}, 352.330080, 0.000010, 0.074000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -3, 3, 0}, 352.330080, 0.000010, 0.075000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 1, -1}, 26.722800, 0.000030, 0.071000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 1, 1}, 26.722800, 0.000030, 0.079000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 1, -1}, 281.630140, 0.000010, 0.076000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 1, 1}, 281.630140, 0.000010, 0.073000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 0, -3}, 320.240460, 0.000010, 0.037000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 1, -3}, 320.240460, 0.000090, 0.074000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 1, -1}, 320.240460, 0.000090, 0.075000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 2, -1}, 320.240460, 0.000010, 0.037000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 1, 0, 0}, 252.653540, 0.000020, 0.053000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 1, 0, 0}, 168.302240, 0.000060, 0.051000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, 0, -3}, 355.786330, 0.000010, 0.123000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, 0, -1}, 355.781590, 0.000020, 0.053000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, 0, 1}, 355.777260, 0.000010, 0.022000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -1, 0, 0}, 253.866720, 0.000020, 0.251000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 0, -1}, 99.567600, 0.000010, 0.198000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 0, 1}, 99.567600, 0.000010, 0.046000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 73.942930, 0.000110, 0.048000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, -1, -1}, 92.519590, 0.000010, 0.155000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, 0, -1}, 271.727810, 0.000040, 0.051000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, 0, 1}, 93.277260, 0.000030, 0.021000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 0, 1}, 359.603860, 0.000010, 0.037000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 1, 1}, 359.603860, 0.000090, 0.075000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 1, 3}, 359.603860, 0.000090, 0.074000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 2, 3}, 359.603860, 0.000010, 0.037000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 0, -1}, 179.939350, 0.000010, 0.035000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 0, 1}, 179.939350, 0.000010, 0.518000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 1, -1}, 180.073430, 0.000010, 0.064000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 1, 1}, 180.073430, 0.000010, 0.088000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 2, -1}, 359.939350, 0.000010, 0.441000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 2, 1}, 359.939350, 0.000010, 0.041000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, -1, -1}, 180.028060, 0.000010, 0.058000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, -1, 1}, 180.028060, 0.000010, 0.105000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 0, -1}, 181.295800, 0.000030, 0.248000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 0, 1}, 181.678880, 0.000020, 0.044000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 1, -1}, 359.880050, 0.000010, 0.109000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 1, 1}, 359.880050, 0.000010, 0.028000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 192.020280, 0.000060, 0.046000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, -1, -1}, 179.879400, 0.000030, 0.134000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, -1, 1}, 179.882500, 0.000020, 0.029000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 0, -1}, 179.839930, 0.000100, 0.048000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 0, 1}, 359.964980, 0.000050, 0.021000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 1, 1}, 359.925290, 0.000010, 0.016000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 1, 0}, 283.388290, 0.000030, 0.074000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 1, 2}, 283.388290, 0.000030, 0.075000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 283.067200, 0.000050, 0.504000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 1, 0}, 103.102610, 0.000030, 0.089000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, -1, 0}, 103.173610, 0.000030, 0.105000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 103.174990, 0.000150, 0.044000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 1, -1}, 26.323150, 0.000020, 0.026000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 1, 1}, 26.323150, 0.000040, 0.088000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 2, -1}, 26.360290, 0.000020, 0.040000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, -1, -1}, 26.323150, 0.000010, 0.025000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 0, -1}, 26.263980, 0.000230, 0.037000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 0, 1}, 26.193680, 0.000100, 14.735000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, -1}, 26.323150, 0.001120, 0.074000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, 1}, 26.323150, 0.001120, 0.075000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 2, 1}, 26.284990, 0.000120, 0.038000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 3, 1}, 26.323150, 0.000010, 0.025000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 0, -1}, 206.193640, 0.000020, 0.490000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 1, -1}, 26.323150, 0.000040, 0.089000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 1, 1}, 26.323150, 0.000020, 0.026000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, 0, -1}, 99.701010, 0.000010, 0.026000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, 0, 1}, 99.701010, 0.000020, 0.088000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, 1, -1}, 99.701010, 0.000010, 0.040000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, -1, -1}, 99.701010, 0.000070, 0.038000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 99.701010, 0.000660, 0.075000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, 1}, 99.701010, 0.000660, 0.074000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 1, -2}, 309.250040, 0.000030, 0.074000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 1, 0}, 309.294550, 0.000050, 0.075000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 1, 1}, 99.701010, 0.000070, 0.037000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, -1, 1}, 99.701010, 0.000010, 0.040000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 99.701010, 0.000020, 0.088000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 99.701010, 0.000010, 0.026000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, -1, -1}, 231.719990, 0.000040, 0.075000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, -1, 1}, 231.719990, 0.000040, 0.074000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -2, -1}, 207.177360, 0.000030, 0.037000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -1, -1}, 207.177360, 0.000270, 0.075000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -1, 1}, 207.177360, 0.000270, 0.075000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, 0, 1}, 207.177360, 0.000030, 0.037000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 1, 0, 0}, 168.182850, 0.000050, 0.049000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 1, 0, 0}, 73.512410, 0.000080, 0.047000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, 0, -1}, 272.940360, 0.000030, 0.049000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, 0, 1}, 91.339940, 0.000020, 0.021000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 0, -1}, 179.914560, 0.000010, 0.036000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 0, 1}, 179.914560, 0.000010, 0.765000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 1, -1}, 179.861260, 0.000020, 0.067000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 1, 1}, 179.861260, 0.000020, 0.084000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 2, -1}, 359.914560, 0.000010, 0.610000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 2, 1}, 359.914560, 0.000010, 0.040000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, -1, -1}, 180.053130, 0.000010, 0.060000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, -1, 1}, 180.053130, 0.000010, 0.098000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, 0, -1}, 179.712500, 0.000030, 0.293000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, 0, 1}, 179.694810, 0.000020, 0.043000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 192.105370, 0.000060, 0.045000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, -1, -1}, 179.848670, 0.000020, 0.124000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, -1, 1}, 179.853500, 0.000010, 0.029000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 0, -1}, 179.850330, 0.000070, 0.047000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 0, 1}, 359.858800, 0.000040, 0.021000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 1, 1}, 179.842260, 0.000010, 0.016000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, 0, 0}, 283.049630, 0.000020, 0.735000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, 1, 0}, 103.072750, 0.000040, 0.084000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, -1, 0}, 103.145140, 0.000020, 0.099000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 103.146430, 0.000110, 0.043000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 1, -1}, 26.561710, 0.000030, 0.078000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 1, 1}, 26.561710, 0.000030, 0.072000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 206.355620, 0.000010, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, 1}, 206.355620, 0.000010, 0.077000},
	{{0, 17, -22, 11, 0, 0, 0, 0, -2, 1, -1}, 47.781670, 0.000040, 0.075000},
	{{0, 17, -22, 11, 0, 0, 0, 0, -2, 1, 1}, 47.781670, 0.000040, 0.074000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 1, 0, 0}, 168.053320, 0.000030, 0.048000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 1, 0, 0}, 71.752140, 0.000050, 0.045000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, 0, -1}, 272.347550, 0.000020, 0.048000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, 0, 1}, 92.227180, 0.000020, 0.021000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -3, 2, -1}, 0.241490, 0.000010, 0.075000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -3, 2, 1}, 0.241490, 0.000010, 0.074000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 0, -1}, 179.932430, 0.000030, 0.036000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 0, 1}, 179.932390, 0.000030, 1.468000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 1, -1}, 180.044740, 0.000040, 0.070000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 1, 1}, 180.044740, 0.000040, 0.080000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, -1, -1}, 179.929740, 0.000010, 0.062000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, -1, 1}, 179.929740, 0.000010, 0.093000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, 0, -1}, 181.242640, 0.000020, 0.359000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 1, 0, 0}, 192.180160, 0.000050, 0.043000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, 0, -1}, 179.820440, 0.000030, 0.046000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, 0, 1}, 359.823370, 0.000040, 0.020000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 1, -1}, 96.977580, 0.000060, 0.075000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 1, 1}, 96.977580, 0.000060, 0.074000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 2, -2}, 283.048470, 0.000030, 0.074000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 283.048470, 0.000030, 0.075000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, -1, 0}, 283.016420, 0.000020, 0.071000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 1, 0}, 103.041390, 0.000060, 0.080000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 1, -1, 0}, 103.114370, 0.000020, 0.093000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 103.115590, 0.000080, 0.042000},
	{{0, 17, -15, 0, -1, 0, 0, 0, -1, 1, -2}, 104.272920, 0.000020, 0.075000},
	{{0, 17, -15, 0, -1, 0, 0, 0, -1, 1, 0}, 284.272920, 0.000020, 0.074000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 206.359800, 0.000020, 0.076000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 0, 1}, 206.359800, 0.000020, 0.073000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 1, -2}, 320.290310, 0.000010, 0.075000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 1, 0}, 320.290310, 0.000010, 0.074000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, -1, -1}, 26.705870, 0.000030, 0.071000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, -1, 1}, 26.705870, 0.000030, 0.078000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, 0, -1}, 27.905360, 0.000020, 1.268000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, 0, 1}, 27.906770, 0.000020, 0.038000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 1, 0, 0}, 167.913340, 0.000030, 0.046000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 0, 1}, 270.038120, 0.000070, 0.074000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 0, 3}, 270.038120, 0.000070, 0.075000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 1, 0, 0}, 72.525650, 0.000050, 0.044000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, 0, -1}, 272.340850, 0.000020, 0.046000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, 0, 1}, 92.220700, 0.000010, 0.021000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -4, 1, 1}, 179.888100, 0.000010, 0.087000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, -1}, 177.314490, 0.000130, 0.037000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 195.188540, 0.000010, 0.074000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 1}, 180.156380, 0.000090, 17.998000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 2}, 195.188540, 0.000010, 0.075000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, -1}, 179.888100, 0.000420, 0.073000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, 1}, 179.888100, 0.000420, 0.076000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 2, 1}, 179.709620, 0.000050, 0.038000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -1, -1}, 179.819880, 0.000010, 0.065000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -1, 1}, 179.819880, 0.000010, 0.088000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 0, -1}, 181.250860, 0.000020, 0.462000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 0, 1}, 193.296110, 0.000030, 0.041000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 1, -1}, 179.888100, 0.000010, 0.090000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 1, 0, 0}, 192.245800, 0.000040, 0.042000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, -2, 1}, 231.717130, 0.000020, 0.044000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, -1, -1}, 251.259570, 0.000030, 0.107000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, -1, 1}, 250.026670, 0.000030, 0.028000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, 0, -1}, 179.785130, 0.000040, 0.044000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, 0, 1}, 347.088710, 0.000030, 0.020000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -4, -1, 1}, 309.479540, 0.000010, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -4, 0, 1}, 309.479540, 0.000010, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -2, -1}, 309.479540, 0.000030, 0.019000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -2, 1}, 309.479540, 0.000060, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -1, -1}, 309.479540, 0.000130, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -1, 1}, 309.479540, 0.000420, 0.081000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 0, -1}, 309.479540, 0.000090, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, -1}, 129.479540, 0.000010, 0.025000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, 0}, 283.019560, 0.000030, 0.038000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, -1}, 129.479540, 0.000060, 0.037000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 0}, 282.826850, 0.000150, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 2}, 282.865740, 0.000240, 0.074000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, -2}, 103.007850, 0.000020, 0.037000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 286.163300, 0.000020, 0.074000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 0}, 103.007850, 0.000020, 9.147000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 1}, 286.163300, 0.000020, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 2}, 283.019560, 0.000030, 0.037000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 1, -2}, 102.949370, 0.000070, 0.073000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 1, 0}, 102.986230, 0.000180, 0.076000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -3, -1}, 309.479540, 0.000070, 0.024000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -3, 1}, 309.479540, 0.000010, 0.071000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -2, -1}, 309.479540, 0.000370, 0.036000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -1, -1}, 309.479540, 0.000220, 0.069000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -1, 1}, 129.479540, 0.000170, 0.080000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 0, 1}, 129.479540, 0.000470, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 1, -1}, 129.479540, 0.000010, 0.083000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 1, 1}, 129.479540, 0.000080, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 2, 1}, 129.479540, 0.000010, 0.019000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -1, 0}, 103.081360, 0.000020, 0.088000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, 0, 0}, 103.082490, 0.000060, 0.041000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -3, -1}, 309.479540, 0.000020, 0.062000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -2, 1}, 129.479210, 0.000610, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, -1}, 129.479350, 0.001030, 0.097000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, 1}, 129.479540, 0.000820, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, -1}, 129.479540, 0.000120, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, 1}, 129.479540, 0.000160, 0.020000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 1, -1}, 129.479540, 0.000010, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 1, 1}, 129.479540, 0.000020, 0.016000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -3, 1}, 129.479540, 0.000020, 0.028000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -2, -1}, 129.479540, 0.000040, 0.046000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -2, 1}, 129.479540, 0.000050, 0.021000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -1, -1}, 129.479540, 0.000040, 0.029000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -1, 1}, 129.479540, 0.000030, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 0, 1}, 26.542610, 0.000010, 0.021000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 1, -1}, 26.542610, 0.000010, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -2, -1}, 26.542610, 0.000040, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -2, 1}, 26.542610, 0.000070, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, -1}, 26.542610, 0.000210, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, 1}, 26.542610, 0.000380, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, -1}, 26.542610, 0.000410, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, 1}, 26.542610, 0.000450, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 1, -1}, 26.542610, 0.000250, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 1, 1}, 26.542610, 0.000020, 0.105000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, -1, 1}, 206.542610, 0.000020, 0.042000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, 0, -1}, 206.542610, 0.000020, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, 0, 1}, 206.542610, 0.000010, 0.096000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -4, -1}, 26.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -4, 1}, 26.542610, 0.000020, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, -1}, 26.542610, 0.000260, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, 1}, 26.542610, 0.000220, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, -1}, 26.542680, 0.002100, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 1}, 26.542810, 0.002330, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, -3}, 206.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, -1}, 26.542520, 0.012160, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 1}, 26.542400, 0.021810, 0.088000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 3}, 206.542610, 0.000080, 0.064000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, -3}, 206.542610, 0.000030, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, -1}, 26.541320, 0.014080, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, 1}, 26.497090, 0.000380, 0.514000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, 3}, 206.542610, 0.000020, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, -1}, 206.542610, 0.000060, 0.086000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, 1}, 206.548950, 0.000480, 0.066000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 2, 1}, 206.542610, 0.000100, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 3, 1}, 206.542610, 0.000010, 0.024000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -2, -1}, 206.542610, 0.000070, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -2, 1}, 206.542610, 0.000020, 0.082000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, -1}, 206.542610, 0.000370, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, 0, 1}, 26.542610, 0.000010, 0.070000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -5, -1}, 26.542610, 0.000050, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -4, -1}, 26.543090, 0.000550, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -4, 1}, 26.542610, 0.000110, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, -3}, 206.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, -1}, 26.543100, 0.006420, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, 1}, 26.543670, 0.001130, 0.076000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, -3}, 206.542610, 0.000140, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, -1}, 26.543020, 0.069650, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 1}, 26.565430, 0.000680, 5.868000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 3}, 206.542610, 0.000190, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -3}, 206.542610, 0.000650, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -1}, 26.542720, 0.630140, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 1}, 26.542870, 0.630370, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 3}, 206.542610, 0.000650, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -3}, 206.542610, 0.000190, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -1}, 206.481330, 0.001490, 6.132000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 1}, 26.544160, 0.067470, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 3}, 206.542610, 0.000140, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, -1}, 26.548670, 0.000990, 0.076000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 1}, 26.544630, 0.006160, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 3}, 206.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 2, -1}, 26.542610, 0.000110, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 2, 1}, 26.544820, 0.000530, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 3, 1}, 26.542610, 0.000050, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -2, -1}, 26.542610, 0.000010, 0.070000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, 1}, 206.542610, 0.000370, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 206.542610, 0.000020, 0.082000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, 0, 1}, 206.542610, 0.000070, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -5, -1}, 206.542610, 0.000010, 0.024000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -4, -1}, 206.542610, 0.000100, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, -1}, 206.543870, 0.000550, 0.066000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, 1}, 206.542610, 0.000060, 0.086000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, -3}, 206.542610, 0.000020, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, -1}, 26.318260, 0.000020, 0.516000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 1}, 26.542380, 0.013650, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 3}, 206.542610, 0.000030, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, -3}, 206.542610, 0.000080, 0.064000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, -1}, 26.542440, 0.021780, 0.088000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 1}, 26.542820, 0.012050, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 3}, 206.542610, 0.000020, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, -1}, 26.543980, 0.002250, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, 1}, 26.543410, 0.002060, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, -1}, 26.542610, 0.000220, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, 1}, 26.542610, 0.000260, 0.015000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 2, -1}, 26.542610, 0.000020, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 2, 1}, 26.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -2, -1}, 206.542610, 0.000010, 0.096000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -2, 1}, 206.542610, 0.000020, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -1, -1}, 206.542610, 0.000020, 0.042000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -3, -1}, 26.542610, 0.000020, 0.105000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -3, 1}, 26.542610, 0.000250, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, -1}, 26.542610, 0.000450, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, 1}, 26.542610, 0.000410, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, -1}, 26.542610, 0.000380, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, 1}, 26.542610, 0.000210, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, 0, -1}, 26.542610, 0.000070, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, 0, 1}, 26.542610, 0.000040, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -3, 1}, 26.542610, 0.000010, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -2, -1}, 26.542610, 0.000010, 0.021000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, -1, -1}, 283.605680, 0.000030, 0.016000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, -1, 1}, 283.605680, 0.000040, 0.029000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, 0, -1}, 283.605680, 0.000050, 0.021000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, 0, 1}, 283.605680, 0.000040, 0.046000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, 1, -1}, 283.605680, 0.000020, 0.028000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -3, -1}, 283.605680, 0.000020, 0.016000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -3, 1}, 283.605680, 0.000010, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, -1}, 283.605680, 0.000160, 0.020000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, 1}, 283.605680, 0.000120, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, -1}, 283.605680, 0.000820, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, 1}, 283.605490, 0.001030, 0.097000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 0, -1}, 283.604300, 0.000630, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 1, 1}, 103.605680, 0.000020, 0.062000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -4, -1}, 283.605680, 0.000010, 0.019000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -3, -1}, 283.605680, 0.000080, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -3, 1}, 283.605680, 0.000010, 0.083000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -2, -1}, 283.605680, 0.000470, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -1, -1}, 283.605680, 0.000170, 0.081000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -1, 1}, 103.605680, 0.000220, 0.069000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 0, 1}, 103.605680, 0.000370, 0.036000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 1, -1}, 103.605680, 0.000010, 0.071000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 1, 1}, 103.605680, 0.000070, 0.024000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -2, -2}, 310.091230, 0.000020, 0.037000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, -2}, 310.051530, 0.000150, 0.074000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, 0}, 310.113750, 0.000190, 0.075000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, 1}, 283.605680, 0.000060, 0.037000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 310.091230, 0.000020, 0.038000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, 1}, 283.605680, 0.000010, 0.025000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -2, 1}, 103.605680, 0.000090, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -1, -1}, 103.605680, 0.000420, 0.081000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -1, 1}, 103.605680, 0.000130, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 0, -1}, 103.605680, 0.000060, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 0, 1}, 103.605680, 0.000030, 0.019000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 4, -2, -1}, 103.605680, 0.000010, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 4, -1, -1}, 103.605680, 0.000010, 0.027000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, -1, -1}, 180.668750, 0.000040, 0.028000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, -1, 1}, 180.668750, 0.000040, 0.107000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, 0, -1}, 180.668750, 0.000020, 0.044000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, -2, 0}, 313.467140, 0.000020, 0.037000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, -1, 0}, 313.467140, 0.000170, 0.075000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, -1, 2}, 313.467140, 0.000170, 0.075000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, 0, 2}, 313.467140, 0.000020, 0.037000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 1, 0, 0}, 167.762600, 0.000020, 0.045000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -4, 1, 1}, 14.987140, 0.000010, 0.088000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 0, -1}, 14.987140, 0.000040, 0.037000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 1, -1}, 14.987140, 0.000350, 0.074000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 1, 1}, 14.987140, 0.000350, 0.075000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 2, 1}, 14.987140, 0.000040, 0.037000},
	{{0, 19, -21, 3, 0, 0, 0, 0, 0, 1, -1}, 14.987140, 0.000010, 0.088000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 1, -1}, 270.735730, 0.000010, 0.071000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 1, 1}, 270.735730, 0.000010, 0.078000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 1, 0, 0}, 71.961690, 0.000040, 0.043000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, 0, -1}, 272.277420, 0.000010, 0.045000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, 0, 1}, 92.277480, 0.000010, 0.020000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 0, -1}, 359.534650, 0.000030, 0.038000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 0, 1}, 359.534240, 0.000030, 1.755000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 1, -1}, 180.120400, 0.000080, 0.077000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 1, 1}, 180.120400, 0.000080, 0.072000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 0, -1}, 0.077750, 0.000010, 0.072000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 0, 1}, 0.077750, 0.000010, 0.077000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, -1, -1}, 179.946900, 0.000020, 0.068000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, -1, 1}, 179.946900, 0.000020, 0.083000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 0, -1}, 181.194840, 0.000020, 0.650000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 0, 1}, 181.195140, 0.000020, 0.040000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 1, 0, 0}, 192.303310, 0.000030, 0.041000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, 0, -1}, 179.753350, 0.000030, 0.043000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, 0, 1}, 359.753440, 0.000020, 0.020000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 1, -2}, 102.972510, 0.000030, 0.076000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 1, 0}, 282.973550, 0.000040, 0.073000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 1, -1, 0}, 103.046130, 0.000030, 0.083000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 1, 0, 0}, 103.047200, 0.000040, 0.040000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, -1, -1}, 26.467170, 0.000020, 0.078000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, -1, 1}, 26.467170, 0.000020, 0.071000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 0, -1}, 271.802270, 0.000020, 0.019000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 0, 1}, 271.802270, 0.000020, 0.041000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 1, -1}, 271.802270, 0.000090, 0.026000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 1, 1}, 271.802270, 0.000160, 0.089000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 2, -1}, 271.655670, 0.000100, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 2, 1}, 91.763620, 0.000010, 0.508000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, -1, -1}, 271.802270, 0.000050, 0.025000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, -1}, 272.000360, 0.000400, 0.038000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 1}, 91.125510, 0.000120, 5.116000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, -1}, 271.818750, 0.004790, 0.075000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, 1}, 271.818750, 0.004790, 0.074000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, -1}, 279.240570, 0.000010, 7.245000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, 1}, 271.943540, 0.000530, 0.037000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 3, 1}, 271.802270, 0.000050, 0.025000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 0, -1}, 271.763620, 0.000010, 0.523000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 0, 1}, 271.677180, 0.000130, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 1, -1}, 271.802270, 0.000160, 0.088000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 1, 1}, 271.802270, 0.000090, 0.026000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 2, -1}, 271.802270, 0.000020, 0.041000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 2, 1}, 271.802270, 0.000020, 0.019000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 1, 0, 0}, 71.346460, 0.000030, 0.042000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 1, -2}, 194.028290, 0.000040, 0.026000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 1, 0}, 194.028290, 0.000060, 0.088000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 2, -2}, 194.028290, 0.000040, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -1, -2}, 194.028290, 0.000020, 0.025000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -1, -1}, 0.003840, 0.000010, 0.038000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, -2}, 193.881620, 0.000270, 0.037000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, -1}, 0.003840, 0.000120, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, 0}, 193.287850, 0.000040, 7.056000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, 1}, 0.003840, 0.000120, 0.074000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, -2}, 194.029370, 0.001920, 0.074000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, 0}, 193.939850, 0.002220, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, 1}, 0.003840, 0.000010, 0.037000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 2, 0}, 193.989060, 0.000220, 0.038000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 3, 0}, 194.028290, 0.000020, 0.025000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -1, -1}, 180.035010, 0.000050, 0.071000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -1, 1}, 180.035010, 0.000050, 0.079000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 0, -1}, 181.065910, 0.000030, 1.096000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 0, 1}, 181.066210, 0.000030, 0.039000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 0, 0}, 193.457710, 0.000060, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 1, -2}, 194.028290, 0.000060, 0.089000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 1, 0}, 194.028290, 0.000040, 0.026000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, 0, -1}, 179.715730, 0.000020, 0.042000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, 0, 1}, 359.715820, 0.000020, 0.020000},
	{{0, 20, -19, 0, -3, 0, 0, 0, 0, -1, -1}, 116.743970, 0.000020, 0.075000},
	{{0, 20, -19, 0, -3, 0, 0, 0, 0, -1, 1}, 116.743970, 0.000020, 0.074000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 0, -2}, 282.989370, 0.000090, 0.075000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 282.981950, 0.000040, 0.074000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 1, -1, 0}, 103.008750, 0.000040, 0.079000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 1, 0, 0}, 103.009750, 0.000040, 0.039000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, 0, -3}, 206.453180, 0.000030, 0.075000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 206.453180, 0.000030, 0.074000},
	{{0, 20, -15, -8, 0, 0, 0, 0, 0, -1, -1}, 100.593760, 0.000020, 0.075000},
	{{0, 20, -15, -8, 0, 0, 0, 0, 0, -1, 1}, 100.593760, 0.000020, 0.074000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 0, -2}, 354.137590, 0.000020, 0.037000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 1, -2}, 354.137590, 0.000180, 0.075000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 1, 0}, 354.137590, 0.000180, 0.075000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 2, 0}, 354.137590, 0.000020, 0.037000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, -1, 1}, 166.674450, 0.000020, 0.074000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, -1, 3}, 166.674450, 0.000020, 0.075000},
	{{0, 21, -23, 0, 0, 0, 1, 0, -2, -1, 1}, 15.436420, 0.000040, 0.075000},
	{{0, 21, -23, 0, 0, 0, 1, 0, -2, -1, 3}, 15.436420, 0.000040, 0.075000},
	{{0, 21, -23, 4, 0, 0, 0, 0, 0, -1, -1}, 59.687720, 0.000010, 0.075000},
	{{0, 21, -23, 4, 0, 0, 0, 0, 0, -1, 1}, 59.687720, 0.000010, 0.074000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -1, 0}, 250.553280, 0.000030, 0.074000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -1, 2}, 250.553280, 0.000030, 0.075000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, -1}, 91.999590, 0.000010, 0.073000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, 1}, 91.999590, 0.000010, 0.076000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 1, 0, 0}, 70.675870, 0.000020, 0.041000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, 0, -1}, 272.252330, 0.000010, 0.043000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, 0, 1}, 272.252330, 0.000010, 0.020000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, -1, -1}, 179.943930, 0.000030, 0.026000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, -1, 1}, 179.943930, 0.000050, 0.087000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 0, 1}, 359.842890, 0.000030, 0.549000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -3, -1}, 179.943930, 0.000010, 0.025000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -2, -1}, 180.034360, 0.000160, 0.037000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -1, -1}, 179.944230, 0.001430, 0.074000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -1, 1}, 179.947580, 0.001410, 0.075000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, -1}, 179.842800, 0.000160, 3.490000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, 1}, 179.893310, 0.000320, 0.038000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 1, 1}, 179.943930, 0.000010, 0.025000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, -2, 1}, 179.856160, 0.000030, 0.040000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, -1, -1}, 179.943930, 0.000050, 0.089000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, -1, 1}, 179.943930, 0.000030, 0.026000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, 0, -1}, 179.676040, 0.000010, 0.041000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, 0, 1}, 359.676130, 0.000010, 0.019000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -2, -2}, 102.924540, 0.000010, 0.037000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -2, -1}, 6.551000, 0.000020, 0.074000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -2, 1}, 6.551000, 0.000020, 0.075000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -1, -2}, 102.928720, 0.000130, 0.074000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -1, 0}, 102.945610, 0.000270, 0.075000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, 0, -2}, 103.538990, 0.000020, 2.939000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, 0, 0}, 103.137050, 0.000070, 0.038000},
	{{0, 22, -28, 7, 0, 0, 0, 0, -2, 1, -1}, 206.042560, 0.000010, 0.075000},
	{{0, 22, -28, 7, 0, 0, 0, 0, -2, 1, 1}, 206.042560, 0.000010, 0.074000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 1, -1}, 347.105670, 0.000010, 0.076000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 1, 1}, 347.105670, 0.000010, 0.073000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, -1, -1}, 272.407720, 0.000030, 0.072000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, -1, 1}, 272.407720, 0.000030, 0.077000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, -1, -1}, 179.796780, 0.000060, 0.077000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, -1, 1}, 179.796780, 0.000060, 0.072000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 0, -1}, 1.612470, 0.000020, 2.950000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 0, 1}, 1.612990, 0.000020, 0.037000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 1, -3}, 179.546240, 0.000020, 0.075000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, -1, -2}, 102.920710, 0.000010, 0.077000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, -1, 0}, 282.931980, 0.000020, 0.072000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, 0, 0}, 102.928600, 0.000020, 0.037000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 1, -1}, 71.694790, 0.000020, 0.074000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 1, 1}, 71.694790, 0.000020, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, 0, -1}, 168.182450, 0.000010, 0.026000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, 0, 1}, 168.182450, 0.000020, 0.089000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, 1, -1}, 168.182450, 0.000010, 0.040000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, -1, -1}, 168.182450, 0.000060, 0.038000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, -1}, 168.182450, 0.000560, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, 1}, 168.182450, 0.000560, 0.074000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 1, -2}, 166.874280, 0.000010, 0.074000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 1, 0}, 166.874280, 0.000010, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 1, 1}, 168.182450, 0.000060, 0.037000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, -1, 1}, 168.182450, 0.000010, 0.040000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, 0, -1}, 168.182450, 0.000020, 0.088000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, 0, 1}, 168.182450, 0.000010, 0.026000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -2, -1}, 271.942470, 0.000030, 0.038000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, -2}, 249.195000, 0.000010, 0.037000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, -1}, 272.281100, 0.000280, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, 1}, 272.281100, 0.000280, 0.074000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, -2}, 249.195950, 0.000110, 0.074000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, -1}, 92.962290, 0.000030, 28.187000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 249.147730, 0.000140, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 1, 0}, 249.195000, 0.000010, 0.038000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -2, -2}, 192.753450, 0.000020, 0.038000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -1, -2}, 192.746130, 0.000200, 0.075000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -1, 0}, 192.001780, 0.000100, 0.074000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, -3}, 359.679650, 0.000010, 0.074000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, -1}, 359.679650, 0.000010, 0.075000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, 0}, 192.753450, 0.000020, 0.037000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -2, -3}, 274.980300, 0.000010, 0.038000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -1, -3}, 274.982150, 0.000140, 0.075000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -1, -1}, 275.070450, 0.000100, 0.074000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, 0, -1}, 274.980300, 0.000010, 0.037000},
	{{0, 24, -27, -1, 0, 0, 0, 0, -2, 1, -1}, 218.206230, 0.000010, 0.074000},
	{{0, 24, -27, -1, 0, 0, 0, 0, -2, 1, 1}, 218.206230, 0.000010, 0.075000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -1, -1}, 350.134900, 0.000020, 0.073000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -1, 1}, 350.134900, 0.000020, 0.076000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -3, 1}, 179.431260, 0.000020, 0.088000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -4, -1}, 179.430540, 0.000050, 0.037000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -3, -1}, 179.428570, 0.000440, 0.074000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -3, 1}, 179.428570, 0.000440, 0.075000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -2, -1}, 179.543570, 0.000020, 5.436000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -2, 1}, 179.465390, 0.000070, 0.038000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 4, -3, -1}, 179.431260, 0.000020, 0.089000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 1, -3}, 356.315990, 0.000020, 0.075000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 1, -1}, 356.315990, 0.000020, 0.074000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 1, -4}, 67.085150, 0.000040, 0.074000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 1, -2}, 67.085150, 0.000040, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -2, -1}, 75.000740, 0.000020, 0.019000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -2, 1}, 75.000740, 0.000020, 0.041000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -1, -1}, 75.000740, 0.000090, 0.026000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -1, 1}, 75.000740, 0.000160, 0.088000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, 0, -1}, 75.000740, 0.000100, 0.040000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -3, -1}, 75.000740, 0.000050, 0.025000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, -1}, 75.024130, 0.000520, 0.037000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, -1}, 74.997470, 0.004640, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, 1}, 74.997470, 0.004640, 0.074000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, -1}, 252.960250, 0.000030, 6.293000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, 1}, 75.133650, 0.000480, 0.037000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 1, 1}, 75.000740, 0.000050, 0.025000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, -2, 1}, 75.000740, 0.000100, 0.040000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, -1, -1}, 75.000740, 0.000160, 0.088000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, -1, 1}, 75.000740, 0.000090, 0.026000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, 0, -1}, 75.000740, 0.000020, 0.041000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, 0, 1}, 75.000740, 0.000020, 0.019000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -2, -2}, 166.278270, 0.000020, 0.037000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -1, -2}, 166.261450, 0.000140, 0.074000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -1, 0}, 166.283480, 0.000180, 0.075000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, 0, 0}, 166.278270, 0.000020, 0.038000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, -1, -3}, 272.164000, 0.000020, 0.074000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, -1, -1}, 272.164960, 0.000040, 0.075000},
	{{0, 27, -20, -20, 0, 0, 0, 0, 0, -1, -1}, 329.815390, 0.000010, 0.075000},
	{{0, 27, -20, -20, 0, 0, 0, 0, 0, -1, 1}, 329.815390, 0.000010, 0.075000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -2, -1}, 335.628310, 0.000020, 0.074000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -2, 1}, 335.628310, 0.000020, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, -2, -2}, 162.705350, 0.000010, 0.037000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, -1, -2}, 162.705350, 0.000100, 0.074000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, -1, 0}, 162.705350, 0.000100, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, 0, 0}, 162.705350, 0.000010, 0.037000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 2, -2}, 140.415620, 0.000010, 0.075000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 2, 0}, 140.415620, 0.000010, 0.075000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -1, 0, -2}, 113.915420, 0.000060, 0.075000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -1, 0, 0}, 113.915420, 0.000060, 0.075000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, 0, -1}, 307.191290, 0.000030, 0.075000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, 0, 1}, 307.191290, 0.000030, 0.074000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -2, 0, -1}, 16.248810, 0.000080, 0.075000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -2, 0, 1}, 16.248810, 0.000080, 0.075000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, 0, -1}, 91.325960, 0.000020, 0.074000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, 0, 1}, 91.325960, 0.000020, 0.075000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, -1, -4}, 281.555620, 0.000030, 0.037000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 0, -4}, 281.555620, 0.000300, 0.074000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 0, -2}, 281.555620, 0.000300, 0.075000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 1, -2}, 281.555620, 0.000030, 0.037000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -2, 0, -1}, 296.452700, 0.000080, 0.075000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -2, 0, 1}, 296.452700, 0.000080, 0.075000},
	{{0, 47, -52, 0, 4, 0, 0, 0, -2, 0, -1}, 259.654280, 0.000030, 0.074000},
	{{0, 47, -52, 0, 4, 0, 0, 0, -2, 0, 1}, 259.654280, 0.000030, 0.075000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -2, 1, 1}, 77.182790, 0.000040, 0.075000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -2, 1, 3}, 77.182790, 0.000040, 0.074000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 2, -2, -1}, 114.257370, 0.000040, 0.074000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 2, -2, 1}, 114.257370, 0.000040, 0.075000},
	{{1, 0, -10, 11, 0, 0, 0, 0, -2, 0, 1}, 126.934340, 0.000020, 0.088000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 2, 0, -1}, 126.934340, 0.000020, 0.088000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 0, -1}, 209.549630, 0.000020, 0.026000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 209.549290, 0.000080, 0.090000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 1, -1}, 209.527020, 0.000020, 0.040000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 1, 1}, 209.527020, 0.000020, 0.478000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, -1, -1}, 211.490280, 0.000040, 0.038000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, -1, 1}, 212.093980, 0.000020, 3.136000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 207.917790, 0.000030, 0.075000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 207.917790, 0.000030, 0.074000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 1, -1}, 212.093980, 0.000020, 68.187000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 1, 1}, 211.490280, 0.000040, 0.037000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, -1, -1}, 210.646740, 0.000020, 0.559000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, -1, 1}, 210.646880, 0.000020, 0.040000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 210.270360, 0.000070, 0.087000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, 0, 1}, 210.352370, 0.000010, 0.026000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 136.634700, 0.000020, 0.027000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 136.641890, 0.000070, 0.098000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 1, -1}, 136.676350, 0.000020, 0.042000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 1, 1}, 136.676340, 0.000020, 0.323000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 109.588550, 0.000020, 0.089000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 139.769830, 0.000010, 0.081000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 139.769830, 0.000010, 0.069000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 109.589330, 0.000030, 3.772000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 289.594670, 0.000630, 0.074000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 289.588020, 0.000030, 0.037000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 138.570120, 0.000030, 0.080000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 258.015740, 0.000040, 0.089000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 34.652790, 0.000080, 0.069000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, -1, -1}, 257.009020, 0.000030, 4.732000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, -1, 1}, 75.756360, 0.000060, 0.037000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 0, -3}, 78.184800, 0.000020, 0.075000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 76.198970, 0.001610, 0.074000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 1, -1}, 76.196120, 0.000090, 0.037000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 53.926580, 0.000030, 0.064000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 177.868570, 0.000020, 0.069000},
	{{1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 316.269220, 0.000010, 0.122000},
	{{1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 135.941270, 0.000030, 0.061000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 0, -2}, 4.341160, 0.000010, 0.037000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 1, -2}, 4.341160, 0.000130, 0.074000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 1, 0}, 4.341160, 0.000130, 0.075000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 2, 0}, 4.341160, 0.000010, 0.037000},
	{{2, -24, 21, 0, 0, 0, 0, 0, 4, -3, -1}, 27.444290, 0.000030, 0.074000},
	{{2, -24, 21, 0, 0, 0, 0, 0, 4, -3, 1}, 27.444290, 0.000030, 0.075000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 1, 0, -2}, 90.189240, 0.000020, 0.074000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 303.942200, 0.000020, 0.075000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 180.161410, 0.000010, 0.140000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 180.161410, 0.000010, 0.051000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 2, -2, 1}, 179.900960, 0.000010, 0.056000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 179.889070, 0.000030, 0.057000},
	{{2, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 132.261220, 0.000020, 0.051000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -3, 1, 0}, 312.755700, 0.000020, 0.075000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -3, 1, 2}, 312.755700, 0.000020, 0.074000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 1, -1}, 96.565360, 0.000020, 0.026000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 1, 1}, 96.565360, 0.000040, 0.088000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 2, -1}, 96.565360, 0.000030, 0.040000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, -1, -1}, 96.565360, 0.000010, 0.025000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 0, -1}, 96.404790, 0.000180, 0.037000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 0, 1}, 95.708770, 0.000030, 7.078000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, -1}, 96.565360, 0.001310, 0.074000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, 1}, 96.565360, 0.001310, 0.075000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 2, 1}, 96.522380, 0.000140, 0.038000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 3, 1}, 96.565360, 0.000010, 0.025000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 0, 1}, 96.565360, 0.000030, 0.040000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 1, -1}, 96.565360, 0.000040, 0.089000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 1, 1}, 96.565360, 0.000020, 0.026000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -2, 1, -1}, 353.962060, 0.000070, 0.074000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -2, 1, 1}, 353.962060, 0.000070, 0.075000},
	{{3, 2, -6, 0, 0, 0, 0, 0, -4, 3, -1}, 239.576240, 0.000010, 0.075000},
	{{3, 2, -6, 0, 0, 0, 0, 0, -4, 3, 1}, 239.576240, 0.000010, 0.075000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -2, 2, -1}, 19.566850, 0.000030, 0.075000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -2, 2, 1}, 19.566850, 0.000030, 0.075000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -2, 1, -1}, 30.689450, 0.000070, 0.074000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -2, 1, 1}, 30.689450, 0.000070, 0.075000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 0, -1}, 73.477260, 0.000010, 0.038000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 1, -1}, 73.477260, 0.000130, 0.075000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 1, 1}, 73.477260, 0.000130, 0.074000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 2, 1}, 73.477260, 0.000010, 0.037000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, 1, -2}, 24.761620, 0.000050, 0.075000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, 1, 0}, 24.577410, 0.000030, 0.074000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 0, -1, -1}, 183.029880, 0.000020, 0.071000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 0, -1, 1}, 183.029880, 0.000020, 0.078000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 99.364550, 0.000030, 0.077000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 99.364550, 0.000030, 0.073000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 0, -3}, 100.631050, 0.000020, 0.038000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 1, -3}, 100.630140, 0.000190, 0.075000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 100.682260, 0.000160, 0.074000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 2, -1}, 100.631050, 0.000020, 0.037000},
	{{5, 0, -13, 7, 0, 0, 0, 0, -2, 1, -1}, 303.081240, 0.000020, 0.075000},
	{{5, 0, -13, 7, 0, 0, 0, 0, -2, 1, 1}, 303.081240, 0.000020, 0.075000},
	{{6, 0, 0, 0, -2, 0, 0, 0, -2, 0, -1}, 231.515270, 0.000010, 0.075000},
	{{6, 0, 0, 0, -2, 0, 0, 0, -2, 0, 1}, 231.515270, 0.000010, 0.074000},
	{{6, 0, 0, 0, 0, 0, 0, 0, -2, 0, -1}, 235.020940, 0.000010, 0.075000},
	{{6, 0, 0, 0, 0, 0, 0, 0, -2, 0, 1}, 235.020940, 0.000010, 0.074000},
	{{7, 0, -4, 0, 0, 0, 0, 0, -2, 0, -1}, 138.003810, 0.000010, 0.076000},
	{{7, 0, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 138.003810, 0.000010, 0.073000}
};


static const struct planet_pert plan_pert_elp12 [ELP12_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 90.000000, 0.020450, 99999.999000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2}, 270.015620, 0.000370, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2}, 89.996790, 0.000100, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 269.939680, 0.007200, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 269.940770, 0.000280, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 270.002760, 0.000040, 0.071000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 270.011120, 0.000250, 1.127000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 90.017110, 0.003430, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 90.017150, 0.000210, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 90.080250, 0.002030, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, -2}, 90.144190, 0.000070, 0.065000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 270.105020, 0.030740, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 270.076590, 0.019600, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, -2}, 90.025180, 0.000040, 0.090000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 270.111560, 0.001240, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 269.932830, 0.000100, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -1, 0}, 90.034450, 0.000070, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 270.041640, 0.000100, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -2, 0}, 270.122460, 0.000340, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -1, 0}, 270.181530, 0.000470, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 270.135950, 0.000180, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0}, 49.837980, 0.000050, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 1, 0}, 171.188640, 0.000040, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0}, 351.051780, 0.000290, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0}, 171.051780, 0.000290, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, -1, 0}, 311.685080, 0.000040, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 224.650410, 0.000050, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, 0}, 243.556420, 0.000020, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0}, 63.584190, 0.000140, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0}, 243.584190, 0.000140, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 0}, 63.556420, 0.000020, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, -2, -2, 0, 0}, 245.695120, 0.000120, 0.040000},
	{{0, 0, 0, 0, 0, 0, 1, -2, -2, 1, 0}, 348.854830, 0.000150, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, -2, -2, 2, 0}, 192.201330, 0.000020, 0.564000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, -2, 0}, 192.008920, 0.000050, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, -1, 0}, 191.147090, 0.001150, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 1, 0}, 11.147090, 0.001150, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 0, 2, 0}, 12.008920, 0.000050, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 2, -2, 0}, 12.201320, 0.000020, 0.564000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 2, -1, 0}, 168.936200, 0.000150, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, -2, 2, 0, 0}, 65.997580, 0.000120, 0.040000},
	{{0, 0, 0, 0, 0, 0, 1, 0, -2, 0, 0}, 277.864270, 0.000220, 0.040000},
	{{0, 0, 0, 0, 0, 0, 1, 0, -2, 1, 0}, 258.865940, 0.000210, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, -2, 0}, 327.315630, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0}, 331.479330, 0.000420, 0.076000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0}, 151.559120, 0.000430, 0.075000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 0, 2, 0}, 147.284410, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 2, -1, 0}, 80.939140, 0.000210, 0.087000},
	{{0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0}, 99.523400, 0.000220, 0.040000},
	{{0, 0, 0, 0, 0, 0, 2, 0, 0, -1, 0}, 71.931690, 0.000100, 0.076000},
	{{0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0}, 251.931690, 0.000100, 0.075000},
	{{0, 0, 0, 0, 0, 1, -3, 0, 0, -1, 0}, 35.752920, 0.000070, 0.075000},
	{{0, 0, 0, 0, 0, 1, -3, 0, 0, 1, 0}, 215.752920, 0.000070, 0.075000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -4, 0, 0}, 357.850250, 0.000050, 0.020000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -4, 1, 0}, 357.835160, 0.000160, 0.028000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -4, 2, 0}, 357.712440, 0.000050, 0.044000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, -1, 0}, 356.324300, 0.000360, 0.026000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 0}, 357.690430, 0.004870, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 1, 0}, 359.149320, 0.004690, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 2, 0}, 182.844670, 0.000220, 0.553000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0}, 177.445410, 0.000110, 0.081000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -3, 0}, 350.505560, 0.000020, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -2, 0}, 350.843340, 0.000430, 0.038000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0}, 350.768110, 0.007850, 0.076000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 2}, 171.509860, 0.000030, 0.073000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0}, 168.620600, 0.000080, 29.457000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, -2}, 351.509860, 0.000030, 0.074000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0}, 170.738190, 0.007860, 0.075000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0}, 170.805560, 0.000430, 0.038000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 3, 0}, 170.400410, 0.000020, 0.025000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0}, 357.701670, 0.000100, 0.081000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -2, 0}, 2.333270, 0.000220, 0.575000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -1, 0}, 178.836450, 0.004670, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 0}, 176.904270, 0.004950, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 1, 0}, 176.201340, 0.000350, 0.026000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 4, -2, 0}, 177.486240, 0.000050, 0.043000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 4, -1, 0}, 177.477120, 0.000150, 0.028000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 4, 0, 0}, 177.094980, 0.000050, 0.020000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, 0, 0}, 260.994470, 0.000270, 0.041000},
	{{0, 0, 0, 0, 0, 2, 0, 0, -2, 1, 0}, 252.271470, 0.000390, 0.088000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, -2, 0}, 55.056360, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, -1, 0}, 56.818950, 0.000470, 0.076000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 1, 0}, 236.960450, 0.000480, 0.075000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 2, 0}, 235.008350, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 2, -1, 0}, 73.323840, 0.000320, 0.087000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 2, 0, 0}, 89.321080, 0.000170, 0.040000},
	{{0, 0, 0, 0, 0, 3, 0, 0, -2, 0, 0}, 146.548620, 0.000050, 0.041000},
	{{0, 0, 0, 0, 0, 3, 0, 0, 0, -1, 0}, 349.336320, 0.000030, 0.076000},
	{{0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0}, 169.336320, 0.000030, 0.075000},
	{{0, 0, 0, 0, 1, -5, 0, 0, -2, 0, 0}, 290.353570, 0.000200, 0.040000},
	{{0, 0, 0, 0, 1, -5, 0, 0, -2, 1, 0}, 282.439060, 0.000110, 0.086000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 0, -1, 0}, 334.876340, 0.000110, 0.075000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 0, 1, 0}, 154.876340, 0.000110, 0.076000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 2, -1, 0}, 96.070220, 0.000120, 0.088000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 2, 0, 0}, 103.554510, 0.000230, 0.041000},
	{{0, 0, 0, 0, 1, -3, 0, 0, -2, 0, 0}, 224.888440, 0.000100, 0.040000},
	{{0, 0, 0, 0, 1, -3, 0, 0, -2, 1, 0}, 211.807430, 0.000060, 0.087000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 0, -1, 0}, 325.512580, 0.000090, 0.075000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 0, 1, 0}, 145.512580, 0.000090, 0.076000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 2, -1, 0}, 28.842730, 0.000060, 0.087000},
	{{0, 0, 0, 0, 1, -3, 0, 0, 2, 0, 0}, 41.884200, 0.000100, 0.040000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, 0, 0}, 82.295380, 0.000320, 0.040000},
	{{0, 0, 0, 0, 1, -2, 0, 0, -2, 1, 0}, 100.925640, 0.000300, 0.087000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, -2, 0}, 28.295180, 0.000030, 0.038000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, -1, 0}, 20.760140, 0.000570, 0.076000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 1, 0}, 200.686610, 0.000570, 0.075000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 0, 2, 0}, 207.635430, 0.000030, 0.038000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, -1, 0}, 278.573340, 0.000300, 0.087000},
	{{0, 0, 0, 0, 1, -2, 0, 0, 2, 0, 0}, 260.368490, 0.000320, 0.040000},
	{{0, 0, 0, 0, 1, -1, 0, 0, -2, 0, 0}, 267.145810, 0.000220, 0.041000},
	{{0, 0, 0, 0, 1, -1, 0, 0, -2, 1, 0}, 267.285260, 0.000220, 0.087000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 0, -1, 0}, 265.687210, 0.000110, 0.076000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 0, 1, 0}, 85.571950, 0.000110, 0.075000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 2, -1, 0}, 86.966940, 0.000220, 0.087000},
	{{0, 0, 0, 0, 1, -1, 0, 0, 2, 0, 0}, 86.873330, 0.000210, 0.040000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -6, 1, 0}, 87.027770, 0.000020, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, -1, 0}, 78.724630, 0.000050, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 0, 0}, 90.371290, 0.000360, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 1, 0}, 91.366420, 0.000950, 0.028000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -4, 2, 0}, 91.762540, 0.000520, 0.044000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -3, 0, 0}, 72.247830, 0.000150, 0.027000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -3, 1, 0}, 273.849370, 0.000070, 0.042000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -2, 0}, 80.236440, 0.000320, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, 0}, 81.839900, 0.002550, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, 2}, 265.199940, 0.000040, 0.090000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 0}, 85.300700, 0.041060, 0.041000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 2}, 265.492630, 0.000180, 0.456000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, 0}, 89.840620, 0.046090, 0.088000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, 2}, 270.253710, 0.000110, 0.065000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 2, 0}, 276.156440, 0.002900, 0.538000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 3, 0}, 288.908440, 0.000140, 0.066000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, -1, 0}, 299.544400, 0.000060, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, -1, 1}, 168.483390, 0.000050, 0.083000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, -1}, 348.869440, 0.000060, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 0, 0}, 281.930250, 0.000820, 0.081000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 1, -1}, 348.535950, 0.000080, 0.080000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 1, 0}, 91.018090, 0.000040, 1.030000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -1, 1, 1}, 348.483390, 0.000050, 0.069000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -3, 0}, 13.523370, 0.000140, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -2, 0}, 21.694250, 0.001950, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 0}, 24.972210, 0.037160, 0.076000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 2}, 200.956890, 0.000130, 0.073000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0}, 195.065650, 0.000600, 11.862000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 2}, 53.653970, 0.000020, 0.037000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, -2}, 25.352080, 0.000160, 0.074000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0}, 203.585050, 0.037410, 0.075000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 2, 0}, 200.331640, 0.002000, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 3, 0}, 197.776640, 0.000120, 0.025000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, -1}, 155.625970, 0.000060, 0.070000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, 0}, 283.977800, 0.000030, 1.246000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, -1, 1}, 168.552830, 0.000090, 0.079000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0}, 88.346290, 0.000610, 0.080000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1}, 168.563740, 0.000060, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 1, -1}, 6.042590, 0.000050, 0.081000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 0}, 84.067830, 0.000040, 0.039000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -3, 0}, 113.130460, 0.000140, 0.067000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -2, 0}, 96.677990, 0.002660, 0.592000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, -2}, 88.547430, 0.000110, 0.065000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, 0}, 266.095610, 0.042820, 0.086000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, -2}, 80.596740, 0.000160, 0.494000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 256.154780, 0.035390, 0.040000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, -2}, 80.042950, 0.000040, 0.089000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 0}, 247.093640, 0.002260, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 2, 0}, 256.493610, 0.000280, 0.019000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, -1, -1}, 268.564350, 0.000020, 0.095000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, -1, 0}, 78.949530, 0.000060, 0.042000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, 0, -1}, 88.411280, 0.000030, 0.042000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 3, 0, 0}, 256.723840, 0.000130, 0.027000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -2, 0}, 267.496590, 0.000470, 0.043000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, -1, 0}, 257.833540, 0.000820, 0.028000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 0, 0}, 255.054290, 0.000310, 0.020000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 4, 1, 0}, 266.639620, 0.000040, 0.016000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 6, -1, 0}, 254.760700, 0.000020, 0.016000},
	{{0, 0, 0, 0, 2, -6, 0, 0, -2, 0, 0}, 191.182910, 0.000070, 0.040000},
	{{0, 0, 0, 0, 2, -6, 0, 0, -2, 1, 0}, 191.182920, 0.000040, 0.087000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 0, -1, 0}, 198.513560, 0.000030, 0.075000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 0, 1, 0}, 18.513560, 0.000030, 0.076000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 2, -1, 0}, 10.402350, 0.000040, 0.087000},
	{{0, 0, 0, 0, 2, -6, 0, 0, 2, 0, 0}, 10.402350, 0.000060, 0.040000},
	{{0, 0, 0, 0, 2, -6, 3, 0, -2, 0, 0}, 108.653010, 0.000060, 0.040000},
	{{0, 0, 0, 0, 2, -6, 3, 0, -2, 1, 0}, 270.043910, 0.000090, 0.087000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, -2, 0}, 90.043910, 0.000030, 0.038000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, -1, 0}, 89.847760, 0.000590, 0.075000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, 1, 0}, 269.847760, 0.000590, 0.075000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 0, 2, 0}, 270.043910, 0.000030, 0.038000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 2, -1, 0}, 90.043910, 0.000090, 0.087000},
	{{0, 0, 0, 0, 2, -6, 3, 0, 2, 0, 0}, 288.330860, 0.000060, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 0, 0}, 331.457170, 0.000020, 0.020000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 1, 0}, 282.322470, 0.000130, 0.028000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -4, 2, 0}, 265.448680, 0.000120, 0.044000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -2, 0}, 74.691380, 0.000070, 0.020000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, -1, 0}, 62.265620, 0.000520, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 0, 0}, 350.230930, 0.001920, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, 0}, 268.645930, 0.011280, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, 2}, 75.960950, 0.000020, 0.065000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 2, 0}, 82.909660, 0.001510, 0.564000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 3, 0}, 77.452290, 0.000120, 0.067000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -1, 0, 0}, 150.026020, 0.000050, 0.081000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -1, 1, 0}, 255.960950, 0.000020, 1.129000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -3, 0}, 78.954340, 0.000220, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, 0}, 76.475230, 0.003440, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, 2}, 75.960950, 0.000020, 3.009000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 0}, 76.559680, 0.063120, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 2}, 256.068760, 0.000250, 0.074000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, -2}, 76.068760, 0.000250, 0.074000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, 0}, 256.561630, 0.063130, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, -2}, 255.960950, 0.000020, 2.988000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, 0}, 256.476650, 0.003440, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 3, 0}, 258.965700, 0.000220, 0.025000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 1, -1, 0}, 75.960950, 0.000020, 1.126000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 1, 0, 0}, 333.503220, 0.000050, 0.081000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -3, 0}, 257.473610, 0.000120, 0.067000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -2, 0}, 262.870970, 0.001510, 0.563000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, -2}, 255.960950, 0.000020, 0.065000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, 0}, 88.520730, 0.011310, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 0, 0}, 165.606930, 0.001920, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 1, 0}, 243.477330, 0.000520, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 2, 0}, 254.553490, 0.000070, 0.020000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, -2, 0}, 85.389610, 0.000120, 0.044000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, -1, 0}, 101.898470, 0.000130, 0.028000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 4, 0, 0}, 149.214580, 0.000020, 0.020000},
	{{0, 0, 0, 0, 2, -4, 0, 0, -2, 0, 0}, 340.785510, 0.000110, 0.040000},
	{{0, 0, 0, 0, 2, -4, 0, 0, -2, 1, 0}, 340.783040, 0.000150, 0.087000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, -1, 0}, 349.394760, 0.000070, 0.076000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, 1, 0}, 169.394760, 0.000070, 0.075000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 2, -1, 0}, 161.037440, 0.000150, 0.087000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 2, 0, 0}, 161.032150, 0.000100, 0.040000},
	{{0, 0, 0, 0, 2, -3, 0, 0, -2, 0, 0}, 30.404270, 0.000170, 0.041000},
	{{0, 0, 0, 0, 2, -3, 0, 0, -2, 1, 0}, 30.333700, 0.000150, 0.088000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, -1, 0}, 30.867880, 0.000180, 0.076000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, 1, 0}, 210.864340, 0.000180, 0.075000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 2, -1, 0}, 210.286140, 0.000150, 0.087000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 2, 0, 0}, 210.369940, 0.000150, 0.040000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, 0, 0}, 89.181660, 0.000380, 0.041000},
	{{0, 0, 0, 0, 2, -2, 0, 0, -2, 1, 0}, 89.445820, 0.000350, 0.088000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, -1, 0}, 86.298040, 0.000180, 0.076000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 0, 1, 0}, 266.006920, 0.000170, 0.075000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, -1, 0}, 268.816090, 0.000370, 0.086000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, 0, 0}, 268.653810, 0.000320, 0.040000},
	{{0, 0, 0, 0, 2, -2, 0, 0, 2, 1, 0}, 88.653930, 0.000020, 0.026000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -4, 1, 0}, 218.756730, 0.000020, 0.028000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -4, 2, 0}, 244.933060, 0.000020, 0.044000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, -1, 0}, 102.585220, 0.000110, 0.026000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 0, 0}, 110.381630, 0.000820, 0.041000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 1, -1}, 222.889910, 0.000030, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 1, 0}, 128.018800, 0.000750, 0.088000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 2, 0}, 340.323520, 0.000050, 0.515000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -1, 0, 0}, 231.214430, 0.000080, 0.082000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -2, 0}, 49.265960, 0.000220, 0.038000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -1, 0}, 47.747410, 0.003860, 0.076000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -1}, 223.171320, 0.000330, 0.075000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0}, 231.538430, 0.000150, 5.931000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0}, 227.280060, 0.003970, 0.074000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 2, -1}, 43.671920, 0.000130, 0.075000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 2, 0}, 229.405220, 0.000230, 0.037000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -2, 0}, 138.904620, 0.000040, 0.623000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -1, 0}, 262.135460, 0.001030, 0.086000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0}, 243.601750, 0.001540, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 1, -1}, 42.889910, 0.000030, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 1, 0}, 241.132010, 0.000220, 0.026000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 4, -1, 0}, 248.477160, 0.000030, 0.027000},
	{{0, 0, 0, 0, 2, 5, 0, 0, 2, -2, 0}, 209.788600, 0.000020, 0.697000},
	{{0, 0, 0, 0, 2, 5, 0, 0, 2, 0, 0}, 29.788600, 0.000020, 0.040000},
	{{0, 0, 0, 0, 3, -5, 0, 0, -2, 0, 0}, 174.975420, 0.000280, 0.041000},
	{{0, 0, 0, 0, 3, -5, 0, 0, -2, 1, 0}, 174.447180, 0.000260, 0.088000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, -1, 0}, 178.380810, 0.000240, 0.076000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, 1, 0}, 358.334070, 0.000240, 0.075000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, -1, 0}, 354.237610, 0.000260, 0.086000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 2, 0, 0}, 354.802090, 0.000250, 0.040000},
	{{0, 0, 0, 0, 3, -4, 0, 0, -2, 0, 0}, 210.936000, 0.000060, 0.041000},
	{{0, 0, 0, 0, 3, -4, 0, 0, -2, 1, 0}, 210.936000, 0.000030, 0.088000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 0, -1, 0}, 212.742310, 0.000020, 0.076000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 0, 1, 0}, 32.742310, 0.000020, 0.075000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 2, -1, 0}, 30.503650, 0.000030, 0.086000},
	{{0, 0, 0, 0, 3, -4, 0, 0, 2, 0, 0}, 30.503650, 0.000050, 0.040000},
	{{0, 0, 0, 0, 3, -3, 0, 0, -2, 0, 0}, 72.073910, 0.000070, 0.041000},
	{{0, 0, 0, 0, 3, -3, 0, 0, -2, 1, 0}, 72.073910, 0.000040, 0.088000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 0, -1, 0}, 80.340540, 0.000020, 0.076000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 0, 1, 0}, 260.340540, 0.000020, 0.075000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 2, -1, 0}, 247.345170, 0.000040, 0.086000},
	{{0, 0, 0, 0, 3, -3, 0, 0, 2, 0, 0}, 247.345160, 0.000050, 0.040000},
	{{0, 0, 0, 0, 3, -2, 0, 0, -2, 0, 0}, 86.810540, 0.000070, 0.041000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 0, -1, 0}, 65.801590, 0.000040, 0.077000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 0, 1, 0}, 245.801590, 0.000040, 0.074000},
	{{0, 0, 0, 0, 3, -2, 0, 0, 2, 0, 0}, 257.948020, 0.000050, 0.040000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -2, 0, 0}, 198.503160, 0.000170, 0.041000},
	{{0, 0, 0, 0, 3, 0, 0, 0, -2, 1, 0}, 162.373660, 0.000040, 0.089000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, -1, 0}, 43.764160, 0.000290, 0.077000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 1, 0}, 225.290750, 0.000340, 0.074000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 2, -1, 0}, 343.470580, 0.000030, 0.085000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 2, 0, 0}, 231.593460, 0.000160, 0.040000},
	{{0, 0, 0, 0, 4, -10, 0, 0, -2, 0, 0}, 129.193580, 0.000040, 0.040000},
	{{0, 0, 0, 0, 4, -10, 0, 0, -2, 1, 0}, 87.394040, 0.000040, 0.087000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, -1, 0}, 268.522400, 0.000240, 0.075000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 0, 1, 0}, 88.522400, 0.000240, 0.075000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 2, -1, 0}, 267.394040, 0.000040, 0.087000},
	{{0, 0, 0, 0, 4, -10, 0, 0, 2, 0, 0}, 307.901350, 0.000050, 0.040000},
	{{0, 0, 0, 0, 4, -5, 0, 0, -2, 0, 0}, 164.669640, 0.000050, 0.041000},
	{{0, 0, 0, 0, 4, -5, 0, 0, 2, 0, 0}, 351.333310, 0.000040, 0.040000},
	{{0, 0, 0, 0, 6, -5, 0, 0, 2, -2, 0}, 50.021870, 0.000020, 0.695000},
	{{0, 0, 0, 0, 6, -5, 0, 0, 2, 0, 0}, 230.021870, 0.000020, 0.040000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -4, 1, 0}, 128.923760, 0.000040, 0.028000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, -1, 0}, 128.708400, 0.000140, 0.027000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 0}, 130.224680, 0.001010, 0.041000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 1, 0}, 128.108000, 0.000990, 0.091000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 2, 0}, 308.446180, 0.000080, 0.434000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0}, 5.756190, 0.000030, 0.079000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0}, 122.414980, 0.000100, 1.881000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0}, 227.623590, 0.000030, 0.073000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, -1, -1}, 218.613610, 0.000020, 0.073000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, -1, 1}, 218.708470, 0.000110, 0.077000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0}, 299.723910, 0.000040, 0.078000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 1, -1}, 38.613610, 0.000020, 0.079000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -2, 0}, 119.371840, 0.000040, 0.805000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -1, 0}, 301.610060, 0.000640, 0.083000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 0, 0}, 294.093270, 0.000450, 0.040000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 1, 0}, 300.145670, 0.000040, 0.026000},
	{{0, 0, 0, 2, 0, -2, 0, 0, -2, 0, 0}, 117.147220, 0.000070, 0.042000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -4, 0, 0}, 214.858230, 0.000050, 0.021000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -4, 1, 0}, 215.368180, 0.000080, 0.028000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, -1, 0}, 219.018220, 0.000280, 0.027000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 0}, 223.319480, 0.002770, 0.042000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 1, 0}, 225.049330, 0.001550, 0.096000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 2, 0}, 52.317010, 0.000080, 0.352000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, -1, -1}, 253.738060, 0.000140, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 0, -1}, 253.722570, 0.000940, 0.040000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 0, 1}, 253.751800, 0.000040, 0.472000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 1, -1}, 73.798330, 0.000600, 0.087000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 1, 1}, 253.751800, 0.000030, 0.065000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 2, -1}, 253.760770, 0.000160, 0.561000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -2, 0}, 238.779930, 0.000050, 0.039000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 0}, 250.095250, 0.000810, 0.082000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 85.519930, 0.000270, 0.940000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0}, 126.247790, 0.000420, 0.070000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -3, -1}, 253.760770, 0.000020, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -2, -1}, 253.748350, 0.000550, 0.038000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, -1}, 253.748350, 0.010080, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, 1}, 253.636080, 0.000340, 0.074000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, -3}, 253.704480, 0.000040, 0.074000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, -1}, 73.748350, 0.010080, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 2, -1}, 73.748350, 0.000550, 0.038000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 3, -1}, 73.760770, 0.000020, 0.025000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -1, 0}, 242.520330, 0.000070, 0.080000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0}, 191.656340, 0.000230, 0.039000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 1, 0}, 208.502670, 0.000040, 0.026000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -2, -1}, 73.760770, 0.000160, 0.567000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, -1, -1}, 253.792650, 0.000680, 0.087000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 0, -1}, 73.721380, 0.000890, 0.040000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 3, 1, -1}, 73.738060, 0.000140, 0.026000},
	{{0, 0, 0, 3, 0, 0, 0, 0, -2, 0, 0}, 56.654620, 0.000060, 0.043000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -1, 0}, 0.427260, 0.000100, 0.076000},
	{{0, 0, 0, 4, 0, 0, 0, 0, -2, 0, 0}, 126.937390, 0.000100, 0.044000},
	{{0, 0, 1, -8, 3, 0, 0, 0, 2, 0, 0}, 145.640290, 0.000060, 0.046000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 0, 0}, 314.157830, 0.000090, 0.039000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 1, 0}, 256.068920, 0.000030, 0.079000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, -1, 1}, 75.164560, 0.000050, 0.075000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 1, 1}, 255.164560, 0.000050, 0.076000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, -1, 0}, 77.339480, 0.000060, 0.070000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 0, 0}, 113.268430, 0.000060, 0.888000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 1, 0}, 298.850690, 0.000240, 0.082000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, -2, 0}, 131.393790, 0.000030, 0.345000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, -1, 0}, 312.300280, 0.000600, 0.097000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 0, 0}, 310.933360, 0.001030, 0.042000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 1, 0}, 310.665720, 0.000100, 0.027000},
	{{0, 0, 1, -4, 2, 0, 0, 0, 2, 0, 0}, 25.726130, 0.000050, 0.042000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 0, 0}, 297.216450, 0.000110, 0.039000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 1, 0}, 216.655990, 0.000120, 0.083000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 1, -1}, 291.284650, 0.000080, 0.076000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, -1, 0}, 11.727880, 0.000250, 0.072000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 0, 0}, 54.954670, 0.000070, 1.681000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 1, 0}, 200.974570, 0.000190, 0.079000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, -1, 0}, 353.165910, 0.000260, 0.092000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 0, 0}, 341.960950, 0.000420, 0.041000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 1, 0}, 352.104590, 0.000030, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, -1, 0}, 48.657170, 0.000030, 0.016000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 0, 0}, 49.492090, 0.000320, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 1, 0}, 49.413800, 0.000590, 0.028000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -4, 2, 0}, 51.452720, 0.000290, 0.043000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 0, 0}, 47.934380, 0.000090, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 0, 1}, 3.341080, 0.000060, 0.042000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 1, 0}, 227.988470, 0.000040, 0.042000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -3, 1, 1}, 183.267750, 0.000030, 0.095000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -2, 0}, 47.770250, 0.000250, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -1, 0}, 46.460160, 0.002150, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -1, 2}, 228.632990, 0.000030, 0.089000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 0}, 48.217330, 0.028620, 0.040000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 2}, 228.856200, 0.000110, 0.489000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, 0}, 50.882790, 0.025910, 0.087000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, 2}, 231.772720, 0.000060, 0.065000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 2, 0}, 236.475000, 0.000990, 0.585000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 3, 0}, 248.458760, 0.000040, 0.067000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, -1, 1}, 3.314720, 0.000060, 0.082000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 0}, 229.568860, 0.000470, 0.080000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 1, 1}, 3.314720, 0.000050, 0.070000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -3, 0}, 42.999920, 0.000190, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -2, 0}, 43.275650, 0.003080, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -2, 2}, 42.298370, 0.000020, 3.702000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 0}, 43.268010, 0.058570, 0.075000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 2}, 222.662890, 0.000220, 0.074000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, -2}, 227.818140, 0.000040, 0.037000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, 0}, 47.289920, 0.001540, 15.781000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, 2}, 229.841240, 0.000040, 0.037000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, -2}, 42.643900, 0.000200, 0.073000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, 0}, 223.467410, 0.058960, 0.076000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, -2}, 223.470800, 0.000020, 2.520000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, 0}, 223.172340, 0.003090, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 3, 0}, 223.150820, 0.000190, 0.025000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, 0}, 51.796410, 0.000540, 0.081000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 1, 0}, 46.026090, 0.000050, 0.039000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -3, 0}, 64.461890, 0.000050, 0.066000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -2, 0}, 56.064650, 0.001240, 0.544000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, -2}, 52.313570, 0.000060, 0.065000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, 0}, 231.978480, 0.028410, 0.088000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, -2}, 50.256750, 0.000120, 0.461000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, 0}, 230.254860, 0.031230, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, -2}, 50.053130, 0.000030, 0.090000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, 0}, 229.043380, 0.002260, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 2, 0}, 228.761740, 0.000300, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 3, -1, 0}, 50.792430, 0.000050, 0.042000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 3, 0, 0}, 230.881340, 0.000100, 0.027000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -2, 0}, 232.039700, 0.000320, 0.044000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, -1, 0}, 230.805360, 0.000650, 0.028000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, 0, 0}, 228.063910, 0.000280, 0.020000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 4, 1, 0}, 229.337760, 0.000030, 0.016000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, 0, 0}, 123.610760, 0.000260, 0.040000},
	{{0, 0, 1, -2, 0, 2, 0, 0, -2, 1, 0}, 125.083680, 0.000240, 0.087000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, -1, 0}, 117.195330, 0.000320, 0.075000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 0, 1, 0}, 297.182220, 0.000320, 0.075000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, -1, 0}, 305.031850, 0.000240, 0.087000},
	{{0, 0, 1, -2, 0, 2, 0, 0, 2, 0, 0}, 303.564220, 0.000260, 0.040000},
	{{0, 0, 1, -2, 1, 0, 0, 0, -2, 0, 0}, 285.158930, 0.000070, 0.040000},
	{{0, 0, 1, -2, 1, 0, 0, 0, -2, 1, 0}, 285.158930, 0.000040, 0.087000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 0, -1, 0}, 281.938950, 0.000040, 0.076000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 0, 1, 0}, 101.938950, 0.000040, 0.075000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 2, -1, 0}, 103.611600, 0.000050, 0.087000},
	{{0, 0, 1, -2, 1, 0, 0, 0, 2, 0, 0}, 103.668810, 0.000070, 0.040000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -4, 0, 0}, 90.697250, 0.000060, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -4, 1, 0}, 90.642410, 0.000200, 0.028000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -4, 2, 0}, 90.652470, 0.000070, 0.044000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, -1, 0}, 90.624250, 0.000350, 0.027000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 0}, 90.679580, 0.005640, 0.041000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 2}, 270.648100, 0.000040, 0.388000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 1, 0}, 90.678990, 0.005350, 0.091000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 2, 0}, 270.702950, 0.000340, 0.446000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 0, 0}, 270.469550, 0.000120, 0.084000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -2, 0}, 90.533060, 0.000180, 0.038000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -1, 0}, 90.525500, 0.003020, 0.078000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0}, 269.178380, 0.000350, 2.135000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 1, 0}, 270.446770, 0.002740, 0.073000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 2, 0}, 270.392380, 0.000130, 0.037000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, -3, 1}, 4.411510, 0.000020, 0.074000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, -1, 1}, 184.411510, 0.000020, 0.077000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 0, 0}, 270.233020, 0.000090, 0.078000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -2, 0}, 90.192960, 0.000180, 0.766000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -1, 0}, 270.361640, 0.003680, 0.084000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, 0}, 270.301260, 0.002720, 0.040000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 1, 0}, 270.287060, 0.000340, 0.026000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 4, -2, 0}, 270.479090, 0.000040, 0.043000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 4, -1, 0}, 270.287760, 0.000050, 0.027000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 4, 0, 0}, 270.316890, 0.000040, 0.020000},
	{{0, 0, 1, 0, -5, 0, 0, 0, -2, 0, 0}, 57.396480, 0.000100, 0.041000},
	{{0, 0, 1, 0, -5, 0, 0, 0, -2, 1, 0}, 57.394510, 0.000040, 0.092000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 0, -1, 0}, 53.413150, 0.000060, 0.079000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 0, 1, 0}, 233.413150, 0.000060, 0.072000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 2, -1, 0}, 235.924620, 0.000030, 0.083000},
	{{0, 0, 1, 0, -5, 0, 0, 0, 2, 0, 0}, 235.924620, 0.000030, 0.040000},
	{{0, 0, 1, 0, -5, 2, 0, 0, -2, 0, 0}, 42.397440, 0.000030, 0.042000},
	{{0, 0, 1, 0, -5, 5, 0, 0, -2, 0, 0}, 273.850450, 0.000080, 0.042000},
	{{0, 0, 1, 0, -5, 5, 0, 0, 0, -1, 0}, 272.856440, 0.000030, 0.080000},
	{{0, 0, 1, 0, -5, 5, 0, 0, 0, 1, 0}, 92.856440, 0.000030, 0.071000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, -1, 0}, 47.452000, 0.000070, 0.027000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 0, 0}, 47.926140, 0.000520, 0.042000},
	{{0, 0, 1, 0, -4, 0, 0, 0, -2, 1, 0}, 47.455540, 0.000360, 0.092000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, -2, 0}, 43.661000, 0.000020, 0.039000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, -1, 0}, 43.231390, 0.000520, 0.079000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 0, 0}, 226.866220, 0.000110, 1.509000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 1, 0}, 222.972520, 0.000480, 0.072000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 2, 0}, 223.726190, 0.000020, 0.037000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 1, -1, 1}, 211.204600, 0.000110, 0.076000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 2, -1, 0}, 243.670240, 0.000090, 0.082000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 2, 0, 0}, 226.083350, 0.000170, 0.039000},
	{{0, 0, 1, 0, -4, 2, 0, 0, -2, 0, 0}, 43.238340, 0.000120, 0.042000},
	{{0, 0, 1, 0, -4, 2, 0, 0, -2, 1, 0}, 43.238340, 0.000050, 0.093000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 0, -1, 0}, 38.340300, 0.000050, 0.080000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 0, 0, 0}, 221.903910, 0.000030, 1.369000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 0, 1, 0}, 218.340300, 0.000050, 0.071000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 1, -1, 1}, 11.054600, 0.000060, 0.075000},
	{{0, 0, 1, 0, -4, 2, 0, 0, 2, -1, 0}, 224.730210, 0.000030, 0.082000},
	{{0, 0, 1, 0, -4, 3, 0, 0, -2, 0, 0}, 96.008730, 0.000070, 0.042000},
	{{0, 0, 1, 0, -4, 3, 0, 0, 2, -1, 0}, 70.084000, 0.000030, 0.082000},
	{{0, 0, 1, 0, -4, 4, 0, 0, -2, 0, 0}, 329.615900, 0.000030, 0.042000},
	{{0, 0, 1, 0, -4, 5, 0, 0, -2, 0, 0}, 207.638820, 0.000200, 0.042000},
	{{0, 0, 1, 0, -4, 5, 0, 0, -2, 1, 0}, 207.638860, 0.000070, 0.094000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 0, -1, 0}, 201.370490, 0.000100, 0.080000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 0, 1, 0}, 21.370490, 0.000100, 0.071000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 2, -2, 0}, 28.765700, 0.000020, 1.062000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 2, -1, 0}, 12.112780, 0.000050, 0.081000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 2, 0, 0}, 28.765700, 0.000020, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 0, 0}, 39.309470, 0.000060, 0.021000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 1, 0}, 39.298640, 0.000200, 0.028000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -4, 2, 0}, 39.928680, 0.000040, 0.045000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, -2, 0}, 38.809690, 0.000020, 0.020000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, -1, 0}, 38.167640, 0.000360, 0.027000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, 0}, 39.554020, 0.005330, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, 2}, 219.278940, 0.000040, 0.350000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 1, 0}, 39.487490, 0.004390, 0.093000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 2, 0}, 219.036190, 0.000260, 0.397000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, -2, 1}, 20.657300, 0.000050, 0.040000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, -1, 1}, 20.647620, 0.000410, 0.087000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 0, -1}, 21.735680, 0.000030, 0.040000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 0, 0}, 218.388370, 0.000140, 0.086000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -1, 0, 1}, 200.669730, 0.000060, 0.555000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -2, 0}, 35.470080, 0.000260, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -1, 0}, 36.600850, 0.004070, 0.080000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 0, 0}, 214.848560, 0.001260, 1.339000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 1, 0}, 214.917110, 0.004000, 0.071000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 2, 0}, 214.608020, 0.000200, 0.037000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -3, 1}, 20.620460, 0.000070, 0.076000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -2, 1}, 200.660350, 0.000130, 37.265000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -1, -1}, 201.025270, 0.000150, 0.074000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, -1, 1}, 20.666090, 0.002260, 0.075000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 0, 0}, 217.993730, 0.000290, 0.076000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 0, 1}, 20.524140, 0.000080, 0.038000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 1, 1, -1}, 21.025270, 0.000150, 0.077000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -3, 0}, 24.661970, 0.000040, 0.070000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -2, 0}, 184.777240, 0.000060, 0.974000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -1, 0}, 358.884380, 0.001310, 0.082000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 0, 0}, 224.470520, 0.001220, 0.039000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 1, 0}, 218.557830, 0.000190, 0.026000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -3, 0}, 23.017390, 0.000150, 0.096000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -2, 0}, 22.298670, 0.000460, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, -1, 0}, 20.173810, 0.000240, 0.027000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 4, 0, 0}, 26.809430, 0.000040, 0.020000},
	{{0, 0, 1, 0, -3, 1, 0, 0, -2, 0, 0}, 220.317100, 0.000030, 0.042000},
	{{0, 0, 1, 0, -3, 2, 0, 0, -2, 0, 0}, 86.285520, 0.000150, 0.042000},
	{{0, 0, 1, 0, -3, 2, 0, 0, -2, 1, 0}, 86.285510, 0.000130, 0.094000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 0, -1, 0}, 85.280360, 0.000130, 0.080000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 0, 0, 0}, 264.660620, 0.000020, 1.227000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 0, 1, 0}, 265.280360, 0.000130, 0.071000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 2, -3, 0}, 90.631770, 0.000020, 0.070000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 2, -1, 0}, 267.170540, 0.000070, 0.081000},
	{{0, 0, 1, 0, -3, 2, 0, 0, 2, 0, 0}, 266.797170, 0.000080, 0.039000},
	{{0, 0, 1, 0, -3, 3, 0, 0, -2, 0, 0}, 150.487790, 0.000130, 0.042000},
	{{0, 0, 1, 0, -3, 3, 0, 0, -2, 1, 0}, 150.487790, 0.000050, 0.094000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 0, -1, 0}, 150.370290, 0.000040, 0.081000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 0, 0, 0}, 330.230200, 0.000030, 1.178000},
	{{0, 0, 1, 0, -3, 3, 0, 0, 0, 1, 0}, 330.370290, 0.000040, 0.071000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, -1, 0}, 262.544800, 0.000050, 0.027000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 0, 0}, 262.555190, 0.000490, 0.042000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 1, 0}, 262.440400, 0.000270, 0.095000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, -1, 0}, 262.821240, 0.000330, 0.081000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 0, 0}, 82.497860, 0.000110, 1.091000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 1, 0}, 82.894650, 0.000260, 0.071000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 1, 0, 0}, 262.581860, 0.000160, 0.075000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 2, -1, 0}, 80.741650, 0.000070, 0.081000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 2, 0, 0}, 82.469040, 0.000170, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, -1, 0}, 35.669540, 0.000070, 0.016000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 0, 0}, 35.946280, 0.000360, 0.021000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 0, 2}, 36.213850, 0.000030, 0.046000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 1, 0}, 36.855250, 0.000810, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -4, 2, 0}, 35.700360, 0.000420, 0.045000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 0, 0}, 36.691020, 0.000130, 0.028000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 0, 1}, 190.504640, 0.000020, 0.044000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 1, 0}, 216.641100, 0.000070, 0.043000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -3, 1, 1}, 10.567760, 0.000020, 0.104000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -2, 0}, 34.509860, 0.000210, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -1, 0}, 36.145990, 0.002710, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 0}, 36.025800, 0.043220, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 2}, 215.728660, 0.000190, 0.340000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, 0}, 36.013090, 0.034260, 0.094000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, 2}, 215.510000, 0.000110, 0.062000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 2, 0}, 216.688950, 0.002140, 0.384000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 3, 0}, 218.076680, 0.000110, 0.063000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -2, 1}, 10.524030, 0.000040, 0.041000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -1, 0}, 216.068850, 0.000070, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, -1, 1}, 10.516690, 0.000580, 0.088000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 0}, 215.727670, 0.001770, 0.087000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 1}, 10.495850, 0.000060, 0.530000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, -1}, 10.543820, 0.000310, 0.085000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, 0}, 35.942130, 0.000200, 0.582000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 1, 1}, 10.557540, 0.000150, 0.066000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 2, -1}, 190.518540, 0.000020, 0.644000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -3, 0}, 30.002330, 0.000120, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -2, 0}, 29.414450, 0.001780, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, 0}, 31.079720, 0.033510, 0.080000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, 2}, 210.258100, 0.000080, 0.069000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, -2}, 32.136320, 0.000090, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 0}, 210.979680, 0.010020, 1.203000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 2}, 34.682860, 0.000100, 0.036000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, -2}, 31.402770, 0.000060, 0.078000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, 0}, 211.449850, 0.027560, 0.071000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 2, 0}, 211.322420, 0.001490, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 3, 0}, 215.287570, 0.000070, 0.025000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, -1}, 190.523170, 0.000080, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, 0}, 38.835350, 0.000180, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, 1}, 190.524110, 0.000250, 8.998000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, -1}, 190.523220, 0.001460, 0.074000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 0}, 33.536420, 0.000390, 17.980000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 1}, 10.525600, 0.003930, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, -1}, 190.526430, 0.000280, 4.497000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 0}, 216.218470, 0.006410, 0.076000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, -1}, 10.524010, 0.001510, 0.077000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, 0}, 216.090150, 0.000340, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 2, -1}, 10.523210, 0.000080, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -3, 0}, 357.667110, 0.000030, 0.070000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -2, 0}, 42.259140, 0.000330, 1.061000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, -2}, 44.615020, 0.000030, 0.069000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, 0}, 211.325400, 0.015690, 0.081000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, 0}, 214.956590, 0.010350, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 1, 0}, 213.542950, 0.000870, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 2, 0}, 215.060900, 0.000070, 0.019000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -2, -1}, 10.518480, 0.000020, 0.501000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -2, 0}, 215.503760, 0.000020, 0.088000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -2, 1}, 10.524110, 0.000040, 0.040000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -1, -1}, 190.481230, 0.000080, 0.089000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -1, 0}, 215.844520, 0.000110, 0.041000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, -1, 1}, 10.524110, 0.000040, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 0, -1}, 10.539270, 0.000140, 0.041000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 3, 0, 0}, 215.734480, 0.000100, 0.026000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -3, 0}, 13.915140, 0.000150, 0.095000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -2, 0}, 199.830970, 0.000370, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, -1, 0}, 201.052100, 0.000930, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 4, 0, 0}, 204.411560, 0.000210, 0.020000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 6, -2, 0}, 191.214400, 0.000030, 0.021000},
	{{0, 0, 1, 0, -2, 1, 0, 0, -2, 0, 0}, 272.976980, 0.000110, 0.042000},
	{{0, 0, 1, 0, -2, 1, 0, 0, -2, 1, 0}, 272.976980, 0.000040, 0.094000},
	{{0, 0, 1, 0, -2, 1, 0, 0, 0, -1, 0}, 272.799620, 0.000030, 0.081000},
	{{0, 0, 1, 0, -2, 1, 0, 0, 0, 1, 0}, 92.799620, 0.000030, 0.071000},
	{{0, 0, 1, 0, -2, 2, 0, 0, -2, 0, 0}, 118.726000, 0.000100, 0.042000},
	{{0, 0, 1, 0, -2, 2, 0, 0, -2, 1, 0}, 118.726000, 0.000090, 0.094000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 0, -1, 0}, 112.409800, 0.000080, 0.081000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 0, 1, 0}, 292.409800, 0.000080, 0.071000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 1, 0, 0}, 101.063710, 0.000070, 0.075000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 2, -3, 0}, 278.863320, 0.000020, 0.071000},
	{{0, 0, 1, 0, -2, 2, 0, 0, 2, -1, 0}, 278.863320, 0.000020, 0.081000},
	{{0, 0, 1, 0, -2, 4, 0, 0, -2, 0, 0}, 78.120650, 0.000120, 0.042000},
	{{0, 0, 1, 0, -2, 4, 0, 0, -2, 1, 0}, 78.120650, 0.000040, 0.095000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 0, -1, 0}, 78.586190, 0.000030, 0.081000},
	{{0, 0, 1, 0, -2, 4, 0, 0, 0, 1, 0}, 258.586190, 0.000030, 0.070000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, -1, 0}, 224.488340, 0.000040, 0.027000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 0, 0}, 284.745020, 0.000360, 0.042000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 1, 0}, 341.542810, 0.000470, 0.095000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 2, 0}, 181.371180, 0.000050, 0.360000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, -2, 0}, 180.153140, 0.000040, 0.039000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, -1, 0}, 199.775470, 0.000370, 0.082000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 0, 0}, 127.233850, 0.000070, 0.999000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 1, 0}, 164.987790, 0.000360, 0.070000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 2, 0}, 181.102120, 0.000030, 0.036000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 2, -2, 0}, 250.196270, 0.000020, 1.294000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 2, -1, 0}, 346.844550, 0.000070, 0.080000},
	{{0, 0, 1, 0, -1, -5, 0, 0, -2, 0, 0}, 48.208200, 0.000080, 0.042000},
	{{0, 0, 1, 0, -1, -5, 0, 0, -2, 1, 0}, 48.207770, 0.000030, 0.093000},
	{{0, 0, 1, 0, -1, -5, 0, 0, 0, -1, 0}, 45.897340, 0.000030, 0.080000},
	{{0, 0, 1, 0, -1, -5, 0, 0, 0, 1, 0}, 225.897340, 0.000030, 0.071000},
	{{0, 0, 1, 0, -1, -2, 0, 0, -2, 0, 0}, 197.019460, 0.000050, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 1, 0}, 91.296820, 0.000050, 0.017000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -6, 2, 0}, 91.571350, 0.000110, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -3, 0}, 91.895890, 0.000020, 0.011000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -2, 0}, 272.078040, 0.000020, 0.013000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, -1, 0}, 90.340950, 0.000290, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 0, 0}, 93.033670, 0.001590, 0.021000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 0, 2}, 91.786760, 0.000130, 0.046000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 1, 0}, 92.534140, 0.004010, 0.028000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 1, 2}, 91.800130, 0.000080, 0.118000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 2, 0}, 92.359770, 0.001810, 0.045000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -4, 3, 0}, 91.071130, 0.000060, 0.114000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, -1, 0}, 92.081740, 0.000060, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, 0, 0}, 91.677540, 0.000190, 0.028000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, 1, 0}, 272.438810, 0.000360, 0.044000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -3, 2, 0}, 272.428200, 0.000030, 0.103000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -3, 0}, 91.680260, 0.000060, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -2, 0}, 91.544810, 0.000770, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -1, 0}, 92.066840, 0.012790, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, -1, 2}, 271.763540, 0.000120, 0.098000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 0}, 91.798620, 0.204970, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 2}, 271.758500, 0.000750, 0.331000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, -2}, 271.743580, 0.000080, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, 0}, 91.745780, 0.157510, 0.095000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 1, 2}, 271.640030, 0.000400, 0.061000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, -2}, 271.651650, 0.000030, 0.041000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, 0}, 271.663040, 0.010340, 0.372000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 2, 2}, 271.662000, 0.000030, 0.034000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 3, 0}, 272.128480, 0.000560, 0.063000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 4, 0}, 271.796960, 0.000030, 0.034000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -2, 0}, 90.691670, 0.000050, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -1, 0}, 90.528590, 0.000660, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, -1, 1}, 6.691910, 0.000040, 0.089000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, -1}, 5.800780, 0.000020, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 0, 0}, 90.581080, 0.007930, 0.087000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 1, -1}, 6.532280, 0.000020, 0.086000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 1, 0}, 270.611780, 0.001210, 0.555000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -1, 2, 0}, 270.349580, 0.000060, 0.066000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -3, 0}, 88.955970, 0.000420, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -2, 0}, 91.250480, 0.006820, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -2, 2}, 91.257180, 0.000040, 0.801000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, -2}, 91.623540, 0.000020, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, 0}, 91.227510, 0.126660, 0.081000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, -1, 2}, 270.777240, 0.000360, 0.069000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, -2}, 90.881500, 0.000090, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0}, 271.226250, 0.042770, 1.092000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 2}, 90.328070, 0.000120, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, -2}, 88.537250, 0.000170, 0.079000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 1, 0}, 271.067260, 0.105040, 0.071000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 2, -2}, 271.289160, 0.000040, 1.718000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 2, 0}, 271.011870, 0.005690, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 3, 0}, 271.060180, 0.000320, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -3, 0}, 270.857260, 0.000030, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -2, 0}, 270.857240, 0.000520, 0.076000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, -1}, 186.642870, 0.000190, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, 0}, 270.698310, 0.003400, 34.860000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, -1, 1}, 6.648000, 0.000190, 0.074000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, -2}, 270.710190, 0.000240, 0.074000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 0}, 90.708880, 0.062090, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 1}, 187.389910, 0.000040, 0.037000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, -1}, 6.642870, 0.000190, 0.076000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 1, 0}, 90.716130, 0.003430, 0.038000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 2, 0}, 90.710190, 0.000210, 0.025000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -3, 0}, 273.148100, 0.000060, 0.071000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -2, -2}, 271.622420, 0.000020, 0.036000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -2, 0}, 89.539130, 0.000990, 1.165000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -1, -2}, 91.053260, 0.000120, 0.069000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, -1, 0}, 270.550450, 0.043660, 0.081000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, -2}, 91.017710, 0.000120, 0.839000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 0, 0}, 270.464420, 0.038750, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 1, -2}, 87.145310, 0.000030, 0.083000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 1, 0}, 269.973640, 0.003190, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 2, 2, 0}, 271.115940, 0.000320, 0.019000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -3, 0}, 90.743790, 0.000040, 0.573000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -2, 0}, 270.721300, 0.000510, 0.087000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -1, -1}, 186.532280, 0.000020, 0.088000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, -1, 0}, 90.618430, 0.000350, 0.040000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 0, -1}, 6.792140, 0.000020, 0.041000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 0, 0}, 90.935860, 0.000390, 0.026000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 3, 1, 0}, 90.710160, 0.000070, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -3, 0}, 91.448630, 0.000020, 0.094000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -2, 0}, 270.887710, 0.000440, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -1, -2}, 270.248450, 0.000020, 0.097000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, -1, 0}, 270.711720, 0.000820, 0.027000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 0, -2}, 270.247130, 0.000020, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 0, 0}, 271.488110, 0.000440, 0.020000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 1, 0}, 270.193240, 0.000060, 0.016000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 4, 2, 0}, 90.540690, 0.000020, 0.013000},
	{{0, 0, 1, 0, -1, 1, 0, 0, -2, 0, 0}, 315.458220, 0.000070, 0.042000},
	{{0, 0, 1, 0, -1, 2, 0, 0, -2, 0, 0}, 140.242960, 0.000060, 0.042000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, 0, 0}, 44.824680, 0.000240, 0.042000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, 1, 0}, 45.261760, 0.000140, 0.094000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, -1, 0}, 41.285470, 0.000190, 0.080000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, 0, 0}, 220.706990, 0.000030, 1.204000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, 1, 0}, 220.608130, 0.000160, 0.071000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 1, 0, 0}, 219.967690, 0.000030, 0.076000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 2, -1, 0}, 204.926640, 0.000070, 0.081000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 2, 0, 0}, 224.847960, 0.000080, 0.039000},
	{{0, 0, 1, 0, 0, -4, 0, 0, -2, 0, 0}, 198.780240, 0.000090, 0.042000},
	{{0, 0, 1, 0, 0, -4, 0, 0, -2, 1, 0}, 198.780180, 0.000030, 0.094000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 0, -1, 0}, 199.319780, 0.000020, 0.081000},
	{{0, 0, 1, 0, 0, -4, 0, 0, 0, 1, 0}, 19.319780, 0.000020, 0.071000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, -1, 0}, 106.799850, 0.000040, 0.027000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 0, 0}, 106.615890, 0.000440, 0.042000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 1, 0}, 107.072080, 0.000240, 0.094000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -1, 0, 0}, 107.014720, 0.000060, 0.087000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, -1, 0}, 106.826180, 0.000330, 0.081000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 0, 0}, 287.204410, 0.000100, 1.113000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 1, 0}, 286.783340, 0.000270, 0.071000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, -1, -1}, 296.530660, 0.000040, 0.075000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, -1, 1}, 116.530710, 0.000060, 0.074000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 0, 0}, 107.017420, 0.000340, 0.075000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 1, 1, -1}, 116.530660, 0.000040, 0.076000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 2, -1, 0}, 287.118650, 0.000070, 0.081000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 2, 0, 0}, 286.994490, 0.000140, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -4, 0, 0}, 16.179640, 0.000030, 0.021000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -4, 1, 0}, 16.080120, 0.000070, 0.028000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -4, 2, 0}, 15.771980, 0.000020, 0.045000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, -1, 0}, 15.964500, 0.000220, 0.027000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 0, 0}, 15.445980, 0.003010, 0.042000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 1, 0}, 15.920740, 0.002290, 0.095000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 2, 0}, 196.034430, 0.000140, 0.370000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, -1, 1}, 23.922190, 0.000050, 0.089000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 0, -1}, 23.922060, 0.000040, 0.040000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 0, 0}, 16.303580, 0.000060, 0.087000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 0, 1}, 23.922200, 0.000030, 0.504000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 1, -1}, 23.922080, 0.000040, 0.086000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -1, 1, 1}, 23.922210, 0.000020, 0.066000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, -2, 0}, 15.608860, 0.000130, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, -1, 0}, 15.630190, 0.002000, 0.081000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 0, 0}, 196.796170, 0.000720, 1.073000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 1, 0}, 195.685490, 0.001800, 0.070000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 2, 0}, 195.631990, 0.000090, 0.036000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, -1}, 203.922170, 0.000360, 0.075000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, 0}, 196.205510, 0.000030, 22.176000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, -1, 1}, 23.922190, 0.000280, 0.074000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, -1}, 203.922220, 0.000040, 8.220000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 0}, 16.272960, 0.000610, 0.075000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 1}, 203.922300, 0.000070, 0.037000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 1, -1}, 23.922170, 0.000360, 0.076000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 1, 0}, 16.272960, 0.000030, 0.038000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, -2, 0}, 195.862990, 0.000040, 1.188000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, -1, 0}, 196.674050, 0.000440, 0.081000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, 0, 0}, 196.171790, 0.000500, 0.039000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 2, 1, 0}, 196.509210, 0.000030, 0.026000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 3, -1, -1}, 203.922090, 0.000020, 0.088000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 3, 0, -1}, 23.922220, 0.000040, 0.041000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -6, 2, 0}, 90.691050, 0.000020, 0.021000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 0, 0}, 90.276590, 0.000130, 0.021000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 1, 0}, 90.674780, 0.000370, 0.028000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -4, 2, 0}, 90.649610, 0.000090, 0.045000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -3, 0, 0}, 90.844420, 0.000040, 0.028000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, -2, 0}, 90.680720, 0.000050, 0.020000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, -1, 0}, 90.636670, 0.000720, 0.027000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 0, 0}, 90.748790, 0.011790, 0.042000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 0, 2}, 270.690710, 0.000030, 0.325000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 1, 0}, 90.689980, 0.008950, 0.095000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 2, 0}, 270.734150, 0.000580, 0.365000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -2, 3, 0}, 270.715920, 0.000030, 0.063000},
	{{0, 0, 1, 0, 0, -1, 0, 0, -1, 0, 0}, 89.760130, 0.000080, 0.088000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -2, 0}, 90.465460, 0.000410, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -1, 0}, 90.454100, 0.007610, 0.081000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, -1, 2}, 270.464610, 0.000020, 0.069000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0}, 270.420370, 0.002740, 1.035000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 1, -2}, 90.464610, 0.000020, 0.079000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 1, 0}, 270.395940, 0.006370, 0.070000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 2, 0}, 270.381150, 0.000310, 0.036000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -2, 0}, 271.801920, 0.000020, 0.076000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -1, -1}, 260.106570, 0.000070, 0.075000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -1, 0}, 270.296480, 0.000080, 12.652000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, -1, 1}, 80.185930, 0.000030, 0.074000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 0}, 90.318370, 0.001440, 0.075000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 1, -1}, 80.106570, 0.000070, 0.076000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 1, 0}, 90.318370, 0.000080, 0.038000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, -2, 0}, 89.065950, 0.000020, 1.238000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, -1, 0}, 270.255010, 0.001970, 0.080000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 0, 0}, 270.079980, 0.002190, 0.039000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 2, 1, 0}, 270.330450, 0.000260, 0.026000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 4, -2, 0}, 270.383040, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 4, -1, 0}, 270.187810, 0.000050, 0.027000},
	{{0, 0, 1, 0, 0, 0, -3, 0, -2, 0, 0}, 182.895490, 0.000040, 0.042000},
	{{0, 0, 1, 0, 0, 0, -2, 0, -2, 0, 0}, 6.998750, 0.000150, 0.042000},
	{{0, 0, 1, 0, 0, 0, -2, 0, -2, 1, 0}, 6.998750, 0.000130, 0.095000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 0, -1, 0}, 7.015130, 0.000130, 0.081000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 0, 0, 0}, 187.004000, 0.000030, 1.024000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 0, 1, 0}, 187.015130, 0.000130, 0.070000},
	{{0, 0, 1, 0, 0, 0, -2, 0, 2, 0, 0}, 186.826190, 0.000050, 0.039000},
	{{0, 0, 1, 0, 0, 0, -1, 0, -2, 0, 0}, 83.676480, 0.000310, 0.042000},
	{{0, 0, 1, 0, 0, 0, -1, 0, -2, 1, 0}, 83.427810, 0.000170, 0.095000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 0, -1, 0}, 85.087400, 0.000200, 0.082000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0}, 266.455240, 0.000040, 1.012000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 0, 1, 0}, 265.407320, 0.000160, 0.070000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 2, -1, 0}, 279.915430, 0.000030, 0.080000},
	{{0, 0, 1, 0, 0, 0, -1, 0, 2, 0, 0}, 269.016760, 0.000060, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, -2, -2, 0, 0}, 13.594470, 0.000220, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -2, -2, 1, 0}, 13.594470, 0.000080, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, -1, 0}, 13.585740, 0.000080, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 1, 0}, 193.585740, 0.000080, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -2, 0, 0}, 91.699660, 0.000220, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -2, 1, 0}, 91.699660, 0.000080, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 0}, 91.378500, 0.000080, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, 0}, 271.378500, 0.000080, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 0, 0}, 158.466710, 0.000050, 0.021000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 1, 0}, 155.503810, 0.000110, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 2, 0}, 156.701810, 0.000030, 0.046000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -1, 0}, 159.543410, 0.000310, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 154.838060, 0.003770, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 153.962990, 0.002950, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 327.358070, 0.000180, 0.360000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 3, 0}, 3.720700, 0.000030, 0.062000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -1, 1}, 5.800200, 0.000060, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, -1}, 176.193820, 0.000070, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 182.886010, 0.000080, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 1}, 181.574980, 0.000170, 0.487000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, -1}, 179.676370, 0.000320, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, 1}, 188.911400, 0.000110, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -2, 0}, 180.150130, 0.000170, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 181.636490, 0.003010, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 11.135900, 0.000080, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 5.677160, 0.001260, 1.000000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 13.351810, 0.000070, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 358.648320, 0.002600, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 359.151680, 0.000140, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -2, -1}, 355.692460, 0.000040, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -2, 1}, 16.726660, 0.000030, 3.575000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, -1}, 4.994660, 0.000900, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 0}, 354.882270, 0.000060, 8.850000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 1}, 186.156990, 0.000180, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 172.912440, 0.000090, 18.600000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 174.803010, 0.001100, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1}, 187.974500, 0.000120, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, -1}, 183.723200, 0.000890, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0}, 174.803010, 0.000060, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 2, -1}, 175.448860, 0.000040, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 60.060070, 0.000130, 1.292000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 287.846700, 0.002100, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -1}, 8.013970, 0.000030, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 314.086490, 0.001360, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 1, 0}, 319.869890, 0.000130, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -1, -1}, 8.006060, 0.000200, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, 0, -1}, 1.585220, 0.000020, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 4, -2, 0}, 307.301620, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 4, -1, 0}, 307.390510, 0.000030, 0.027000},
	{{0, 0, 1, 0, 0, 0, 1, -2, -2, 0, 0}, 253.791360, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 0, 1, 0, -2, 0, 0}, 173.748990, 0.000050, 0.042000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, -1, 0}, 255.711370, 0.000040, 0.027000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, 0, 0}, 255.323730, 0.000540, 0.042000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -2, 1, 0}, 257.463360, 0.000210, 0.096000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 0, -1}, 64.276320, 0.000070, 0.040000},
	{{0, 0, 1, 0, 0, 1, 0, 0, -1, 1, -1}, 244.060690, 0.000070, 0.087000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 0, -1, 0}, 254.424430, 0.000170, 0.082000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0}, 75.119870, 0.000090, 0.967000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 0}, 81.041190, 0.000070, 0.070000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -2, -1}, 64.144830, 0.000040, 0.038000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -1, -1}, 64.181740, 0.000910, 0.075000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, -1, 1}, 244.213520, 0.000080, 0.074000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 1, -1}, 244.181740, 0.000910, 0.076000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 2, -1}, 244.144830, 0.000040, 0.038000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 2, -1, 0}, 256.023180, 0.000020, 0.080000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 2, 0, 0}, 254.510340, 0.000050, 0.039000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 3, -1, -1}, 64.060690, 0.000070, 0.087000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 3, 0, -1}, 244.276320, 0.000070, 0.040000},
	{{0, 0, 1, 0, 0, 2, 0, 0, -2, 0, 0}, 153.288490, 0.000050, 0.042000},
	{{0, 0, 1, 0, 0, 2, 0, 0, -1, 1, -1}, 146.927540, 0.000020, 0.087000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, -1, -1}, 326.729330, 0.000150, 0.076000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 1, -1}, 146.729330, 0.000150, 0.075000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 3, -1, -1}, 326.927540, 0.000020, 0.087000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, -1, 0}, 101.689720, 0.000050, 0.027000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 0, 0}, 101.691570, 0.000540, 0.042000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 1, 0}, 101.592990, 0.000310, 0.095000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, -1, 0}, 101.723350, 0.000360, 0.081000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 0, 0}, 281.136320, 0.000120, 1.093000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 1, 0}, 281.739590, 0.000290, 0.071000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 1, 0, 0}, 101.207830, 0.000170, 0.075000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 2, -1, 0}, 278.451940, 0.000090, 0.081000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 2, 0, 0}, 280.343230, 0.000170, 0.039000},
	{{0, 0, 1, 0, 1, -3, 0, 0, -2, 0, 0}, 38.900790, 0.000100, 0.042000},
	{{0, 0, 1, 0, 1, -3, 0, 0, -2, 1, 0}, 38.900790, 0.000080, 0.095000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 0, -1, 0}, 38.306310, 0.000080, 0.081000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 0, 1, 0}, 218.306310, 0.000080, 0.070000},
	{{0, 0, 1, 0, 1, -3, 0, 0, 2, 0, 0}, 215.228500, 0.000030, 0.039000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, -1, 0}, 273.226670, 0.000050, 0.027000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, 0, 0}, 273.148270, 0.000540, 0.042000},
	{{0, 0, 1, 0, 1, -2, 0, 0, -2, 1, 0}, 273.334140, 0.000270, 0.096000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, -1, 0}, 271.998540, 0.000350, 0.082000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 0, 0}, 91.358680, 0.000120, 0.984000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 0, 1, 0}, 91.727960, 0.000290, 0.070000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 2, -1, 0}, 81.440230, 0.000030, 0.080000},
	{{0, 0, 1, 0, 1, -2, 0, 0, 2, 0, 0}, 89.155590, 0.000130, 0.039000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -2, 0, 0}, 156.363150, 0.000040, 0.042000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -1, 0, -1}, 3.735230, 0.000070, 0.040000},
	{{0, 0, 1, 0, 1, -1, 0, 0, -1, 1, -1}, 184.199330, 0.000050, 0.087000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, -2, -1}, 3.990440, 0.000030, 0.038000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, -1, -1}, 3.911230, 0.000800, 0.075000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 1, -1}, 183.911230, 0.000800, 0.075000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 2, -1}, 183.990440, 0.000030, 0.038000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 3, -1, -1}, 4.199330, 0.000050, 0.087000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 3, 0, -1}, 183.735230, 0.000070, 0.040000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, -1, 0}, 157.997110, 0.000020, 0.016000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, 0, 0}, 336.467110, 0.000090, 0.021000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, 1, 0}, 338.310180, 0.000250, 0.028000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -4, 2, 0}, 336.373350, 0.000060, 0.046000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, -2, 0}, 334.902070, 0.000020, 0.020000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, -1, 0}, 334.078080, 0.000360, 0.027000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, 0}, 334.676370, 0.005000, 0.042000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, 2}, 155.110450, 0.000030, 0.313000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 1, 0}, 337.411820, 0.003480, 0.096000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 2, 0}, 162.518480, 0.000220, 0.350000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, -1, -1}, 165.536530, 0.000050, 0.026000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 0, -1}, 165.544550, 0.000440, 0.040000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 0, 1}, 165.508620, 0.000040, 0.468000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 1, -1}, 345.823680, 0.000210, 0.087000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 1, 1}, 165.508630, 0.000030, 0.065000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -1, 2, -1}, 165.426760, 0.000060, 0.554000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, -2, 0}, 318.132690, 0.000110, 0.039000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, -1, 0}, 317.544480, 0.001650, 0.082000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0}, 145.721100, 0.000570, 0.922000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0}, 149.700400, 0.001040, 0.070000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 2, 0}, 156.097730, 0.000040, 0.036000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -2, -1}, 165.577270, 0.000210, 0.038000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -1, -1}, 165.577270, 0.003930, 0.076000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, -1, 1}, 165.692170, 0.000430, 0.073000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0}, 308.928390, 0.000070, 0.074000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 1}, 345.012780, 0.000050, 0.037000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 1, -1}, 345.577270, 0.003930, 0.075000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 2, -1}, 345.577270, 0.000210, 0.038000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, -2, 0}, 140.328800, 0.000040, 1.450000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, -1, 0}, 332.718330, 0.000110, 0.080000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, 0, 0}, 9.069680, 0.000080, 0.039000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 2, 1, 0}, 336.391000, 0.000060, 0.026000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, -2, -1}, 345.627420, 0.000060, 0.574000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, -1, -1}, 165.734680, 0.000270, 0.087000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 0, -1}, 345.475010, 0.000340, 0.040000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 3, 1, -1}, 345.536530, 0.000050, 0.026000},
	{{0, 0, 1, 0, 2, -7, 0, 0, -2, 0, 0}, 203.766450, 0.000080, 0.042000},
	{{0, 0, 1, 0, 2, -7, 0, 0, 0, -1, 0}, 203.707140, 0.000020, 0.081000},
	{{0, 0, 1, 0, 2, -7, 0, 0, 0, 1, 0}, 23.707140, 0.000020, 0.070000},
	{{0, 0, 1, 0, 2, -6, 0, 0, -2, 0, 0}, 281.225420, 0.000150, 0.042000},
	{{0, 0, 1, 0, 2, -6, 0, 0, -2, 1, 0}, 281.225420, 0.000050, 0.095000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, -1, 0}, 281.183150, 0.000040, 0.081000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, 0, 0}, 101.127740, 0.000040, 1.036000},
	{{0, 0, 1, 0, 2, -6, 0, 0, 0, 1, 0}, 101.183150, 0.000040, 0.070000},
	{{0, 0, 1, 0, 2, -6, 3, 0, -2, 0, 0}, 347.327530, 0.000050, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 0, 0}, 155.693580, 0.000050, 0.021000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 1, 0}, 156.929340, 0.000170, 0.028000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -4, 2, 0}, 155.619460, 0.000050, 0.046000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, -2, 0}, 156.883480, 0.000020, 0.020000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, -1, 0}, 157.283200, 0.000280, 0.027000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, 0}, 157.195060, 0.005200, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, 2}, 336.961680, 0.000040, 0.322000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 1, 0}, 156.586500, 0.004290, 0.095000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 2, 0}, 336.426060, 0.000300, 0.361000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -1, 0, -1}, 149.055630, 0.000040, 0.040000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -2, 0}, 156.510510, 0.000170, 0.039000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -1, 0}, 155.859680, 0.002930, 0.082000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 0, 0}, 335.529420, 0.001210, 1.001000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 1, 0}, 335.346820, 0.003060, 0.070000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 2, 0}, 334.980940, 0.000160, 0.036000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, 0}, 155.351960, 0.000440, 0.075000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, 1}, 329.056060, 0.000030, 0.037000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, -1, 0}, 336.615950, 0.000450, 0.080000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 0, 0}, 333.066190, 0.000790, 0.039000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 1, 0}, 334.589850, 0.000110, 0.026000},
	{{0, 0, 1, 0, 2, -4, 0, 0, -2, 0, 0}, 13.386470, 0.000030, 0.042000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, -1, -1}, 52.384080, 0.000020, 0.075000},
	{{0, 0, 1, 0, 2, -4, 0, 0, 1, 1, -1}, 232.384080, 0.000020, 0.076000},
	{{0, 0, 1, 0, 2, -3, 0, 0, -2, 0, 0}, 273.775140, 0.000070, 0.042000},
	{{0, 0, 1, 0, 2, -2, 0, 0, -2, 0, 0}, 330.323910, 0.000100, 0.042000},
	{{0, 0, 1, 0, 2, -2, 0, 0, -2, 1, 0}, 330.323910, 0.000030, 0.096000},
	{{0, 0, 1, 0, 2, 0, 0, 0, -2, 0, 0}, 338.300730, 0.000230, 0.042000},
	{{0, 0, 1, 0, 2, 0, 0, 0, -2, 1, 0}, 352.956570, 0.000050, 0.097000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 0, -1, 0}, 316.864250, 0.000070, 0.083000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 0, 1, 0}, 149.603230, 0.000030, 0.069000},
	{{0, 0, 1, 0, 3, -5, 0, 0, -2, 0, 0}, 59.050940, 0.000060, 0.042000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 1, -1, -1}, 260.123920, 0.000020, 0.076000},
	{{0, 0, 1, 0, 3, -5, 0, 0, 1, 1, -1}, 80.123920, 0.000020, 0.075000},
	{{0, 0, 1, 0, 4, -10, 0, 0, -2, 0, 0}, 348.140340, 0.000070, 0.042000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -2, 0, 0}, 4.128700, 0.000270, 0.043000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -2, 1, 0}, 7.340540, 0.000070, 0.101000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, -1, 0}, 340.922340, 0.000120, 0.085000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0}, 155.888800, 0.000040, 0.653000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0}, 166.441330, 0.000080, 0.068000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -1, 0}, 330.936040, 0.000250, 0.077000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, 0, 0}, 328.655310, 0.000030, 0.038000},
	{{0, 0, 1, 2, -3, 0, 0, 0, 2, -1, 0}, 154.516990, 0.000040, 0.075000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -2, 0, 0}, 127.203840, 0.000160, 0.044000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -2, 1, 0}, 136.238040, 0.000050, 0.106000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -1, 0, -1}, 150.785060, 0.000060, 0.042000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -1, 1, -1}, 330.858400, 0.000030, 0.095000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, -1, -1}, 150.811420, 0.000060, 0.082000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, 1, -1}, 150.811420, 0.000050, 0.070000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 0, -1, 0}, 223.018580, 0.000030, 0.066000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 0, 0, 0}, 222.709090, 0.000040, 0.500000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 0, 1, 0}, 42.482400, 0.000070, 0.089000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, -1, 0}, 43.036840, 0.000180, 0.105000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, 0, 0}, 42.640120, 0.000720, 0.044000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 2, 1, 0}, 42.694380, 0.000060, 0.028000},
	{{0, 0, 2, -8, 3, 0, 0, 0, 4, 0, 0}, 222.685130, 0.000040, 0.021000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 1, 0}, 148.210250, 0.000020, 0.079000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 3, 0}, 328.210250, 0.000020, 0.072000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 0, -1, 0}, 99.126680, 0.000030, 0.069000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 0, 1, 0}, 279.126680, 0.000030, 0.083000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 2, -1, 0}, 287.035330, 0.000080, 0.097000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 2, 0, 0}, 285.996150, 0.000160, 0.042000},
	{{0, 0, 2, -6, 2, 0, 0, 0, 2, -1, 0}, 343.924570, 0.000030, 0.096000},
	{{0, 0, 2, -6, 2, 0, 0, 0, 2, 0, 0}, 343.924570, 0.000100, 0.042000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 0, 0}, 323.163930, 0.000060, 0.039000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 1, 0}, 186.562910, 0.000020, 0.082000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 1, -1}, 261.961090, 0.000080, 0.076000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, -1, 0}, 4.018950, 0.000180, 0.072000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 0, 0}, 18.092430, 0.000040, 1.519000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 1, 0}, 185.984500, 0.000180, 0.079000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, -1, 0}, 270.996680, 0.000090, 0.092000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, 0, 0}, 272.963530, 0.000160, 0.042000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 0, 0}, 30.155960, 0.000080, 0.020000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 1, 0}, 31.853000, 0.000270, 0.028000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -4, 2, 0}, 33.843880, 0.000060, 0.043000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -3, 0, 0}, 30.699360, 0.000030, 0.027000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -2, 0}, 32.277180, 0.000030, 0.019000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -1, 0}, 30.968420, 0.000620, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, 0}, 30.563360, 0.008610, 0.040000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 1, 0}, 32.460000, 0.008340, 0.086000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 2, 0}, 215.096480, 0.000350, 0.607000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -1, 0, 0}, 211.942700, 0.000120, 0.080000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -3, 0}, 27.752060, 0.000050, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -2, 0}, 27.846630, 0.000830, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, 0}, 27.791530, 0.015960, 0.075000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, 2}, 207.747340, 0.000060, 0.074000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, 0}, 29.984430, 0.000860, 7.890000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, -2}, 27.747340, 0.000060, 0.073000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, 0}, 208.077360, 0.016220, 0.076000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 2, 0}, 207.795220, 0.000860, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 3, 0}, 207.611070, 0.000050, 0.025000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, 0, 0}, 22.482360, 0.000280, 0.082000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -2, 0}, 35.693390, 0.000500, 0.526000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, -2}, 32.146260, 0.000020, 0.065000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, 0}, 213.408370, 0.010210, 0.088000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, -2}, 32.657000, 0.000030, 0.448000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, 0}, 212.724410, 0.010970, 0.041000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 1, -2}, 32.820870, 0.000020, 0.091000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 1, 0}, 211.632250, 0.000770, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 2, 0}, 212.743010, 0.000060, 0.020000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 3, 0, 0}, 213.304410, 0.000040, 0.027000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, -2, 0}, 213.940640, 0.000080, 0.044000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, -1, 0}, 212.826770, 0.000210, 0.028000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 4, 0, 0}, 212.680020, 0.000110, 0.020000},
	{{0, 0, 2, -4, 1, 0, 0, 0, -2, 0, 0}, 245.384810, 0.000150, 0.040000},
	{{0, 0, 2, -4, 1, 0, 0, 0, -2, 1, 0}, 245.845890, 0.000070, 0.087000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 0, -1, 0}, 243.666810, 0.000130, 0.075000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 0, 1, 0}, 63.666810, 0.000130, 0.076000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 2, -1, 0}, 66.236250, 0.000070, 0.087000},
	{{0, 0, 2, -4, 1, 0, 0, 0, 2, 0, 0}, 65.591350, 0.000160, 0.040000},
	{{0, 0, 2, -4, 2, 0, 0, 0, -2, 0, 0}, 90.553630, 0.000240, 0.040000},
	{{0, 0, 2, -4, 2, 0, 0, 0, -2, 1, 0}, 90.962300, 0.000200, 0.087000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, -1, 0}, 89.322280, 0.000340, 0.076000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 0, 1, 0}, 269.135270, 0.000300, 0.075000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 2, -1, 0}, 270.814880, 0.000170, 0.087000},
	{{0, 0, 2, -4, 2, 0, 0, 0, 2, 0, 0}, 270.455020, 0.000220, 0.040000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, 0, 0}, 60.875010, 0.000090, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, 1, 0}, 60.855780, 0.000300, 0.028000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -4, 2, 0}, 60.725420, 0.000080, 0.044000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -3, 0, 0}, 61.118650, 0.000040, 0.027000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, -2, 0}, 62.358180, 0.000040, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, -1, 0}, 60.665420, 0.000570, 0.027000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, 0}, 61.052100, 0.009110, 0.041000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, 2}, 240.802930, 0.000020, 0.398000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 1, 0}, 60.940470, 0.008440, 0.090000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 2, 0}, 241.171010, 0.000500, 0.459000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 3, 0}, 240.874350, 0.000030, 0.065000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 0, 0}, 240.674470, 0.000170, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -2, 0}, 59.785710, 0.000400, 0.038000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, 0}, 59.834340, 0.007680, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, 2}, 239.799710, 0.000020, 0.071000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, 0}, 240.321300, 0.001200, 2.470000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, 0}, 239.739410, 0.007020, 0.073000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 2, 0}, 239.731250, 0.000370, 0.037000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, -1, 1}, 143.385220, 0.000060, 0.077000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 0, 0}, 240.922530, 0.000080, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -2, 0}, 61.108840, 0.000260, 0.730000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -1, 0}, 241.136130, 0.005360, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, -2}, 60.593850, 0.000030, 0.587000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, 0}, 240.558940, 0.004580, 0.040000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 1, 0}, 240.463320, 0.000350, 0.026000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 4, -2, 0}, 240.808580, 0.000060, 0.043000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 4, -1, 0}, 240.622780, 0.000170, 0.027000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 4, 0, 0}, 240.785840, 0.000050, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, -1, 0}, 91.025140, 0.000070, 0.016000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 0, 0}, 86.923020, 0.000430, 0.021000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 0, 2}, 88.770420, 0.000050, 0.046000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 1, 0}, 87.321360, 0.001060, 0.028000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -4, 2, 0}, 87.940380, 0.000500, 0.045000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -3, 0, 0}, 88.172130, 0.000180, 0.028000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -3, 1, 0}, 268.261920, 0.000090, 0.044000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -2, 0}, 89.101370, 0.000260, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, -1, 0}, 87.974930, 0.003560, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, -2}, 268.599730, 0.000020, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 0}, 88.576000, 0.057230, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 2}, 268.891120, 0.000250, 0.329000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, -2}, 268.811480, 0.000020, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, 0}, 88.871130, 0.043960, 0.095000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, 2}, 269.005340, 0.000130, 0.061000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 2, 0}, 269.153560, 0.002870, 0.369000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 3, 0}, 268.300780, 0.000130, 0.063000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, -1, 0}, 90.573490, 0.000060, 0.041000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 0, 0}, 90.379550, 0.001110, 0.087000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -1, 1, 0}, 270.340400, 0.000200, 0.548000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -3, 0}, 89.614580, 0.000130, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -2, 0}, 89.570180, 0.001830, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, 0}, 89.535310, 0.037260, 0.081000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, 2}, 270.696680, 0.000080, 0.069000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, -2}, 90.054910, 0.000120, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0}, 269.743410, 0.013290, 1.068000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 2}, 89.662230, 0.000130, 0.036000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, -2}, 92.093240, 0.000070, 0.079000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, 0}, 270.143830, 0.031160, 0.070000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 2, 0}, 270.268000, 0.001740, 0.036000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 3, 0}, 269.967230, 0.000090, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -4, 0}, 270.238910, 0.000020, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -2, 0}, 270.491580, 0.000170, 0.076000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, -1}, 189.340310, 0.000130, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, 0}, 270.230700, 0.000630, 20.152000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, -1, 1}, 9.570050, 0.000090, 0.074000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, -2}, 270.234880, 0.000040, 0.074000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 0}, 90.274820, 0.011120, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, -1}, 9.340310, 0.000130, 0.076000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 1, 0}, 90.234890, 0.000620, 0.038000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 2, 0}, 90.238910, 0.000020, 0.025000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -3, 0}, 272.268820, 0.000020, 0.071000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -2, 0}, 92.252520, 0.000170, 1.194000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -1, -2}, 89.499300, 0.000030, 0.069000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -1, 0}, 270.492420, 0.011170, 0.081000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, -2}, 89.791280, 0.000020, 0.854000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, 0}, 270.957810, 0.010920, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 1, 0}, 271.131340, 0.000900, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 2, 0}, 269.684480, 0.000080, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, -2, 0}, 270.431760, 0.000040, 0.087000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, -1, 0}, 90.218730, 0.000090, 0.040000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 3, 0, 0}, 89.392340, 0.000050, 0.026000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -2, 0}, 269.862340, 0.000100, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -1, 0}, 270.232990, 0.000330, 0.027000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, 0, 0}, 270.450350, 0.000100, 0.020000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, 1, 0}, 90.714280, 0.000030, 0.016000},
	{{0, 0, 2, -2, 0, 2, 0, 0, -2, 0, 0}, 20.922360, 0.000040, 0.042000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, -1, 0}, 346.283510, 0.000050, 0.027000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 0, 0}, 344.124900, 0.000650, 0.043000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 1, 0}, 348.860650, 0.000190, 0.100000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, -1, 0}, 325.027620, 0.000330, 0.085000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 0, 0}, 139.877250, 0.000170, 0.681000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 1, 0}, 144.698680, 0.000190, 0.068000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -1, 0}, 308.601200, 0.000490, 0.077000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, 0, 0}, 304.150060, 0.000080, 0.038000},
	{{0, 0, 2, 0, -7, 10, 0, 0, 2, -3, 0}, 337.917360, 0.000020, 0.075000},
	{{0, 0, 2, 0, -7, 10, 0, 0, 2, -1, 0}, 337.917360, 0.000020, 0.076000},
	{{0, 0, 2, 0, -6, 0, 0, 0, -2, 0, 0}, 308.520010, 0.000080, 0.043000},
	{{0, 0, 2, 0, -6, 0, 0, 0, 2, -1, 0}, 311.063950, 0.000050, 0.077000},
	{{0, 0, 2, 0, -6, 5, 0, 0, -2, 0, 0}, 170.019520, 0.000090, 0.043000},
	{{0, 0, 2, 0, -6, 5, 0, 0, 2, -1, 0}, 169.072670, 0.000180, 0.076000},
	{{0, 0, 2, 0, -5, 0, 0, 0, -2, 0, 0}, 299.143800, 0.000340, 0.043000},
	{{0, 0, 2, 0, -5, 0, 0, 0, -2, 1, 0}, 299.003640, 0.000140, 0.101000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, -1, 0}, 299.978440, 0.000290, 0.086000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, 0, 0}, 120.614700, 0.000120, 0.634000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, 1, 0}, 120.601470, 0.000140, 0.067000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, -2, 0}, 119.582260, 0.000040, 5.114000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, -1, 0}, 299.495890, 0.000710, 0.077000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 2, 0, 0}, 300.059410, 0.000120, 0.038000},
	{{0, 0, 2, 0, -5, 2, 0, 0, -2, 0, 0}, 280.259190, 0.000130, 0.043000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 0, -1, 0}, 281.199710, 0.000060, 0.086000},
	{{0, 0, 2, 0, -5, 2, 0, 0, 2, -1, 0}, 281.485480, 0.000220, 0.076000},
	{{0, 0, 2, 0, -5, 3, 0, 0, -2, 0, 0}, 304.007000, 0.000070, 0.043000},
	{{0, 0, 2, 0, -5, 3, 0, 0, 2, -1, 0}, 302.106620, 0.000150, 0.076000},
	{{0, 0, 2, 0, -5, 4, 0, 0, -2, 0, 0}, 154.014510, 0.000040, 0.043000},
	{{0, 0, 2, 0, -5, 4, 0, 0, 2, -3, 0}, 163.796440, 0.000030, 0.075000},
	{{0, 0, 2, 0, -5, 4, 0, 0, 2, -1, 0}, 148.285050, 0.000150, 0.076000},
	{{0, 0, 2, 0, -5, 5, 0, 0, -2, 0, 0}, 146.731690, 0.000190, 0.043000},
	{{0, 0, 2, 0, -5, 5, 0, 0, -2, 1, 0}, 146.740210, 0.000090, 0.103000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, -1, 0}, 144.464570, 0.000690, 0.087000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, 0, 0}, 324.765920, 0.000110, 0.572000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, 1, 0}, 326.542930, 0.000070, 0.067000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -3, 0}, 336.914980, 0.000040, 0.075000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -2, 0}, 323.754420, 0.000190, 38.763000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -1, 0}, 144.217740, 0.003770, 0.076000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, 0, 0}, 144.470080, 0.000220, 0.038000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 4, -3, 0}, 141.986970, 0.000040, 0.087000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 4, -2, 0}, 144.155540, 0.000080, 0.040000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 4, -1, 0}, 144.207060, 0.000030, 0.026000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -4, 0, 0}, 289.888180, 0.000030, 0.021000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -4, 1, 0}, 289.819560, 0.000070, 0.029000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, -1, 0}, 289.842260, 0.000220, 0.028000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 0, 0}, 289.772060, 0.003010, 0.043000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 1, 0}, 289.802530, 0.001760, 0.102000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 2, 0}, 109.651100, 0.000120, 0.291000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -2, 0}, 290.313090, 0.000170, 0.040000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -1, 0}, 290.278690, 0.003370, 0.086000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 0, 0}, 111.558590, 0.001050, 0.601000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 1, 0}, 110.944920, 0.001130, 0.067000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 2, 0}, 110.786550, 0.000070, 0.035000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 1, 0, 0}, 291.432180, 0.000040, 0.071000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -3, 0}, 109.926830, 0.000110, 0.075000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -2, 0}, 110.095740, 0.000690, 8.990000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, -2}, 109.940000, 0.000040, 0.073000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, 0}, 289.761230, 0.011910, 0.076000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, 0, 0}, 290.467390, 0.000890, 0.038000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, 1, 0}, 290.159060, 0.000080, 0.025000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -3, 0}, 289.765120, 0.000030, 0.088000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -2, 0}, 289.815640, 0.000160, 0.041000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 4, -1, 0}, 289.939870, 0.000100, 0.026000},
	{{0, 0, 2, 0, -4, 1, 0, 0, -2, 0, 0}, 105.304120, 0.000040, 0.043000},
	{{0, 0, 2, 0, -4, 1, 0, 0, 2, -1, 0}, 99.720490, 0.000050, 0.076000},
	{{0, 0, 2, 0, -4, 2, 0, 0, -2, 0, 0}, 272.703270, 0.000250, 0.043000},
	{{0, 0, 2, 0, -4, 2, 0, 0, -2, 1, 0}, 272.713800, 0.000110, 0.103000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, -2, 0}, 272.224220, 0.000030, 0.040000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, -1, 0}, 272.407220, 0.000580, 0.087000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, 0, 0}, 92.379790, 0.000100, 0.578000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 0, 1, 0}, 92.521490, 0.000100, 0.067000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -2, 0}, 92.264690, 0.000150, 23.075000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, -1, 0}, 272.381680, 0.002790, 0.076000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 2, 0, 0}, 272.056350, 0.000200, 0.038000},
	{{0, 0, 2, 0, -4, 2, 0, 0, 4, -2, 0}, 272.231760, 0.000030, 0.040000},
	{{0, 0, 2, 0, -4, 3, 0, 0, -2, 0, 0}, 329.162340, 0.000140, 0.044000},
	{{0, 0, 2, 0, -4, 3, 0, 0, -2, 1, 0}, 329.162340, 0.000040, 0.103000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, -2, 0}, 147.299460, 0.000070, 0.040000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, -1, 0}, 327.183070, 0.000680, 0.087000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, 0, 0}, 147.621670, 0.000130, 0.567000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 0, 1, 0}, 148.911140, 0.000020, 0.067000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -3, 0}, 142.687240, 0.000210, 0.075000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -2, 0}, 147.228410, 0.000230, 106.494000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -1, 0}, 327.163340, 0.004570, 0.075000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, 0, 0}, 327.311290, 0.000260, 0.038000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 4, -3, 0}, 328.929310, 0.000110, 0.087000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 4, -2, 0}, 327.342660, 0.000160, 0.040000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 4, -1, 0}, 327.164260, 0.000040, 0.026000},
	{{0, 0, 2, 0, -4, 4, -2, 0, 2, -3, 0}, 264.859960, 0.000020, 0.075000},
	{{0, 0, 2, 0, -4, 4, -2, 0, 2, -1, 0}, 84.859960, 0.000020, 0.075000},
	{{0, 0, 2, 0, -4, 4, 0, 0, -2, 0, 0}, 207.582380, 0.000030, 0.044000},
	{{0, 0, 2, 0, -4, 4, 0, 0, 0, -1, 0}, 26.939600, 0.000030, 0.087000},
	{{0, 0, 2, 0, -4, 4, 0, 0, 2, -1, 0}, 26.939140, 0.000190, 0.075000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, -1, 0}, 81.228080, 0.000050, 0.028000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 0, 0}, 81.229680, 0.000540, 0.044000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 1, 0}, 81.230290, 0.000190, 0.104000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, -2, 0}, 260.993400, 0.000080, 0.041000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, -1, 0}, 261.200440, 0.000840, 0.088000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, 1, 0}, 261.283810, 0.000170, 0.066000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -3, 0}, 236.436960, 0.000050, 0.076000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -2, 0}, 81.568430, 0.000340, 17.093000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -1, 0}, 261.218910, 0.005850, 0.075000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, 0, 0}, 265.078280, 0.000100, 0.038000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 4, -2, 0}, 260.305160, 0.000040, 0.040000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 4, -1, 0}, 261.201860, 0.000050, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, -1, 0}, 280.016990, 0.000030, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 0, 0}, 279.425090, 0.000210, 0.021000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 1, 0}, 280.416180, 0.000410, 0.029000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -4, 2, 0}, 280.485570, 0.000120, 0.047000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -3, 0, 0}, 280.209720, 0.000070, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -3, 0}, 280.102410, 0.000020, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -2, 0}, 280.260820, 0.000170, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -1, 0}, 280.294450, 0.001920, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, -1, 2}, 100.235440, 0.000020, 0.106000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, 0}, 280.177550, 0.022060, 0.043000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, 2}, 100.362880, 0.000090, 0.259000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, 0}, 280.341450, 0.012410, 0.103000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, 2}, 100.579070, 0.000020, 0.058000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 2, 0}, 100.313400, 0.000900, 0.284000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 3, 0}, 100.385660, 0.000060, 0.060000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, -1, 0}, 100.085800, 0.000060, 0.042000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -1, 0, 0}, 101.530810, 0.000150, 0.094000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -3, 0}, 99.649910, 0.000040, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, 0}, 281.289380, 0.000420, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, 2}, 280.089040, 0.000030, 0.481000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 0}, 280.165160, 0.077250, 0.087000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 2}, 100.171140, 0.000190, 0.065000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, -2}, 280.825100, 0.000040, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 0}, 100.188780, 0.014800, 0.572000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, -2}, 280.694190, 0.000030, 0.084000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, 0}, 100.770830, 0.008190, 0.067000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 2, 0}, 100.639640, 0.000430, 0.035000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, -2, 0}, 280.659870, 0.000040, 0.081000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, -1, 0}, 280.085840, 0.000160, 1.163000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 1, 0, 0}, 278.194270, 0.000390, 0.071000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -5, 0}, 100.152030, 0.000030, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -4, 0}, 100.152230, 0.000490, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, 0}, 100.149060, 0.008950, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, 2}, 99.823440, 0.000020, 0.074000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, -2}, 100.082790, 0.000080, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 0}, 100.096650, 0.023410, 37.133000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 2}, 100.082790, 0.000080, 0.037000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, -2}, 100.073960, 0.001450, 0.073000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 0}, 280.069240, 0.410110, 0.076000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, -2}, 280.085860, 0.000170, 2.774000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, 0}, 280.382320, 0.024600, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 1, -2}, 100.384600, 0.000060, 0.078000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 1, 0}, 279.998430, 0.001470, 0.025000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 2, 0}, 280.034190, 0.000070, 0.019000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 3, -2, 0}, 100.013020, 0.000110, 0.081000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 3, -1, 0}, 100.085830, 0.000120, 0.039000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -4, 0}, 99.862350, 0.000130, 0.555000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -3, 0}, 279.992990, 0.003450, 0.087000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, -2}, 280.082790, 0.000030, 0.469000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, 0}, 280.061180, 0.008040, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, -2}, 100.085870, 0.000080, 0.090000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, 0}, 280.083780, 0.003910, 0.026000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, 0, 0}, 278.102140, 0.000490, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, 1, 0}, 280.085790, 0.000040, 0.016000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -4, 0}, 279.991810, 0.000040, 0.044000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -3, 0}, 280.044130, 0.000130, 0.028000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -2, 0}, 280.071150, 0.000110, 0.020000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 6, -1, 0}, 280.082790, 0.000020, 0.016000},
	{{0, 0, 2, 0, -3, 0, 2, 0, 2, -1, 0}, 259.784040, 0.000050, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, -2, 0, 0}, 93.602120, 0.000130, 0.044000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -2, 0}, 271.307370, 0.000210, 0.040000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, -1, 0}, 271.423910, 0.000980, 0.087000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 0, 0, 0}, 91.438280, 0.000120, 0.561000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -3, 0}, 269.805140, 0.000330, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -2, 0}, 91.340350, 0.000270, 142.500000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, -1, 0}, 271.456480, 0.004420, 0.075000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 2, 0, 0}, 271.456480, 0.000240, 0.038000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -3, 0}, 91.914250, 0.000140, 0.087000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -2, 0}, 91.279880, 0.000110, 0.040000},
	{{0, 0, 2, 0, -3, 1, 0, 0, 4, -1, 0}, 271.431690, 0.000040, 0.026000},
	{{0, 0, 2, 0, -3, 2, 0, 0, -2, 0, 0}, 292.892510, 0.000150, 0.044000},
	{{0, 0, 2, 0, -3, 2, 0, 0, -2, 1, 0}, 292.892510, 0.000040, 0.103000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 0, -1, 0}, 100.845560, 0.000150, 0.087000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 0, 0, 0}, 111.126570, 0.000040, 0.551000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 0, 1, 0}, 105.519860, 0.000020, 0.066000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -3, 0}, 91.208640, 0.000030, 0.076000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -2, 0}, 281.142040, 0.000060, 24.411000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, -1, 0}, 101.465820, 0.000970, 0.075000},
	{{0, 0, 2, 0, -3, 2, 0, 0, 2, 0, 0}, 101.443470, 0.000050, 0.038000},
	{{0, 0, 2, 0, -3, 5, 0, 0, -2, 0, 0}, 166.314860, 0.000090, 0.044000},
	{{0, 0, 2, 0, -3, 5, 0, 0, 2, -1, 0}, 40.222740, 0.000040, 0.075000},
	{{0, 0, 2, 0, -2, -5, 0, 0, -2, 0, 0}, 298.355040, 0.000060, 0.043000},
	{{0, 0, 2, 0, -2, -5, 0, 0, 2, -1, 0}, 299.411910, 0.000100, 0.076000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 0, -2, 0}, 255.357110, 0.000020, 0.040000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 0, -1, 0}, 75.662430, 0.000140, 0.087000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -2, 0}, 255.391550, 0.000050, 95.036000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, -1, 0}, 75.636280, 0.000840, 0.076000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 2, 0, 0}, 75.662300, 0.000040, 0.038000},
	{{0, 0, 2, 0, -2, -2, 0, 0, 4, -2, 0}, 75.357110, 0.000020, 0.040000},
	{{0, 0, 2, 0, -2, -1, 0, 0, 2, -3, 0}, 250.431290, 0.000030, 0.076000},
	{{0, 0, 2, 0, -2, -1, 0, 0, 2, -1, 0}, 78.081300, 0.000170, 0.075000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, -1, 0}, 268.877070, 0.000130, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 0, 0}, 272.014350, 0.000840, 0.021000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 0, 2}, 270.879800, 0.000050, 0.048000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 1, 0}, 271.721130, 0.001990, 0.029000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 2, 0}, 271.244970, 0.000760, 0.047000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -4, 3, 0}, 270.573700, 0.000030, 0.127000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -3, 0, 0}, 271.530070, 0.000050, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -3, 1, 0}, 91.140250, 0.000160, 0.045000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -3, 0}, 271.439010, 0.000030, 0.016000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -2, 0}, 271.740950, 0.000150, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, -1, 0}, 271.525680, 0.004610, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 0}, 270.939280, 0.105030, 0.044000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 2}, 90.847580, 0.000410, 0.254000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, -2}, 90.806360, 0.000020, 0.027000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, 0}, 270.860620, 0.060820, 0.104000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, 2}, 90.782040, 0.000190, 0.058000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 2, 0}, 90.798760, 0.004510, 0.277000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 3, 0}, 90.969340, 0.000250, 0.059000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, -1, 0}, 268.977310, 0.000040, 0.042000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, -1, 1}, 267.587180, 0.000030, 0.096000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 0, 0}, 91.757900, 0.000690, 0.095000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -1, 1, 0}, 270.563340, 0.000110, 0.368000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -4, 0}, 90.122130, 0.000060, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -3, 0}, 89.984230, 0.000700, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -2, 0}, 89.996650, 0.011600, 0.041000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -2, 2}, 90.104990, 0.000080, 0.462000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, -2}, 270.121980, 0.000020, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, 0}, 89.978630, 0.144500, 0.088000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, 2}, 270.087260, 0.000340, 0.065000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, -2}, 270.307510, 0.000330, 0.040000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, 0}, 94.020890, 0.002000, 0.546000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, 2}, 270.385120, 0.000340, 0.035000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 1, -2}, 90.002760, 0.000040, 0.085000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 1, 0}, 90.394290, 0.032800, 0.066000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 2, 0}, 90.340220, 0.001840, 0.035000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 3, 0}, 90.388110, 0.000110, 0.024000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, -2, 0}, 270.129490, 0.000140, 0.081000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, -1, 0}, 90.128840, 0.000530, 1.059000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 0, 0}, 270.680350, 0.001350, 0.070000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 1, 0}, 270.162530, 0.000090, 0.036000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -4, 0}, 90.047700, 0.000230, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -3, 0}, 90.057830, 0.004310, 0.076000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -3, 2}, 90.116510, 0.000030, 0.073000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, -2}, 270.127200, 0.000250, 0.037000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, 0}, 270.117780, 0.060900, 17.430000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, 2}, 270.153840, 0.000240, 0.037000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, -2}, 270.120770, 0.004500, 0.074000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, 0}, 90.119690, 1.058700, 0.075000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, -2}, 90.128000, 0.000610, 3.621000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 0, 0}, 90.125700, 0.043500, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, -2}, 90.112830, 0.000420, 0.077000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 1, 0}, 90.221120, 0.002850, 0.025000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 2, -2}, 90.113620, 0.000030, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, 2, 0}, 89.897880, 0.000150, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, -2, 0}, 270.196290, 0.000030, 0.080000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, -1, 0}, 270.121830, 0.000330, 0.039000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 3, 0, 0}, 270.121830, 0.000040, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -4, 0}, 90.101470, 0.000180, 0.583000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -3, 0}, 270.092130, 0.003700, 0.087000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -3, 2}, 270.121980, 0.000020, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -2, -2}, 90.121980, 0.000090, 0.488000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -2, 0}, 90.138260, 0.007170, 0.040000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -1, -2}, 270.125210, 0.000280, 0.089000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, -1, 0}, 90.126620, 0.008870, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 0, -2}, 270.117320, 0.000020, 0.041000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 0, 0}, 90.122490, 0.000890, 0.019000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 1, 0}, 90.139960, 0.000060, 0.015000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 4, 2, 0}, 270.118100, 0.000020, 0.013000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -4, 0}, 270.090930, 0.000040, 0.043000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -3, 0}, 90.169080, 0.000050, 0.028000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -2, 0}, 90.128780, 0.000190, 0.020000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 6, -1, 0}, 90.121860, 0.000090, 0.016000},
	{{0, 0, 2, 0, -2, 1, 0, 0, -2, 0, 0}, 131.732640, 0.000030, 0.044000},
	{{0, 0, 2, 0, -2, 1, 0, 0, 2, -1, 0}, 275.994650, 0.000050, 0.075000},
	{{0, 0, 2, 0, -2, 2, 0, 0, -2, 0, 0}, 13.513140, 0.000090, 0.044000},
	{{0, 0, 2, 0, -2, 2, 0, 0, 0, -1, 0}, 190.954120, 0.000040, 0.088000},
	{{0, 0, 2, 0, -2, 2, 0, 0, 2, -1, 0}, 190.954190, 0.000220, 0.075000},
	{{0, 0, 2, 0, -2, 3, 0, 0, -2, 0, 0}, 259.154610, 0.000100, 0.044000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 0, -1, 0}, 80.933980, 0.000040, 0.088000},
	{{0, 0, 2, 0, -2, 3, 0, 0, 2, -1, 0}, 80.933980, 0.000250, 0.075000},
	{{0, 0, 2, 0, -2, 5, 0, 0, -2, 0, 0}, 197.136770, 0.000050, 0.044000},
	{{0, 0, 2, 0, -2, 5, 0, 0, 2, -3, 0}, 230.766100, 0.000030, 0.077000},
	{{0, 0, 2, 0, -2, 5, 0, 0, 2, -1, 0}, 50.766100, 0.000030, 0.074000},
	{{0, 0, 2, 0, -1, -5, 0, 0, -2, 0, 0}, 288.783210, 0.000150, 0.043000},
	{{0, 0, 2, 0, -1, -5, 0, 0, -2, 1, 0}, 288.774760, 0.000080, 0.103000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, -1, 0}, 288.989690, 0.000620, 0.087000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, 0, 0}, 109.040770, 0.000100, 0.573000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, 1, 0}, 109.025300, 0.000070, 0.067000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -3, 0}, 140.812690, 0.000020, 0.075000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -2, 0}, 108.703920, 0.000170, 35.635000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -1, 0}, 288.962820, 0.003330, 0.076000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, 0, 0}, 288.987360, 0.000200, 0.038000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 4, -3, 0}, 285.195570, 0.000040, 0.087000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 4, -2, 0}, 288.705800, 0.000070, 0.040000},
	{{0, 0, 2, 0, -1, -4, 0, 0, 2, -1, 0}, 66.429410, 0.000050, 0.075000},
	{{0, 0, 2, 0, -1, -2, 0, 0, -2, 0, 0}, 81.918410, 0.000110, 0.044000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 0, -1, 0}, 259.909020, 0.000070, 0.088000},
	{{0, 0, 2, 0, -1, -2, 0, 0, 2, -1, 0}, 259.908760, 0.000420, 0.075000},
	{{0, 0, 2, 0, -1, -1, 0, 0, 2, -3, 0}, 82.414570, 0.000030, 0.076000},
	{{0, 0, 2, 0, -1, -1, 0, 0, 2, -1, 0}, 82.414570, 0.000030, 0.075000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, -2, 0}, 171.953600, 0.000020, 0.014000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 0, 0}, 351.406320, 0.000350, 0.021000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 1, 0}, 352.463460, 0.000610, 0.029000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -4, 2, 0}, 352.923150, 0.000150, 0.048000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -3, 0, 0}, 353.404860, 0.000090, 0.028000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -3, 1, 0}, 173.423470, 0.000040, 0.046000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -2, 0}, 355.392890, 0.000100, 0.020000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, -1, 0}, 353.631090, 0.001390, 0.028000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, 0}, 354.460190, 0.020100, 0.044000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, 2}, 175.283290, 0.000040, 0.249000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 1, 0}, 354.871770, 0.010390, 0.105000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 2, 0}, 175.319490, 0.000690, 0.271000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 3, 0}, 174.512820, 0.000050, 0.059000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, -1, 0}, 347.765300, 0.000050, 0.042000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 0, 0}, 344.903790, 0.000420, 0.096000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -1, 1, 0}, 167.773260, 0.000060, 0.357000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -3, 0}, 180.720650, 0.000030, 0.026000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -2, 0}, 332.825330, 0.000190, 0.041000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, -1, 0}, 336.368770, 0.003760, 0.088000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 0, 0}, 174.728970, 0.002090, 0.522000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 1, 0}, 182.785720, 0.002440, 0.066000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 2, 0}, 190.473050, 0.000080, 0.035000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 3, 0}, 354.877440, 0.000020, 0.024000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, 0}, 163.225310, 0.000310, 0.070000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, 1}, 169.552930, 0.000030, 0.036000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 1, 0}, 167.773260, 0.000040, 0.036000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -3, 0}, 8.557570, 0.000020, 0.076000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -2, 0}, 41.896220, 0.000630, 7.058000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, -2}, 44.378700, 0.000060, 0.074000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, 0}, 217.418230, 0.012240, 0.075000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 0, -1}, 350.555770, 0.000040, 0.076000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 0, 0}, 188.961530, 0.000350, 0.038000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, 1, 0}, 165.711390, 0.000070, 0.025000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 4, -2, 0}, 215.546930, 0.000130, 0.040000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 4, -1, 0}, 215.662300, 0.000110, 0.026000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, -1, 0}, 277.638540, 0.000050, 0.028000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 0, 0}, 276.631300, 0.000570, 0.044000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 1, 0}, 279.509500, 0.000200, 0.104000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, -2, 0}, 97.790210, 0.000090, 0.041000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, -1, 0}, 97.438390, 0.000900, 0.088000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, 1, 0}, 98.430440, 0.000170, 0.066000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -3, 0}, 107.146560, 0.000030, 0.076000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -2, 0}, 277.652440, 0.000360, 17.781000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -1, 0}, 97.655640, 0.006250, 0.075000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, 0, 0}, 95.286260, 0.000120, 0.038000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 4, -2, 0}, 97.681860, 0.000040, 0.040000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 4, -1, 0}, 97.668670, 0.000060, 0.026000},
	{{0, 0, 2, 0, 0, -4, 0, 0, -2, 0, 0}, 95.373150, 0.000210, 0.044000},
	{{0, 0, 2, 0, 0, -4, 0, 0, -2, 1, 0}, 95.373140, 0.000050, 0.104000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, -1, 0}, 276.402260, 0.000110, 0.088000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 0, 1, 0}, 275.413160, 0.000030, 0.066000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, -2, 0}, 96.918460, 0.000040, 11.088000},
	{{0, 0, 2, 0, 0, -4, 0, 0, 2, -1, 0}, 276.184060, 0.000790, 0.075000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, -1, 0}, 2.900890, 0.000100, 0.028000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 0, 0}, 3.291200, 0.000850, 0.044000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 1, 0}, 2.684750, 0.000280, 0.104000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, -3, 0}, 183.020110, 0.000020, 0.026000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, -2, 0}, 183.011490, 0.000040, 0.041000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, -1, 0}, 182.919640, 0.000460, 0.088000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 0, 0}, 181.985730, 0.000120, 0.527000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 1, 0}, 182.843370, 0.000280, 0.066000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, -2, 0}, 3.020070, 0.000250, 8.056000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, -1, 0}, 182.872430, 0.004270, 0.075000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 2, 0, 0}, 183.108350, 0.000090, 0.038000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 4, -2, 0}, 183.020210, 0.000040, 0.040000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 4, -1, 0}, 183.020110, 0.000020, 0.026000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -4, 0, 0}, 270.201450, 0.000050, 0.021000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -4, 1, 0}, 270.210380, 0.000100, 0.029000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, -1, 0}, 270.208180, 0.000260, 0.028000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 0, 0}, 270.231800, 0.004420, 0.044000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 1, 0}, 270.211180, 0.002380, 0.105000},
	{{0, 0, 2, 0, 0, -2, 0, 0, -2, 2, 0}, 90.220140, 0.000190, 0.270000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -2, 0}, 89.859200, 0.000060, 0.041000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, -1, 0}, 89.888850, 0.001280, 0.088000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 0, 0}, 90.128490, 0.000630, 0.518000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 1, 0}, 90.109200, 0.001430, 0.066000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 0, 2, 0}, 90.003920, 0.000070, 0.035000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 1, -2, 0}, 89.849370, 0.000020, 0.082000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 1, 0, 0}, 269.849370, 0.000020, 0.070000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -3, 0}, 265.645630, 0.000040, 0.076000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -2, 0}, 270.040860, 0.000960, 6.326000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, -2}, 270.023390, 0.000110, 0.074000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, -1, 0}, 90.033690, 0.017550, 0.075000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 0, 0}, 90.288890, 0.000140, 0.037000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 1, -2}, 90.005550, 0.000040, 0.076000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 2, 1, 0}, 269.983810, 0.000060, 0.025000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, -2, 0}, 90.043530, 0.000180, 0.040000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, -1, 0}, 90.038220, 0.000140, 0.026000},
	{{0, 0, 2, 0, 0, -2, 0, 0, 4, 0, 0}, 90.005550, 0.000040, 0.019000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -4, 0, 0}, 167.935270, 0.000030, 0.021000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -4, 1, 0}, 348.462900, 0.000020, 0.029000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, -1, 0}, 348.476910, 0.000130, 0.028000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 0, 0}, 348.380200, 0.001300, 0.044000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 1, 0}, 347.809140, 0.000590, 0.105000},
	{{0, 0, 2, 0, 0, -1, 0, 0, -2, 2, 0}, 168.429710, 0.000020, 0.267000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, -1, 0}, 345.321680, 0.000140, 0.089000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 0, 0}, 169.532560, 0.000120, 0.509000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 0, 1, 0}, 169.550550, 0.000150, 0.066000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, -2, 0}, 352.833730, 0.000030, 5.207000},
	{{0, 0, 2, 0, 0, -1, 0, 0, 2, -1, 0}, 172.620230, 0.000720, 0.074000},
	{{0, 0, 2, 0, 0, 0, -2, 0, -2, 0, 0}, 268.798450, 0.000160, 0.044000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 0, -1, 0}, 91.769120, 0.000030, 0.089000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 0, 0, 0}, 88.976620, 0.000040, 0.506000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 0, 1, 0}, 86.847940, 0.000020, 0.066000},
	{{0, 0, 2, 0, 0, 0, -2, 0, 2, -1, 0}, 89.760640, 0.000260, 0.074000},
	{{0, 0, 2, 0, 0, 0, -1, 0, -2, 0, 0}, 339.056050, 0.000050, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, -2, -2, 0, 0}, 270.219050, 0.000060, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, -2, 2, -1, 0}, 90.018980, 0.000060, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, -1, 0}, 93.721120, 0.000040, 0.028000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 91.459860, 0.000730, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 1, 0}, 93.231300, 0.000220, 0.105000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 2, 0}, 287.638600, 0.000030, 0.265000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 0, -1}, 100.397290, 0.000070, 0.042000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 0, 0}, 293.877290, 0.000040, 0.096000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, -2, 0}, 295.590410, 0.000030, 0.041000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 84.838920, 0.000090, 0.089000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 291.219060, 0.000430, 0.500000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 289.574590, 0.000370, 0.066000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0}, 114.651480, 0.000080, 0.070000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 302.415400, 0.000020, 0.077000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 115.820260, 0.000110, 4.425000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 293.177030, 0.001930, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, -1}, 102.711820, 0.000070, 0.075000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 300.706230, 0.000110, 0.037000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 4, -2, 0}, 290.551710, 0.000020, 0.040000},
	{{0, 0, 2, 0, 0, 1, 0, 0, -2, 0, 0}, 153.293240, 0.000060, 0.044000},
	{{0, 0, 2, 0, 1, -5, 0, 0, -2, 0, 0}, 16.818420, 0.000070, 0.044000},
	{{0, 0, 2, 0, 1, -5, 0, 0, 2, -1, 0}, 288.624980, 0.000080, 0.075000},
	{{0, 0, 2, 0, 1, -2, 0, 0, -2, 0, 0}, 169.246180, 0.000090, 0.044000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -2, 0, 0}, 229.964980, 0.000380, 0.044000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -2, 1, 0}, 228.940590, 0.000100, 0.106000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -1, 0, -1}, 62.537420, 0.000030, 0.042000},
	{{0, 0, 2, 0, 1, 0, 0, 0, -1, 1, -1}, 242.690490, 0.000020, 0.096000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 0, -1, 0}, 225.327240, 0.000030, 0.090000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 0, 1, 0}, 45.327240, 0.000030, 0.065000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, -1, 0}, 342.333100, 0.000070, 0.074000},
	{{0, 0, 2, 0, 1, 2, 0, 0, 2, -3, 0}, 225.697030, 0.000020, 0.078000},
	{{0, 0, 2, 0, 1, 2, 0, 0, 2, -1, 0}, 45.697030, 0.000020, 0.073000},
	{{0, 0, 2, 0, 2, -8, 0, 0, -2, 0, 0}, 191.769910, 0.000030, 0.044000},
	{{0, 0, 2, 0, 2, -8, 0, 0, 2, -1, 0}, 11.409310, 0.000070, 0.075000},
	{{0, 0, 2, 0, 2, -7, 0, 0, -2, 0, 0}, 98.273210, 0.000120, 0.044000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 0, -1, 0}, 278.734930, 0.000050, 0.088000},
	{{0, 0, 2, 0, 2, -7, 0, 0, 2, -1, 0}, 278.734980, 0.000260, 0.075000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, -1, 0}, 53.330470, 0.000040, 0.028000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 0, 0}, 53.424670, 0.000530, 0.044000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 1, 0}, 53.042540, 0.000130, 0.105000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 0, -1, 0}, 51.627620, 0.000100, 0.089000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 0, 0, 0}, 232.121170, 0.000030, 0.500000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 0, 1, 0}, 232.892090, 0.000070, 0.066000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 2, -3, 0}, 78.081740, 0.000030, 0.077000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 2, -1, 0}, 238.391240, 0.000150, 0.074000},
	{{0, 0, 2, 0, 2, 0, 0, 0, 2, -3, 0}, 218.323620, 0.000030, 0.078000},
	{{0, 0, 2, 0, 2, 0, 0, 0, 2, -1, 0}, 218.323620, 0.000030, 0.073000},
	{{0, 0, 2, 0, 3, -1, 0, 0, 2, -3, 0}, 216.939630, 0.000020, 0.078000},
	{{0, 0, 2, 0, 3, -1, 0, 0, 2, -1, 0}, 36.939630, 0.000020, 0.073000},
	{{0, 0, 2, 0, 4, -3, 0, 0, 2, -3, 0}, 338.541600, 0.000020, 0.078000},
	{{0, 0, 2, 0, 4, -3, 0, 0, 2, -1, 0}, 158.541600, 0.000020, 0.073000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, -3, 0}, 217.337480, 0.000020, 0.078000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, -2, 0}, 217.131800, 0.000020, 2.019000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, -1, 0}, 37.337480, 0.000020, 0.073000},
	{{0, 0, 2, 0, 4, -2, 0, 0, 2, 0, 0}, 37.131800, 0.000020, 0.037000},
	{{0, 0, 2, 0, 5, -5, 0, 0, 2, -3, 0}, 354.916990, 0.000020, 0.078000},
	{{0, 0, 2, 0, 5, -5, 0, 0, 2, -1, 0}, 174.916990, 0.000020, 0.073000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 1, 0}, 297.620160, 0.000080, 0.075000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 2, 0, 0}, 259.697520, 0.000070, 0.043000},
	{{0, 0, 3, -8, 1, 5, 0, 0, 2, -1, 0}, 291.999160, 0.000050, 0.095000},
	{{0, 0, 3, -8, 1, 5, 0, 0, 2, 0, 0}, 291.999160, 0.000130, 0.042000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -4, 1, 0}, 299.718330, 0.000020, 0.027000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, -1, 0}, 299.383550, 0.000130, 0.026000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 0, 0}, 299.504070, 0.000680, 0.039000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 1, 0}, 300.323280, 0.000360, 0.080000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -2, 2, 0}, 119.791380, 0.000040, 1.293000},
	{{0, 0, 3, -8, 3, 0, 0, 0, -1, 0, 0}, 118.939120, 0.000040, 0.075000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, -1, 0}, 121.389540, 0.000940, 0.070000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 0, 0}, 119.778970, 0.000870, 0.999000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 1, 0}, 299.199150, 0.003130, 0.082000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 2, 0}, 298.835620, 0.000200, 0.039000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -2, 0}, 120.312910, 0.000420, 0.360000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -1, 0}, 299.962100, 0.007160, 0.095000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, -2}, 119.748340, 0.000020, 0.322000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, 0}, 299.680800, 0.011160, 0.042000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 1, 0}, 299.481790, 0.000840, 0.027000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 2, 0}, 299.748490, 0.000050, 0.020000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 3, 0, 0}, 299.740230, 0.000050, 0.028000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, -2, 0}, 300.152260, 0.000110, 0.046000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, -1, 0}, 299.797810, 0.000410, 0.028000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, 0, 0}, 299.678860, 0.000200, 0.021000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 4, 1, 0}, 119.727730, 0.000030, 0.016000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 1, -1}, 234.439170, 0.000020, 0.026000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 2, -1}, 234.498160, 0.000240, 0.040000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -3, 3, -1}, 234.408070, 0.000180, 0.087000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 0, -1}, 52.160320, 0.000040, 0.038000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 1, -1}, 52.160310, 0.000650, 0.075000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, -1}, 233.436680, 0.000080, 650.233000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 3, -1}, 54.479060, 0.000790, 0.075000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 4, -1}, 54.479060, 0.000040, 0.038000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, -1, 0}, 346.273090, 0.000070, 0.072000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, 1, 0}, 166.273090, 0.000070, 0.080000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 0, -1}, 233.494930, 0.000040, 0.563000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 1, -1}, 53.843840, 0.000440, 0.087000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 2, -1}, 54.386390, 0.000270, 0.040000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 1, 3, -1}, 54.439170, 0.000020, 0.026000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, -1, 0}, 259.616470, 0.000070, 0.093000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, 0, 0}, 250.196060, 0.000170, 0.042000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -4, 1, 0}, 1.992610, 0.000040, 0.027000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, -1, 0}, 1.851860, 0.000180, 0.026000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 0, 0}, 0.987640, 0.001420, 0.040000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 1, 0}, 3.916530, 0.001310, 0.086000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 2, 0}, 188.015290, 0.000040, 0.631000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -2, 0}, 358.671660, 0.000150, 0.037000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -1, 0}, 358.871510, 0.002830, 0.074000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, 0}, 1.377810, 0.000260, 5.260000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 1, 0}, 179.245620, 0.002860, 0.077000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 2, 0}, 179.365150, 0.000170, 0.038000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 1, -2, 0}, 183.334450, 0.000020, 0.070000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 1, 0, 0}, 3.334450, 0.000020, 0.082000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -2, 0}, 8.211870, 0.000080, 0.509000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -1, 0}, 185.125860, 0.001820, 0.089000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 0, 0}, 184.606560, 0.002080, 0.041000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 1, 0}, 183.996090, 0.000260, 0.026000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 4, -1, 0}, 184.711580, 0.000050, 0.028000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, -1, 0}, 61.159560, 0.000060, 0.026000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 0, 0}, 61.074340, 0.000570, 0.040000},
	{{0, 0, 3, -6, 2, 0, 0, 0, -2, 1, 0}, 61.415040, 0.000460, 0.087000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, -2, 0}, 59.919230, 0.000040, 0.038000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, -1, 0}, 59.958100, 0.000850, 0.075000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 1, 0}, 239.968820, 0.000850, 0.076000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 2, 0}, 239.915790, 0.000040, 0.038000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, -1, 0}, 241.496920, 0.000470, 0.087000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, 0, 0}, 241.126270, 0.000580, 0.040000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 2, 1, 0}, 241.224540, 0.000060, 0.026000},
	{{0, 0, 3, -5, -4, 0, 0, 0, -2, 0, 0}, 217.663300, 0.000030, 0.040000},
	{{0, 0, 3, -5, -4, 0, 0, 0, 2, 0, 0}, 37.770340, 0.000030, 0.040000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -4, 0, 0}, 31.553810, 0.000040, 0.020000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -4, 1, 0}, 31.701960, 0.000160, 0.028000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -4, 2, 0}, 31.581210, 0.000050, 0.044000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, -1, 0}, 31.429050, 0.000280, 0.027000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, 0}, 31.917790, 0.004210, 0.041000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, 2}, 211.745370, 0.000030, 0.408000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 1, 0}, 31.790710, 0.003980, 0.090000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 2, 0}, 212.175630, 0.000240, 0.473000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -1, 0, 0}, 211.460030, 0.000090, 0.083000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -2, 0}, 30.175840, 0.000210, 0.038000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -1, 0}, 30.108890, 0.003650, 0.077000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 0, 0}, 210.858540, 0.000510, 2.928000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, -2}, 208.466140, 0.000160, 0.075000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, 0}, 209.995270, 0.003440, 0.074000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 2, 0}, 209.912730, 0.000180, 0.037000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -2, 0}, 32.210210, 0.000130, 0.698000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -1, 0}, 211.632080, 0.002780, 0.085000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 0, 0}, 211.299920, 0.002430, 0.040000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 1, 0}, 211.203850, 0.000220, 0.026000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 4, -2, 0}, 211.437480, 0.000030, 0.043000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 4, -1, 0}, 211.377790, 0.000040, 0.027000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 4, 0, 0}, 211.665780, 0.000030, 0.020000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, -1, 0}, 237.302520, 0.000030, 0.016000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 0, 0}, 62.840300, 0.000150, 0.021000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 1, 0}, 58.626910, 0.000290, 0.028000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -4, 2, 0}, 58.800060, 0.000090, 0.045000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -3, 0, 0}, 57.693700, 0.000050, 0.028000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, -2, 0}, 58.649760, 0.000080, 0.020000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, -1, 0}, 58.916760, 0.000880, 0.027000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, 0}, 58.045060, 0.013540, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, 2}, 238.656480, 0.000030, 0.335000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 1, 0}, 58.659440, 0.010670, 0.094000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 2, 0}, 239.221930, 0.000700, 0.378000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 3, 0}, 238.656850, 0.000050, 0.063000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, -1, 0}, 61.285840, 0.000110, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, -1, 1}, 324.815450, 0.000040, 0.088000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, 0}, 241.077070, 0.001790, 0.087000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 1, 0}, 61.235620, 0.000230, 0.568000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -2, 0}, 60.001180, 0.000440, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, 0}, 59.685410, 0.008790, 0.081000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, 2}, 240.017650, 0.000040, 0.069000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 0, 0}, 240.230870, 0.002990, 1.145000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 1, -2}, 60.017650, 0.000040, 0.079000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 1, 0}, 240.655770, 0.007490, 0.071000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 2, 0}, 240.391350, 0.000380, 0.037000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 3, 0}, 238.820870, 0.000030, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -3, 0}, 61.551960, 0.000030, 0.038000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -2, 0}, 61.551950, 0.000570, 0.075000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, -1}, 144.795100, 0.000110, 0.074000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 0}, 61.218450, 0.000560, 72.752000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 1}, 324.810930, 0.000180, 0.075000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, -2}, 61.235600, 0.000040, 0.074000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 0}, 241.232080, 0.010400, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, -1}, 324.795100, 0.000110, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 1, 0}, 241.236880, 0.000560, 0.038000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 2, 0}, 241.235630, 0.000030, 0.025000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -2, 0}, 62.552300, 0.000110, 1.110000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -1, 0}, 240.174460, 0.004060, 0.081000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, 0}, 242.400480, 0.003310, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 1, 0}, 239.837730, 0.000270, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -2, 0}, 241.056930, 0.000150, 0.087000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, -1, 0}, 241.242210, 0.000300, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 3, 0, 0}, 241.237710, 0.000100, 0.026000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 4, -2, 0}, 240.421150, 0.000040, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 4, -1, 0}, 240.942090, 0.000080, 0.027000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 4, 0, 0}, 244.370440, 0.000030, 0.020000},
	{{0, 0, 3, -4, 2, 0, 0, 0, -2, 0, 0}, 326.725690, 0.000060, 0.042000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -4, 0, 0}, 273.774170, 0.000050, 0.021000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -4, 1, 0}, 277.248910, 0.000110, 0.029000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -4, 2, 0}, 276.618530, 0.000040, 0.046000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, -1, 0}, 277.005870, 0.000260, 0.027000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 0, 0}, 278.142340, 0.005000, 0.043000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 1, 0}, 277.422380, 0.003150, 0.099000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 2, 0}, 98.141270, 0.000230, 0.315000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -1, 0, 0}, 94.345790, 0.000030, 0.091000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -1, 2, 0}, 274.345790, 0.000030, 0.064000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -2, 0}, 272.953490, 0.000230, 0.040000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -1, 0}, 273.130150, 0.003840, 0.084000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 0, 0}, 92.462330, 0.001580, 0.712000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 1, 0}, 92.537770, 0.002260, 0.068000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 2, 0}, 92.570210, 0.000120, 0.036000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, -2, 0}, 96.629590, 0.000030, 0.079000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 1, 0, 0}, 276.629590, 0.000030, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -3, 0}, 86.112480, 0.000030, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -2, 0}, 91.177990, 0.000350, 2.710000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -1, 0}, 270.947100, 0.005580, 0.078000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, 0}, 273.553510, 0.000500, 0.038000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 1, 0}, 270.028100, 0.000090, 0.025000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 4, -2, 0}, 270.552610, 0.000050, 0.041000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 4, -1, 0}, 270.590370, 0.000050, 0.027000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, -1, 0}, 166.444810, 0.000020, 0.016000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, 0, 0}, 347.068290, 0.000110, 0.021000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, 1, 0}, 346.401590, 0.000250, 0.029000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -4, 2, 0}, 346.600380, 0.000060, 0.048000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, -1, 0}, 346.558010, 0.000410, 0.028000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, 0}, 346.541920, 0.005550, 0.044000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, 2}, 166.766050, 0.000040, 0.247000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 1, 0}, 346.969060, 0.002840, 0.105000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 2, 0}, 166.923530, 0.000210, 0.269000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -1, 0, 0}, 347.297960, 0.000080, 0.096000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -2, 0}, 346.424260, 0.000080, 0.041000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -1, 0}, 345.784260, 0.001140, 0.088000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, 0}, 165.276090, 0.000560, 0.516000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 1, 0}, 166.120790, 0.000750, 0.066000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 2, 0}, 167.074620, 0.000020, 0.035000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, 0, 0}, 167.297930, 0.000060, 0.070000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -2, 0}, 349.674490, 0.000090, 6.150000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, 0}, 169.060760, 0.001860, 0.075000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, -1}, 40.758540, 0.000190, 0.075000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, 0}, 166.443600, 0.000100, 0.037000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 4, -2, 0}, 169.091790, 0.000020, 0.040000},
	{{0, 0, 3, -1, 0, 0, 0, 0, -2, 0, 0}, 248.925440, 0.000070, 0.045000},
	{{0, 0, 3, 0, -6, 0, 0, 0, -2, 0, 0}, 294.451280, 0.000080, 0.045000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 2, -1, 0}, 120.639500, 0.000130, 0.072000},
	{{0, 0, 3, 0, -6, 0, 0, 0, 2, 0, 0}, 301.238300, 0.000070, 0.037000},
	{{0, 0, 3, 0, -6, 5, 0, 0, -2, 0, 0}, 122.006380, 0.000040, 0.045000},
	{{0, 0, 3, 0, -6, 5, 0, 0, 2, -2, 0}, 132.995960, 0.000020, 1.124000},
	{{0, 0, 3, 0, -6, 5, 0, 0, 2, -1, 0}, 316.733420, 0.000050, 0.071000},
	{{0, 0, 3, 0, -6, 5, 0, 0, 2, 0, 0}, 132.995960, 0.000020, 0.036000},
	{{0, 0, 3, 0, -5, 0, 0, 0, -2, 0, 0}, 284.067050, 0.000350, 0.045000},
	{{0, 0, 3, 0, -5, 0, 0, 0, -2, 1, 0}, 283.217160, 0.000070, 0.112000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 0, -1, 0}, 114.840890, 0.000040, 0.094000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 0, 0, 0}, 108.139400, 0.000090, 0.388000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 0, 1, 0}, 108.105230, 0.000150, 0.063000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, -2, 0}, 289.594160, 0.000060, 1.243000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, -1, 0}, 109.634770, 0.001070, 0.071000},
	{{0, 0, 3, 0, -5, 0, 0, 0, 2, 0, 0}, 291.034080, 0.000260, 0.037000},
	{{0, 0, 3, 0, -5, 2, 0, 0, -2, 0, 0}, 256.257680, 0.000040, 0.045000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 2, -2, 0}, 271.172000, 0.000020, 1.146000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 2, -1, 0}, 91.196030, 0.000050, 0.071000},
	{{0, 0, 3, 0, -5, 2, 0, 0, 2, 0, 0}, 271.172000, 0.000020, 0.037000},
	{{0, 0, 3, 0, -5, 5, 0, 0, -2, 0, 0}, 73.139870, 0.000140, 0.045000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 0, 0, 0}, 254.328740, 0.000040, 0.364000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, -3, 0}, 56.677520, 0.000020, 0.081000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, -1, 0}, 258.777680, 0.000200, 0.070000},
	{{0, 0, 3, 0, -5, 5, 0, 0, 2, 0, 0}, 78.248120, 0.000130, 0.036000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -4, 1, 0}, 272.119960, 0.000060, 0.030000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, -1, 0}, 272.299560, 0.000220, 0.028000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 0, 0}, 271.285740, 0.002070, 0.045000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 1, 0}, 272.000580, 0.000870, 0.113000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 2, 0}, 91.543320, 0.000070, 0.225000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, -2, 0}, 98.880770, 0.000020, 0.042000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, -1, 0}, 122.470130, 0.000300, 0.094000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 0, 0}, 96.197540, 0.000270, 0.376000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 1, 0}, 97.763900, 0.000790, 0.063000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 2, 0}, 100.463290, 0.000040, 0.034000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 1, -3, 0}, 104.469890, 0.000060, 0.040000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 1, -2, 0}, 104.136390, 0.000140, 0.087000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -2, 0}, 279.862020, 0.000300, 1.125000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -1, 0}, 99.166560, 0.005840, 0.071000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 0, 0}, 280.758150, 0.001510, 0.036000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, 1, 0}, 280.300720, 0.000300, 0.025000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -4, 0}, 104.640240, 0.000130, 0.075000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 3, -2, 0}, 103.700180, 0.000350, 0.075000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 4, -2, 0}, 101.248480, 0.000060, 0.039000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 4, 0, 0}, 276.319530, 0.000030, 0.019000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 5, -4, 0}, 284.402930, 0.000060, 0.087000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 5, -3, 0}, 284.469890, 0.000060, 0.040000},
	{{0, 0, 3, 0, -4, 2, 0, 0, -2, 0, 0}, 188.086920, 0.000040, 0.045000},
	{{0, 0, 3, 0, -4, 3, 0, 0, 0, -1, 0}, 224.210090, 0.000030, 0.095000},
	{{0, 0, 3, 0, -4, 5, 0, 0, -2, 0, 0}, 336.137060, 0.000100, 0.046000},
	{{0, 0, 3, 0, -4, 5, 0, 0, 0, -1, 0}, 158.277740, 0.000040, 0.096000},
	{{0, 0, 3, 0, -4, 5, 0, 0, 2, -1, 0}, 338.276760, 0.000030, 0.070000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, -1, 0}, 75.252040, 0.000020, 0.017000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 0, 0}, 276.814110, 0.000080, 0.021000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 1, 0}, 250.721980, 0.000220, 0.030000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -4, 2, 0}, 257.464540, 0.000030, 0.049000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, -1, 0}, 245.568410, 0.000450, 0.028000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, 0}, 253.476180, 0.007900, 0.045000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, 2}, 75.941790, 0.000020, 0.206000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 1, 0}, 255.023960, 0.003380, 0.114000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 2, 0}, 73.990090, 0.000270, 0.221000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -1, 0, 0}, 78.301920, 0.000050, 0.104000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -2, 0}, 349.916170, 0.000060, 0.042000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -1, 0}, 167.286480, 0.003260, 0.095000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 0, 0}, 63.093530, 0.001310, 0.364000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 1, 0}, 85.306520, 0.002720, 0.062000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, 2, 0}, 85.022440, 0.000110, 0.034000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 1, 0, 0}, 266.298670, 0.000100, 0.066000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -3, 0}, 302.009370, 0.000100, 0.081000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -2, 0}, 274.122470, 0.001060, 1.028000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -1, -2}, 269.501700, 0.000070, 0.079000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, -1, 0}, 83.905010, 0.021390, 0.070000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, -2}, 89.906010, 0.000060, 1.564000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 0, 0}, 272.906610, 0.005520, 0.036000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 1, 0}, 270.266950, 0.000320, 0.025000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 2, 2, 0}, 269.856050, 0.000060, 0.019000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 3, -4, 0}, 270.098340, 0.000020, 0.076000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 3, -2, 0}, 90.098340, 0.000020, 0.075000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -3, 0}, 340.765330, 0.000030, 0.080000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -2, 0}, 67.187070, 0.000240, 0.039000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, -1, 0}, 334.308980, 0.000060, 0.026000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, 0, 0}, 269.688260, 0.000090, 0.019000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 4, 1, 0}, 90.091470, 0.000030, 0.015000},
	{{0, 0, 3, 0, -3, 1, 0, 0, 0, -1, 0}, 168.501320, 0.000040, 0.095000},
	{{0, 0, 3, 0, -2, -5, 0, 0, -2, 0, 0}, 280.404490, 0.000040, 0.045000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 2, -2, 0}, 288.851180, 0.000020, 1.127000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 2, -1, 0}, 109.103260, 0.000050, 0.071000},
	{{0, 0, 3, 0, -2, -5, 0, 0, 2, 0, 0}, 288.851180, 0.000020, 0.036000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, -1, 0}, 347.021920, 0.000020, 0.017000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 0, 0}, 166.336510, 0.000200, 0.021000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 1, 0}, 166.601020, 0.000410, 0.030000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -4, 2, 0}, 166.023930, 0.000070, 0.050000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -3, 0, 0}, 166.287820, 0.000040, 0.029000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, -1, 0}, 165.776670, 0.000520, 0.028000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 0, 0}, 165.725670, 0.010460, 0.046000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 0, 2}, 345.541310, 0.000020, 0.202000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 1, 0}, 165.706490, 0.004330, 0.116000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -2, 2, 0}, 346.438930, 0.000380, 0.217000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -1, 0, 0}, 345.198570, 0.000020, 0.105000},
	{{0, 0, 3, 0, -2, 0, 0, 0, -1, 2, 0}, 345.198570, 0.000020, 0.059000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -3, 0}, 347.103880, 0.000060, 0.027000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -2, 0}, 346.923450, 0.000660, 0.042000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, -1, 0}, 346.783550, 0.005900, 0.096000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 0, 0}, 320.552350, 0.000110, 0.353000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 1, 0}, 341.368640, 0.001100, 0.062000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 0, 2, 0}, 335.763160, 0.000030, 0.034000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 1, -2, -1}, 165.997540, 0.000020, 0.040000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 1, -1, -1}, 167.286320, 0.000080, 0.087000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -3, 0}, 350.157750, 0.000030, 0.082000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -2, 0}, 155.517190, 0.000270, 0.946000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, -1, 0}, 180.847970, 0.004300, 0.070000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, 0, 0}, 130.895310, 0.000480, 0.036000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 2, 1, 0}, 141.571650, 0.000090, 0.024000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -2, 0}, 347.185050, 0.000030, 0.074000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, -1}, 167.556020, 0.000390, 0.075000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, 0}, 347.184900, 0.000050, 0.037000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, -2, 0}, 173.982510, 0.000080, 0.039000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 4, -1, 0}, 167.184910, 0.000150, 0.026000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 5, -2, -1}, 345.997540, 0.000020, 0.040000},
	{{0, 0, 3, 0, -1, -5, 0, 0, -2, 0, 0}, 262.267280, 0.000120, 0.045000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, -3, 0}, 280.088050, 0.000020, 0.081000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, -1, 0}, 98.619830, 0.000190, 0.070000},
	{{0, 0, 3, 0, -1, -5, 0, 0, 2, 0, 0}, 278.610400, 0.000130, 0.036000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -4, 0, 0}, 70.397040, 0.000050, 0.021000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -4, 1, 0}, 253.936230, 0.000040, 0.030000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, -1, 0}, 255.782710, 0.000120, 0.029000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 0, 0}, 254.674130, 0.001340, 0.046000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 1, 0}, 255.471080, 0.000440, 0.117000},
	{{0, 0, 3, 0, -1, 0, 0, 0, -2, 2, 0}, 75.264430, 0.000030, 0.213000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 0, -1, 0}, 189.516820, 0.000050, 0.097000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 0, 0, 0}, 95.868510, 0.000020, 0.343000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 0, 1, 0}, 103.281990, 0.000030, 0.062000},
	{{0, 0, 3, 0, -1, 0, 0, 0, 2, -1, 0}, 306.512960, 0.000030, 0.069000},
	{{0, 0, 3, 0, 0, -5, 0, 0, -2, 0, 0}, 168.669340, 0.000110, 0.046000},
	{{0, 0, 3, 0, 0, -5, 0, 0, 0, -1, 0}, 354.728390, 0.000050, 0.096000},
	{{0, 0, 3, 0, 0, -5, 0, 0, 2, -1, 0}, 174.728640, 0.000030, 0.070000},
	{{0, 0, 3, 0, 0, -4, 0, 0, -2, 0, 0}, 0.562990, 0.000110, 0.046000},
	{{0, 0, 3, 0, 0, -4, 0, 0, 2, -1, 0}, 182.727680, 0.000130, 0.070000},
	{{0, 0, 3, 0, 0, -4, 0, 0, 2, 0, 0}, 2.727680, 0.000110, 0.036000},
	{{0, 0, 3, 0, 0, -3, 0, 0, -2, 0, 0}, 266.805420, 0.000230, 0.046000},
	{{0, 0, 3, 0, 0, -3, 0, 0, -2, 1, 0}, 266.806940, 0.000080, 0.117000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 0, -1, 0}, 85.288070, 0.000050, 0.097000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 0, 0, 0}, 87.965770, 0.000050, 0.345000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 0, 1, 0}, 88.585280, 0.000070, 0.062000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, -1, 0}, 89.900090, 0.000500, 0.070000},
	{{0, 0, 3, 0, 0, -3, 0, 0, 2, 0, 0}, 269.918170, 0.000200, 0.036000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, -1, 0}, 166.915550, 0.000020, 0.029000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, 0, 0}, 166.977150, 0.000460, 0.046000},
	{{0, 0, 3, 0, 0, -2, 0, 0, -2, 1, 0}, 166.959520, 0.000100, 0.117000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 0, -1, 0}, 347.225000, 0.000080, 0.097000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 0, 0, 0}, 346.652630, 0.000030, 0.341000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 0, 1, 0}, 346.865950, 0.000050, 0.062000},
	{{0, 0, 3, 0, 0, -2, 0, 0, 2, -1, 0}, 167.097380, 0.000090, 0.069000},
	{{0, 0, 3, 0, 0, -1, 0, 0, -2, 0, 0}, 245.964820, 0.000140, 0.046000},
	{{0, 0, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 3.757610, 0.000130, 0.046000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 200.052280, 0.000040, 0.333000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -3, 0}, 306.575690, 0.000030, 0.083000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 129.151590, 0.000020, 0.816000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -1, 0}, 213.912870, 0.000040, 0.069000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 29.028370, 0.000030, 0.036000},
	{{0, 0, 3, 0, 1, 0, 0, 0, -2, 0, 0}, 125.668270, 0.000030, 0.046000},
	{{0, 0, 3, 0, 2, -5, 0, 0, -2, 0, 0}, 310.272260, 0.000050, 0.046000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 1, 0}, 62.225650, 0.000040, 0.075000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, -1, 0}, 237.801930, 0.000040, 0.093000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, 0, 0}, 231.633100, 0.000110, 0.042000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 0, 0}, 332.968580, 0.000270, 0.040000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 1, 0}, 335.800580, 0.000220, 0.085000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -2, 0}, 329.862910, 0.000030, 0.037000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -1, 0}, 330.142250, 0.000640, 0.074000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 0, 0}, 321.050460, 0.000070, 3.945000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 1, 0}, 150.595610, 0.000660, 0.077000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 2, 0}, 150.839350, 0.000030, 0.038000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, -1, 0}, 158.639250, 0.000320, 0.089000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 0, 0}, 156.402930, 0.000480, 0.041000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 1, 0}, 156.990930, 0.000040, 0.026000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, -1, 0}, 9.173350, 0.000090, 0.026000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 0, 0}, 9.044680, 0.000790, 0.040000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 1, 0}, 9.723520, 0.000630, 0.087000},
	{{0, 0, 4, -8, 1, 5, 0, 0, -2, 2, 0}, 191.750960, 0.000020, 0.564000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, -2, 0}, 7.016770, 0.000070, 0.038000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, -1, 0}, 6.806730, 0.001140, 0.075000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 1, 0}, 186.806160, 0.001140, 0.075000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 0, 2, 0}, 187.016880, 0.000070, 0.038000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, -2, 0}, 11.746680, 0.000020, 0.564000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, -1, 0}, 189.719830, 0.000630, 0.087000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, 0, 0}, 189.041760, 0.000790, 0.040000},
	{{0, 0, 4, -8, 1, 5, 0, 0, 2, 1, 0}, 189.170210, 0.000090, 0.026000},
	{{0, 0, 4, -8, 2, 0, 0, 0, -2, 0, 0}, 31.454030, 0.000030, 0.040000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 0, -1, 0}, 31.825900, 0.000040, 0.075000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 0, 1, 0}, 211.825900, 0.000040, 0.076000},
	{{0, 0, 4, -8, 2, 0, 0, 0, 2, 0, 0}, 211.644150, 0.000040, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 0, 0}, 196.782400, 0.000020, 0.013000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 1, 0}, 16.780800, 0.000030, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -6, 2, 0}, 16.781400, 0.000090, 0.021000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, -1, 0}, 16.697890, 0.000150, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 0, 0}, 16.689240, 0.000900, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 0, 2}, 16.780900, 0.000080, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, 0}, 16.878660, 0.002370, 0.028000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, 2}, 16.781060, 0.000060, 0.107000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 2, 0}, 17.135640, 0.001230, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 3, 0}, 16.784240, 0.000030, 0.103000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, -1, 0}, 16.780410, 0.000020, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 0, 0}, 16.779010, 0.000060, 0.027000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 1, 0}, 196.936960, 0.000250, 0.042000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -3, 2, 0}, 196.780620, 0.000030, 0.094000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -3, 0}, 16.781860, 0.000030, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -2, 0}, 16.175450, 0.000530, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, 0}, 16.407540, 0.007750, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, 2}, 196.239360, 0.000090, 0.090000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 0}, 16.688970, 0.112160, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 2}, 196.692950, 0.000450, 0.475000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, -2}, 196.781430, 0.000040, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, 0}, 17.112630, 0.112510, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, 2}, 197.052630, 0.000310, 0.065000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, -2}, 196.782190, 0.000020, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, 0}, 197.808920, 0.005650, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, 2}, 196.781990, 0.000020, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 3, 0}, 199.131970, 0.000230, 0.067000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, -1, 0}, 196.271600, 0.000190, 0.039000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 0, 0}, 196.681830, 0.001870, 0.081000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 1, 0}, 17.716800, 0.000110, 1.128000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 2, 0}, 18.370890, 0.000030, 0.071000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -4, 0}, 14.333720, 0.000020, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -3, 0}, 15.029060, 0.000540, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 0}, 14.992380, 0.008620, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 2}, 14.944060, 0.000060, 3.003000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 0}, 14.988410, 0.157800, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 2}, 194.809050, 0.000560, 0.074000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, -2}, 196.762000, 0.000030, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, 0}, 16.424760, 0.000020, 1783.359000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, 2}, 16.786980, 0.000030, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, -2}, 14.800180, 0.000560, 0.074000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, 0}, 194.988330, 0.157800, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, -2}, 194.943970, 0.000060, 2.993000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, 0}, 194.992560, 0.008620, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 3, 0}, 195.029650, 0.000540, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 4, 0}, 194.334160, 0.000020, 0.019000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, -2, 0}, 198.374540, 0.000030, 0.071000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, -1, 0}, 197.715080, 0.000110, 1.127000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, 0, 0}, 16.681750, 0.001880, 0.081000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, 1, 0}, 16.272560, 0.000190, 0.039000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -3, 0}, 19.131840, 0.000230, 0.067000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, -2}, 16.783600, 0.000020, 0.035000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, 0}, 17.810790, 0.005660, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, 2}, 16.783620, 0.000020, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, -2}, 17.053820, 0.000310, 0.065000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 0}, 197.114210, 0.112560, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 2}, 16.783910, 0.000040, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, -2}, 16.695180, 0.000450, 0.474000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, 0}, 196.692240, 0.112260, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, -2}, 16.242510, 0.000090, 0.090000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, 0}, 196.409110, 0.007760, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 2, 0}, 196.176830, 0.000530, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 3, 0}, 196.783930, 0.000030, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, -2, 0}, 16.784320, 0.000030, 0.094000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, -1, 0}, 16.940440, 0.000250, 0.042000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, 0, 0}, 196.785450, 0.000060, 0.027000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 3, 1, 0}, 196.784560, 0.000020, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -3, 0}, 196.783720, 0.000030, 0.103000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -2, 0}, 197.136910, 0.001230, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, -2}, 196.784010, 0.000060, 0.107000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, 0}, 196.880430, 0.002370, 0.028000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 0, -2}, 196.783910, 0.000080, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 0, 0}, 196.693610, 0.000900, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 1, 0}, 196.700600, 0.000150, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, -2, 0}, 196.783830, 0.000090, 0.021000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, -1, 0}, 196.783890, 0.000030, 0.016000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 6, 0, 0}, 16.783930, 0.000020, 0.013000},
	{{0, 0, 4, -8, 5, -5, 0, 0, -2, 0, 0}, 151.301250, 0.000180, 0.040000},
	{{0, 0, 4, -8, 5, -5, 0, 0, -2, 1, 0}, 151.301250, 0.000110, 0.087000},
	{{0, 0, 4, -8, 5, -5, 0, 0, 2, -1, 0}, 331.300370, 0.000110, 0.087000},
	{{0, 0, 4, -8, 5, -5, 0, 0, 2, 0, 0}, 331.300370, 0.000180, 0.040000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -4, 1, 0}, 2.770260, 0.000050, 0.028000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -4, 2, 0}, 2.552590, 0.000020, 0.044000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, -1, 0}, 2.761040, 0.000240, 0.027000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 0, 0}, 2.685270, 0.002140, 0.041000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 1, 0}, 2.820810, 0.002010, 0.089000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 2, 0}, 183.348930, 0.000100, 0.487000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 0, 0}, 182.398740, 0.000020, 0.083000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 2, 0}, 2.398740, 0.000020, 0.069000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -2, 0}, 0.696480, 0.000110, 0.038000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -1, 0}, 0.444730, 0.001870, 0.077000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, 0}, 181.451640, 0.000240, 3.594000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 1, 0}, 180.386280, 0.001840, 0.074000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 2, 0}, 180.324880, 0.000100, 0.037000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -2, 0}, 3.340720, 0.000070, 0.669000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -1, 0}, 182.610290, 0.001510, 0.085000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 0, 0}, 182.266940, 0.001440, 0.040000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 1, 0}, 182.222540, 0.000140, 0.026000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 4, -1, 0}, 182.232680, 0.000040, 0.027000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -4, 0, 0}, 30.539770, 0.000040, 0.021000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -4, 1, 0}, 30.525550, 0.000090, 0.028000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -4, 2, 0}, 30.515200, 0.000040, 0.045000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, -1, 0}, 30.601790, 0.000260, 0.027000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, 0}, 30.369900, 0.004080, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, 2}, 210.515550, 0.000030, 0.343000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 1, 0}, 30.684820, 0.003290, 0.094000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 2, 0}, 210.401650, 0.000220, 0.387000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, -1, 1}, 294.001940, 0.000040, 0.088000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, 0, 0}, 211.648740, 0.000160, 0.087000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -2, 0}, 30.927180, 0.000150, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -1, 0}, 30.218980, 0.002630, 0.080000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 0, 0}, 212.273120, 0.000840, 1.235000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 1, 0}, 211.168860, 0.002260, 0.071000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 2, 0}, 211.273600, 0.000110, 0.037000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, -1}, 113.990720, 0.000050, 0.074000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, 0}, 32.288640, 0.000030, 12.968000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, 1}, 294.001940, 0.000200, 0.075000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, 0}, 212.241030, 0.000550, 0.076000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 1, -1}, 293.990720, 0.000050, 0.077000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 1, 0}, 212.241030, 0.000030, 0.038000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -2, 0}, 32.460030, 0.000060, 1.037000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -1, 0}, 205.778960, 0.001750, 0.081000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, 0}, 210.905040, 0.001180, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 1, 0}, 211.896880, 0.000150, 0.026000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 4, -2, 0}, 204.538260, 0.000020, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 4, -1, 0}, 191.993940, 0.000060, 0.027000},
	{{0, 0, 4, -6, 2, 0, 0, 0, -2, 0, 0}, 11.535880, 0.000070, 0.042000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -4, 0, 0}, 240.766380, 0.000030, 0.021000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -4, 1, 0}, 246.137430, 0.000070, 0.029000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, -1, 0}, 246.094010, 0.000210, 0.027000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 0, 0}, 246.916300, 0.003150, 0.043000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 1, 0}, 245.692770, 0.001980, 0.099000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 2, 0}, 66.675280, 0.000140, 0.321000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -2, 0}, 243.207780, 0.000150, 0.040000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -1, 0}, 243.240380, 0.002330, 0.084000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 0, 0}, 62.677720, 0.000980, 0.745000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 1, 0}, 62.683880, 0.001510, 0.069000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 2, 0}, 62.694180, 0.000080, 0.036000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -2, 0}, 61.649610, 0.000210, 2.313000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -1, 0}, 241.341120, 0.003270, 0.078000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, 0}, 242.420900, 0.000280, 0.038000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 1, 0}, 241.479240, 0.000060, 0.025000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 4, -2, 0}, 241.195400, 0.000030, 0.041000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -4, 1, 0}, 295.601750, 0.000050, 0.029000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, -1, 0}, 295.400570, 0.000230, 0.028000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 0, 0}, 296.604610, 0.002240, 0.044000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 1, 0}, 295.896410, 0.001150, 0.104000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 2, 0}, 117.218330, 0.000080, 0.274000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -1, 0, 0}, 138.298690, 0.000070, 0.095000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -2, 0}, 87.680180, 0.000170, 0.041000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -1, 0}, 87.715220, 0.002470, 0.088000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 0, 0}, 123.573470, 0.000140, 0.534000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 1, 0}, 99.308450, 0.000700, 0.066000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 2, 0}, 101.334460, 0.000040, 0.035000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 1, 0, 0}, 318.298590, 0.000050, 0.070000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -3, 0}, 73.669300, 0.000020, 0.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -2, 0}, 271.742910, 0.001060, 10.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, -2}, 271.667230, 0.000090, 0.074000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, 0}, 91.920220, 0.018820, 0.075000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, 0}, 93.317570, 0.000470, 0.038000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 1, -2}, 90.642810, 0.000020, 0.077000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 1, 0}, 266.531770, 0.000020, 0.025000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -2, 0}, 92.303780, 0.000160, 0.040000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -1, 0}, 91.973590, 0.000170, 0.026000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, -1, 0}, 166.189260, 0.000020, 0.028000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, 0, 0}, 167.575340, 0.000510, 0.045000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, 1, 0}, 166.590050, 0.000140, 0.110000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, -1, 0}, 181.265000, 0.000080, 0.092000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 0, 0}, 340.989650, 0.000070, 0.416000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 1, 0}, 341.485980, 0.000080, 0.064000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, -1, 0}, 308.902460, 0.000250, 0.072000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, 0, 0}, 112.581850, 0.000090, 0.037000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, 0, 0}, 244.499980, 0.000370, 0.046000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, 1, 0}, 246.551940, 0.000080, 0.117000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, -1, 0}, 247.425230, 0.000030, 0.097000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, 1, 0}, 67.425230, 0.000030, 0.062000},
	{{0, 0, 4, 0, -7, 0, 0, 0, 2, -1, 0}, 121.318200, 0.000040, 0.067000},
	{{0, 0, 4, 0, -7, 0, 0, 0, 2, 0, 0}, 300.781700, 0.000040, 0.036000},
	{{0, 0, 4, 0, -6, 0, 0, 0, -2, 0, 0}, 285.385920, 0.000110, 0.047000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 0, 1, 0}, 109.362490, 0.000030, 0.060000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 2, -1, 0}, 110.626980, 0.000240, 0.067000},
	{{0, 0, 4, 0, -6, 0, 0, 0, 2, 0, 0}, 290.560590, 0.000140, 0.035000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 2, -3, 0}, 258.166130, 0.000020, 0.088000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 2, -2, 0}, 78.304750, 0.000030, 0.529000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 2, -1, 0}, 258.166130, 0.000020, 0.066000},
	{{0, 0, 4, 0, -6, 5, 0, 0, 2, 0, 0}, 78.304750, 0.000030, 0.035000},
	{{0, 0, 4, 0, -5, 0, 0, 0, -2, 0, 0}, 273.480300, 0.000310, 0.047000},
	{{0, 0, 4, 0, -5, 0, 0, 0, -2, 1, 0}, 272.366060, 0.000060, 0.127000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, -1, 0}, 101.352890, 0.000060, 0.103000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, 0, 0}, 96.296850, 0.000060, 0.279000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 0, 1, 0}, 99.972990, 0.000200, 0.059000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, -2, 0}, 280.205760, 0.000070, 0.554000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, -1, 0}, 100.283710, 0.001090, 0.066000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, 0, 0}, 280.342720, 0.000590, 0.035000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 2, 1, 0}, 280.317000, 0.000100, 0.024000},
	{{0, 0, 4, 0, -5, 0, 0, 0, 4, 0, 0}, 100.333790, 0.000020, 0.019000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, -1, 0}, 256.755120, 0.000090, 0.029000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 0, 0}, 256.622210, 0.000900, 0.047000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 1, 0}, 256.223120, 0.000280, 0.128000},
	{{0, 0, 4, 0, -4, 0, 0, 0, -2, 2, 0}, 80.500370, 0.000020, 0.184000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, -1, 0}, 81.942120, 0.000190, 0.104000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 0, 0}, 41.422650, 0.000030, 0.273000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 1, 0}, 86.821470, 0.000490, 0.059000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 0, 2, 0}, 86.256880, 0.000030, 0.033000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, -2, 0}, 269.104510, 0.000170, 0.529000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, -1, 0}, 89.805320, 0.003250, 0.066000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 0, 0}, 269.689910, 0.001890, 0.035000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 2, 1, 0}, 269.573470, 0.000180, 0.024000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 4, -2, 0}, 89.256980, 0.000040, 0.038000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 4, -1, 0}, 269.635440, 0.000050, 0.025000},
	{{0, 0, 4, 0, -4, 0, 0, 0, 4, 0, 0}, 269.457040, 0.000030, 0.019000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -4, 0, 0}, 333.361200, 0.000040, 0.022000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, -1, 0}, 154.050030, 0.000080, 0.029000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 0, 0}, 153.856640, 0.000900, 0.048000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 1, 0}, 153.993770, 0.000230, 0.129000},
	{{0, 0, 4, 0, -3, 0, 0, 0, -2, 2, 0}, 333.766210, 0.000020, 0.181000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, -1, 0}, 26.364300, 0.000120, 0.105000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, 0, 0}, 333.492740, 0.000080, 0.267000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 0, 1, 0}, 329.142380, 0.000100, 0.059000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, -1, 0}, 275.523940, 0.000260, 0.066000},
	{{0, 0, 4, 0, -3, 0, 0, 0, 2, 0, 0}, 81.027570, 0.000150, 0.035000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, -3, 0}, 98.517510, 0.000020, 0.088000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, -2, 0}, 278.517510, 0.000030, 0.530000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, -1, 0}, 98.517510, 0.000020, 0.066000},
	{{0, 0, 4, 0, -2, -5, 0, 0, 2, 0, 0}, 278.517510, 0.000030, 0.035000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -4, 0, 0}, 242.817180, 0.000040, 0.022000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, -1, 0}, 61.168500, 0.000050, 0.029000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 0, 0}, 61.496260, 0.000700, 0.048000},
	{{0, 0, 4, 0, -2, 0, 0, 0, -2, 1, 0}, 60.013990, 0.000070, 0.131000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 0, -2, 0}, 244.133950, 0.000020, 0.044000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 0, -1, 0}, 245.004570, 0.000220, 0.106000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 0, 0, 0}, 69.888130, 0.000030, 0.261000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 0, 1, 0}, 239.939810, 0.000040, 0.059000},
	{{0, 0, 4, 0, -2, 0, 0, 0, 2, -1, 0}, 65.721730, 0.000040, 0.065000},
	{{0, 0, 4, 0, -1, 0, 0, 0, -2, 0, 0}, 155.008570, 0.000100, 0.048000},
	{{0, 0, 4, 0, -1, 0, 0, 0, 2, -1, 0}, 227.912380, 0.000030, 0.065000},
	{{0, 0, 4, 0, -1, 0, 0, 0, 2, 0, 0}, 81.429060, 0.000060, 0.035000},
	{{0, 0, 4, 0, 0, -4, 0, 0, 2, -1, 0}, 89.887210, 0.000050, 0.065000},
	{{0, 0, 4, 0, 0, -4, 0, 0, 2, 0, 0}, 269.887210, 0.000070, 0.035000},
	{{0, 0, 4, 0, 0, -3, 0, 0, -2, 0, 0}, 164.376880, 0.000040, 0.048000},
	{{0, 0, 4, 0, 0, -2, 0, 0, -2, 0, 0}, 63.835030, 0.000040, 0.048000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -3, 0}, 36.541870, 0.000030, 0.091000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -2, 0}, 218.119290, 0.000050, 0.449000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -1, 0}, 216.541870, 0.000030, 0.065000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 38.072390, 0.000040, 0.035000},
	{{0, 0, 4, 0, 1, 0, 0, 0, 2, -1, 0}, 29.690630, 0.000030, 0.064000},
	{{0, 0, 4, 0, 1, 0, 0, 0, 2, 0, 0}, 207.343970, 0.000060, 0.035000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 2, -1, 0}, 216.926150, 0.000030, 0.094000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 2, 0, 0}, 216.926150, 0.000090, 0.042000},
	{{0, 0, 5, -10, 0, 0, 0, 0, -2, 0, 0}, 302.402890, 0.000100, 0.040000},
	{{0, 0, 5, -10, 0, 0, 0, 0, -2, 1, 0}, 302.168400, 0.000050, 0.085000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, -1, 0}, 302.975550, 0.000180, 0.074000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, 1, 0}, 122.975550, 0.000180, 0.077000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 2, -1, 0}, 132.584400, 0.000070, 0.090000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 2, 0, 0}, 129.673650, 0.000220, 0.041000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -4, 1, 0}, 333.835550, 0.000040, 0.028000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, -1, 0}, 333.832030, 0.000130, 0.026000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 0, 0}, 333.734030, 0.001200, 0.041000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 1, 0}, 334.042950, 0.001130, 0.089000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 2, 0}, 154.776390, 0.000060, 0.503000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -2, 0}, 331.037060, 0.000070, 0.038000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -1, 0}, 331.005590, 0.001130, 0.077000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 0, 0}, 147.580200, 0.000070, 4.655000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 1, 0}, 150.842620, 0.001090, 0.074000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 2, 0}, 151.311090, 0.000070, 0.037000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -2, 0}, 334.325950, 0.000040, 0.641000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -1, 0}, 153.507990, 0.000910, 0.085000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 0, 0}, 153.193880, 0.000870, 0.040000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 1, 0}, 153.203910, 0.000090, 0.026000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 4, 0, 0}, 333.158860, 0.000030, 0.020000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -4, 1, 0}, 1.977020, 0.000050, 0.028000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, -1, 0}, 1.976580, 0.000160, 0.027000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 0, 0}, 1.980440, 0.001380, 0.042000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 1, 0}, 1.999350, 0.001100, 0.093000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 2, 0}, 181.868840, 0.000080, 0.397000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -1, -1, 1}, 264.296350, 0.000060, 0.087000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, -2, 0}, 1.804690, 0.000030, 0.039000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, -1, 0}, 3.623530, 0.000740, 0.080000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 0, 0}, 182.689800, 0.000220, 1.340000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 1, 0}, 181.860570, 0.000720, 0.071000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 2, 0}, 181.812800, 0.000040, 0.037000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -1, 1}, 264.296360, 0.000330, 0.075000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, 0, 0}, 182.818610, 0.000110, 0.076000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -2, 0}, 3.076490, 0.000040, 0.973000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -1, 0}, 199.629490, 0.000480, 0.082000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 0, 0}, 183.100920, 0.000590, 0.039000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 4, -2, 0}, 315.228750, 0.000030, 0.042000},
	{{0, 0, 5, -8, 1, 5, 0, 0, -2, 0, 0}, 264.667660, 0.000140, 0.042000},
	{{0, 0, 5, -8, 1, 5, 0, 0, -2, 1, 0}, 264.667660, 0.000050, 0.095000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, -1, 0}, 94.318580, 0.000030, 0.016000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 0, 0}, 274.391280, 0.000200, 0.021000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 1, 0}, 274.558220, 0.000530, 0.028000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -4, 2, 0}, 275.017420, 0.000110, 0.046000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -3, 0, 0}, 274.686180, 0.000050, 0.028000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, -2, 0}, 275.127070, 0.000040, 0.020000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, -1, 0}, 274.296910, 0.000790, 0.027000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, 0}, 274.816550, 0.011050, 0.042000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, 2}, 95.055140, 0.000020, 0.322000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 1, 0}, 275.261260, 0.007100, 0.095000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 2, 0}, 95.760270, 0.000420, 0.361000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -2, 0}, 274.936500, 0.000200, 0.039000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -1, 0}, 275.629800, 0.003070, 0.082000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 0, 0}, 96.982880, 0.000870, 1.001000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 1, 0}, 102.122540, 0.000900, 0.070000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 2, 0}, 248.946810, 0.000020, 0.036000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 1, 0, 0}, 93.065270, 0.000040, 0.075000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, -2, 0}, 97.035490, 0.000040, 1.291000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, -1, 0}, 271.282140, 0.000390, 0.080000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, 0, 0}, 271.310160, 0.000690, 0.039000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 2, 1, 0}, 273.390020, 0.000140, 0.026000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 4, -1, 0}, 273.846980, 0.000020, 0.027000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -4, 1, 0}, 216.585670, 0.000040, 0.029000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, -1, 0}, 216.569430, 0.000190, 0.027000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 0, 0}, 216.477370, 0.001740, 0.043000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 1, 0}, 216.588100, 0.001120, 0.098000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 2, 0}, 37.022030, 0.000070, 0.328000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, -2, 0}, 214.612140, 0.000070, 0.040000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, -1, 0}, 213.568980, 0.001280, 0.083000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 0, 0}, 31.656370, 0.000480, 0.782000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 1, 0}, 33.583860, 0.000880, 0.069000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 2, 0}, 33.023670, 0.000040, 0.036000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -2, 0}, 33.081220, 0.000100, 2.017000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -1, 0}, 212.216480, 0.001530, 0.078000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, 0}, 215.510780, 0.000100, 0.038000},
	{{0, 0, 5, -6, -1, 0, 0, 0, 2, -3, 0}, 18.374370, 0.000020, 0.075000},
	{{0, 0, 5, -6, -1, 0, 0, 0, 2, -1, 0}, 198.374370, 0.000020, 0.076000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -4, 0, 0}, 80.298510, 0.000040, 0.021000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, -1, 0}, 280.526580, 0.000040, 0.028000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 0, 0}, 259.075520, 0.000980, 0.044000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 1, 0}, 255.881610, 0.000530, 0.103000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 2, 0}, 77.225790, 0.000020, 0.279000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -3, 0}, 61.809610, 0.000040, 0.026000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -2, 0}, 61.534030, 0.000620, 0.040000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -1, 0}, 61.267190, 0.006790, 0.087000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 0, 0}, 239.210470, 0.000590, 0.553000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 1, 0}, 66.587330, 0.000400, 0.066000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 2, 0}, 67.489740, 0.000020, 0.035000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -4, 0}, 62.846880, 0.000020, 0.038000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -3, 0}, 62.847140, 0.000380, 0.076000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, 0}, 241.751400, 0.002280, 27.873000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, -2}, 241.741750, 0.000150, 0.074000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, 0}, 61.734160, 0.039740, 0.075000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, 0}, 61.849130, 0.001730, 0.038000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 1, 0}, 61.793220, 0.000070, 0.025000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -3, 0}, 241.352110, 0.000240, 0.087000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -2, 0}, 61.864490, 0.000160, 0.040000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, -1, 0}, 61.746440, 0.000340, 0.026000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 4, 0, 0}, 61.742180, 0.000040, 0.019000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 0, 0}, 222.631690, 0.000300, 0.045000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 1, 0}, 216.330390, 0.000070, 0.109000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -2, 0}, 88.752190, 0.000030, 0.041000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -1, 0}, 100.563870, 0.000200, 0.092000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 0, 0}, 79.747610, 0.000170, 0.427000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 1, 0}, 81.613950, 0.000270, 0.064000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -2, 0}, 269.579130, 0.000150, 1.762000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -1, 0}, 89.688870, 0.002650, 0.072000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 0, 0}, 271.461380, 0.000340, 0.037000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 1, 0}, 270.469330, 0.000050, 0.025000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 4, -2, 0}, 89.544270, 0.000030, 0.040000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, 0, 0}, 176.586650, 0.000310, 0.046000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, 1, 0}, 177.182360, 0.000050, 0.116000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, -1, 0}, 340.903880, 0.000130, 0.096000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, 0, 0}, 318.241620, 0.000040, 0.348000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, 1, 0}, 337.961590, 0.000040, 0.062000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, -1, 0}, 271.912600, 0.000140, 0.070000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, 0, 0}, 116.465040, 0.000150, 0.036000},
	{{0, 0, 5, -3, 0, 0, 0, 0, -2, 0, 0}, 57.583290, 0.000050, 0.047000},
	{{0, 0, 5, -2, 0, 0, 0, 0, -2, 0, 0}, 142.397270, 0.000030, 0.048000},
	{{0, 0, 5, 0, -7, 0, 0, 0, 2, -1, 0}, 110.507100, 0.000070, 0.063000},
	{{0, 0, 5, 0, -7, 0, 0, 0, 2, 0, 0}, 290.507100, 0.000120, 0.034000},
	{{0, 0, 5, 0, -6, 0, 0, 0, -2, 0, 0}, 272.606450, 0.000090, 0.049000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 0, 1, 0}, 100.051690, 0.000030, 0.056000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, -1, 0}, 100.051680, 0.000280, 0.063000},
	{{0, 0, 5, 0, -6, 0, 0, 0, 2, 0, 0}, 280.051680, 0.000220, 0.034000},
	{{0, 0, 5, 0, -5, 0, 0, 0, -2, 0, 0}, 254.953170, 0.000210, 0.050000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 0, -1, 0}, 95.638130, 0.000030, 0.115000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 0, 0, 0}, 64.168030, 0.000020, 0.218000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 0, 1, 0}, 86.889510, 0.000090, 0.056000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, -2, 0}, 269.666500, 0.000030, 0.357000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, -1, 0}, 88.992570, 0.000720, 0.062000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, 0, 0}, 269.210680, 0.000510, 0.034000},
	{{0, 0, 5, 0, -5, 0, 0, 0, 2, 1, 0}, 269.124700, 0.000090, 0.023000},
	{{0, 0, 5, 0, -4, 0, 0, 0, -2, 0, 0}, 152.758160, 0.000170, 0.050000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 0, -1, 0}, 145.056330, 0.000020, 0.116000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 0, 0, 0}, 292.790450, 0.000030, 0.214000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 0, 1, 0}, 325.056330, 0.000020, 0.056000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 2, -1, 0}, 299.312920, 0.000090, 0.062000},
	{{0, 0, 5, 0, -4, 0, 0, 0, 2, 0, 0}, 111.085640, 0.000150, 0.034000},
	{{0, 0, 5, 0, -3, 0, 0, 0, -2, 0, 0}, 49.476990, 0.000090, 0.050000},
	{{0, 0, 5, 0, -2, 0, 0, 0, -2, 0, 0}, 317.417190, 0.000050, 0.050000},
	{{0, 0, 5, 0, -1, 0, 0, 0, 2, -2, 0}, 39.976360, 0.000040, 0.318000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, -2, 0}, 266.949410, 0.000020, 0.046000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 266.949410, 0.000020, 0.200000},
	{{0, 0, 6, -16, 4, 5, 0, 0, 2, 0, 0}, 8.554290, 0.000120, 0.044000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 2, -1, 0}, 193.392190, 0.000040, 0.095000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 2, 0, 0}, 193.392190, 0.000100, 0.042000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, -1, 0}, 273.427000, 0.000030, 0.073000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 1, 0}, 93.427000, 0.000030, 0.078000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 2, 0, 0}, 103.940160, 0.000050, 0.041000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, -1, 0}, 304.844360, 0.000090, 0.026000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 0, 0}, 304.710990, 0.000800, 0.041000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 1, 0}, 305.277220, 0.000770, 0.088000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 2, 0}, 126.218010, 0.000040, 0.519000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -2, 0}, 303.244460, 0.000050, 0.038000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -1, 0}, 301.662060, 0.000830, 0.076000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 0, 0}, 121.593790, 0.000060, 6.602000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 1, 0}, 121.593910, 0.000840, 0.075000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 2, 0}, 122.029650, 0.000050, 0.038000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, -2, 0}, 307.150050, 0.000020, 0.616000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, -1, 0}, 124.783830, 0.000540, 0.086000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 0, 0}, 124.214260, 0.000660, 0.040000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 1, 0}, 124.258740, 0.000070, 0.026000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, -1, 0}, 333.254530, 0.000040, 0.027000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 0, 0}, 333.245900, 0.000460, 0.042000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 1, 0}, 333.364630, 0.000300, 0.093000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, -1, 0}, 332.301360, 0.000280, 0.080000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 0, 0}, 153.515730, 0.000100, 1.464000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 1, 0}, 152.377600, 0.000260, 0.072000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 1, -1, 1}, 54.932160, 0.000100, 0.076000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, -1, 0}, 154.124110, 0.000260, 0.082000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, 0, 0}, 154.100980, 0.000200, 0.039000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -4, 0, 0}, 7.555520, 0.000040, 0.021000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, -1, 0}, 187.472570, 0.000110, 0.027000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 0, 0}, 187.402970, 0.000930, 0.043000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 1, 0}, 187.651760, 0.000640, 0.097000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 2, 0}, 6.369150, 0.000020, 0.335000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, -2, 0}, 185.058920, 0.000020, 0.040000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, -1, 0}, 184.628520, 0.000660, 0.083000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 0, 0}, 3.844510, 0.000270, 0.823000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 1, 0}, 4.530340, 0.000480, 0.069000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 2, 0}, 5.183770, 0.000020, 0.036000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -1, 0}, 183.230040, 0.000650, 0.079000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, -1, 0}, 216.839280, 0.000090, 0.028000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 0, 0}, 221.160050, 0.000530, 0.043000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 1, 0}, 224.487560, 0.000140, 0.103000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -1, 0}, 212.602620, 0.005340, 0.087000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 0, 0}, 33.032860, 0.000890, 0.573000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 1, 0}, 35.338060, 0.000340, 0.067000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -4, 0}, 31.523120, 0.000040, 0.038000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -3, 0}, 31.523110, 0.000640, 0.075000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, 0}, 32.355220, 0.001690, 36.376000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, -2}, 32.336250, 0.000110, 0.073000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, 0}, 212.343640, 0.030480, 0.076000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, 0}, 212.341700, 0.001910, 0.038000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 1, 0}, 212.370520, 0.000130, 0.025000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -3, 0}, 212.740590, 0.000250, 0.087000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -2, 0}, 212.355420, 0.000590, 0.040000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, -1, 0}, 212.339200, 0.000280, 0.026000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 4, 0, 0}, 212.336940, 0.000030, 0.020000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -4, 0, 0}, 351.959830, 0.000050, 0.021000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, -1, 0}, 172.678930, 0.000050, 0.028000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 0, 0}, 172.406280, 0.000760, 0.044000},
	{{0, 0, 6, -8, 3, 0, 0, 0, -2, 1, 0}, 173.307830, 0.000160, 0.105000},
	{{0, 0, 6, -8, 3, 0, 0, 0, 0, -1, 0}, 175.046340, 0.000040, 0.089000},
	{{0, 0, 6, -8, 3, 0, 0, 0, 0, 0, 0}, 352.710550, 0.000040, 0.500000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 0, 0}, 212.917650, 0.000240, 0.045000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 1, 0}, 204.621870, 0.000070, 0.109000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, -2, 0}, 60.317270, 0.000030, 0.041000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, -1, 0}, 66.517640, 0.000230, 0.091000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 0, 0}, 53.888420, 0.000120, 0.439000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 1, 0}, 55.277120, 0.000240, 0.064000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -2, 0}, 240.761730, 0.000150, 1.983000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -1, 0}, 60.844730, 0.002630, 0.073000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, 0}, 242.156760, 0.000280, 0.037000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 1, 0}, 241.427620, 0.000060, 0.025000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 4, -2, 0}, 60.741940, 0.000030, 0.040000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 0, 0}, 239.656970, 0.000250, 0.046000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 1, 0}, 210.622830, 0.000020, 0.115000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -2, 0}, 318.830760, 0.000040, 0.042000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -1, 0}, 325.389050, 0.000260, 0.096000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, 0, 0}, 96.294180, 0.000160, 0.356000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, 1, 0}, 85.354250, 0.000150, 0.062000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -2, 0}, 269.916710, 0.000060, 0.965000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -1, 0}, 96.872730, 0.001290, 0.070000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 0, 0}, 270.478050, 0.000350, 0.036000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 1, 0}, 270.582580, 0.000040, 0.025000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 3, -1, -1}, 13.220590, 0.000050, 0.076000},
	{{0, 0, 6, -5, 0, 0, 0, 0, -2, 0, 0}, 130.942890, 0.000090, 0.047000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, -1, 0}, 299.851910, 0.000160, 0.067000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, 0, 0}, 118.644850, 0.000180, 0.036000},
	{{0, 0, 6, 0, -8, 0, 0, 0, 2, 0, 0}, 290.248110, 0.000040, 0.033000},
	{{0, 0, 6, 0, -7, 0, 0, 0, 2, -1, 0}, 99.584550, 0.000060, 0.059000},
	{{0, 0, 6, 0, -7, 0, 0, 0, 2, 0, 0}, 279.584550, 0.000150, 0.033000},
	{{0, 0, 6, 0, -6, 0, 0, 0, -2, 0, 0}, 252.139560, 0.000030, 0.052000},
	{{0, 0, 6, 0, -6, 0, 0, 0, 2, -1, 0}, 88.117140, 0.000130, 0.059000},
	{{0, 0, 6, 0, -6, 0, 0, 0, 2, 0, 0}, 268.117140, 0.000130, 0.033000},
	{{0, 0, 6, 0, -5, 0, 0, 0, 2, 0, 0}, 113.284380, 0.000050, 0.033000},
	{{0, 0, 7, -16, 4, 5, 0, 0, -2, 0, 0}, 265.617360, 0.000090, 0.039000},
	{{0, 0, 7, -16, 4, 5, 0, 0, -2, 1, 0}, 265.617360, 0.000060, 0.080000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, -1, 0}, 85.617360, 0.000160, 0.070000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 0, 0}, 85.617360, 0.000110, 1.000000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 0, 1, 0}, 265.617360, 0.000150, 0.082000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, -2, 0}, 85.617360, 0.000020, 0.360000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, -1, 0}, 265.617360, 0.000820, 0.095000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, 0, 0}, 265.617360, 0.001140, 0.042000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 2, 1, 0}, 265.617360, 0.000120, 0.027000},
	{{0, 0, 7, -16, 4, 5, 0, 0, 4, -1, 0}, 265.617360, 0.000020, 0.028000},
	{{0, 0, 7, -15, 0, 0, 0, 0, -2, 0, 0}, 169.791620, 0.000030, 0.039000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, -1, 0}, 346.482220, 0.000050, 0.070000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, 0, 0}, 349.508690, 0.000050, 1.025000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, 1, 0}, 166.497090, 0.000090, 0.081000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, -1, 0}, 167.831080, 0.000150, 0.095000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, 0, 0}, 168.016280, 0.000330, 0.042000},
	{{0, 0, 7, -13, -1, 0, 0, 0, -2, 0, 0}, 206.214640, 0.000110, 0.040000},
	{{0, 0, 7, -13, -1, 0, 0, 0, -2, 1, 0}, 206.771870, 0.000050, 0.087000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 0, -1, 0}, 205.106570, 0.000120, 0.075000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 0, 1, 0}, 25.106570, 0.000120, 0.075000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 2, -1, 0}, 26.764840, 0.000050, 0.087000},
	{{0, 0, 7, -13, -1, 0, 0, 0, 2, 0, 0}, 26.207350, 0.000110, 0.040000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, -1, 0}, 275.846080, 0.000090, 0.026000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 0, 0}, 275.684200, 0.000780, 0.041000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 1, 0}, 276.475810, 0.000620, 0.088000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 2, 0}, 98.546450, 0.000020, 0.537000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, -2, 0}, 272.489440, 0.000040, 0.038000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, -1, 0}, 272.728890, 0.000960, 0.076000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, 0}, 93.758800, 0.000040, 11.350000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 1, 0}, 92.627890, 0.000960, 0.075000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 2, 0}, 92.516980, 0.000040, 0.038000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -2, 0}, 277.845660, 0.000030, 0.593000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -1, 0}, 95.889290, 0.000570, 0.086000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 0, 0}, 95.259870, 0.000700, 0.040000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 1, 0}, 95.393710, 0.000070, 0.026000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, 0, 0}, 304.455600, 0.000170, 0.041000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, 1, 0}, 304.540400, 0.000120, 0.092000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, -1, 0}, 303.752840, 0.000120, 0.079000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, 0, 0}, 124.038510, 0.000020, 1.613000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, 1, 0}, 123.752840, 0.000120, 0.072000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 2, -1, 0}, 125.222770, 0.000100, 0.083000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 2, 0, 0}, 124.932620, 0.000140, 0.039000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, -1, 0}, 158.982030, 0.000070, 0.027000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 0, 0}, 158.877840, 0.000550, 0.042000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 1, 0}, 159.136210, 0.000290, 0.097000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, -1, 0}, 156.266200, 0.000400, 0.083000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 0, 0}, 334.997050, 0.000160, 0.868000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 1, 0}, 335.963090, 0.000300, 0.069000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, -1, 0}, 154.625530, 0.000250, 0.079000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, 0, 0}, 158.692190, 0.000040, 0.039000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, 0, 0}, 191.084910, 0.000220, 0.043000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, 1, 0}, 192.513240, 0.000080, 0.102000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, -2, 0}, 183.058360, 0.000050, 0.040000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, -1, 0}, 183.689520, 0.000960, 0.086000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 0, 0}, 4.333290, 0.000200, 0.594000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 1, 0}, 6.590530, 0.000160, 0.067000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -3, 0}, 3.463260, 0.000040, 0.075000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -2, 0}, 3.125710, 0.000260, 11.006000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -1, 0}, 183.146600, 0.004630, 0.076000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 0, 0}, 183.232920, 0.000360, 0.038000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 4, -2, 0}, 183.126250, 0.000050, 0.041000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 4, -1, 0}, 183.126660, 0.000040, 0.026000},
	{{0, 0, 7, -10, 1, 0, 0, 0, 2, -1, 0}, 56.090070, 0.000060, 0.075000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, 0, 0}, 181.937570, 0.000240, 0.044000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, 1, 0}, 171.842210, 0.000030, 0.108000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, -1, 0}, 35.934130, 0.000180, 0.091000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 0, 0}, 24.490760, 0.000060, 0.452000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 1, 0}, 26.505490, 0.000150, 0.065000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -2, 0}, 211.658760, 0.000100, 2.269000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -1, 0}, 31.803460, 0.001850, 0.073000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, 0}, 212.634400, 0.000200, 0.037000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 1, 0}, 212.374210, 0.000030, 0.025000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 0, 0}, 225.903540, 0.000230, 0.045000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 1, 0}, 212.821780, 0.000020, 0.114000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, -1, 0}, 99.972520, 0.000260, 0.095000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, 0, 0}, 46.855420, 0.000110, 0.364000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, 1, 0}, 59.165020, 0.000150, 0.062000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, -2, 0}, 241.225170, 0.000070, 1.028000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, -1, 0}, 55.572420, 0.001110, 0.070000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 0, 0}, 241.503050, 0.000310, 0.036000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 1, 0}, 241.443290, 0.000060, 0.025000},
	{{0, 0, 7, -8, 3, 0, 0, 0, -2, 0, 0}, 69.930020, 0.000060, 0.046000},
	{{0, 0, 7, -7, 0, 0, 0, 0, -2, 0, 0}, 257.081760, 0.000090, 0.047000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, -1, 0}, 95.028760, 0.000030, 0.100000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 0, 0}, 84.584710, 0.000090, 0.305000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 1, 0}, 87.808090, 0.000070, 0.060000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -1, 0}, 90.060180, 0.000540, 0.068000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 0, 0}, 270.416320, 0.000270, 0.036000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 1, 0}, 90.417420, 0.000020, 0.024000},
	{{0, 0, 7, -6, 0, 0, 0, 0, -2, 0, 0}, 133.143180, 0.000050, 0.048000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, -1, 0}, 299.845730, 0.000120, 0.065000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, 0, 0}, 119.844320, 0.000180, 0.035000},
	{{0, 0, 7, 0, -8, 0, 0, 0, 2, 0, 0}, 278.931100, 0.000040, 0.032000},
	{{0, 0, 7, 0, -7, 0, 0, 0, 2, 0, 0}, 266.698430, 0.000070, 0.032000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 2, -1, 0}, 142.434730, 0.000030, 0.096000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 2, 0, 0}, 142.434730, 0.000090, 0.042000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 0, 0}, 342.680440, 0.000120, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 1, 0}, 342.680440, 0.000240, 0.028000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -4, 2, 0}, 342.680440, 0.000120, 0.044000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -3, 0, 0}, 342.680440, 0.000050, 0.027000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -2, 0}, 342.680440, 0.000050, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -1, 0}, 342.680440, 0.000610, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, -1, 2}, 162.680440, 0.000020, 0.090000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 0, 0}, 342.680440, 0.010730, 0.040000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 0, 2}, 162.680440, 0.000030, 0.474000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 1, 0}, 342.680440, 0.013770, 0.087000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 1, 2}, 162.680440, 0.000020, 0.065000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 2, 0}, 162.680440, 0.000930, 0.564000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -2, 3, 0}, 162.680440, 0.000050, 0.067000},
	{{0, 0, 8, -16, 4, 5, 0, 0, -1, 0, 0}, 162.680440, 0.000190, 0.081000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -2, 0}, 162.680440, 0.000140, 0.038000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, -1, 0}, 162.680440, 0.001810, 0.075000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 1, 0}, 342.680440, 0.001810, 0.075000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 0, 2, 0}, 342.680440, 0.000140, 0.038000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 1, 0, 0}, 342.680440, 0.000190, 0.081000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -3, 0}, 342.680440, 0.000050, 0.067000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -2, 0}, 342.680440, 0.000930, 0.564000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -1, -2}, 342.680440, 0.000020, 0.065000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, -1, 0}, 162.680440, 0.013770, 0.087000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 0, -2}, 342.680440, 0.000030, 0.474000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 0, 0}, 162.680440, 0.010730, 0.040000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 1, -2}, 342.680440, 0.000020, 0.090000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 1, 0}, 162.680440, 0.000610, 0.026000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 2, 2, 0}, 162.680440, 0.000050, 0.020000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 3, 0, 0}, 162.680440, 0.000050, 0.027000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, -2, 0}, 162.680440, 0.000120, 0.044000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, -1, 0}, 162.680440, 0.000240, 0.028000},
	{{0, 0, 8, -16, 4, 5, 0, 0, 4, 0, 0}, 162.680440, 0.000120, 0.020000},
	{{0, 0, 8, -16, 6, 0, 0, 0, -2, 0, 0}, 351.024760, 0.000140, 0.040000},
	{{0, 0, 8, -16, 6, 0, 0, 0, -2, 1, 0}, 351.024760, 0.000080, 0.087000},
	{{0, 0, 8, -16, 6, 0, 0, 0, 2, -1, 0}, 171.024760, 0.000080, 0.087000},
	{{0, 0, 8, -16, 6, 0, 0, 0, 2, 0, 0}, 171.024760, 0.000140, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -4, 0, 0}, 246.811540, 0.000030, 0.020000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -4, 1, 0}, 246.825490, 0.000090, 0.028000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -4, 2, 0}, 246.824340, 0.000030, 0.044000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, -1, 0}, 246.253450, 0.000260, 0.026000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, 0}, 246.731870, 0.003310, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 1, 0}, 247.367270, 0.003300, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 2, 0}, 68.522350, 0.000170, 0.556000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -1, 0, 0}, 66.694090, 0.000070, 0.081000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -2, 0}, 243.789380, 0.000250, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, 0}, 243.683280, 0.004520, 0.076000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, 0}, 61.778920, 0.000050, 40.427000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, 0}, 63.660330, 0.004510, 0.075000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 2, 0}, 63.740420, 0.000250, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 1, 0, 0}, 246.775440, 0.000070, 0.081000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -2, 0}, 248.399030, 0.000160, 0.572000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -1, 0}, 67.233200, 0.003190, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, 0}, 66.568460, 0.003170, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 1, 0}, 66.110320, 0.000250, 0.026000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 4, -2, 0}, 66.693630, 0.000030, 0.044000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 4, -1, 0}, 66.669140, 0.000080, 0.028000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 4, 0, 0}, 66.649890, 0.000030, 0.020000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 0, 0}, 275.614400, 0.000130, 0.041000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 1, 0}, 275.614310, 0.000050, 0.092000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, -1, 0}, 271.993560, 0.000040, 0.079000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 1, 0}, 91.993560, 0.000040, 0.072000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 2, -1, 0}, 94.994720, 0.000060, 0.083000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 2, 0, 0}, 95.899610, 0.000060, 0.040000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, -1, 0}, 131.707820, 0.000040, 0.027000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 0, 0}, 131.575890, 0.000410, 0.042000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 1, 0}, 132.169770, 0.000200, 0.096000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, -1, 0}, 128.329280, 0.000260, 0.082000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, 0, 0}, 306.040080, 0.000100, 0.919000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, 1, 0}, 307.578300, 0.000210, 0.070000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 2, -1, 0}, 126.369730, 0.000100, 0.080000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 2, 0, 0}, 307.635770, 0.000020, 0.039000},
	{{0, 0, 8, -12, 0, 0, 0, 0, -2, 0, 0}, 160.665270, 0.000180, 0.043000},
	{{0, 0, 8, -12, 0, 0, 0, 0, -2, 1, 0}, 160.665350, 0.000050, 0.101000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, -1, 0}, 154.870280, 0.000300, 0.086000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, 0, 0}, 335.113410, 0.000090, 0.617000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, 1, 0}, 336.935730, 0.000070, 0.067000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -2, 0}, 334.131820, 0.000070, 6.484000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -1, 0}, 154.181750, 0.001260, 0.076000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, 0, 0}, 154.398760, 0.000220, 0.038000},
	{{0, 0, 8, -12, 2, 0, 0, 0, 2, -1, 0}, 39.287610, 0.000060, 0.075000},
	{{0, 0, 8, -11, 0, 0, 0, 0, -2, 0, 0}, 141.697810, 0.000110, 0.044000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, -1, 0}, 5.629580, 0.000140, 0.090000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, 0, 0}, 348.872310, 0.000060, 0.465000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, 1, 0}, 356.340260, 0.000060, 0.065000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -2, 0}, 182.745840, 0.000060, 2.649000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, -2}, 183.559820, 0.000060, 0.076000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, 0}, 2.851010, 0.001130, 0.073000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, 0}, 184.151330, 0.000050, 0.037000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 1, -2}, 3.559820, 0.000060, 0.075000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 0, 0}, 200.615460, 0.000140, 0.045000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, -1, 0}, 52.715940, 0.000080, 0.095000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, 0, 0}, 28.001470, 0.000100, 0.373000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, 1, 0}, 30.644780, 0.000100, 0.063000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -2, 0}, 212.479820, 0.000040, 1.100000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -1, 0}, 32.426780, 0.000840, 0.071000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, 0}, 212.414330, 0.000220, 0.036000},
	{{0, 0, 8, -9, 0, 0, 0, 0, -2, 0, 0}, 235.372000, 0.000120, 0.046000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, -1, 0}, 64.754960, 0.000030, 0.100000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, 0, 0}, 58.635050, 0.000100, 0.311000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, 1, 0}, 60.437280, 0.000090, 0.061000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -2, 0}, 243.400240, 0.000030, 0.694000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -1, 0}, 61.381170, 0.000710, 0.068000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, 0}, 241.137590, 0.000270, 0.036000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 1, 0}, 241.264490, 0.000030, 0.024000},
	{{0, 0, 8, -8, 0, 0, 0, 0, -2, 0, 0}, 249.700010, 0.000040, 0.048000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, -1, 0}, 89.546290, 0.000020, 0.105000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, 1, 0}, 90.065310, 0.000030, 0.059000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -1, 0}, 89.860170, 0.000300, 0.066000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, 0, 0}, 270.062420, 0.000180, 0.035000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, -1, 0}, 300.578360, 0.000100, 0.063000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, 0, 0}, 120.577210, 0.000170, 0.034000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, -1, 0}, 264.224140, 0.000040, 0.070000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, 0, 0}, 264.224270, 0.000030, 1.000000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 0, 1, 0}, 84.224140, 0.000040, 0.082000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 2, -1, 0}, 84.224220, 0.000130, 0.095000},
	{{0, 0, 9, -19, 0, 3, 0, 0, 2, 0, 0}, 84.224210, 0.000240, 0.042000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, -1, 0}, 217.720040, 0.000040, 0.026000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 0, 0}, 217.565000, 0.000460, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 1, 0}, 218.350700, 0.000360, 0.087000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -2, 0}, 214.786860, 0.000030, 0.038000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -1, 0}, 215.092220, 0.000710, 0.075000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 1, 0}, 35.144320, 0.000710, 0.076000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 2, 0}, 34.796780, 0.000030, 0.038000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -2, 0}, 218.047480, 0.000030, 0.552000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -1, 0}, 38.732280, 0.000380, 0.087000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 0, 0}, 37.850830, 0.000480, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 1, 0}, 38.034770, 0.000040, 0.026000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 0, 0}, 246.749920, 0.000050, 0.041000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, -1, 0}, 246.615560, 0.000020, 0.078000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, 1, 0}, 66.615560, 0.000020, 0.073000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -4, 1, 0}, 239.743510, 0.000040, 0.028000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, -1, 0}, 239.743510, 0.000120, 0.027000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 0, 0}, 239.743510, 0.001170, 0.042000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 1, 0}, 239.743510, 0.000820, 0.095000},
	{{0, 0, 9, -16, 4, 5, 0, 0, -2, 2, 0}, 59.743510, 0.000060, 0.360000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, -1, 0}, 239.743510, 0.000170, 0.082000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 0, 0}, 59.743510, 0.000090, 1.000000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 0, 1, 0}, 59.743510, 0.000160, 0.070000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 2, -1, 0}, 239.743510, 0.000060, 0.080000},
	{{0, 0, 9, -16, 4, 5, 0, 0, 2, 0, 0}, 239.743510, 0.000090, 0.039000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -4, 0, 0}, 295.215920, 0.000030, 0.021000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, -1, 0}, 111.753030, 0.000090, 0.027000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 0, 0}, 113.900490, 0.000830, 0.042000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 1, 0}, 110.158660, 0.000550, 0.096000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, -1, 0}, 105.389080, 0.000390, 0.082000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 0, 0}, 284.581690, 0.000140, 0.976000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 1, 0}, 279.368560, 0.000290, 0.070000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, -1, -1}, 358.080740, 0.000020, 0.075000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, 0}, 101.625300, 0.000040, 0.075000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 1, -1}, 178.080740, 0.000020, 0.076000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 2, 0, 0}, 260.928400, 0.000090, 0.039000},
	{{0, 0, 9, -14, 0, 0, 0, 0, -2, 0, 0}, 130.526040, 0.000080, 0.043000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 0, -1, 0}, 126.357350, 0.000090, 0.085000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 0, 1, 0}, 307.814860, 0.000020, 0.068000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, -1, 0}, 125.887090, 0.000400, 0.077000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, 0, 0}, 125.546280, 0.000070, 0.038000},
	{{0, 0, 9, -13, 0, 0, 0, 0, -2, 0, 0}, 88.385270, 0.000060, 0.044000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, -1, 0}, 335.883950, 0.000090, 0.090000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 0, 0}, 334.503920, 0.000030, 0.479000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 1, -2}, 334.618930, 0.000030, 0.087000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 1, 0}, 327.269650, 0.000030, 0.065000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -2, 0}, 154.051300, 0.000040, 3.184000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, -2}, 154.656350, 0.000200, 0.075000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, 0}, 333.923240, 0.000660, 0.074000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, 0}, 154.633930, 0.000120, 0.037000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 1, -2}, 334.656350, 0.000200, 0.076000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 4, -1, -2}, 154.618930, 0.000030, 0.087000},
	{{0, 0, 9, -12, 0, 0, 0, 0, -2, 0, 0}, 171.713350, 0.000070, 0.045000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, -1, 0}, 3.483170, 0.000050, 0.094000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, 1, 0}, 3.356620, 0.000040, 0.063000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -1, 0}, 3.426880, 0.000490, 0.071000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 0, 0}, 183.421590, 0.000110, 0.037000},
	{{0, 0, 9, -11, 0, 0, 0, 0, -2, 0, 0}, 208.259680, 0.000070, 0.046000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, -1, 0}, 33.300170, 0.000030, 0.099000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, 0, 0}, 31.024790, 0.000060, 0.317000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, 1, 0}, 31.834710, 0.000060, 0.061000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, -2, 0}, 214.981860, 0.000030, 0.726000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, -1, 0}, 32.364790, 0.000510, 0.068000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 0, 0}, 212.015150, 0.000220, 0.036000},
	{{0, 0, 9, -10, 0, 0, 0, 0, -2, 0, 0}, 233.603100, 0.000070, 0.047000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, -1, 0}, 61.703700, 0.000020, 0.104000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, 0, 0}, 58.565400, 0.000060, 0.272000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, 1, 0}, 60.983440, 0.000050, 0.059000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -1, 0}, 61.227360, 0.000430, 0.066000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, 0, 0}, 241.925780, 0.000240, 0.035000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 2, -1, 0}, 89.469740, 0.000160, 0.064000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 2, 0, 0}, 269.468370, 0.000080, 0.035000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 4, -1, -4}, 94.410560, 0.000070, 0.075000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 4, 1, -4}, 274.410560, 0.000070, 0.075000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 2, -1, 0}, 301.027080, 0.000070, 0.062000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 2, 0, 0}, 121.026110, 0.000140, 0.034000},
	{{0, 0, 10, -19, 0, 0, 0, 0, -2, 0, 0}, 188.562150, 0.000040, 0.040000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, -1, 0}, 188.423990, 0.000030, 0.075000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, 1, 0}, 8.423990, 0.000030, 0.076000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 2, 0, 0}, 9.591750, 0.000050, 0.041000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -4, 0, 0}, 161.287350, 0.000020, 0.020000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -4, 1, 0}, 161.287350, 0.000040, 0.028000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -4, 2, 0}, 161.287350, 0.000020, 0.044000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, -1, 0}, 161.287350, 0.000160, 0.026000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 0, 0}, 161.287350, 0.002140, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 1, 0}, 161.287350, 0.002690, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 2, 0}, 341.287350, 0.000170, 0.564000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -1, 0, 0}, 341.287390, 0.000050, 0.081000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, -2, 0}, 341.287280, 0.000030, 0.038000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, -1, 0}, 341.287280, 0.000460, 0.075000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, 1, 0}, 161.287350, 0.000460, 0.075000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 0, 2, 0}, 161.287340, 0.000030, 0.038000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 1, 0, 0}, 161.287230, 0.000050, 0.081000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -2, 0}, 161.287270, 0.000170, 0.564000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -1, 0}, 341.287270, 0.002690, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 0, 0}, 341.287270, 0.002150, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 1, 0}, 341.287270, 0.000160, 0.026000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 4, -2, 0}, 341.287270, 0.000020, 0.044000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 4, -1, 0}, 341.287270, 0.000040, 0.028000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 4, 0, 0}, 341.287270, 0.000020, 0.020000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 0, 0}, 232.200690, 0.000100, 0.042000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 1, 0}, 232.200710, 0.000080, 0.095000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, -1, 0}, 240.941200, 0.000090, 0.081000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, 0, 0}, 63.477440, 0.000020, 1.040000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, 1, 0}, 60.941200, 0.000090, 0.070000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 2, -3, 0}, 247.478890, 0.000030, 0.071000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 2, -1, 0}, 67.478890, 0.000030, 0.080000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 2, 0, 0}, 70.544020, 0.000040, 0.039000},
	{{0, 0, 10, -16, 0, 0, 0, 0, -2, 0, 0}, 100.770460, 0.000040, 0.043000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 2, -1, 0}, 96.627900, 0.000130, 0.077000},
	{{0, 0, 10, -16, 4, 5, 0, 0, -2, 0, 0}, 136.806580, 0.000120, 0.044000},
	{{0, 0, 10, -16, 4, 5, 0, 0, -2, 1, 0}, 136.806580, 0.000030, 0.105000},
	{{0, 0, 10, -15, 0, 0, 0, 0, -2, 0, 0}, 19.096430, 0.000110, 0.044000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 0, -1, 0}, 302.383030, 0.000060, 0.089000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -1, 0}, 302.383030, 0.000360, 0.074000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, 0, 0}, 125.503430, 0.000070, 0.037000},
	{{0, 0, 10, -15, 1, 0, 0, 0, 2, -1, -2}, 339.586980, 0.000020, 0.075000},
	{{0, 0, 10, -15, 1, 0, 0, 0, 2, 1, -2}, 159.586980, 0.000020, 0.075000},
	{{0, 0, 10, -14, 0, 0, 0, 0, -2, 0, 0}, 143.190560, 0.000030, 0.045000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 0, -1, 0}, 334.423450, 0.000030, 0.093000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 0, 0, 0}, 334.441710, 0.000030, 0.391000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 0, 1, 0}, 334.471720, 0.000020, 0.063000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, -1, 0}, 334.443410, 0.000270, 0.071000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, 0, 0}, 154.439490, 0.000160, 0.037000},
	{{0, 0, 10, -13, 0, 0, 0, 0, -2, 0, 0}, 181.563850, 0.000040, 0.046000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 0, -1, 0}, 3.475460, 0.000020, 0.098000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 0, 1, 0}, 3.301740, 0.000030, 0.061000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, -1, 0}, 3.376460, 0.000300, 0.069000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, 0, 0}, 183.370890, 0.000100, 0.036000},
	{{0, 0, 10, -12, 0, 0, 0, 0, -2, 0, 0}, 207.586110, 0.000040, 0.047000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 0, 1, 0}, 32.114110, 0.000040, 0.059000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, -1, 0}, 32.619400, 0.000320, 0.066000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, 0, 0}, 212.279180, 0.000190, 0.035000},
	{{0, 0, 10, -11, 0, 0, 0, 0, -2, 0, 0}, 229.983060, 0.000030, 0.049000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 0, 1, 0}, 60.743030, 0.000030, 0.057000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -1, 0}, 61.615050, 0.000260, 0.064000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, 0, 0}, 240.996050, 0.000180, 0.035000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 2, -1, 0}, 88.485400, 0.000080, 0.062000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 2, 0, 0}, 268.485930, 0.000160, 0.034000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 2, -1, 0}, 301.272090, 0.000050, 0.060000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 2, 0, 0}, 121.271240, 0.000110, 0.033000},
	{{0, 0, 11, -21, 2, 0, 0, 0, -2, 0, 0}, 218.086360, 0.000110, 0.040000},
	{{0, 0, 11, -21, 2, 0, 0, 0, -2, 1, 0}, 219.956740, 0.000110, 0.087000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, -1, 0}, 213.882690, 0.000240, 0.075000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, 1, 0}, 33.882690, 0.000240, 0.075000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 2, -1, 0}, 39.921870, 0.000110, 0.087000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 2, 0, 0}, 38.057970, 0.000110, 0.040000},
	{{0, 0, 11, -19, 0, 0, 0, 0, -2, 0, 0}, 213.836870, 0.000040, 0.042000},
	{{0, 0, 11, -19, 0, 3, 0, 0, -2, 0, 0}, 58.350410, 0.000230, 0.042000},
	{{0, 0, 11, -19, 0, 3, 0, 0, -2, 1, 0}, 58.350410, 0.000130, 0.095000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, -1, 0}, 58.350470, 0.000040, 0.082000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, 0, 0}, 238.350360, 0.000030, 1.000000},
	{{0, 0, 11, -19, 0, 3, 0, 0, 0, 1, 0}, 238.350470, 0.000040, 0.070000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 2, -1, 0}, 67.703990, 0.000040, 0.077000},
	{{0, 0, 11, -17, 0, 0, 0, 0, -2, 0, 0}, 120.055980, 0.000030, 0.044000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 0, -1, 0}, 276.348960, 0.000040, 0.089000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 2, -1, 0}, 276.349070, 0.000220, 0.074000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, -1, 0}, 305.472570, 0.000140, 0.072000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, 0, 0}, 125.462510, 0.000080, 0.037000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 0, 0, 0}, 334.373270, 0.000030, 0.331000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 2, -1, 0}, 334.395710, 0.000170, 0.069000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 2, 0, 0}, 154.393620, 0.000150, 0.036000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 0, 1, 0}, 3.214880, 0.000020, 0.059000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, -1, 0}, 3.300440, 0.000210, 0.066000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, 0, 0}, 183.294460, 0.000080, 0.035000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 0, 1, 0}, 32.137000, 0.000020, 0.058000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, -1, 0}, 32.136490, 0.000220, 0.064000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, 0, 0}, 212.136390, 0.000150, 0.035000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 0, -1, 0}, 247.869120, 0.000020, 0.116000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 0, 1, 0}, 67.869120, 0.000020, 0.056000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, -1, 0}, 60.678630, 0.000160, 0.062000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, 0, 0}, 240.678400, 0.000130, 0.034000},
	{{0, 0, 11, -11, 0, 0, 0, 0, 2, -1, 0}, 86.748210, 0.000040, 0.060000},
	{{0, 0, 11, -11, 0, 0, 0, 0, 2, 0, 0}, 266.748950, 0.000090, 0.033000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, -1, 0}, 301.350810, 0.000040, 0.058000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, 0, 0}, 121.350050, 0.000090, 0.033000},
	{{0, 0, 12, -19, 0, 0, 0, 0, 2, -1, 0}, 247.624060, 0.000140, 0.075000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, -1, 0}, 275.687770, 0.000070, 0.072000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, -1, 0}, 305.422730, 0.000090, 0.069000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, 0, 0}, 125.415360, 0.000080, 0.036000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 0, 0, 0}, 334.292120, 0.000030, 0.286000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, -1, 0}, 334.330950, 0.000120, 0.067000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, 0, 0}, 154.330250, 0.000140, 0.035000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 0, -1, 0}, 183.101010, 0.000020, 0.108000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 0, 1, 0}, 3.101010, 0.000020, 0.058000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, -1, 0}, 3.195660, 0.000150, 0.064000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, 0, 0}, 183.588960, 0.000230, 0.035000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, -1, 0}, 31.946520, 0.000150, 0.062000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, 0, 0}, 211.946400, 0.000120, 0.034000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 2, -1, 0}, 60.253680, 0.000100, 0.060000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 2, 0, 0}, 240.253050, 0.000060, 0.034000},
	{{0, 0, 12, -12, 0, 0, 0, 0, 2, 0, 0}, 263.141690, 0.000040, 0.033000},
	{{0, 0, 12, -11, 0, 0, 0, 0, 2, 0, 0}, 121.277260, 0.000070, 0.032000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 2, -1, 0}, 218.264020, 0.000120, 0.075000},
	{{0, 0, 13, -20, 0, 0, 0, 0, 2, -1, 0}, 246.061230, 0.000040, 0.072000},
	{{0, 0, 13, -19, 0, 0, 0, 0, 2, -1, 0}, 276.457320, 0.000040, 0.070000},
	{{0, 0, 13, -19, 0, 0, 0, 0, 2, 0, 0}, 96.437890, 0.000040, 0.036000},
	{{0, 0, 13, -18, 0, 0, 0, 0, 2, -1, 0}, 305.362250, 0.000060, 0.067000},
	{{0, 0, 13, -18, 0, 0, 0, 0, 2, 0, 0}, 125.356950, 0.000070, 0.036000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 2, -1, 0}, 334.245920, 0.000080, 0.065000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 2, 0, 0}, 154.246310, 0.000130, 0.035000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 0, 0, 0}, 2.941840, 0.000040, 0.223000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 2, -1, 0}, 3.068930, 0.000100, 0.063000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 2, 0, 0}, 183.068970, 0.000190, 0.034000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, -1, 0}, 31.703670, 0.000100, 0.061000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, 0, 0}, 211.703360, 0.000060, 0.034000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 0, 0, 0}, 59.367300, 0.000030, 0.180000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 2, -1, 0}, 59.691490, 0.000060, 0.059000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 2, 0, 0}, 239.691680, 0.000150, 0.033000},
	{{0, 0, 13, -12, 0, 0, 0, 0, 2, 0, 0}, 121.051930, 0.000050, 0.032000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 0, -2, 0}, 188.664130, 0.000110, 0.040000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 0, -1, 0}, 8.672640, 0.000120, 0.087000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -3, 0}, 187.861850, 0.000230, 0.075000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, 0}, 188.816360, 0.000070, 362.998000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -1, 0}, 8.668090, 0.001500, 0.075000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, 0, 0}, 8.668090, 0.000080, 0.038000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 4, -3, 0}, 8.987480, 0.000100, 0.087000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 4, -2, 0}, 8.664130, 0.000110, 0.040000},
	{{0, 0, 14, -19, 0, 0, 0, 0, 2, -1, 0}, 305.287600, 0.000050, 0.065000},
	{{0, 0, 14, -19, 0, 0, 0, 0, 2, 0, 0}, 125.283920, 0.000070, 0.035000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 2, -1, 0}, 335.528420, 0.000060, 0.063000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 2, 0, 0}, 154.811880, 0.000110, 0.034000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 2, -1, 0}, 2.898750, 0.000070, 0.061000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 2, 0, 0}, 182.898800, 0.000160, 0.034000},
	{{0, 0, 14, -16, 0, 0, 0, 0, 2, -1, 0}, 31.400730, 0.000070, 0.059000},
	{{0, 0, 14, -16, 0, 0, 0, 0, 2, 0, 0}, 211.400810, 0.000160, 0.033000},
	{{0, 0, 14, -15, 0, 0, 0, 0, 2, -1, 0}, 58.945220, 0.000040, 0.057000},
	{{0, 0, 14, -15, 0, 0, 0, 0, 2, 0, 0}, 238.945450, 0.000100, 0.033000},
	{{0, 0, 14, -13, 0, 0, 0, 0, 2, 0, 0}, 120.658600, 0.000030, 0.031000},
	{{0, 0, 15, -20, 0, 0, 0, 0, 2, -1, 0}, 305.193910, 0.000030, 0.063000},
	{{0, 0, 15, -20, 0, 0, 0, 0, 2, 0, 0}, 125.193930, 0.000060, 0.034000},
	{{0, 0, 15, -19, 0, 0, 0, 0, 2, -1, 0}, 334.010380, 0.000050, 0.061000},
	{{0, 0, 15, -19, 0, 0, 0, 0, 2, 0, 0}, 154.010410, 0.000100, 0.034000},
	{{0, 0, 15, -18, 0, 0, 0, 0, 2, -1, 0}, 2.690860, 0.000050, 0.059000},
	{{0, 0, 15, -18, 0, 0, 0, 0, 2, 0, 0}, 182.690910, 0.000120, 0.033000},
	{{0, 0, 15, -17, 0, 0, 0, 0, 2, -1, 0}, 31.028200, 0.000040, 0.057000},
	{{0, 0, 15, -17, 0, 0, 0, 0, 2, 0, 0}, 211.028300, 0.000120, 0.033000},
	{{0, 0, 15, -16, 0, 0, 0, 0, 2, 0, 0}, 237.937400, 0.000060, 0.032000},
	{{0, 0, 16, -21, 0, 0, 0, 0, 2, 0, 0}, 125.085600, 0.000050, 0.034000},
	{{0, 0, 16, -20, 0, 0, 0, 0, 2, -1, 0}, 333.851770, 0.000030, 0.059000},
	{{0, 0, 16, -20, 0, 0, 0, 0, 2, 0, 0}, 153.851810, 0.000080, 0.033000},
	{{0, 0, 16, -19, 0, 0, 0, 0, 2, -1, 0}, 2.441520, 0.000040, 0.058000},
	{{0, 0, 16, -19, 0, 0, 0, 0, 2, 0, 0}, 182.441580, 0.000100, 0.033000},
	{{0, 0, 16, -18, 0, 0, 0, 0, 2, -1, 0}, 30.573400, 0.000030, 0.056000},
	{{0, 0, 16, -18, 0, 0, 0, 0, 2, 0, 0}, 210.573520, 0.000080, 0.032000},
	{{0, 0, 16, -17, 0, 0, 0, 0, 2, 0, 0}, 236.528380, 0.000040, 0.032000},
	{{0, 0, 17, -22, 0, 0, 0, 0, 2, 0, 0}, 124.956610, 0.000050, 0.033000},
	{{0, 0, 17, -21, 0, 0, 0, 0, 2, 0, 0}, 153.664040, 0.000070, 0.033000},
	{{0, 0, 17, -20, 0, 0, 0, 0, 2, 0, 0}, 182.146270, 0.000070, 0.032000},
	{{0, 0, 17, -19, 0, 0, 0, 0, 2, 0, 0}, 210.018980, 0.000060, 0.032000},
	{{0, 0, 18, -23, 0, 0, 0, 0, 2, 0, 0}, 124.805470, 0.000040, 0.033000},
	{{0, 0, 18, -22, 0, 0, 0, 0, 2, 0, 0}, 153.444780, 0.000050, 0.032000},
	{{0, 0, 18, -21, 0, 0, 0, 0, 2, 0, 0}, 181.799360, 0.000050, 0.032000},
	{{0, 0, 18, -20, 0, 0, 0, 0, 2, 0, 0}, 209.339990, 0.000040, 0.031000},
	{{0, 0, 19, -24, 0, 0, 0, 0, 2, 0, 0}, 124.630640, 0.000030, 0.032000},
	{{0, 0, 19, -23, 0, 0, 0, 0, 2, 0, 0}, 153.191360, 0.000040, 0.032000},
	{{0, 0, 19, -22, 0, 0, 0, 0, 2, 0, 0}, 181.393770, 0.000040, 0.031000},
	{{0, 0, 20, -24, 0, 0, 0, 0, 2, 0, 0}, 152.900640, 0.000030, 0.031000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -4, 1, 0}, 57.067010, 0.000020, 0.040000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 0, 0}, 57.067010, 0.000080, 0.076000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 2, 0}, 237.067010, 0.000080, 0.075000},
	{{0, 0, 20, -16, 0, 0, 0, 0, 0, 1, 0}, 237.067010, 0.000020, 0.040000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 0, 0}, 118.796190, 0.000020, 0.076000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 2, 0}, 298.796190, 0.000020, 0.075000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 0, 0}, 35.758940, 0.000030, 0.075000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 2, 0}, 215.758940, 0.000030, 0.076000},
	{{0, 1, -8, 12, 0, 0, 0, 0, -2, 0, 0}, 235.524670, 0.000110, 0.040000},
	{{0, 1, -8, 12, 0, 0, 0, 0, -2, 1, 0}, 235.524670, 0.000070, 0.087000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 0, -1, 0}, 234.847680, 0.000100, 0.075000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 0, 1, 0}, 54.847680, 0.000100, 0.075000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 2, -1, 0}, 55.524770, 0.000070, 0.087000},
	{{0, 1, -8, 12, 0, 0, 0, 0, 2, 0, 0}, 55.524770, 0.000110, 0.040000},
	{{0, 1, -7, 0, 2, 0, 0, 0, -2, 0, 0}, 321.681380, 0.000040, 0.033000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 72.144660, 0.000030, 0.034000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 252.144660, 0.000030, 0.385000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 248.474770, 0.000040, 0.229000},
	{{0, 1, -6, 0, 1, 0, 0, 0, -2, 0, 0}, 141.212640, 0.000040, 0.034000},
	{{0, 1, -6, 0, 2, 0, 0, 0, -2, 0, 0}, 21.782040, 0.000030, 0.035000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 142.193560, 0.000020, 0.036000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 322.024080, 0.000030, 0.067000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 322.024360, 0.000040, 0.625000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 142.024080, 0.000030, 0.086000},
	{{0, 1, -5, 3, 0, 0, 0, 0, -2, 1, 0}, 84.328420, 0.000080, 0.075000},
	{{0, 1, -5, 3, 0, 0, 0, 0, -2, 3, 0}, 283.969960, 0.000050, 0.075000},
	{{0, 1, -4, 0, -1, 0, 0, 0, -2, 0, 0}, 144.540910, 0.000050, 0.037000},
	{{0, 1, -4, 0, -1, 0, 0, 0, -2, 1, 0}, 152.341080, 0.000090, 0.072000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 157.139510, 0.000030, 0.037000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 339.085010, 0.000070, 0.072000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 59.653080, 0.000020, 1.665000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 268.465780, 0.000030, 0.079000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 340.138530, 0.000040, 0.421000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 152.493450, 0.000110, 0.045000},
	{{0, 1, -4, 0, 2, 0, 0, 0, 2, -2, 0}, 180.680120, 0.000020, 0.251000},
	{{0, 1, -4, 0, 2, 0, 0, 0, 2, 0, 0}, 180.680120, 0.000020, 0.044000},
	{{0, 1, -4, 1, 0, 0, 0, 0, -2, 1, 0}, 27.131440, 0.000030, 0.075000},
	{{0, 1, -4, 4, 0, 0, 0, 0, 0, -1, 0}, 119.736640, 0.000030, 0.074000},
	{{0, 1, -4, 4, 0, 0, 0, 0, 0, 1, 0}, 299.736640, 0.000030, 0.077000},
	{{0, 1, -3, 0, -2, 0, 0, 0, -2, 1, 0}, 320.082680, 0.000060, 0.077000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -3, 1, 1}, 76.989100, 0.000020, 0.085000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 47.076040, 0.000030, 0.038000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 68.026630, 0.000950, 0.078000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 236.586680, 0.000040, 2.503000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 265.648230, 0.000040, 0.073000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 256.465330, 0.000160, 0.074000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 66.227430, 0.000150, 0.073000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, -1}, 76.531890, 0.000060, 0.072000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 76.465330, 0.000160, 0.077000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 248.231470, 0.000460, 0.068000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 246.385570, 0.000370, 0.728000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 73.316710, 0.000680, 0.084000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 256.989100, 0.000020, 0.090000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 246.966160, 0.000050, 0.091000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 79.369060, 0.000080, 0.041000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 253.867580, 0.000030, 0.318000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 66.476480, 0.000120, 0.099000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 67.884640, 0.000270, 0.043000},
	{{0, 1, -3, 0, 1, 0, 0, 0, 2, -2, 0}, 179.356280, 0.000030, 0.326000},
	{{0, 1, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 359.356280, 0.000030, 0.043000},
	{{0, 1, -3, 0, 2, 0, 0, 0, -2, 1, 0}, 268.665270, 0.000040, 0.079000},
	{{0, 1, -3, 0, 3, 0, 0, 0, 2, 0, 0}, 80.753430, 0.000050, 0.042000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 2, -3, 0}, 90.206490, 0.000020, 0.065000},
	{{0, 1, -3, 2, 0, 0, 0, 0, 2, -1, 0}, 270.206490, 0.000020, 0.090000},
	{{0, 1, -2, 0, -1, 0, 0, 0, -2, 1, 0}, 294.026560, 0.000020, 0.084000},
	{{0, 1, -2, 0, -1, 0, 0, 0, -2, 3, 0}, 294.026560, 0.000020, 0.069000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -4, 0, 0}, 12.320920, 0.000030, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -4, 1, 0}, 214.289150, 0.000050, 0.027000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -3, 0, 1}, 346.602050, 0.000020, 0.042000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -3, 1, 1}, 166.657970, 0.000040, 0.093000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 208.036380, 0.000350, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 210.804070, 0.002220, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 166.614460, 0.000050, 0.086000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 295.037890, 0.000980, 0.084000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 178.522410, 0.000140, 0.715000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 3, 0}, 183.897320, 0.000030, 0.068000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, 1}, 346.648290, 0.000390, 0.080000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 347.247980, 0.000030, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 178.422710, 0.000290, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 165.355360, 0.000120, 1.472000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 166.620570, 0.000780, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, 1}, 166.643110, 0.000320, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, -1}, 346.622960, 0.000040, 2.892000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 195.909910, 0.000490, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 195.746190, 0.008710, 0.073000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 2}, 211.353200, 0.000050, 0.076000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 166.331990, 0.000140, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 192.871580, 0.001310, 2.670000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 166.614460, 0.000310, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, -2}, 198.919750, 0.000020, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 16.085020, 0.007750, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 16.863580, 0.000410, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 3, 0}, 16.795500, 0.000020, 0.025000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 346.678970, 0.000260, 0.068000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 346.670480, 0.000500, 0.082000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 346.672400, 0.000270, 0.700000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 190.509140, 0.000300, 0.083000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 357.808130, 0.000080, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 166.660310, 0.000380, 0.085000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 331.730590, 0.000140, 0.465000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 139.042830, 0.001410, 0.090000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 149.715200, 0.001770, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 87.450560, 0.000070, 0.027000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 3, 0, -1}, 166.715520, 0.000030, 0.043000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 3.326580, 0.000020, 0.044000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, -1, 0}, 165.470030, 0.000100, 0.028000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, 0, 0}, 16.366920, 0.000050, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, 1, 0}, 357.841080, 0.000020, 0.016000},
	{{0, 1, -2, 0, 1, 0, 0, 0, -2, 0, 0}, 265.178010, 0.000090, 0.040000},
	{{0, 1, -2, 0, 1, 0, 0, 0, -2, 1, 0}, 268.133400, 0.000160, 0.085000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 0, -1, 0}, 86.990000, 0.000040, 0.074000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 0, 0, 0}, 88.750610, 0.000160, 3.446000},
	{{0, 1, -2, 0, 1, 0, 0, 0, 0, 1, 0}, 266.990000, 0.000040, 0.077000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 0, -1, 0}, 150.845910, 0.000070, 0.074000},
	{{0, 1, -2, 0, 2, 0, 0, 0, 0, 1, 0}, 330.845910, 0.000070, 0.077000},
	{{0, 1, -2, 1, 0, 0, 0, 0, 0, -1, 0}, 258.887430, 0.000020, 0.076000},
	{{0, 1, -2, 1, 0, 0, 0, 0, 0, 1, 0}, 78.887430, 0.000020, 0.075000},
	{{0, 1, -2, 2, 0, 0, 0, 0, -2, 0, 0}, 310.941540, 0.000030, 0.042000},
	{{0, 1, -2, 2, 0, 0, 0, 0, -2, 2, 0}, 130.941540, 0.000030, 0.406000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 0, -1, 0}, 312.501390, 0.000020, 0.080000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 0, 1, 0}, 132.501390, 0.000020, 0.072000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, -3, 0}, 134.755520, 0.000030, 0.070000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, -2, 0}, 134.755530, 0.000030, 0.922000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, -1, 0}, 314.755520, 0.000030, 0.082000},
	{{0, 1, -2, 2, 0, 0, 0, 0, 2, 0, 0}, 314.755530, 0.000030, 0.039000},
	{{0, 1, -2, 3, 0, 0, 0, 0, 2, -3, 0}, 326.451620, 0.000030, 0.072000},
	{{0, 1, -2, 3, 0, 0, 0, 0, 2, -1, 0}, 146.451620, 0.000030, 0.079000},
	{{0, 1, -2, 4, 0, 0, 0, 0, 2, -3, 0}, 333.639460, 0.000020, 0.075000},
	{{0, 1, -2, 4, 0, 0, 0, 0, 2, -1, 0}, 153.639460, 0.000020, 0.076000},
	{{0, 1, -1, 0, -2, 0, 0, 0, -2, 0, 0}, 114.956620, 0.000020, 0.041000},
	{{0, 1, -1, 0, -2, 0, 0, 0, -2, 2, 0}, 114.956620, 0.000020, 0.448000},
	{{0, 1, -1, 0, -1, 0, 0, 0, -2, 0, 0}, 306.458130, 0.000070, 0.041000},
	{{0, 1, -1, 0, -1, 0, 0, 0, -2, 2, 0}, 1.983280, 0.000020, 0.432000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, -3, 0}, 283.925910, 0.000020, 0.069000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, -2, 0}, 283.925910, 0.000030, 0.811000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, -1, 0}, 103.925910, 0.000020, 0.083000},
	{{0, 1, -1, 0, -1, 0, 0, 0, 2, 0, 0}, 103.925910, 0.000030, 0.040000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -6, 1, 0}, 269.983450, 0.000030, 0.017000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -6, 2, 0}, 269.979610, 0.000020, 0.021000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, -1, 0}, 269.988230, 0.000170, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 269.992660, 0.000980, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 0, 2}, 269.979910, 0.000070, 0.045000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 1, 0}, 269.991440, 0.002530, 0.028000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 1, 2}, 269.980890, 0.000030, 0.114000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 2, 0}, 269.968080, 0.001120, 0.045000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 3, 0}, 269.708120, 0.000060, 0.110000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 3, 2}, 269.985330, 0.000020, 0.056000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, -1, 0}, 269.970430, 0.000020, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 0, 0}, 269.950740, 0.000100, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -3, 1, 0}, 89.975440, 0.000250, 0.043000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -3, 0}, 270.008570, 0.000030, 0.016000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -2, 0}, 270.018780, 0.000610, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 269.989450, 0.008310, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 269.985230, 0.123620, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 2}, 89.984740, 0.000460, 0.366000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, -2}, 89.983610, 0.000020, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 269.984520, 0.100600, 0.092000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, 2}, 89.984800, 0.000310, 0.063000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 2, -2}, 89.968210, 0.000020, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 89.990450, 0.005580, 0.417000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 2, 2}, 89.991920, 0.000030, 0.034000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 89.937610, 0.000160, 0.064000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, -1, 0}, 90.002150, 0.000380, 0.040000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 90.009450, 0.005110, 0.085000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 1, 0}, 270.011030, 0.000460, 0.661000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 2, 0}, 269.597370, 0.000050, 0.068000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -3, 0}, 270.008220, 0.000490, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -2, 0}, 270.009860, 0.007390, 0.039000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -2, 2}, 270.013340, 0.000040, 1.043000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 270.009930, 0.138110, 0.079000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 2}, 90.011800, 0.000480, 0.070000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, -2}, 270.001320, 0.000270, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 90.044090, 0.037400, 1.599000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 2}, 270.025480, 0.000360, 0.036000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, -2}, 270.085770, 0.000300, 0.077000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 90.016060, 0.119980, 0.072000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 2, -2}, 90.009390, 0.000040, 3.425000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 2, 0}, 90.016630, 0.006520, 0.037000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 3, 0}, 90.018270, 0.000380, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -2, 0}, 270.105060, 0.000220, 0.074000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 126.180320, 0.000020, 0.073000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, 0}, 270.017330, 0.000700, 3.824000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, 1}, 140.920280, 0.000120, 0.076000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, -2}, 270.021510, 0.000040, 0.072000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 90.020940, 0.010930, 0.077000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, -1}, 306.180320, 0.000020, 0.078000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, 0}, 90.021790, 0.000550, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 2, 0}, 270.182570, 0.000020, 0.025000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 87.901630, 0.000020, 0.069000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 89.935200, 0.000970, 0.871000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, -2}, 269.818370, 0.000020, 0.068000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 89.881250, 0.010420, 0.083000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, -2}, 269.992760, 0.000060, 0.675000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 90.009270, 0.027470, 0.039000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 1, -2}, 270.038540, 0.000030, 0.085000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 1, 0}, 90.001260, 0.002600, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 2, 0}, 90.071470, 0.000350, 0.019000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 3, -1, 0}, 90.017880, 0.000140, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 3, 0, 0}, 90.020640, 0.000150, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -3, 0}, 270.249420, 0.000030, 0.097000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -2, 0}, 89.670850, 0.000090, 0.042000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, -1, 0}, 89.973430, 0.000430, 0.027000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, 0, 0}, 89.927550, 0.000090, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 4, 1, 0}, 270.034200, 0.000020, 0.016000},
	{{0, 1, -1, 0, 1, 0, 0, 0, -2, 0, 0}, 76.307000, 0.000060, 0.042000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 0, -1, 0}, 79.063610, 0.000070, 0.080000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 0, 1, 0}, 259.063610, 0.000070, 0.072000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 1, -1, 1}, 1.854730, 0.000080, 0.075000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 2, -2, 0}, 51.669880, 0.000030, 0.940000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 2, -1, 0}, 234.421010, 0.000050, 0.082000},
	{{0, 1, -1, 0, 1, 0, 0, 0, 2, 0, 0}, 231.669880, 0.000030, 0.039000},
	{{0, 1, -1, 2, 0, 0, 0, 0, 2, -3, 0}, 301.636810, 0.000020, 0.075000},
	{{0, 1, -1, 2, 0, 0, 0, 0, 2, -1, 0}, 141.869860, 0.000050, 0.076000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 0, -1, 0}, 51.562240, 0.000020, 0.079000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 0, 1, 0}, 231.562240, 0.000020, 0.072000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 2, -3, 0}, 229.617500, 0.000030, 0.069000},
	{{0, 1, 0, -2, 0, 0, 0, 0, 2, -1, 0}, 49.617500, 0.000030, 0.083000},
	{{0, 1, 0, 0, -2, 0, 0, 0, -2, 0, 0}, 32.718770, 0.000070, 0.043000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, -2, 0}, 270.990830, 0.000030, 0.040000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, -1, 0}, 90.454200, 0.000040, 0.085000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0}, 270.990830, 0.000030, 0.649000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 0, 1, 0}, 270.454200, 0.000040, 0.068000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, -3, 0}, 93.603980, 0.000030, 0.074000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, -2, 0}, 97.025830, 0.000020, 4.296000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, -1, 0}, 93.603980, 0.000030, 0.077000},
	{{0, 1, 0, 0, -1, 0, 0, 0, 2, 0, 0}, 277.025830, 0.000020, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -6, 2, 0}, 167.045330, 0.000020, 0.022000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, -1, 0}, 346.158430, 0.000030, 0.016000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 0, 0}, 168.090080, 0.000280, 0.021000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 1, 0}, 166.919040, 0.000560, 0.029000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 2, 0}, 168.088960, 0.000100, 0.047000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 0, 0}, 166.363280, 0.000040, 0.028000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 0, 1}, 193.336750, 0.000020, 0.045000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -3, 1, 1}, 193.338620, 0.000030, 0.114000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -2, 0}, 166.712470, 0.000040, 0.020000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -1, 0}, 167.394580, 0.000880, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 167.029940, 0.011430, 0.043000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 2}, 348.256780, 0.000030, 0.268000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 167.046500, 0.006140, 0.101000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 344.886040, 0.000370, 0.294000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 3, 0}, 359.148620, 0.000040, 0.060000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -1, -1}, 193.336510, 0.000020, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -1, 1}, 13.341240, 0.000090, 0.095000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, -1}, 193.351620, 0.000560, 0.041000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 350.104030, 0.000150, 0.093000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 1}, 193.335740, 0.000430, 0.373000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 1, -1}, 192.395290, 0.000300, 0.092000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 1, 1}, 193.338700, 0.000240, 0.063000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 2, -1}, 193.335520, 0.000020, 0.426000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -2, 0}, 170.775770, 0.000330, 0.040000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 171.664010, 0.005490, 0.086000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1}, 12.782610, 0.000090, 0.085000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 352.617790, 0.001960, 0.615000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 13.337450, 0.000040, 0.066000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 351.521360, 0.001960, 0.067000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 355.238060, 0.000060, 0.036000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, -1}, 193.335180, 0.000070, 0.039000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, 1}, 13.424280, 0.000050, 1.105000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, -1}, 193.335020, 0.001240, 0.079000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 1}, 193.337650, 0.001030, 0.071000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 13.335610, 0.000400, 1.749000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 180.556530, 0.000170, 0.071000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 13.386310, 0.000190, 0.036000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 1, -1}, 13.376430, 0.001190, 0.072000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 2, -1}, 13.335030, 0.000070, 0.037000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 0.054360, 0.000040, 0.075000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 358.227400, 0.000530, 6.734000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 180.192670, 0.007440, 0.076000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 13.337480, 0.000190, 0.077000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 184.733630, 0.000490, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 350.342210, 0.000040, 0.025000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, -1, -1}, 193.326610, 0.000160, 0.083000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 3, 0, -1}, 13.334310, 0.000150, 0.040000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 4, -2, 0}, 180.662010, 0.000080, 0.041000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 4, -1, 0}, 180.794250, 0.000060, 0.026000},
	{{0, 1, 0, 0, 1, 0, 0, 0, 2, -3, 0}, 15.840440, 0.000020, 0.075000},
	{{0, 1, 0, 0, 1, 0, 0, 0, 2, -1, 0}, 212.403920, 0.000060, 0.076000},
	{{0, 1, 0, 0, 2, 0, 0, 0, 2, -3, 0}, 224.446950, 0.000030, 0.076000},
	{{0, 1, 0, 0, 2, 0, 0, 0, 2, -1, 0}, 44.446950, 0.000030, 0.075000},
	{{0, 1, 1, 0, -3, 0, 0, 0, -2, 0, 0}, 281.362610, 0.000050, 0.045000},
	{{0, 1, 1, 0, -2, 0, 0, 0, -2, 1, 0}, 270.054630, 0.000030, 0.111000},
	{{0, 1, 1, 0, -2, 0, 0, 0, -2, 3, 0}, 270.054630, 0.000030, 0.057000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 0, -2, 0}, 269.971890, 0.000020, 0.042000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 0, 0, 0}, 89.971890, 0.000020, 0.407000},
	{{0, 1, 1, 0, -2, 0, 0, 0, 2, -1, 0}, 90.142260, 0.000050, 0.072000},
	{{0, 1, 1, 0, -1, 0, 0, 0, -2, 0, 0}, 180.652940, 0.000030, 0.045000},
	{{0, 1, 1, 0, -1, 0, 0, 0, -2, 2, 0}, 0.652940, 0.000030, 0.232000},
	{{0, 1, 1, 0, -1, 0, 0, 0, 0, -2, 0}, 75.847560, 0.000020, 0.042000},
	{{0, 1, 1, 0, -1, 0, 0, 0, 0, 0, 0}, 75.847560, 0.000020, 0.394000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -4, 0, 0}, 240.646830, 0.000040, 0.021000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, -1, 0}, 84.826800, 0.000090, 0.028000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 83.939960, 0.001080, 0.045000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 90.027830, 0.000230, 0.113000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 273.027510, 0.000040, 0.227000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, -1}, 99.967810, 0.000060, 0.043000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 101.103730, 0.000260, 0.094000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 295.365630, 0.000490, 0.381000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 291.846560, 0.000300, 0.063000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 115.190850, 0.000050, 0.067000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 105.861860, 0.000030, 1.174000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 292.716690, 0.000670, 0.071000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 123.540080, 0.000070, 0.037000},
	{{0, 1, 2, 0, -2, 0, 0, 0, -2, 0, 0}, 359.307710, 0.000020, 0.047000},
	{{0, 1, 2, 0, -2, 0, 0, 0, -2, 2, 0}, 359.307710, 0.000020, 0.191000},
	{{0, 1, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 5.068530, 0.000150, 0.047000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 201.033780, 0.000040, 0.276000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 330.583040, 0.000040, 0.088000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 135.096430, 0.000040, 0.540000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 150.583040, 0.000040, 0.066000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 2.770210, 0.000040, 0.035000},
	{{0, 1, 2, 0, 1, 0, 0, 0, 2, 0, 0}, 218.859540, 0.000080, 0.035000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, -3, 0}, 50.599810, 0.000030, 0.095000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, -2, 0}, 31.027980, 0.000040, 0.361000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, -1, 0}, 230.599810, 0.000030, 0.062000},
	{{0, 1, 3, 0, -1, 0, 0, 0, 2, 0, 0}, 211.027980, 0.000040, 0.034000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 218.213120, 0.000020, 0.116000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 38.213120, 0.000020, 0.056000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 218.141340, 0.000030, 0.351000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, 2, 0}, 38.213110, 0.000020, 0.018000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, -3, 0}, 39.247320, 0.000020, 0.105000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, -2, 0}, 218.783300, 0.000020, 0.265000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, -1, 0}, 219.247320, 0.000020, 0.059000},
	{{0, 1, 4, 0, -1, 0, 0, 0, 2, 0, 0}, 38.783300, 0.000020, 0.033000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, -2, 0}, 297.614690, 0.000040, 0.260000},
	{{0, 1, 5, -2, 0, 0, 0, 0, 2, -2, 0}, 218.184570, 0.000020, 0.264000},
	{{0, 1, 5, -2, 0, 0, 0, 0, 2, 0, 0}, 38.184570, 0.000020, 0.033000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 2, -3, 0}, 38.357600, 0.000020, 0.117000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 2, -2, 0}, 38.314570, 0.000020, 0.214000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 2, -1, 0}, 38.357600, 0.000020, 0.056000},
	{{0, 1, 5, 0, -2, 0, 0, 0, 2, 0, 0}, 218.314570, 0.000020, 0.032000},
	{{0, 1, 6, -11, 0, 0, 0, 0, 2, -3, 0}, 232.279770, 0.000020, 0.075000},
	{{0, 1, 6, -11, 0, 0, 0, 0, 2, -1, 0}, 52.279770, 0.000020, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -4, 2, 0}, 25.930280, 0.000120, 0.040000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -4, 3, 0}, 24.215050, 0.000110, 0.087000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 0, 0}, 25.930280, 0.000020, 0.038000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 1, 0}, 20.933400, 0.000260, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 3, 0}, 231.397440, 0.000140, 0.075000},
	{{0, 2, -13, 15, 0, 0, 0, 0, -2, 4, 0}, 205.930280, 0.000020, 0.038000},
	{{0, 2, -13, 15, 0, 0, 0, 0, 0, 1, 0}, 204.215050, 0.000110, 0.087000},
	{{0, 2, -13, 15, 0, 0, 0, 0, 0, 2, 0}, 205.930280, 0.000120, 0.040000},
	{{0, 2, -8, 0, 2, 0, 0, 0, -2, 0, 0}, 321.676910, 0.000030, 0.034000},
	{{0, 2, -8, 2, 0, 0, 0, 0, -2, 1, 0}, 141.778350, 0.000030, 0.066000},
	{{0, 2, -8, 2, 0, 0, 0, 0, -2, 3, 0}, 321.778350, 0.000030, 0.088000},
	{{0, 2, -8, 9, 0, 0, 0, 0, -2, 0, 0}, 353.805250, 0.000040, 0.040000},
	{{0, 2, -8, 9, 0, 0, 0, 0, 0, -1, 0}, 351.442650, 0.000030, 0.076000},
	{{0, 2, -8, 9, 0, 0, 0, 0, 0, 1, 0}, 171.442650, 0.000030, 0.075000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 232.941800, 0.000040, 0.066000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 52.941800, 0.000040, 0.089000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 237.669850, 0.000020, 0.267000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 57.669850, 0.000020, 0.044000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 239.124960, 0.000040, 0.129000},
	{{0, 2, -7, 0, 2, 0, 0, 0, -2, 0, 0}, 21.779280, 0.000030, 0.035000},
	{{0, 2, -7, 7, 0, 0, 0, 0, -2, 0, 0}, 324.685960, 0.000110, 0.040000},
	{{0, 2, -7, 7, 0, 0, 0, 0, -2, 1, 0}, 324.685960, 0.000070, 0.087000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 0, -1, 0}, 327.226650, 0.000090, 0.075000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 0, 1, 0}, 147.226650, 0.000090, 0.076000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 2, -1, 0}, 144.595030, 0.000070, 0.087000},
	{{0, 2, -7, 7, 0, 0, 0, 0, 2, 0, 0}, 144.595030, 0.000120, 0.040000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 141.890690, 0.000070, 0.036000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 346.625740, 0.000050, 0.070000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 321.871410, 0.000090, 1.026000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 147.362960, 0.000080, 0.081000},
	{{0, 2, -5, 0, -2, 0, 0, 0, -2, 1, 0}, 71.494810, 0.000060, 0.075000},
	{{0, 2, -5, 0, -1, 0, 0, 0, -2, 1, 0}, 241.737920, 0.000040, 0.075000},
	{{0, 2, -5, 0, 0, -1, 0, 0, -2, 1, 0}, 323.891100, 0.000030, 0.075000},
	{{0, 2, -5, 0, 0, 0, -2, 0, -2, 1, 0}, 68.081210, 0.000040, 0.075000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 158.283120, 0.000040, 0.040000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 157.649370, 0.000130, 0.038000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 157.609810, 0.001840, 0.076000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 349.407450, 0.000100, 39.899000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 324.711780, 0.000110, 0.075000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 307.673920, 0.000040, 0.067000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 338.364810, 0.000050, 0.572000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 154.648450, 0.000350, 0.087000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 34.109800, 0.000080, 0.103000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 75.360490, 0.000170, 0.044000},
	{{0, 2, -5, 0, 1, 0, 0, 0, -2, 1, 0}, 150.014880, 0.000050, 0.076000},
	{{0, 2, -4, 0, -2, 0, 0, 0, -2, 1, 0}, 141.841370, 0.000030, 0.081000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 281.194450, 0.000060, 0.026000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 283.895490, 0.000350, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 57.552430, 0.000280, 0.082000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 105.293540, 0.000040, 0.976000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 80.498900, 0.000040, 0.077000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 248.339730, 0.000490, 0.076000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 82.643390, 0.000530, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 260.498900, 0.000040, 0.074000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 262.104690, 0.000050, 0.037000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 246.677520, 0.000830, 0.071000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 206.634820, 0.000230, 1.335000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 30.539320, 0.000560, 0.080000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 40.419910, 0.000020, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 244.090840, 0.000130, 0.086000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 79.788820, 0.000050, 0.040000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 82.643390, 0.000090, 0.087000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 117.987620, 0.000100, 0.396000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 289.586100, 0.001900, 0.093000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 288.635360, 0.002880, 0.042000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 289.561060, 0.000240, 0.027000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 288.235140, 0.000060, 0.028000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 42.447110, 0.000020, 0.021000},
	{{0, 2, -4, 0, 1, 0, 0, 0, 2, 0, 0}, 359.408860, 0.000060, 0.042000},
	{{0, 2, -4, 0, 2, 0, 0, 0, 2, 0, 0}, 89.849360, 0.000050, 0.041000},
	{{0, 2, -4, 2, 0, 0, 0, 0, -2, 0, 0}, 88.138950, 0.000020, 0.041000},
	{{0, 2, -4, 2, 0, 0, 0, 0, -2, 2, 0}, 268.138950, 0.000020, 0.479000},
	{{0, 2, -4, 2, 0, 0, 0, 0, 0, -1, 0}, 89.103990, 0.000040, 0.077000},
	{{0, 2, -4, 2, 0, 0, 0, 0, 0, 1, 0}, 269.103990, 0.000040, 0.074000},
	{{0, 2, -4, 4, 0, 0, 0, 0, 2, -3, 0}, 151.473550, 0.000030, 0.073000},
	{{0, 2, -4, 4, 0, 0, 0, 0, 2, -1, 0}, 331.473550, 0.000030, 0.078000},
	{{0, 2, -3, 0, -3, 0, 0, 0, -2, 0, 0}, 30.944780, 0.000040, 0.040000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 0, -1, 0}, 321.886550, 0.000040, 0.075000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 0, 1, 0}, 141.886550, 0.000040, 0.075000},
	{{0, 2, -3, 0, -3, 0, 0, 0, 2, 0, 0}, 210.919860, 0.000040, 0.040000},
	{{0, 2, -3, 0, -1, 0, 0, 0, 0, -1, 0}, 31.029220, 0.000030, 0.076000},
	{{0, 2, -3, 0, -1, 0, 0, 0, 0, 1, 0}, 211.029220, 0.000030, 0.075000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, -1, 0}, 0.483900, 0.000050, 0.016000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 2.174640, 0.000510, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 0, 2}, 1.490950, 0.000040, 0.045000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 1.979990, 0.001170, 0.028000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 2, 0}, 1.250750, 0.000540, 0.044000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 0, 0}, 1.798990, 0.000170, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 1, 0}, 181.497590, 0.000080, 0.042000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 1, 1}, 166.645860, 0.000020, 0.098000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -3, 2, 0}, 1.326320, 0.000020, 0.097000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -2, 0}, 0.676240, 0.000400, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 1.408420, 0.003590, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 1.434340, 0.052470, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 2}, 181.164840, 0.000220, 0.424000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, -2}, 181.320930, 0.000020, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 1.589910, 0.048830, 0.089000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 2}, 181.019000, 0.000150, 0.064000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 181.946400, 0.002700, 0.494000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 181.791120, 0.000170, 0.065000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 180.745860, 0.000060, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 346.625440, 0.000320, 0.084000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 346.414000, 0.000060, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 180.697740, 0.001170, 0.083000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 165.949640, 0.000100, 0.766000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, -1}, 166.666810, 0.000230, 0.081000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, 0}, 0.737070, 0.000060, 0.879000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 166.664620, 0.000150, 0.069000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 358.480380, 0.000170, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 358.493580, 0.002830, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 347.339280, 0.000040, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 358.711940, 0.055070, 0.077000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 2}, 178.419190, 0.000190, 0.072000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 357.828160, 0.000030, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 347.323450, 0.000820, 0.076000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 179.964850, 0.006380, 3.983000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 346.577670, 0.000150, 0.073000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 2}, 0.162440, 0.000080, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, -2}, 358.419190, 0.000190, 0.075000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 167.324780, 0.000050, 11.864000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 178.558150, 0.051640, 0.074000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 178.543680, 0.002700, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 3, 0}, 178.644420, 0.000160, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, 1}, 174.326290, 0.000060, 2.131000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 346.578740, 0.000450, 0.071000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 346.589130, 0.001080, 0.078000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 346.577900, 0.000270, 1.246000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 47.476910, 0.000050, 0.079000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 348.871690, 0.000180, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 166.585880, 0.000490, 0.080000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 1.969270, 0.000060, 0.068000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 2.020740, 0.001290, 0.657000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, -2}, 0.797080, 0.000070, 0.066000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 181.017950, 0.028340, 0.085000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 0.308370, 0.000090, 0.539000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 347.478660, 0.000190, 0.086000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 179.998870, 0.027040, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, -2}, 0.719590, 0.000040, 0.088000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 179.132190, 0.001900, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 179.995140, 0.000220, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, -1, 0}, 0.146580, 0.000040, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, 0, -1}, 166.564360, 0.000060, 0.042000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 3, 0, 0}, 179.865710, 0.000100, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -2, 0}, 179.957430, 0.000220, 0.043000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 176.864160, 0.000450, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 178.133010, 0.000270, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 1, 0}, 181.258400, 0.000040, 0.016000},
	{{0, 2, -3, 0, 1, 0, 0, 0, -2, 0, 0}, 259.870330, 0.000040, 0.041000},
	{{0, 2, -3, 0, 1, 0, 0, 0, -2, 1, 0}, 93.029820, 0.000050, 0.090000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 0, 0}, 88.759310, 0.000130, 2.982000},
	{{0, 2, -3, 0, 1, 0, 0, 0, 0, 2, 0}, 88.717440, 0.000020, 0.037000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 2, -2, 0}, 150.194910, 0.000020, 0.738000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 2, -1, 0}, 330.309830, 0.000060, 0.084000},
	{{0, 2, -3, 0, 2, 0, 0, 0, 2, 0, 0}, 330.194910, 0.000020, 0.040000},
	{{0, 2, -3, 2, 0, 0, 0, 0, -2, 0, 0}, 130.236630, 0.000030, 0.043000},
	{{0, 2, -3, 2, 0, 0, 0, 0, -2, 2, 0}, 310.236630, 0.000030, 0.324000},
	{{0, 2, -3, 2, 0, 0, 0, 0, 2, -2, 0}, 134.719050, 0.000030, 2.176000},
	{{0, 2, -3, 2, 0, 0, 0, 0, 2, 0, 0}, 314.719050, 0.000030, 0.038000},
	{{0, 2, -3, 3, 0, 0, 0, 0, 2, -3, 0}, 323.514690, 0.000040, 0.076000},
	{{0, 2, -3, 3, 0, 0, 0, 0, 2, -1, 0}, 143.514690, 0.000040, 0.075000},
	{{0, 2, -2, 0, -1, 0, 0, 0, -2, 0, 0}, 342.112270, 0.000060, 0.042000},
	{{0, 2, -2, 0, -1, 0, 0, 0, -2, 2, 0}, 279.730270, 0.000040, 0.340000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 2, -2, 0}, 283.996180, 0.000030, 1.647000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 2, -1, 0}, 102.205450, 0.000050, 0.079000},
	{{0, 2, -2, 0, -1, 0, 0, 0, 2, 0, 0}, 103.996180, 0.000030, 0.039000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -6, 1, 0}, 90.380970, 0.000040, 0.017000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -6, 2, 0}, 90.314700, 0.000130, 0.022000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, -1, 0}, 89.658380, 0.000240, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 0, 0}, 90.793100, 0.001240, 0.021000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 0, 2}, 90.306400, 0.000110, 0.047000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 1, 0}, 90.735580, 0.003040, 0.029000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 1, 2}, 90.323680, 0.000060, 0.123000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 2, 0}, 90.546370, 0.001310, 0.046000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -4, 3, 0}, 89.977100, 0.000030, 0.118000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, -1, 0}, 90.415510, 0.000030, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, 0, 0}, 90.915530, 0.000050, 0.028000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -3, 1, 0}, 270.397570, 0.000310, 0.044000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -3, 0}, 90.310840, 0.000070, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 90.265370, 0.000540, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 90.484510, 0.009780, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -1, 2}, 270.310460, 0.000070, 0.101000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 90.363860, 0.166440, 0.043000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 2}, 270.331830, 0.000590, 0.298000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, -2}, 270.305340, 0.000070, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 90.310810, 0.116170, 0.098000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, 2}, 270.301190, 0.000270, 0.060000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, -2}, 270.342040, 0.000020, 0.042000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 270.217930, 0.008190, 0.331000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, 2}, 270.298220, 0.000020, 0.033000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 3, 0}, 270.241440, 0.000550, 0.061000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, -1, 0}, 270.144220, 0.000140, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 278.285290, 0.000110, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 270.057750, 0.001830, 0.090000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 101.977360, 0.000020, 0.089000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 1, 0}, 90.104390, 0.000200, 0.468000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 2, 0}, 89.936830, 0.000030, 0.065000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -3, 0}, 90.378880, 0.000160, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 90.506360, 0.002620, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, 2}, 90.257330, 0.000020, 0.631000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 90.391760, 0.049190, 0.083000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, 2}, 270.292500, 0.000050, 0.067000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, -2}, 270.147570, 0.000040, 0.039000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 270.233820, 0.026110, 0.799000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 2}, 269.805760, 0.000030, 0.036000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 1, -2}, 89.835790, 0.000120, 0.081000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 270.142920, 0.049240, 0.069000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 2, -2}, 270.260380, 0.000020, 1.090000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 270.140370, 0.002650, 0.036000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 3, -2}, 89.749270, 0.000020, 0.071000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 3, 0}, 270.221440, 0.000140, 0.024000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 277.482860, 0.000480, 0.077000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 89.980180, 0.000070, 2.747000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 275.611160, 0.000220, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, -2}, 89.989470, 0.000310, 0.076000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 269.967440, 0.002000, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 96.134240, 0.000070, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 97.482860, 0.000480, 0.074000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, 0}, 269.951780, 0.000100, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 2, -2}, 270.039030, 0.000020, 0.075000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 90.704770, 0.000430, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, -2}, 90.019000, 0.000030, 0.037000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 89.904700, 0.006360, 1.912000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, 2}, 90.083030, 0.000030, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, -2}, 90.025560, 0.000330, 0.071000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 269.996920, 0.120470, 0.079000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, -2}, 90.117340, 0.000050, 1.168000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 269.970260, 0.042700, 0.038000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 1, -2}, 89.966820, 0.000110, 0.081000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 270.145620, 0.002810, 0.025000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 2, 0}, 270.130570, 0.000300, 0.019000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, -1, -1}, 281.977360, 0.000020, 0.086000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, -1, 0}, 89.999930, 0.000090, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, 0, -2}, 89.989470, 0.000060, 0.087000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, 0, -1}, 95.612330, 0.000050, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 3, 0, 0}, 269.994210, 0.000230, 0.026000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 270.071610, 0.001270, 0.041000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -1, -2}, 269.981400, 0.000060, 0.094000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, -1, 0}, 270.015420, 0.001630, 0.027000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, 0, -2}, 269.988590, 0.000030, 0.042000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, 0, 0}, 270.020500, 0.000510, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 4, 1, 0}, 270.076340, 0.000040, 0.016000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 6, -2, 0}, 270.045940, 0.000030, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 6, -1, 0}, 270.007920, 0.000020, 0.016000},
	{{0, 2, -2, 0, 1, 0, 0, 0, -2, 0, 0}, 76.480110, 0.000070, 0.043000},
	{{0, 2, -2, 0, 1, 0, 0, 0, -2, 1, 0}, 262.220660, 0.000030, 0.099000},
	{{0, 2, -2, 0, 1, 0, 0, 0, -2, 3, 0}, 262.220660, 0.000030, 0.061000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 2, -1, 0}, 246.378060, 0.000070, 0.078000},
	{{0, 2, -2, 0, 1, 0, 0, 0, 2, 0, 0}, 226.893680, 0.000040, 0.038000},
	{{0, 2, -2, 1, 0, 0, 0, 0, 2, -3, 0}, 316.019310, 0.000020, 0.075000},
	{{0, 2, -2, 1, 0, 0, 0, 0, 2, -1, 0}, 136.019310, 0.000020, 0.075000},
	{{0, 2, -1, -2, 0, 0, 0, 0, -2, 0, 0}, 225.098890, 0.000040, 0.042000},
	{{0, 2, -1, -2, 0, 0, 0, 0, -2, 2, 0}, 45.098890, 0.000040, 0.338000},
	{{0, 2, -1, -2, 0, 0, 0, 0, 2, -2, 0}, 229.612800, 0.000030, 1.706000},
	{{0, 2, -1, -2, 0, 0, 0, 0, 2, 0, 0}, 49.612800, 0.000030, 0.039000},
	{{0, 2, -1, 0, -2, 0, 0, 0, -2, 0, 0}, 207.137600, 0.000070, 0.044000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 2, -3, 0}, 51.185680, 0.000020, 0.077000},
	{{0, 2, -1, 0, -2, 0, 0, 0, 2, -1, 0}, 51.439820, 0.000050, 0.074000},
	{{0, 2, -1, 0, -1, 0, 0, 0, -2, 0, 0}, 91.279050, 0.000180, 0.044000},
	{{0, 2, -1, 0, -1, 0, 0, 0, -2, 1, 0}, 271.350980, 0.000060, 0.107000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 0, -1, 0}, 271.468640, 0.000030, 0.090000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 0, 0, 0}, 90.953800, 0.000150, 0.462000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 0, 1, 0}, 91.468640, 0.000030, 0.065000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, -1, 0}, 87.548320, 0.000150, 0.073000},
	{{0, 2, -1, 0, -1, 0, 0, 0, 2, 0, 0}, 274.042110, 0.000100, 0.037000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, -1, 0}, 167.425380, 0.000090, 0.017000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 346.613380, 0.000280, 0.021000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 1, 0}, 347.177670, 0.000560, 0.029000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 2, 0}, 346.369820, 0.000130, 0.048000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 0, 0}, 347.413900, 0.000070, 0.029000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 0, 1}, 193.231160, 0.000020, 0.047000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 1, 0}, 166.957720, 0.000030, 0.046000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -3, 1, 1}, 193.253080, 0.000020, 0.122000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -2, 0}, 347.196420, 0.000080, 0.020000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 347.029470, 0.001130, 0.028000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 347.118860, 0.016390, 0.044000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 2}, 166.475000, 0.000030, 0.229000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 347.242670, 0.007940, 0.108000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 168.247720, 0.000630, 0.248000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 161.808490, 0.000020, 0.058000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, -1, -1}, 193.232740, 0.000020, 0.027000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, -1, 1}, 13.178420, 0.000080, 0.100000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 193.178750, 0.000440, 0.042000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 193.222020, 0.000370, 0.303000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, -1}, 190.938400, 0.000190, 0.097000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, 1}, 193.239060, 0.000170, 0.060000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -2, 0}, 345.741940, 0.000070, 0.041000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 346.900760, 0.002110, 0.091000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 162.329160, 0.001390, 0.444000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 163.761500, 0.001590, 0.064000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 2, 0}, 161.505980, 0.000050, 0.035000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -2, -1}, 193.279370, 0.000020, 0.040000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 193.287630, 0.000570, 0.083000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, 1}, 193.300350, 0.000590, 0.068000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 13.304600, 0.000410, 0.835000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 193.049720, 0.000040, 0.068000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 13.277340, 0.000230, 0.036000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 1, -1}, 13.432340, 0.000540, 0.069000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 347.735090, 0.000070, 0.078000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 339.942740, 0.000150, 2.096000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 153.685640, 0.001990, 0.073000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 193.337960, 0.000220, 0.074000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 337.464440, 0.000250, 0.037000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 1, 0}, 348.486230, 0.000030, 0.025000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, -1, -1}, 193.330150, 0.000190, 0.079000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 3, 0, -1}, 13.306830, 0.000100, 0.039000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 4, -2, 0}, 148.992580, 0.000020, 0.040000},
	{{0, 2, 0, -3, 0, 0, 0, 0, 2, -3, 0}, 337.540920, 0.000030, 0.075000},
	{{0, 2, 0, -3, 0, 0, 0, 0, 2, -1, 0}, 157.540920, 0.000030, 0.076000},
	{{0, 2, 0, 0, -3, 0, 0, 0, -2, 0, 0}, 99.165780, 0.000050, 0.046000},
	{{0, 2, 0, 0, -2, 0, 0, 0, -2, 1, 0}, 90.117810, 0.000070, 0.119000},
	{{0, 2, 0, 0, -2, 0, 0, 0, -2, 3, 0}, 270.063600, 0.000020, 0.055000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 0, -2, 0}, 90.061620, 0.000020, 0.043000},
	{{0, 2, 0, 0, -2, 0, 0, 0, 0, 0, 0}, 270.009070, 0.000080, 0.324000},
	{{0, 2, 0, 0, -1, 0, 0, 0, -2, 0, 0}, 180.569560, 0.000030, 0.046000},
	{{0, 2, 0, 0, -1, 0, 0, 0, -2, 2, 0}, 0.569560, 0.000030, 0.202000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -4, 0, 0}, 65.491710, 0.000070, 0.022000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, -1, 0}, 225.492380, 0.000080, 0.029000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 220.722420, 0.000870, 0.047000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 231.005810, 0.000310, 0.121000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 344.333870, 0.000020, 0.199000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -1, 0, -1}, 99.197150, 0.000050, 0.044000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 129.651860, 0.000140, 0.100000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 301.384920, 0.000470, 0.308000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 303.348500, 0.000220, 0.061000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 115.575090, 0.000040, 0.064000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 300.391660, 0.000430, 0.068000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 116.609080, 0.000140, 0.036000},
	{{0, 2, 1, -8, 0, 0, 0, 0, -2, 0, 0}, 109.932670, 0.000110, 0.040000},
	{{0, 2, 1, -8, 0, 0, 0, 0, -2, 1, 0}, 109.932670, 0.000070, 0.087000},
	{{0, 2, 1, -8, 0, 0, 0, 0, 2, -1, 0}, 290.002150, 0.000060, 0.087000},
	{{0, 2, 1, -8, 0, 0, 0, 0, 2, 0, 0}, 290.002150, 0.000110, 0.040000},
	{{0, 2, 1, 0, -2, 0, 0, 0, -2, 0, 0}, 359.208180, 0.000020, 0.048000},
	{{0, 2, 1, 0, -2, 0, 0, 0, -2, 2, 0}, 359.208180, 0.000020, 0.171000},
	{{0, 2, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 69.141200, 0.000090, 0.049000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 212.762170, 0.000050, 0.235000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 15.321870, 0.000020, 0.033000},
	{{0, 2, 1, 0, 1, 0, 0, 0, 2, -3, 0}, 217.251120, 0.000030, 0.094000},
	{{0, 2, 1, 0, 1, 0, 0, 0, 2, -1, 0}, 217.251120, 0.000030, 0.063000},
	{{0, 2, 1, 0, 1, 0, 0, 0, 2, 0, 0}, 37.733040, 0.000060, 0.034000},
	{{0, 2, 2, 0, -1, 0, 0, 0, 2, 0, 0}, 67.512520, 0.000050, 0.033000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 218.243910, 0.000050, 0.125000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 38.243910, 0.000050, 0.054000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 216.070980, 0.000050, 0.288000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 218.274810, 0.000020, 0.060000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 1, 0}, 38.274810, 0.000020, 0.023000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 2, 0}, 38.243910, 0.000060, 0.018000},
	{{0, 2, 2, 0, 1, 0, 0, 0, 2, 0, 0}, 209.690840, 0.000050, 0.033000},
	{{0, 2, 3, -2, 0, 0, 0, 0, 2, -2, 0}, 174.581080, 0.000020, 0.293000},
	{{0, 2, 3, -2, 0, 0, 0, 0, 2, 0, 0}, 354.581080, 0.000020, 0.033000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 0, 0, 0}, 219.531340, 0.000030, 0.162000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 2, -2, 0}, 218.783110, 0.000020, 0.228000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 2, -1, 0}, 39.480820, 0.000080, 0.057000},
	{{0, 2, 3, 0, -1, 0, 0, 0, 2, 0, 0}, 38.783110, 0.000020, 0.032000},
	{{0, 2, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 32.096650, 0.000040, 0.054000},
	{{0, 2, 3, 0, 0, 0, 0, 0, -2, 2, 0}, 212.096650, 0.000040, 0.125000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 299.692250, 0.000020, 0.143000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 119.692250, 0.000020, 0.051000},
	{{0, 2, 4, -2, 0, 0, 0, 0, 2, -2, 0}, 38.229660, 0.000040, 0.227000},
	{{0, 2, 4, -2, 0, 0, 0, 0, 2, 0, 0}, 218.229660, 0.000040, 0.032000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, -3, 0}, 218.358030, 0.000020, 0.126000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, -2, 0}, 38.314380, 0.000020, 0.188000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, -1, 0}, 38.358030, 0.000020, 0.054000},
	{{0, 2, 4, 0, -2, 0, 0, 0, 2, 0, 0}, 218.314380, 0.000020, 0.031000},
	{{0, 3, -9, 0, 2, 0, 0, 0, -2, 0, 0}, 321.670570, 0.000030, 0.035000},
	{{0, 3, -9, 4, 0, 0, 0, 0, 2, 0, 0}, 262.389770, 0.000040, 0.044000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 25.578790, 0.000020, 0.036000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 205.578790, 0.000020, 0.068000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 205.578790, 0.000020, 0.741000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 25.578790, 0.000020, 0.084000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 60.829720, 0.000020, 0.055000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 240.829720, 0.000020, 0.120000},
	{{0, 3, -8, 0, 2, 0, 0, 0, -2, 0, 0}, 21.774820, 0.000030, 0.036000},
	{{0, 3, -8, 0, 2, 0, 0, 0, -2, 1, 0}, 201.892030, 0.000040, 0.069000},
	{{0, 3, -8, 4, 0, 0, 0, 0, -2, 0, 0}, 160.577790, 0.000040, 0.039000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 0, -1, 0}, 334.106890, 0.000030, 0.070000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 0, 0, 0}, 336.615070, 0.000030, 1.003000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 0, 1, 0}, 158.855930, 0.000090, 0.082000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, -1, 0}, 159.518610, 0.000210, 0.095000},
	{{0, 3, -8, 4, 0, 0, 0, 0, 2, 0, 0}, 159.979670, 0.000440, 0.042000},
	{{0, 3, -7, 0, -1, 0, 0, 0, -2, 1, 0}, 357.246770, 0.000070, 0.073000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, -1, 2}, 140.727770, 0.000030, 0.075000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 141.857910, 0.000060, 0.037000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 4.116890, 0.000030, 0.074000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 1, 2}, 320.727770, 0.000030, 0.076000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 321.857910, 0.000060, 2.862000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 184.116890, 0.000030, 0.077000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 321.765030, 0.000020, 0.035000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 298.100990, 0.000020, 0.065000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 247.643530, 0.000020, 0.471000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 118.100990, 0.000020, 0.090000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 100.651580, 0.000040, 0.107000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 105.115370, 0.000170, 0.044000},
	{{0, 3, -7, 0, 0, 1, 0, 0, -2, 1, 0}, 229.426660, 0.000020, 0.074000},
	{{0, 3, -7, 0, 0, 1, 0, 0, -2, 3, 0}, 229.426660, 0.000020, 0.077000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 1, 0}, 92.619490, 0.000030, 0.074000},
	{{0, 3, -7, 0, 1, 0, 0, 0, -2, 3, 0}, 272.619490, 0.000030, 0.077000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -4, 0, 0}, 237.640870, 0.000040, 0.020000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -4, 1, 0}, 237.640760, 0.000140, 0.028000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -4, 2, 0}, 237.640520, 0.000040, 0.044000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, -1, 0}, 237.957670, 0.000300, 0.026000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 0, 0}, 237.706310, 0.004190, 0.040000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 0, 2}, 57.640860, 0.000030, 0.474000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 1, 0}, 237.319550, 0.004290, 0.087000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -2, 2, 0}, 56.715280, 0.000220, 0.563000},
	{{0, 3, -7, 4, 0, 0, 0, 0, -1, 0, 0}, 57.647970, 0.000090, 0.081000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -2, 0}, 239.422670, 0.000300, 0.038000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, -1, 0}, 239.436000, 0.005410, 0.075000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 1, 0}, 59.438660, 0.005400, 0.075000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 2, 0}, 59.426670, 0.000300, 0.038000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 1, 0, 0}, 237.643180, 0.000090, 0.081000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, -2, 0}, 236.729400, 0.000220, 0.565000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, -1, 0}, 57.329290, 0.004260, 0.087000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 0, 0}, 57.715220, 0.004160, 0.040000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 2, 1, 0}, 57.966500, 0.000300, 0.026000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 4, -2, 0}, 57.650770, 0.000040, 0.044000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 4, -1, 0}, 57.650470, 0.000130, 0.028000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 4, 0, 0}, 57.650340, 0.000040, 0.020000},
	{{0, 3, -6, 0, -2, 0, 0, 0, -2, 1, 0}, 94.670100, 0.000030, 0.078000},
	{{0, 3, -6, 0, -2, 0, 0, 0, -2, 3, 0}, 94.670100, 0.000030, 0.073000},
	{{0, 3, -6, 0, -1, 0, 0, 0, -2, 1, 0}, 326.769550, 0.000080, 0.079000},
	{{0, 3, -6, 0, -1, 0, 0, 0, -2, 3, 0}, 142.464950, 0.000020, 0.072000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -3, 0, 1}, 328.814340, 0.000030, 0.040000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -3, 1, 1}, 149.666100, 0.000020, 0.087000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 355.746940, 0.000100, 0.039000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 336.408200, 0.000020, 0.079000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 73.604280, 0.000040, 0.072000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, 1}, 329.134920, 0.000320, 0.075000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, -1}, 148.990310, 0.000050, 0.073000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 149.134920, 0.000320, 0.076000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 195.004940, 0.000100, 0.070000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 181.267800, 0.000080, 0.890000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 1.738460, 0.000270, 0.082000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 329.666100, 0.000020, 0.088000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 148.814340, 0.000030, 0.041000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 180.328050, 0.000080, 0.345000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 0.317770, 0.001120, 0.097000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 1.118380, 0.001660, 0.042000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 359.304760, 0.000180, 0.027000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 359.425210, 0.000070, 0.028000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 179.909220, 0.000040, 0.021000},
	{{0, 3, -6, 0, 2, 0, 0, 0, 2, 0, 0}, 198.724230, 0.000070, 0.042000},
	{{0, 3, -6, 2, 0, 0, 0, 0, -2, 0, 0}, 184.491960, 0.000040, 0.040000},
	{{0, 3, -6, 2, 0, 0, 0, 0, 2, 0, 0}, 4.686740, 0.000050, 0.041000},
	{{0, 3, -6, 4, 0, 0, 0, 0, -2, 0, 0}, 138.999790, 0.000330, 0.042000},
	{{0, 3, -6, 4, 0, 0, 0, 0, -2, 1, 0}, 140.291150, 0.000170, 0.095000},
	{{0, 3, -6, 4, 0, 0, 0, 0, 0, -1, 0}, 171.286920, 0.000020, 0.082000},
	{{0, 3, -6, 4, 0, 0, 0, 0, 2, 0, 0}, 130.745680, 0.000070, 0.039000},
	{{0, 3, -5, -3, 0, 0, 0, 0, -2, 1, 0}, 188.356780, 0.000030, 0.076000},
	{{0, 3, -5, -3, 0, 0, 0, 0, -2, 3, 0}, 8.356780, 0.000030, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 75.667060, 0.000140, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 75.490110, 0.000290, 0.028000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 77.920210, 0.000130, 0.043000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -3, 0, 0}, 73.879170, 0.000050, 0.027000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -2, 0}, 75.449860, 0.000080, 0.019000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 72.263750, 0.000850, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, -1, 2}, 262.997710, 0.000040, 0.089000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 74.031460, 0.013390, 0.040000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 2}, 255.019410, 0.000030, 0.504000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 75.871980, 0.015580, 0.086000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, 2}, 242.719520, 0.000020, 0.066000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 256.285810, 0.000870, 0.606000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 256.826440, 0.000050, 0.067000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 243.935290, 0.000230, 0.080000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -3, 0}, 63.906600, 0.000030, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 68.768020, 0.000690, 0.038000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 67.839810, 0.013140, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 2}, 247.851710, 0.000050, 0.074000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 74.149300, 0.000760, 8.102000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 78.409220, 0.000170, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, -2}, 67.851710, 0.000050, 0.073000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 248.717350, 0.013750, 0.076000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 247.267100, 0.000650, 0.038000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 3, 0}, 242.703750, 0.000030, 0.025000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 76.964090, 0.000060, 0.081000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 310.492720, 0.000200, 0.082000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 76.964070, 0.000050, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 283.218810, 0.000040, 0.039000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -3, 0}, 78.916720, 0.000060, 0.066000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 77.657580, 0.001070, 0.527000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, -2}, 75.755370, 0.000030, 0.065000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 256.977610, 0.018300, 0.088000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, -2}, 76.411680, 0.000070, 0.448000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 256.541590, 0.017770, 0.041000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 1, -2}, 76.315530, 0.000040, 0.091000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 255.821860, 0.001140, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 256.728260, 0.000110, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 3, -2, 0}, 282.979580, 0.000050, 0.096000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 3, -1, 0}, 283.275860, 0.000130, 0.042000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 3, 0, 0}, 265.231110, 0.000110, 0.027000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 257.629000, 0.000150, 0.044000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, -1, 0}, 256.598160, 0.000400, 0.028000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 254.190510, 0.000130, 0.020000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 4, 1, 0}, 255.765360, 0.000030, 0.016000},
	{{0, 3, -5, 0, 0, 2, 0, 0, 0, -1, 0}, 269.673780, 0.000030, 0.075000},
	{{0, 3, -5, 0, 0, 2, 0, 0, 0, 1, 0}, 89.673780, 0.000030, 0.076000},
	{{0, 3, -5, 0, 0, 3, 0, 0, -2, 0, 0}, 177.116050, 0.000040, 0.040000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 0, -1, 0}, 177.325830, 0.000040, 0.075000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 0, 1, 0}, 357.325830, 0.000040, 0.076000},
	{{0, 3, -5, 0, 0, 3, 0, 0, 2, 0, 0}, 357.124200, 0.000040, 0.040000},
	{{0, 3, -5, 0, 1, 0, 0, 0, -2, 0, 0}, 172.527170, 0.000230, 0.040000},
	{{0, 3, -5, 0, 1, 0, 0, 0, -2, 1, 0}, 172.382050, 0.000110, 0.087000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, -1, 0}, 172.451290, 0.000230, 0.075000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 0, 1, 0}, 352.451290, 0.000230, 0.076000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 2, -1, 0}, 353.464040, 0.000130, 0.087000},
	{{0, 3, -5, 0, 1, 0, 0, 0, 2, 0, 0}, 355.114700, 0.000160, 0.040000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, -1, 0}, 268.985980, 0.000080, 0.026000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 0, 0}, 268.994230, 0.000700, 0.040000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 1, 0}, 268.550680, 0.000570, 0.087000},
	{{0, 3, -5, 0, 2, 0, 0, 0, -2, 2, 0}, 88.970770, 0.000040, 0.550000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, -2, 0}, 270.821040, 0.000040, 0.038000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, -1, 0}, 270.310400, 0.000970, 0.076000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 1, 0}, 90.318830, 0.000970, 0.075000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 0, 2, 0}, 90.730390, 0.000040, 0.038000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, -1, 0}, 88.507600, 0.000520, 0.087000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, 0, 0}, 88.932830, 0.000630, 0.040000},
	{{0, 3, -5, 0, 2, 0, 0, 0, 2, 1, 0}, 88.949360, 0.000050, 0.026000},
	{{0, 3, -5, 0, 3, 0, 0, 0, -2, 0, 0}, 260.283520, 0.000030, 0.041000},
	{{0, 3, -5, 0, 3, 0, 0, 0, 2, -1, 0}, 80.199410, 0.000040, 0.086000},
	{{0, 3, -5, 2, 0, 0, 0, 0, -2, 0, 0}, 89.160630, 0.000050, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -6, 1, 0}, 0.608460, 0.000020, 0.017000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, -1, 0}, 1.378210, 0.000050, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 0, 0}, 2.493930, 0.000340, 0.021000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 1, 0}, 0.585080, 0.000870, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 2, 0}, 0.459710, 0.000380, 0.045000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 0, 0}, 0.444350, 0.000070, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -3, 1, 0}, 180.324140, 0.000180, 0.044000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -2, 0}, 0.601340, 0.000360, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 0.625310, 0.002880, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, 2}, 180.585320, 0.000030, 0.097000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 0.540040, 0.045560, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 2}, 180.604350, 0.000190, 0.335000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 0.611500, 0.034890, 0.094000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, 2}, 180.650360, 0.000090, 0.062000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 180.668790, 0.002230, 0.377000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 180.688480, 0.000120, 0.063000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -2, 0}, 0.213850, 0.000080, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 0.334030, 0.000890, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 166.628220, 0.000090, 0.088000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 346.581290, 0.000160, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 180.345950, 0.009570, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 346.631620, 0.000130, 0.518000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 346.636010, 0.000190, 0.086000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, 0}, 0.308790, 0.001330, 0.567000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 346.628220, 0.000090, 0.066000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 2, 0}, 0.287190, 0.000120, 0.067000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -3, 0}, 1.638690, 0.000110, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 1.406830, 0.001800, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 1.191510, 0.034880, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 2}, 180.934370, 0.000110, 0.069000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, -2}, 0.845290, 0.000120, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 346.483460, 0.000070, 0.080000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 181.019870, 0.011450, 1.141000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 346.311810, 0.000040, 0.070000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 2}, 0.916170, 0.000080, 0.036000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, -2}, 1.993730, 0.000060, 0.079000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 181.144870, 0.027780, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 180.934070, 0.001500, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 3, 0}, 181.043000, 0.000090, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -3, 0}, 359.954330, 0.000210, 0.038000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 359.954330, 0.003800, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 167.629430, 0.000050, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 0.310130, 0.003190, 95.796000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 165.483790, 0.000080, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -2}, 0.282400, 0.000210, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 346.623390, 0.000050, 5.644000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 180.288880, 0.060070, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 354.574770, 0.000050, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 347.629430, 0.000050, 0.076000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 180.287570, 0.003270, 0.038000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 2, 0}, 180.281880, 0.000180, 0.025000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 245.602290, 0.000040, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 179.116260, 0.000370, 1.114000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, -2}, 181.611420, 0.000030, 0.069000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 192.879470, 0.003620, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 346.528290, 0.000060, 0.082000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 182.041490, 0.005660, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 1, -2}, 1.611420, 0.000030, 0.083000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 180.158830, 0.000570, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 181.320490, 0.000050, 0.019000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -3, 0}, 1.355060, 0.000030, 0.560000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -2, 0}, 180.569710, 0.001190, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 166.645460, 0.000060, 0.088000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, -1, 0}, 180.336720, 0.002050, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 0, -1}, 166.477130, 0.000040, 0.041000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 0, 0}, 180.297190, 0.000610, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 3, 1, 0}, 180.283000, 0.000060, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -3, 0}, 4.179060, 0.000050, 0.094000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -2, 0}, 193.482290, 0.000240, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 189.814140, 0.000480, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 185.496210, 0.000070, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, 1, 0}, 1.695370, 0.000020, 0.016000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 5, -2, 0}, 180.409600, 0.000040, 0.028000},
	{{0, 3, -4, 0, 1, 0, 0, 0, -2, 0, 0}, 80.000000, 0.000110, 0.042000},
	{{0, 3, -4, 0, 1, 0, 0, 0, -2, 1, 0}, 85.612260, 0.000070, 0.095000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, -1, 0}, 86.762130, 0.000020, 0.081000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, 0, 0}, 88.688720, 0.000030, 1.041000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, 1, 0}, 266.762130, 0.000020, 0.070000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 0, 2, 0}, 88.688720, 0.000030, 0.036000},
	{{0, 3, -4, 0, 1, 0, 0, 0, 2, -1, 0}, 237.788640, 0.000040, 0.080000},
	{{0, 3, -4, 0, 2, 0, 0, 0, -2, 0, 0}, 173.490650, 0.000080, 0.042000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 1, -1, -1}, 320.961690, 0.000020, 0.075000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 1, 1, -1}, 140.961690, 0.000020, 0.075000},
	{{0, 3, -4, 0, 2, 0, 0, 0, 2, 0, 0}, 330.257360, 0.000050, 0.039000},
	{{0, 3, -4, 2, 0, 0, 0, 0, 2, -3, 0}, 201.430750, 0.000020, 0.076000},
	{{0, 3, -4, 2, 0, 0, 0, 0, 2, -1, 0}, 21.430750, 0.000020, 0.075000},
	{{0, 3, -3, 0, -2, 0, 0, 0, 2, -1, 0}, 300.309060, 0.000030, 0.076000},
	{{0, 3, -3, 0, -1, 0, 0, 0, -2, 0, 0}, 305.945310, 0.000070, 0.044000},
	{{0, 3, -3, 0, -1, 0, 0, 0, -2, 2, 0}, 182.199710, 0.000030, 0.280000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -3, 0}, 13.162660, 0.000020, 0.076000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -2, 0}, 284.045500, 0.000020, 54.802000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, -1, 0}, 172.569880, 0.000080, 0.075000},
	{{0, 3, -3, 0, -1, 0, 0, 0, 2, 0, 0}, 104.045500, 0.000020, 0.038000},
	{{0, 3, -3, 0, 0, -3, 0, 0, 2, -3, 0}, 212.063660, 0.000040, 0.075000},
	{{0, 3, -3, 0, 0, -3, 0, 0, 2, -1, 0}, 32.063660, 0.000040, 0.075000},
	{{0, 3, -3, 0, 0, -1, 0, 0, 2, -1, 0}, 2.790900, 0.000060, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 97.667870, 0.000140, 0.021000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 99.297860, 0.000190, 0.029000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -4, 2, 0}, 93.328470, 0.000070, 0.047000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -3, 0, 0}, 93.938560, 0.000050, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -2, 0}, 91.142770, 0.000220, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 92.090050, 0.001860, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, -1, 2}, 272.087240, 0.000020, 0.108000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 92.987570, 0.017290, 0.044000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 92.719170, 0.009870, 0.104000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 1, 2}, 92.087240, 0.000020, 0.058000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 271.786850, 0.000960, 0.274000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 271.026320, 0.000100, 0.059000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 265.107110, 0.000190, 0.042000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 268.578900, 0.000060, 0.042000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 65.187920, 0.000190, 0.095000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -4, 0}, 90.143050, 0.000020, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 90.044740, 0.000430, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 90.140290, 0.006580, 0.041000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, 2}, 89.986280, 0.000050, 0.452000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 90.105400, 0.099320, 0.088000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, 2}, 270.122390, 0.000230, 0.065000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 269.465560, 0.000040, 0.040000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 270.575620, 0.007370, 0.533000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, 2}, 269.901910, 0.000050, 0.035000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, -2}, 90.206750, 0.000190, 0.085000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 89.177320, 0.007070, 0.066000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 89.626310, 0.000470, 0.035000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -2, 0}, 264.899130, 0.000060, 0.082000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 272.090300, 0.000090, 0.080000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 89.997470, 0.000370, 1.011000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 276.589950, 0.000050, 0.069000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 268.344470, 0.002250, 0.070000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 96.594640, 0.000060, 0.036000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 92.090300, 0.000090, 0.071000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 1, 0}, 270.023660, 0.000120, 0.036000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -4, 0}, 95.827910, 0.000030, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 95.359750, 0.000660, 0.076000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, -2}, 269.995090, 0.000170, 0.037000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 269.995730, 0.034520, 9.751000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, 2}, 269.981520, 0.000130, 0.037000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, -2}, 269.988200, 0.002960, 0.074000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 89.981870, 0.598270, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 89.990760, 0.000320, 4.330000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 101.318590, 0.000140, 0.076000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 89.853030, 0.011390, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, -2}, 90.014670, 0.000650, 0.077000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 89.753240, 0.000950, 0.025000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 2, -2}, 90.020570, 0.000040, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 270.213840, 0.000060, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, -1, 0}, 269.941400, 0.000130, 0.039000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 3, 0, 0}, 270.062780, 0.000190, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -4, 0}, 88.804260, 0.000070, 0.598000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -3, 0}, 269.467160, 0.001230, 0.086000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -2, -2}, 89.986280, 0.000050, 0.499000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -2, 0}, 89.967940, 0.004970, 0.040000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -1, -2}, 269.998770, 0.000250, 0.089000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 89.958650, 0.004900, 0.026000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 89.967190, 0.000350, 0.019000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -3, 0}, 90.063420, 0.000070, 0.028000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -2, 0}, 89.982360, 0.000120, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 6, -1, 0}, 89.981970, 0.000050, 0.016000},
	{{0, 3, -3, 0, 0, 1, 0, 0, 2, -3, 0}, 177.687770, 0.000020, 0.076000},
	{{0, 3, -3, 0, 0, 1, 0, 0, 2, -1, 0}, 357.687770, 0.000020, 0.075000},
	{{0, 3, -3, 0, 1, 0, 0, 0, -2, 0, 0}, 60.118010, 0.000070, 0.044000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, -3, 0}, 300.291400, 0.000020, 0.077000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, -1, 0}, 120.291400, 0.000020, 0.074000},
	{{0, 3, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 242.075250, 0.000030, 0.037000},
	{{0, 3, -3, 0, 2, 0, 0, 0, 2, -3, 0}, 85.170900, 0.000020, 0.077000},
	{{0, 3, -3, 0, 2, 0, 0, 0, 2, -1, 0}, 85.170900, 0.000020, 0.074000},
	{{0, 3, -2, -3, 0, 0, 0, 0, 2, -3, 0}, 33.513440, 0.000030, 0.073000},
	{{0, 3, -2, -3, 0, 0, 0, 0, 2, -1, 0}, 213.513440, 0.000030, 0.078000},
	{{0, 3, -2, -2, 0, 0, 0, 0, 2, -2, 0}, 229.607400, 0.000030, 25.521000},
	{{0, 3, -2, -2, 0, 0, 0, 0, 2, 0, 0}, 49.607400, 0.000030, 0.038000},
	{{0, 3, -2, 0, -2, 0, 0, 0, -2, 0, 0}, 179.596780, 0.000020, 0.045000},
	{{0, 3, -2, 0, -2, 0, 0, 0, -2, 2, 0}, 179.596780, 0.000020, 0.223000},
	{{0, 3, -2, 0, -1, 0, 0, 0, -2, 0, 0}, 91.305460, 0.000200, 0.046000},
	{{0, 3, -2, 0, -1, 0, 0, 0, -2, 2, 0}, 271.488920, 0.000030, 0.219000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 0, 0, 0}, 90.939550, 0.000100, 0.358000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 2, -1, 0}, 94.785240, 0.000090, 0.070000},
	{{0, 3, -2, 0, -1, 0, 0, 0, 2, 0, 0}, 274.004320, 0.000090, 0.036000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -4, 0, 0}, 170.057980, 0.000050, 0.021000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -4, 1, 0}, 346.713260, 0.000040, 0.030000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 347.044110, 0.000320, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 347.468700, 0.002030, 0.046000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 347.445190, 0.000860, 0.116000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 165.343230, 0.000040, 0.215000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, -1, -1}, 193.183260, 0.000030, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, -1, 1}, 13.214330, 0.000060, 0.107000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 193.092920, 0.000360, 0.044000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 193.265320, 0.000270, 0.254000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 193.378380, 0.000060, 0.104000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 1, 1}, 193.259770, 0.000110, 0.058000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -3, 0}, 347.152350, 0.000020, 0.027000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 346.764800, 0.000340, 0.042000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 346.670570, 0.004210, 0.096000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 158.269560, 0.000510, 0.348000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 25.508230, 0.000060, 0.062000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 13.167820, 0.000060, 0.087000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 193.309980, 0.000340, 0.065000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 13.364250, 0.000340, 0.549000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 13.266240, 0.000210, 0.035000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 13.307390, 0.000340, 0.066000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -4, 0}, 162.632890, 0.000020, 0.039000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 176.075230, 0.000040, 0.082000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 168.203420, 0.000050, 0.907000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 166.120930, 0.003640, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 193.341090, 0.000080, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 341.913500, 0.000100, 0.036000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 344.121190, 0.000040, 0.024000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -2, -1}, 193.285110, 0.000130, 20.498000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -1, -1}, 13.287530, 0.002220, 0.075000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, 0, -1}, 13.292930, 0.000160, 0.038000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 166.714690, 0.000070, 0.039000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 4, -1, 0}, 167.044270, 0.000080, 0.026000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 5, -2, -1}, 13.287310, 0.000020, 0.040000},
	{{0, 3, -1, -2, 0, 0, 0, 0, -2, 0, 0}, 90.495020, 0.000020, 0.046000},
	{{0, 3, -1, -2, 0, 0, 0, 0, -2, 2, 0}, 270.495020, 0.000020, 0.218000},
	{{0, 3, -1, 0, -2, 0, 0, 0, 0, -2, 0}, 89.989550, 0.000030, 0.044000},
	{{0, 3, -1, 0, -2, 0, 0, 0, 0, 0, 0}, 269.989550, 0.000030, 0.270000},
	{{0, 3, -1, 0, -1, 0, 0, 0, -2, 0, 0}, 180.407490, 0.000030, 0.048000},
	{{0, 3, -1, 0, -1, 0, 0, 0, -2, 2, 0}, 0.407490, 0.000030, 0.180000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 132.199460, 0.000030, 0.029000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 158.596230, 0.000240, 0.048000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 134.269820, 0.000040, 0.131000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 98.197760, 0.000040, 0.046000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 181.672490, 0.000120, 0.107000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 294.995610, 0.000520, 0.258000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 295.781640, 0.000200, 0.058000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 117.979000, 0.000030, 0.062000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 255.929680, 0.000020, 0.090000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 303.304160, 0.000340, 0.065000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 116.315250, 0.000160, 0.035000},
	{{0, 3, 0, 0, -2, 0, 0, 0, -2, 0, 0}, 359.026510, 0.000020, 0.050000},
	{{0, 3, 0, 0, -2, 0, 0, 0, -2, 2, 0}, 359.026510, 0.000020, 0.154000},
	{{0, 3, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 22.274670, 0.000090, 0.050000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 202.183430, 0.000030, 0.205000},
	{{0, 3, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 35.388360, 0.000040, 0.034000},
	{{0, 3, 1, 0, -1, 0, 0, 0, 2, -2, 0}, 242.577640, 0.000020, 0.249000},
	{{0, 3, 1, 0, -1, 0, 0, 0, 2, 0, 0}, 62.577640, 0.000020, 0.033000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 38.326870, 0.000020, 0.136000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 218.326870, 0.000020, 0.052000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 216.206600, 0.000050, 0.244000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 34.673430, 0.000030, 0.033000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, 2, 0}, 38.211620, 0.000020, 0.018000},
	{{0, 3, 1, 0, 1, 0, 0, 0, 2, -1, 0}, 209.517730, 0.000030, 0.057000},
	{{0, 3, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 32.080980, 0.000050, 0.056000},
	{{0, 3, 2, 0, 0, 0, 0, 0, -2, 2, 0}, 212.080980, 0.000050, 0.116000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 114.785090, 0.000030, 0.145000},
	{{0, 3, 5, -15, 0, 0, 0, 0, 2, -3, 0}, 246.703710, 0.000030, 0.076000},
	{{0, 3, 5, -15, 0, 0, 0, 0, 2, -1, 0}, 66.703710, 0.000030, 0.075000},
	{{0, 4, -10, 3, 0, 0, 0, 0, -2, 1, 0}, 62.551430, 0.000020, 0.075000},
	{{0, 4, -10, 3, 0, 0, 0, 0, -2, 3, 0}, 242.551430, 0.000020, 0.076000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 35.924440, 0.000040, 0.037000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 127.038150, 0.000030, 0.072000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 215.924440, 0.000040, 1.381000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 307.038150, 0.000030, 0.080000},
	{{0, 4, -8, 0, 0, -1, 0, 0, -2, 1, 0}, 54.315450, 0.000060, 0.077000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 141.773860, 0.000030, 0.038000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 214.695370, 0.000020, 0.077000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 321.773860, 0.000030, 3.622000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 34.695370, 0.000020, 0.074000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 321.811120, 0.000030, 0.036000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 141.811120, 0.000030, 0.668000},
	{{0, 4, -8, 0, 1, 0, 0, 0, -2, 0, 0}, 132.073810, 0.000020, 0.038000},
	{{0, 4, -8, 0, 1, 0, 0, 0, -2, 1, 0}, 270.300310, 0.000090, 0.078000},
	{{0, 4, -8, 0, 1, 0, 0, 0, -2, 2, 0}, 312.073810, 0.000020, 2.775000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 112.214050, 0.000060, 0.040000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 146.847510, 0.000080, 0.083000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 344.188900, 0.000100, 0.073000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 157.956160, 0.000070, 0.078000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 2.728810, 0.000110, 0.091000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 14.893680, 0.000080, 0.041000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 75.167710, 0.000040, 0.020000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -4, 1, 0}, 74.756450, 0.000080, 0.028000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -4, 2, 0}, 80.063480, 0.000030, 0.045000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 76.574250, 0.000270, 0.027000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 75.381550, 0.003930, 0.041000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 75.617320, 0.003160, 0.091000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 251.941830, 0.000170, 0.439000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, -1, 1}, 79.238450, 0.000050, 0.085000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 252.194680, 0.000150, 0.084000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 75.404680, 0.000290, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 72.680500, 0.004470, 0.078000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 253.740840, 0.000950, 1.992000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 252.627720, 0.004130, 0.073000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 250.357320, 0.000200, 0.037000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, -1}, 79.213360, 0.000080, 0.072000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 79.238460, 0.000270, 0.077000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 250.446340, 0.000240, 0.078000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 79.193280, 0.000070, 0.038000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, 1, -1}, 259.213360, 0.000080, 0.079000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 251.258250, 0.000080, 0.786000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 140.182860, 0.000060, 0.083000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 252.868400, 0.000780, 0.040000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 254.446450, 0.000130, 0.026000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 75.197510, 0.000050, 0.020000},
	{{0, 4, -6, 0, 1, 0, 0, 0, 2, -2, 0}, 359.543650, 0.000030, 0.842000},
	{{0, 4, -6, 0, 1, 0, 0, 0, 2, 0, 0}, 359.543650, 0.000030, 0.039000},
	{{0, 4, -6, 0, 2, 0, 0, 0, -2, 0, 0}, 269.871380, 0.000050, 0.042000},
	{{0, 4, -6, 2, 0, 0, 0, 0, 2, -3, 0}, 218.672020, 0.000020, 0.074000},
	{{0, 4, -6, 2, 0, 0, 0, 0, 2, -1, 0}, 38.672020, 0.000020, 0.077000},
	{{0, 4, -5, 0, -1, 0, 0, 0, 2, -1, 0}, 8.189930, 0.000040, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 180.259130, 0.000030, 0.021000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 183.409340, 0.000100, 0.029000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 182.566710, 0.000030, 0.047000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 183.939370, 0.000210, 0.027000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 184.289060, 0.004140, 0.043000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 182.932520, 0.002890, 0.100000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 4.159490, 0.000170, 0.305000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 181.045460, 0.000040, 0.060000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, -1}, 166.527700, 0.000420, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 358.595840, 0.000050, 0.092000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 165.876670, 0.000190, 0.391000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 1, -1}, 166.547600, 0.000100, 0.091000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 1, 1}, 166.538290, 0.000110, 0.063000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 2, -1}, 166.380430, 0.000020, 0.450000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -3, 0}, 2.864480, 0.000020, 0.026000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 1.468470, 0.000220, 0.040000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 0.785290, 0.004440, 0.085000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 346.441700, 0.000040, 0.084000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 178.515510, 0.000460, 0.666000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 175.963910, 0.000350, 0.068000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -2, -1}, 166.513430, 0.000070, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -2, 1}, 346.486150, 0.000040, 1.279000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 166.513500, 0.001210, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 166.518550, 0.000950, 0.071000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 346.516390, 0.000330, 2.231000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 358.596020, 0.000300, 0.072000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 349.664980, 0.000230, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 346.513500, 0.001210, 0.073000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 2, -1}, 346.513500, 0.000070, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 182.110040, 0.001590, 3.678000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, -2}, 181.433630, 0.000080, 0.072000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 1.379140, 0.026710, 0.077000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 346.463120, 0.000160, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 2.189500, 0.004470, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 1, -2}, 182.256780, 0.000020, 0.079000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 2.662730, 0.000250, 0.025000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, -1, -1}, 166.515450, 0.000120, 0.084000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 3, 0, -1}, 346.511310, 0.000120, 0.040000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -3, 0}, 3.967320, 0.000050, 0.089000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 358.815470, 0.000250, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -1, 0}, 1.167430, 0.000280, 0.027000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 7.205490, 0.000060, 0.020000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 6, -2, 0}, 184.613690, 0.000020, 0.020000},
	{{0, 4, -5, 0, 0, 1, 0, 0, 2, -1, 0}, 269.716910, 0.000040, 0.077000},
	{{0, 4, -5, 0, 1, 0, 0, 0, -2, 0, 0}, 277.378050, 0.000110, 0.043000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 0, -1, 0}, 268.009470, 0.000020, 0.086000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 0, 0, 0}, 88.851740, 0.000050, 0.630000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 0, 1, 0}, 88.009470, 0.000020, 0.067000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 2, -3, 0}, 89.842120, 0.000030, 0.074000},
	{{0, 4, -5, 0, 1, 0, 0, 0, 2, -1, 0}, 359.737820, 0.000050, 0.077000},
	{{0, 4, -5, 0, 2, 0, 0, 0, 2, 0, 0}, 330.294850, 0.000040, 0.038000},
	{{0, 4, -5, 2, 0, 0, 0, 0, 2, -3, 0}, 314.657630, 0.000040, 0.080000},
	{{0, 4, -5, 2, 0, 0, 0, 0, 2, -1, 0}, 134.657630, 0.000040, 0.071000},
	{{0, 4, -4, 0, -1, 0, 0, 0, -2, 0, 0}, 283.109100, 0.000050, 0.045000},
	{{0, 4, -4, 0, -1, 0, 0, 0, 2, -1, 0}, 282.648580, 0.000060, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -6, 2, 0}, 269.121260, 0.000020, 0.022000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -4, -1, 0}, 269.550580, 0.000030, 0.017000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -4, 0, 0}, 90.048150, 0.000070, 0.021000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -4, 1, 0}, 89.500020, 0.000220, 0.030000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, -2, 0}, 89.681960, 0.000020, 0.021000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 89.116580, 0.000370, 0.028000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 88.980500, 0.005340, 0.045000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 88.895800, 0.002650, 0.111000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 269.067360, 0.000350, 0.234000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 268.595220, 0.000040, 0.057000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 92.440710, 0.000040, 0.101000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -3, 0}, 90.269100, 0.000030, 0.027000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 90.374850, 0.000370, 0.042000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 90.279400, 0.005950, 0.093000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -1, 2}, 90.092320, 0.000020, 0.062000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, -2}, 270.053760, 0.000120, 0.041000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 90.143250, 0.006270, 0.400000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, 2}, 270.039630, 0.000100, 0.034000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, -2}, 270.114250, 0.000120, 0.090000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 90.067170, 0.007320, 0.063000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 90.057660, 0.000470, 0.034000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 3, 0}, 90.359080, 0.000020, 0.024000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 91.140200, 0.000070, 0.086000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 279.951830, 0.000040, 0.085000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 90.039120, 0.000070, 0.619000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 270.088060, 0.001230, 0.067000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 99.836000, 0.000060, 0.035000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 99.951830, 0.000040, 0.068000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 270.100750, 0.000070, 0.036000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 270.399450, 0.000210, 0.080000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 270.012130, 0.004190, 1.374000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, -2}, 269.863100, 0.000310, 0.078000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 89.992240, 0.079450, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, -2}, 90.042320, 0.000060, 2.535000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 270.061850, 0.014760, 0.037000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 270.211150, 0.000700, 0.025000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 269.955490, 0.000160, 0.019000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -2, 0}, 90.102420, 0.000350, 0.076000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, -1, 0}, 90.064590, 0.000080, 0.038000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, 0, -2}, 90.064520, 0.000040, 0.078000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 3, 0, 0}, 270.064540, 0.000230, 0.025000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -2, 0}, 90.049430, 0.000840, 0.039000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -1, -2}, 90.199170, 0.000050, 0.084000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 90.122490, 0.000430, 0.026000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 0, -2}, 90.016790, 0.000060, 0.040000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 270.012940, 0.000160, 0.019000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 4, 1, 0}, 270.211220, 0.000040, 0.015000},
	{{0, 4, -4, 0, 1, 0, 0, 0, -2, 0, 0}, 75.719200, 0.000050, 0.045000},
	{{0, 4, -4, 0, 1, 0, 0, 0, 2, -1, 0}, 50.453370, 0.000050, 0.071000},
	{{0, 4, -3, 0, -2, 0, 0, 0, -2, 0, 0}, 178.127060, 0.000020, 0.047000},
	{{0, 4, -3, 0, -2, 0, 0, 0, -2, 2, 0}, 358.127060, 0.000020, 0.196000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 0, 0, 0}, 91.394350, 0.000090, 0.293000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 0, 2, 0}, 91.138910, 0.000020, 0.033000},
	{{0, 4, -3, 0, -1, 0, 0, 0, 2, 0, 0}, 273.964890, 0.000080, 0.036000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 166.152240, 0.000040, 0.022000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 343.418370, 0.000050, 0.029000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 343.518700, 0.000620, 0.047000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 344.639190, 0.000270, 0.125000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 196.636230, 0.000020, 0.190000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 13.301170, 0.000040, 0.115000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 192.899910, 0.000290, 0.045000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 193.297660, 0.000220, 0.220000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 1, -1}, 193.299680, 0.000070, 0.111000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 193.312840, 0.000080, 0.056000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 346.865760, 0.000030, 0.043000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 345.056930, 0.000390, 0.103000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 34.850710, 0.000040, 0.286000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 352.822910, 0.000070, 0.060000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 193.323280, 0.000230, 0.093000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, -1, 1}, 193.326820, 0.000260, 0.062000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 13.381670, 0.000370, 0.408000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 13.327110, 0.000200, 0.034000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 13.323280, 0.000230, 0.064000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 170.894450, 0.000030, 0.087000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 347.108200, 0.000030, 0.579000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 169.260490, 0.000940, 0.067000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 193.346340, 0.000040, 0.067000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 350.372390, 0.000420, 0.035000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 347.992780, 0.000060, 0.024000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, -1, -1}, 13.324670, 0.000120, 0.072000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, 0, -1}, 13.329380, 0.000030, 0.037000},
	{{0, 4, -2, 0, -1, 0, 0, 0, -2, 0, 0}, 180.165280, 0.000020, 0.049000},
	{{0, 4, -2, 0, -1, 0, 0, 0, -2, 2, 0}, 0.165280, 0.000020, 0.162000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 121.806940, 0.000030, 0.030000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 130.244910, 0.000230, 0.049000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 116.265840, 0.000110, 0.114000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 295.216570, 0.000490, 0.222000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 296.212260, 0.000160, 0.056000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 296.111630, 0.000300, 0.063000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 116.226280, 0.000170, 0.034000},
	{{0, 4, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 19.690500, 0.000080, 0.052000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 151.113310, 0.000020, 0.268000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 331.113310, 0.000020, 0.033000},
	{{0, 4, -1, 0, 1, 0, 0, 0, 2, 0, 0}, 35.385940, 0.000030, 0.033000},
	{{0, 4, 0, 0, -1, 0, 0, 0, 2, -2, 0}, 237.098290, 0.000030, 0.215000},
	{{0, 4, 0, 0, -1, 0, 0, 0, 2, 0, 0}, 57.098290, 0.000030, 0.032000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 38.212040, 0.000030, 0.154000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 218.212040, 0.000030, 0.030000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 217.988520, 0.000040, 0.212000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 37.988520, 0.000040, 0.032000},
	{{0, 4, 0, 0, 1, 0, 0, 0, 2, -2, 0}, 27.340160, 0.000020, 0.208000},
	{{0, 4, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 207.340160, 0.000020, 0.032000},
	{{0, 4, 1, 0, -1, 0, 0, 0, 2, -3, 0}, 219.245440, 0.000020, 0.131000},
	{{0, 4, 1, 0, -1, 0, 0, 0, 2, -1, 0}, 39.245440, 0.000020, 0.053000},
	{{0, 4, 1, 0, -1, 0, 0, 0, 2, 0, 0}, 38.783950, 0.000040, 0.031000},
	{{0, 4, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 32.066680, 0.000040, 0.058000},
	{{0, 4, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 212.066680, 0.000040, 0.108000},
	{{0, 5, -13, 6, 0, 0, 0, 0, -2, 1, 0}, 20.075130, 0.000040, 0.076000},
	{{0, 5, -13, 6, 0, 0, 0, 0, -2, 3, 0}, 200.075130, 0.000040, 0.075000},
	{{0, 5, -11, 0, 1, 0, 0, 0, -2, 1, 0}, 231.905830, 0.000030, 0.070000},
	{{0, 5, -11, 0, 2, 0, 0, 0, -2, 1, 0}, 141.651920, 0.000030, 0.070000},
	{{0, 5, -11, 2, 0, 0, 0, 0, -2, 0, 0}, 321.769320, 0.000040, 0.038000},
	{{0, 5, -11, 2, 0, 0, 0, 0, -2, 2, 0}, 141.769320, 0.000040, 28.573000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 33.072800, 0.000040, 0.038000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 213.072800, 0.000040, 10.166000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 347.558740, 0.000020, 0.274000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 167.558740, 0.000020, 0.044000},
	{{0, 5, -10, 0, 0, 3, 0, 0, -2, 1, 0}, 133.357670, 0.000020, 0.075000},
	{{0, 5, -10, 0, 0, 3, 0, 0, -2, 3, 0}, 313.357670, 0.000020, 0.075000},
	{{0, 5, -10, 0, 1, 0, 0, 0, -2, 1, 0}, 37.750300, 0.000050, 0.075000},
	{{0, 5, -9, 0, -1, 0, 0, 0, -2, 0, 0}, 330.286230, 0.000020, 0.039000},
	{{0, 5, -9, 0, -1, 0, 0, 0, -2, 2, 0}, 150.286230, 0.000020, 1.224000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 138.607640, 0.000040, 0.039000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 173.331130, 0.000030, 0.081000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 318.603260, 0.000040, 1.109000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 353.331130, 0.000030, 0.071000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 38.594950, 0.000110, 0.076000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 2, 0}, 129.241270, 0.000030, 0.075000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 307.499010, 0.000030, 0.037000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 260.150310, 0.000020, 0.071000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 211.498530, 0.000030, 1.146000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 81.458490, 0.000060, 0.081000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 83.883760, 0.000120, 0.094000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 85.434010, 0.000210, 0.042000},
	{{0, 5, -9, 5, 0, 0, 0, 0, 2, -3, 0}, 289.057920, 0.000020, 0.076000},
	{{0, 5, -9, 5, 0, 0, 0, 0, 2, -1, 0}, 109.057920, 0.000020, 0.075000},
	{{0, 5, -8, 0, -2, 0, 0, 0, 0, -1, 0}, 108.041240, 0.000030, 0.075000},
	{{0, 5, -8, 0, -2, 0, 0, 0, 0, 1, 0}, 288.041240, 0.000030, 0.076000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 170.315630, 0.000030, 0.020000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -4, 1, 0}, 162.274560, 0.000050, 0.028000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 155.135710, 0.000020, 0.044000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 161.454400, 0.000240, 0.026000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 161.827800, 0.002900, 0.041000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 162.400880, 0.002650, 0.088000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 331.945600, 0.000120, 0.526000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 341.681490, 0.000060, 0.082000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 157.958420, 0.000180, 0.038000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 159.403980, 0.003700, 0.076000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 333.764310, 0.000060, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 339.352040, 0.000190, 7.836000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 339.326200, 0.003600, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 339.236140, 0.000190, 0.038000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 163.262600, 0.000080, 0.607000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 342.402050, 0.002040, 0.086000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 341.398750, 0.001980, 0.040000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 341.299650, 0.000280, 0.026000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 341.983190, 0.000020, 0.043000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 341.634760, 0.000050, 0.028000},
	{{0, 5, -8, 0, 2, 0, 0, 0, 0, -1, 0}, 181.998140, 0.000030, 0.077000},
	{{0, 5, -8, 0, 2, 0, 0, 0, 0, 1, 0}, 1.998140, 0.000030, 0.074000},
	{{0, 5, -8, 3, 0, 0, 0, 0, 2, -3, 0}, 86.822160, 0.000030, 0.075000},
	{{0, 5, -8, 3, 0, 0, 0, 0, 2, -1, 0}, 266.822160, 0.000030, 0.076000},
	{{0, 5, -7, -4, 0, 0, 0, 0, 2, 0, 0}, 22.335210, 0.000070, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -4, 0, 0}, 257.920070, 0.000040, 0.021000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -4, 1, 0}, 259.387190, 0.000080, 0.028000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -4, 2, 0}, 251.748020, 0.000030, 0.046000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 256.691540, 0.000230, 0.027000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 259.223780, 0.003530, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 258.447040, 0.002710, 0.097000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 83.036400, 0.000170, 0.345000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, -1, -1}, 259.267430, 0.000020, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, -1, 1}, 261.122190, 0.000050, 0.090000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 259.219580, 0.000350, 0.041000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 65.287310, 0.000030, 0.089000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 259.282360, 0.000040, 0.458000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 79.822250, 0.000080, 0.088000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 1, 1}, 259.282360, 0.000030, 0.065000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 2, -1}, 259.429810, 0.000040, 0.541000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 245.362920, 0.000050, 0.039000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 260.944840, 0.001090, 0.082000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 78.273890, 0.000630, 0.887000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 79.219120, 0.001250, 0.070000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 79.620640, 0.000060, 0.036000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -2, -1}, 259.370650, 0.000140, 0.038000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 259.370650, 0.002500, 0.076000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 260.160470, 0.000600, 0.073000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 65.287860, 0.000200, 0.074000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 79.243420, 0.000100, 0.037000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 79.370650, 0.002500, 0.075000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 2, -1}, 79.370650, 0.000140, 0.038000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 253.945240, 0.000130, 1.547000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, -2}, 285.259870, 0.000020, 0.070000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 74.090330, 0.002280, 0.079000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 77.937270, 0.001150, 0.039000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 1, -2}, 285.249220, 0.000040, 0.081000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 76.572740, 0.000100, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, -2, -1}, 79.430250, 0.000040, 0.588000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, -1, -1}, 259.562650, 0.000160, 0.087000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 0, -1}, 79.267310, 0.000240, 0.040000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 3, 1, -1}, 79.267430, 0.000020, 0.026000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, -2, 0}, 76.311820, 0.000030, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, -1, 0}, 76.899190, 0.000030, 0.027000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, 0, -2}, 285.232700, 0.000050, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 76.767870, 0.000040, 0.020000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 0, -1, 0}, 89.859210, 0.000030, 0.084000},
	{{0, 5, -7, 0, 2, 0, 0, 0, 0, 1, 0}, 269.859210, 0.000030, 0.069000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, -3, 0}, 67.239450, 0.000020, 0.078000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, -2, 0}, 90.181320, 0.000030, 2.398000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, -1, 0}, 247.239450, 0.000020, 0.073000},
	{{0, 5, -7, 2, 0, 0, 0, 0, 2, 0, 0}, 270.181320, 0.000030, 0.037000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 0, 0}, 99.366070, 0.000410, 0.040000},
	{{0, 5, -6, -4, 0, 0, 0, 0, -2, 1, 0}, 100.364320, 0.000350, 0.087000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, -2, 0}, 94.046420, 0.000020, 0.038000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, -1, 0}, 95.118680, 0.000470, 0.075000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 1, 0}, 275.115760, 0.000470, 0.075000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 0, 2, 0}, 274.047340, 0.000020, 0.038000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, -1, 0}, 280.351390, 0.000350, 0.087000},
	{{0, 5, -6, -4, 0, 0, 0, 0, 2, 0, 0}, 279.355400, 0.000410, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -4, 1, 0}, 175.311060, 0.000050, 0.029000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 176.397180, 0.000190, 0.028000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 175.088400, 0.001440, 0.044000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 175.243940, 0.000760, 0.107000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 193.200230, 0.000020, 0.058000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 165.608470, 0.000260, 0.042000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 182.262210, 0.000040, 0.098000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 165.143610, 0.000090, 0.314000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 1, -1}, 166.438240, 0.000040, 0.096000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 166.427690, 0.000040, 0.061000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 180.956780, 0.000160, 0.041000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, -2}, 2.305030, 0.000100, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 181.476100, 0.002930, 0.090000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, -2}, 2.295990, 0.000800, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 166.369440, 0.000060, 0.089000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, -2}, 182.395850, 0.000200, 0.087000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 182.500480, 0.000950, 0.065000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 2, -2}, 2.322940, 0.000100, 0.557000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 182.563700, 0.000030, 0.035000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -1, -1}, 166.375700, 0.000360, 0.082000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 166.400940, 0.000370, 0.068000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 346.436860, 0.000250, 0.931000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 1.044990, 0.000170, 0.069000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 349.803910, 0.000180, 0.036000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 1, -1}, 346.375700, 0.000360, 0.070000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, -2}, 2.312290, 0.000370, 0.038000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 1.268510, 0.001200, 2.828000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -2}, 2.306270, 0.006900, 0.076000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 181.905020, 0.021100, 0.073000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 166.369440, 0.000340, 0.074000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 3.510580, 0.001500, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -2}, 182.312290, 0.006820, 0.075000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 5.664110, 0.000080, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 2, -2}, 182.312290, 0.000370, 0.038000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, -1, -1}, 172.821640, 0.000100, 0.080000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, 0, -1}, 346.390390, 0.000040, 0.039000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 3, 0, 0}, 2.457510, 0.000040, 0.025000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -2, -2}, 182.322940, 0.000100, 0.570000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -2, 0}, 183.241750, 0.000240, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -1, -2}, 2.357920, 0.000330, 0.087000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 179.649690, 0.000110, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 0, -2}, 182.295520, 0.000720, 0.040000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 6.274400, 0.000050, 0.019000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 4, 1, -2}, 182.305030, 0.000100, 0.026000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 6, -3, 0}, 181.847480, 0.000020, 0.027000},
	{{0, 5, -6, 0, 1, 0, 0, 0, -2, 0, 0}, 279.254300, 0.000100, 0.044000},
	{{0, 5, -6, 0, 1, 0, 0, 0, 0, 0, 0}, 88.845400, 0.000040, 0.452000},
	{{0, 5, -5, -4, 0, 0, 0, 0, -2, 0, 0}, 351.370650, 0.000060, 0.042000},
	{{0, 5, -5, 0, -1, 0, 0, 0, -2, 0, 0}, 281.397090, 0.000050, 0.046000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 89.235840, 0.000030, 0.022000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 88.754000, 0.000050, 0.030000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 268.837220, 0.000050, 0.050000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -3, 2, 0}, 89.995170, 0.000020, 0.134000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 88.055070, 0.001120, 0.046000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 86.264110, 0.000520, 0.120000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 269.208980, 0.000190, 0.204000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 265.606970, 0.000020, 0.055000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 89.881470, 0.000080, 0.108000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -3, 0}, 90.463740, 0.000030, 0.027000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 87.528880, 0.000790, 0.099000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, -2}, 265.643500, 0.000120, 0.042000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 90.069460, 0.006260, 0.320000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 2}, 270.009070, 0.000080, 0.033000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 90.039380, 0.005390, 0.061000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 90.036870, 0.000390, 0.034000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 90.286010, 0.000050, 0.446000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 270.229430, 0.000800, 0.065000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 100.145210, 0.000060, 0.035000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 1, 0}, 270.221210, 0.000050, 0.035000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -3, 0}, 261.843690, 0.000030, 0.084000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 269.997680, 0.001860, 0.739000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, -2}, 267.193860, 0.000160, 0.082000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 90.068310, 0.037600, 0.068000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, -2}, 90.033570, 0.000060, 0.980000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 270.057660, 0.014390, 0.036000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 1, -2}, 266.589870, 0.000060, 0.070000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 270.019980, 0.000750, 0.024000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 269.900250, 0.000120, 0.018000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, -2, 0}, 270.143830, 0.000120, 0.073000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, -1, 0}, 90.066390, 0.000080, 0.037000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, 0, -2}, 270.063530, 0.000170, 0.075000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, 0, 0}, 270.066340, 0.000250, 0.025000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 3, 2, 0}, 270.066330, 0.000020, 0.015000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 90.060480, 0.000440, 0.038000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, -1, 0}, 90.082290, 0.000100, 0.025000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 270.002990, 0.000190, 0.019000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 4, 1, 0}, 270.019670, 0.000040, 0.015000},
	{{0, 5, -5, 0, 1, 0, 0, 0, -2, 0, 0}, 75.896720, 0.000050, 0.046000},
	{{0, 5, -5, 0, 1, 0, 0, 0, 2, -2, 0}, 256.289600, 0.000020, 0.695000},
	{{0, 5, -5, 0, 1, 0, 0, 0, 2, -1, 0}, 256.289640, 0.000040, 0.068000},
	{{0, 5, -5, 0, 1, 0, 0, 0, 2, 0, 0}, 76.289600, 0.000020, 0.036000},
	{{0, 5, -4, 0, -1, 0, 0, 0, -2, 1, 0}, 271.486610, 0.000020, 0.134000},
	{{0, 5, -4, 0, -1, 0, 0, 0, -2, 3, 0}, 271.486610, 0.000020, 0.052000},
	{{0, 5, -4, 0, -1, 0, 0, 0, 0, 0, 0}, 91.470960, 0.000070, 0.247000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 272.947200, 0.000030, 0.049000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 341.994790, 0.000080, 0.136000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 13.309820, 0.000040, 0.124000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 193.297030, 0.000210, 0.046000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 193.289190, 0.000180, 0.193000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 193.290200, 0.000050, 0.119000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 193.309820, 0.000040, 0.054000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 344.756290, 0.000130, 0.110000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 3.111810, 0.000070, 0.242000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 340.321410, 0.000070, 0.058000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 193.325100, 0.000140, 0.098000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 193.325390, 0.000190, 0.060000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 13.324310, 0.000350, 0.325000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 13.324780, 0.000170, 0.033000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 13.325100, 0.000140, 0.061000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 355.787790, 0.000020, 0.425000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 173.446400, 0.000680, 0.064000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 352.660510, 0.000500, 0.035000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 351.610540, 0.000060, 0.024000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 3, -1, -1}, 13.322350, 0.000060, 0.069000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 3, 0, -1}, 13.327470, 0.000020, 0.036000},
	{{0, 5, -3, 0, -1, 0, 0, 0, -2, 0, 0}, 179.843340, 0.000020, 0.051000},
	{{0, 5, -3, 0, -1, 0, 0, 0, -2, 2, 0}, 179.843340, 0.000020, 0.147000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 123.760400, 0.000230, 0.051000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 114.639140, 0.000040, 0.157000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 115.281840, 0.000080, 0.123000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 293.156050, 0.000470, 0.195000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 296.266130, 0.000130, 0.054000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 272.731110, 0.000020, 0.101000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 298.007620, 0.000260, 0.060000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 121.916080, 0.000170, 0.033000},
	{{0, 5, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 19.615030, 0.000020, 0.054000},
	{{0, 5, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 19.615030, 0.000020, 0.127000},
	{{0, 5, -2, 0, 1, 0, 0, 0, 2, 0, 0}, 35.385160, 0.000030, 0.032000},
	{{0, 5, -1, 0, -1, 0, 0, 0, 2, 0, 0}, 55.660430, 0.000060, 0.031000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, 2, 0}, 38.212470, 0.000020, 0.017000},
	{{0, 5, -1, 0, 1, 0, 0, 0, 2, -2, 0}, 28.622640, 0.000040, 0.184000},
	{{0, 5, -1, 0, 1, 0, 0, 0, 2, 0, 0}, 208.622640, 0.000040, 0.031000},
	{{0, 5, 0, 0, -1, 0, 0, 0, 2, 0, 0}, 38.783760, 0.000030, 0.031000},
	{{0, 5, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 32.050320, 0.000040, 0.060000},
	{{0, 5, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 212.050320, 0.000040, 0.101000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 309.605420, 0.000020, 0.037000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 129.605420, 0.000020, 2.115000},
	{{0, 6, -12, 2, 0, 0, 0, 0, -2, 0, 0}, 321.762220, 0.000030, 0.039000},
	{{0, 6, -12, 2, 0, 0, 0, 0, -2, 2, 0}, 141.762220, 0.000030, 1.693000},
	{{0, 6, -11, 0, -1, 0, 0, 0, -2, 1, 0}, 62.713390, 0.000020, 0.078000},
	{{0, 6, -11, 0, -1, 0, 0, 0, -2, 3, 0}, 62.713390, 0.000020, 0.073000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 68.220180, 0.000030, 0.038000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 287.217630, 0.000040, 0.079000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 248.220180, 0.000030, 1.897000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 107.217630, 0.000040, 0.073000},
	{{0, 6, -11, 0, 1, 0, 0, 0, 0, -1, 0}, 140.436740, 0.000030, 0.069000},
	{{0, 6, -11, 0, 1, 0, 0, 0, 0, 1, 0}, 320.436740, 0.000030, 0.083000},
	{{0, 6, -11, 0, 2, 0, 0, 0, -2, 1, 0}, 21.957400, 0.000030, 0.080000},
	{{0, 6, -11, 0, 2, 0, 0, 0, -2, 3, 0}, 201.957400, 0.000030, 0.072000},
	{{0, 6, -11, 0, 3, 0, 0, 0, 2, -1, 0}, 305.901020, 0.000030, 0.095000},
	{{0, 6, -11, 0, 3, 0, 0, 0, 2, 0, 0}, 305.901020, 0.000080, 0.042000},
	{{0, 6, -10, -3, 0, 0, 0, 0, -2, 1, 0}, 176.499690, 0.000020, 0.075000},
	{{0, 6, -10, -3, 0, 0, 0, 0, -2, 3, 0}, 356.499690, 0.000020, 0.076000},
	{{0, 6, -10, 0, -1, 0, 0, 0, -2, 1, 0}, 331.626130, 0.000060, 0.085000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, -2, 0}, 141.704940, 0.000020, 0.019000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 233.038790, 0.000070, 0.040000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 225.528280, 0.000060, 0.085000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 325.935030, 0.000030, 0.655000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 325.143850, 0.000030, 0.068000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 288.196440, 0.000050, 0.074000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 108.196440, 0.000050, 0.077000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 65.702100, 0.000070, 0.089000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 67.678150, 0.000130, 0.041000},
	{{0, 6, -10, 0, 1, 0, 0, 0, -2, 1, 0}, 129.000000, 0.000030, 0.086000},
	{{0, 6, -10, 0, 1, 0, 0, 0, -2, 3, 0}, 129.000000, 0.000030, 0.067000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, -1, 0}, 23.079240, 0.000040, 0.026000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 0, 0}, 23.026840, 0.000470, 0.040000},
	{{0, 6, -10, 0, 3, 0, 0, 0, -2, 1, 0}, 23.746120, 0.000380, 0.087000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, -2, 0}, 19.908050, 0.000030, 0.038000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, -1, 0}, 20.532950, 0.000630, 0.075000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 1, 0}, 200.529120, 0.000630, 0.075000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 0, 2, 0}, 199.907110, 0.000030, 0.038000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, -1, 0}, 203.740930, 0.000370, 0.087000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, 0, 0}, 203.018710, 0.000470, 0.040000},
	{{0, 6, -10, 0, 3, 0, 0, 0, 2, 1, 0}, 203.070830, 0.000040, 0.026000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 160.255150, 0.000040, 0.027000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 157.370670, 0.000440, 0.042000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 162.960820, 0.000250, 0.093000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -1, -1, 1}, 336.551870, 0.000050, 0.087000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 157.561680, 0.000390, 0.080000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 338.881640, 0.000130, 1.328000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 341.127620, 0.000410, 0.071000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -1, 1}, 336.551870, 0.000280, 0.075000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 340.050780, 0.000140, 0.076000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 175.523520, 0.000560, 0.082000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 178.705450, 0.000050, 0.039000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 4, -3, 0}, 179.321380, 0.000030, 0.096000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 180.090160, 0.000090, 0.042000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 4, -1, 0}, 180.180630, 0.000040, 0.027000},
	{{0, 6, -9, 2, 0, 0, 0, 0, 2, -3, 0}, 91.524690, 0.000030, 0.076000},
	{{0, 6, -9, 2, 0, 0, 0, 0, 2, -1, 0}, 271.524690, 0.000030, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 77.243010, 0.000120, 0.028000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 318.072710, 0.000050, 0.044000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 263.819450, 0.000150, 0.103000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -3, 0}, 258.187630, 0.000020, 0.026000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 259.318390, 0.000150, 0.040000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 77.136630, 0.011650, 0.087000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 256.865830, 0.001760, 0.570000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 253.644040, 0.000370, 0.067000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, -1, -1}, 258.986090, 0.000090, 0.080000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, -1, 1}, 258.988290, 0.000060, 0.070000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 72.241780, 0.000090, 0.071000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 78.988280, 0.000060, 0.036000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 1, 1, -1}, 78.986090, 0.000090, 0.072000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -4, 0}, 258.849500, 0.000100, 0.038000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 258.845540, 0.001830, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 257.192700, 0.003910, 47.898000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, -2}, 257.246240, 0.000260, 0.073000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 77.220870, 0.070540, 0.076000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 79.101730, 0.000070, 0.077000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 77.622490, 0.004390, 0.038000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 77.317510, 0.000280, 0.025000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -4, 0}, 254.515290, 0.000030, 0.557000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -3, 0}, 76.370240, 0.000740, 0.087000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 77.154860, 0.001540, 0.040000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 77.230090, 0.000670, 0.026000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 77.244430, 0.000070, 0.020000},
	{{0, 6, -8, 0, 1, 0, 0, 0, 2, -1, 0}, 154.226290, 0.000120, 0.075000},
	{{0, 6, -8, 0, 2, 0, 0, 0, 2, -3, 0}, 84.657480, 0.000020, 0.076000},
	{{0, 6, -8, 0, 2, 0, 0, 0, 2, -1, 0}, 264.657480, 0.000020, 0.075000},
	{{0, 6, -8, 2, 0, 0, 0, 0, 2, -2, 0}, 90.171230, 0.000020, 0.959000},
	{{0, 6, -8, 2, 0, 0, 0, 0, 2, 0, 0}, 270.171230, 0.000020, 0.036000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 179.733260, 0.000340, 0.045000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 174.372870, 0.000090, 0.115000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 188.177380, 0.000030, 0.221000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, -1, 1}, 346.307800, 0.000030, 0.106000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 166.268610, 0.000170, 0.043000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 166.295170, 0.000070, 0.263000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 1, 1}, 166.307800, 0.000030, 0.059000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 170.980710, 0.000060, 0.042000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 236.353410, 0.000280, 0.095000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 177.528290, 0.000590, 0.363000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 181.883270, 0.000940, 0.062000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 181.640350, 0.000020, 0.034000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 166.252520, 0.000300, 0.087000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 168.120120, 0.000210, 0.065000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 346.295550, 0.000240, 0.588000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 1.972070, 0.000130, 0.066000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 346.296170, 0.000100, 0.035000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 346.276020, 0.000180, 0.067000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 359.691280, 0.000370, 1.021000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 180.878190, 0.007940, 0.070000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, -1}, 166.249240, 0.000070, 0.071000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 3.557730, 0.002100, 0.036000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 2.153140, 0.000130, 0.025000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -2, -1}, 346.216480, 0.000040, 13.397000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -2, 0}, 2.304870, 0.000110, 0.075000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -1, -1}, 166.219480, 0.000700, 0.076000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, 0, 0}, 2.444430, 0.000040, 0.025000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, -2, 0}, 183.388390, 0.000090, 0.039000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 356.366020, 0.000020, 0.019000},
	{{0, 6, -7, 0, 1, 0, 0, 0, -2, 0, 0}, 280.417290, 0.000090, 0.046000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 0, -2, 0}, 88.837090, 0.000020, 0.042000},
	{{0, 6, -7, 0, 1, 0, 0, 0, 0, 0, 0}, 88.837090, 0.000020, 0.352000},
	{{0, 6, -6, 0, -1, 0, 0, 0, -2, 0, 0}, 279.529930, 0.000050, 0.047000},
	{{0, 6, -6, 0, -1, 0, 0, 0, 2, 0, 0}, 276.663770, 0.000040, 0.035000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 269.627010, 0.000110, 0.048000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 273.945900, 0.000050, 0.129000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 273.354110, 0.000120, 0.181000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 89.943840, 0.000060, 0.116000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 268.151150, 0.000040, 0.044000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 271.078520, 0.000580, 0.105000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, -2}, 269.992020, 0.000060, 0.043000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 90.095040, 0.005270, 0.266000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 90.010850, 0.003820, 0.059000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 90.002050, 0.000300, 0.033000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 270.019500, 0.000560, 0.062000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 100.451560, 0.000060, 0.034000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 270.021470, 0.001020, 0.505000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, -2}, 270.019240, 0.000070, 0.086000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 90.041770, 0.021960, 0.066000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, -2}, 90.033070, 0.000050, 0.608000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 270.063890, 0.012370, 0.035000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 1, -2}, 270.029860, 0.000030, 0.067000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 270.028800, 0.000680, 0.024000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 270.017320, 0.000100, 0.018000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, -2, 0}, 270.066240, 0.000050, 0.070000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, -1, 0}, 90.065720, 0.000070, 0.036000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 3, 0, 0}, 270.065690, 0.000220, 0.024000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -2, 0}, 90.020280, 0.000250, 0.037000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, -1, 0}, 270.041360, 0.000020, 0.025000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, 0, 0}, 270.025130, 0.000200, 0.019000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 4, 2, 0}, 270.033050, 0.000020, 0.013000},
	{{0, 6, -6, 0, 1, 0, 0, 0, -2, 0, 0}, 76.059120, 0.000050, 0.048000},
	{{0, 6, -6, 0, 1, 0, 0, 0, 2, 0, 0}, 76.339150, 0.000030, 0.035000},
	{{0, 6, -5, 0, -1, 0, 0, 0, 0, 0, 0}, 91.506690, 0.000080, 0.214000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 177.547220, 0.000100, 0.050000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 345.150500, 0.000060, 0.149000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 184.256830, 0.000030, 0.153000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, -1}, 193.280050, 0.000160, 0.048000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 193.278070, 0.000140, 0.172000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 337.302350, 0.000060, 0.118000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 354.257420, 0.000060, 0.210000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 339.580250, 0.000030, 0.056000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 193.321740, 0.000100, 0.105000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 193.321540, 0.000110, 0.058000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 13.321300, 0.000310, 0.270000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 13.321230, 0.000140, 0.033000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 13.321740, 0.000100, 0.059000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 176.156270, 0.000550, 0.062000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 353.841260, 0.000490, 0.034000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 354.499820, 0.000070, 0.023000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 120.186390, 0.000200, 0.053000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 115.439680, 0.000060, 0.133000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 294.200190, 0.000410, 0.174000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 296.307560, 0.000100, 0.053000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 39.899210, 0.000030, 0.251000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 298.006740, 0.000190, 0.058000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 124.075710, 0.000170, 0.033000},
	{{0, 6, -2, 0, -1, 0, 0, 0, 2, 0, 0}, 63.608970, 0.000060, 0.031000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 218.239430, 0.000030, 0.182000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 38.239430, 0.000030, 0.048000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 218.212270, 0.000020, 0.031000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, 2, 0}, 38.212270, 0.000020, 0.017000},
	{{0, 6, -2, 0, 1, 0, 0, 0, 2, 0, 0}, 208.638800, 0.000070, 0.031000},
	{{0, 6, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 32.033200, 0.000030, 0.063000},
	{{0, 6, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 212.033200, 0.000030, 0.095000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 306.984080, 0.000030, 0.143000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 126.984080, 0.000030, 0.030000},
	{{0, 6, 0, -2, 0, 0, 0, 0, 2, -2, 0}, 38.300590, 0.000020, 0.145000},
	{{0, 6, 0, -2, 0, 0, 0, 0, 2, 0, 0}, 218.300590, 0.000020, 0.030000},
	{{0, 7, -19, 11, 0, 0, 0, 0, -2, 1, 0}, 248.556360, 0.000040, 0.075000},
	{{0, 7, -19, 11, 0, 0, 0, 0, -2, 3, 0}, 68.556360, 0.000040, 0.075000},
	{{0, 7, -14, 5, 0, 0, 0, 0, 0, -1, 0}, 19.176360, 0.000030, 0.076000},
	{{0, 7, -14, 5, 0, 0, 0, 0, 0, 1, 0}, 199.176360, 0.000030, 0.075000},
	{{0, 7, -13, 0, -1, 0, 0, 0, -2, 1, 0}, 141.983800, 0.000070, 0.076000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 309.962420, 0.000020, 0.038000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 23.693860, 0.000020, 0.076000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 129.962420, 0.000020, 6.550000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 353.675460, 0.000030, 0.075000},
	{{0, 7, -13, 0, 2, 0, 0, 0, -2, 0, 0}, 141.577780, 0.000020, 0.038000},
	{{0, 7, -13, 0, 2, 0, 0, 0, -2, 2, 0}, 321.577780, 0.000020, 3.113000},
	{{0, 7, -13, 0, 3, 0, 0, 0, -2, 1, 0}, 131.586680, 0.000030, 0.078000},
	{{0, 7, -13, 0, 3, 0, 0, 0, -2, 3, 0}, 311.586680, 0.000030, 0.073000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 0, 0}, 321.752980, 0.000030, 0.040000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 1, 0}, 321.752980, 0.000030, 0.083000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 2, 0}, 141.752980, 0.000030, 0.822000},
	{{0, 7, -13, 2, 0, 0, 0, 0, -2, 3, 0}, 141.752980, 0.000030, 0.069000},
	{{0, 7, -13, 2, 0, 0, 0, 0, 0, -1, 0}, 141.752980, 0.000020, 0.072000},
	{{0, 7, -13, 2, 0, 0, 0, 0, 0, 1, 0}, 321.752980, 0.000020, 0.079000},
	{{0, 7, -13, 3, 0, 0, 0, 0, 0, -1, 0}, 110.157360, 0.000040, 0.075000},
	{{0, 7, -13, 3, 0, 0, 0, 0, 0, 1, 0}, 290.157360, 0.000040, 0.076000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 67.048170, 0.000030, 0.039000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 83.342110, 0.000050, 0.083000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 247.048170, 0.000030, 0.868000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 263.342110, 0.000050, 0.069000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 235.153130, 0.000120, 0.041000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 213.334840, 0.000060, 0.090000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 328.164730, 0.000020, 0.465000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 322.021220, 0.000030, 0.065000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 285.575530, 0.000020, 0.038000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 220.281570, 0.000100, 0.078000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 105.575530, 0.000020, 2.641000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 40.281570, 0.000100, 0.073000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 66.992060, 0.000040, 0.084000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 63.811870, 0.000040, 0.040000},
	{{0, 7, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 128.958300, 0.000040, 0.041000},
	{{0, 7, -11, 0, 1, 0, 0, 0, -2, 2, 0}, 308.958300, 0.000040, 0.447000},
	{{0, 7, -11, 0, 1, 0, 0, 0, 0, -1, 0}, 128.920480, 0.000030, 0.078000},
	{{0, 7, -11, 0, 1, 0, 0, 0, 0, 1, 0}, 308.920480, 0.000030, 0.073000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 354.102660, 0.000220, 0.043000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 344.318940, 0.000060, 0.099000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 164.253300, 0.000100, 0.084000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 343.618030, 0.000030, 2.529000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 164.253010, 0.000570, 0.078000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 163.580280, 0.000210, 0.038000},
	{{0, 7, -10, 0, 3, 0, 0, 0, 2, -3, 0}, 171.503090, 0.000020, 0.075000},
	{{0, 7, -10, 0, 3, 0, 0, 0, 2, -1, 0}, 124.085130, 0.000050, 0.076000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 259.387400, 0.000130, 0.045000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 257.047810, 0.000030, 0.110000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 261.318260, 0.000210, 0.092000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 247.625300, 0.000120, 0.420000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 255.690810, 0.000210, 0.064000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, -1, -1}, 258.924850, 0.000040, 0.084000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 73.250730, 0.000050, 0.068000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 78.938600, 0.000050, 0.035000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 1, -1}, 78.924850, 0.000040, 0.069000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 81.171940, 0.000060, 0.079000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 79.635650, 0.000110, 1.654000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 258.567500, 0.002350, 0.072000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 82.880210, 0.000370, 0.037000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 79.294440, 0.000050, 0.025000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 257.872370, 0.000030, 0.039000},
	{{0, 7, -9, 0, 1, 0, 0, 0, 2, -3, 0}, 359.896320, 0.000020, 0.080000},
	{{0, 7, -9, 0, 1, 0, 0, 0, 2, -1, 0}, 179.896320, 0.000020, 0.072000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 5.054420, 0.000030, 0.047000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 181.840780, 0.000080, 0.123000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, -1}, 166.130570, 0.000110, 0.045000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 166.145640, 0.000050, 0.226000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 182.415180, 0.000160, 0.101000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 181.167780, 0.000560, 0.296000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 182.037230, 0.000750, 0.060000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, -1, -1}, 166.143140, 0.000110, 0.091000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, -1, 1}, 166.151140, 0.000100, 0.063000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 346.150280, 0.000200, 0.430000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 1.934500, 0.000090, 0.064000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 346.151170, 0.000070, 0.034000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 1, -1}, 346.143140, 0.000110, 0.064000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 1.309670, 0.000030, 0.086000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 1.607360, 0.000180, 0.623000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 182.057350, 0.004310, 0.067000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, -1}, 168.112150, 0.000040, 0.068000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 3.061510, 0.002110, 0.036000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 2.290660, 0.000120, 0.024000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 3, -1, -1}, 353.822260, 0.000080, 0.072000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 3, 0, 0}, 2.438060, 0.000040, 0.025000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 181.852330, 0.000050, 0.038000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 357.158380, 0.000020, 0.019000},
	{{0, 7, -8, 0, 1, 0, 0, 0, -2, 0, 0}, 281.584500, 0.000090, 0.047000},
	{{0, 7, -7, 0, -1, 0, 0, 0, -2, 0, 0}, 277.541660, 0.000050, 0.049000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 270.939790, 0.000030, 0.030000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 270.841120, 0.000580, 0.049000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 270.307730, 0.000090, 0.141000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 269.863450, 0.000150, 0.163000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 89.946560, 0.000050, 0.125000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 269.754190, 0.000050, 0.045000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 270.567170, 0.000760, 0.113000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, -2}, 269.983200, 0.000050, 0.045000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 90.047900, 0.004300, 0.228000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 90.041250, 0.002680, 0.057000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 90.166100, 0.000210, 0.032000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 270.011310, 0.000320, 0.060000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 100.730270, 0.000060, 0.033000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 270.194730, 0.000630, 0.384000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, -2}, 270.026900, 0.000080, 0.091000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 90.025470, 0.013900, 0.063000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, -2}, 90.023030, 0.000110, 0.440000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 270.020810, 0.010130, 0.034000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 1, -2}, 90.029000, 0.000020, 0.064000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 270.008150, 0.000600, 0.024000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 2, 0}, 270.002770, 0.000080, 0.018000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 3, -1, 0}, 90.062550, 0.000070, 0.035000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 3, 0, 0}, 270.062510, 0.000210, 0.024000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, -2, 0}, 89.925720, 0.000180, 0.037000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, -1, 0}, 269.992950, 0.000060, 0.025000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 270.011170, 0.000150, 0.019000},
	{{0, 7, -7, 0, 1, 0, 0, 0, -2, 0, 0}, 76.204780, 0.000050, 0.049000},
	{{0, 7, -6, 0, -1, 0, 0, 0, 0, 0, 0}, 91.508850, 0.000070, 0.189000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 198.052900, 0.000020, 0.052000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 347.104780, 0.000020, 0.164000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 198.302150, 0.000020, 0.140000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 193.266810, 0.000260, 0.049000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 193.475850, 0.000090, 0.155000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 330.053510, 0.000030, 0.127000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, -1, -1}, 193.315720, 0.000080, 0.112000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 193.315410, 0.000080, 0.056000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 13.315480, 0.000280, 0.231000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 13.315120, 0.000110, 0.032000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 1, -1}, 13.315720, 0.000080, 0.057000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 178.102360, 0.000440, 0.059000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 355.185230, 0.000450, 0.033000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 356.303210, 0.000060, 0.023000},
	{{0, 7, -5, 0, -2, 0, 0, 0, 0, -2, 0}, 89.984220, 0.000050, 0.049000},
	{{0, 7, -5, 0, -2, 0, 0, 0, 0, 0, 0}, 269.984220, 0.000050, 0.161000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 117.189650, 0.000310, 0.054000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 116.550620, 0.000050, 0.145000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 294.281940, 0.000350, 0.157000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 296.322150, 0.000080, 0.051000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 41.927100, 0.000020, 0.217000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 295.961220, 0.000160, 0.056000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 123.898960, 0.000160, 0.032000},
	{{0, 7, -4, 0, 1, 0, 0, 0, 2, -2, 0}, 39.105920, 0.000020, 0.176000},
	{{0, 7, -4, 0, 1, 0, 0, 0, 2, 0, 0}, 219.105920, 0.000020, 0.031000},
	{{0, 7, -3, 0, -1, 0, 0, 0, 2, -2, 0}, 54.702190, 0.000030, 0.153000},
	{{0, 7, -3, 0, -1, 0, 0, 0, 2, 0, 0}, 54.702190, 0.000030, 0.030000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 218.235840, 0.000030, 0.205000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 38.235840, 0.000030, 0.046000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 218.025870, 0.000020, 0.151000},
	{{0, 7, -3, 0, 1, 0, 0, 0, 2, 0, 0}, 208.650660, 0.000060, 0.030000},
	{{0, 7, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 32.012200, 0.000040, 0.065000},
	{{0, 7, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 212.012200, 0.000040, 0.090000},
	{{0, 7, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 236.633920, 0.000040, 0.075000},
	{{0, 7, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 56.633920, 0.000040, 0.076000},
	{{0, 8, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 19.622370, 0.000030, 0.035000},
	{{0, 8, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 199.622370, 0.000030, 0.450000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 216.045490, 0.000030, 0.074000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 3, 0}, 36.045490, 0.000030, 0.077000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 193.764680, 0.000020, 0.066000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 13.764680, 0.000020, 0.089000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 353.703820, 0.000070, 0.105000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 353.494740, 0.000180, 0.044000},
	{{0, 8, -15, 0, 2, 0, 0, 0, -2, 1, 0}, 234.676560, 0.000030, 0.075000},
	{{0, 8, -15, 0, 3, 0, 0, 0, -2, 1, 0}, 41.040690, 0.000020, 0.076000},
	{{0, 8, -15, 0, 3, 0, 0, 0, -2, 3, 0}, 221.040690, 0.000020, 0.075000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 250.396030, 0.000040, 0.026000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 251.792200, 0.000220, 0.039000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 251.028590, 0.000070, 0.080000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 72.871960, 0.000240, 0.070000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 77.619910, 0.000230, 1.004000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 248.871020, 0.000680, 0.082000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 2, 0}, 248.420280, 0.000040, 0.039000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 71.516800, 0.000110, 0.361000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 250.783710, 0.001920, 0.095000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 249.779750, 0.003020, 0.042000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 250.033880, 0.000290, 0.027000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 4, -2, 0}, 250.237730, 0.000030, 0.046000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 4, -1, 0}, 250.426380, 0.000090, 0.028000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 4, 0, 0}, 250.085340, 0.000060, 0.021000},
	{{0, 8, -14, 2, 0, 0, 0, 0, -2, 0, 0}, 321.741570, 0.000030, 0.041000},
	{{0, 8, -14, 2, 0, 0, 0, 0, -2, 2, 0}, 141.741570, 0.000030, 0.543000},
	{{0, 8, -14, 2, 0, 0, 0, 0, 0, -1, 0}, 132.040440, 0.000020, 0.076000},
	{{0, 8, -14, 2, 0, 0, 0, 0, 0, 1, 0}, 312.040440, 0.000020, 0.075000},
	{{0, 8, -13, 0, -1, 0, 0, 0, 0, -1, 0}, 241.610170, 0.000020, 0.075000},
	{{0, 8, -13, 0, -1, 0, 0, 0, 0, 1, 0}, 61.610170, 0.000020, 0.076000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, -1, 0}, 322.169260, 0.000030, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 0, 0}, 324.945010, 0.000250, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 1, 0}, 327.639960, 0.000660, 0.028000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 2, 0}, 326.237610, 0.000340, 0.044000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -3, 0, 0}, 327.993060, 0.000100, 0.027000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -3, 1, 0}, 147.896620, 0.000050, 0.042000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -2, 0}, 326.886920, 0.000270, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 326.264340, 0.002010, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, 2}, 147.887440, 0.000030, 0.090000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 327.344660, 0.030050, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 2}, 147.217900, 0.000120, 0.474000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 328.084760, 0.031250, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, 2}, 147.202510, 0.000080, 0.065000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 151.185840, 0.001720, 0.562000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 149.889670, 0.000120, 0.067000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, -1, 0}, 145.675010, 0.000030, 0.039000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 145.354160, 0.000530, 0.081000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -1, 1, 0}, 325.582260, 0.000030, 1.122000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -3, 0}, 324.127680, 0.000110, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 322.921060, 0.001840, 0.038000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 323.441380, 0.035770, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 2}, 143.246130, 0.000130, 0.074000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 155.204470, 0.000080, 238.919000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, -2}, 323.246130, 0.000130, 0.074000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 143.433500, 0.035740, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 143.211800, 0.001830, 0.038000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 3, 0}, 143.076870, 0.000110, 0.025000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, -1, 0}, 147.883980, 0.000030, 1.133000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 328.029370, 0.000530, 0.081000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 1, 1, 0}, 327.883310, 0.000030, 0.039000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 329.792370, 0.000120, 0.067000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 329.106870, 0.001680, 0.565000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, -2}, 327.196530, 0.000080, 0.065000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 148.047000, 0.031030, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, -2}, 327.082220, 0.000120, 0.475000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 147.210640, 0.029750, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, -2}, 327.852420, 0.000030, 0.090000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 146.297090, 0.001990, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 2, 0}, 146.828600, 0.000270, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 3, -1, 0}, 327.847540, 0.000050, 0.042000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 3, 0, 0}, 147.940740, 0.000100, 0.027000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -2, 0}, 147.954110, 0.000340, 0.044000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, -1, 0}, 147.452420, 0.000650, 0.028000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, 0, 0}, 144.766630, 0.000250, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 4, 1, 0}, 146.410330, 0.000030, 0.016000},
	{{0, 8, -13, 0, 1, 0, 0, 0, 0, -1, 0}, 250.867950, 0.000030, 0.076000},
	{{0, 8, -13, 0, 1, 0, 0, 0, 0, 1, 0}, 70.867950, 0.000030, 0.075000},
	{{0, 8, -12, -2, 0, 0, 0, 0, 0, -1, 0}, 12.329720, 0.000020, 0.075000},
	{{0, 8, -12, -2, 0, 0, 0, 0, 0, 1, 0}, 192.329720, 0.000020, 0.076000},
	{{0, 8, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 331.630380, 0.000030, 0.042000},
	{{0, 8, -12, 0, -1, 0, 0, 0, -2, 2, 0}, 151.630380, 0.000030, 0.371000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -4, 0, 0}, 234.029510, 0.000020, 0.021000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -4, 1, 0}, 206.696080, 0.000080, 0.028000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 199.575180, 0.000200, 0.027000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 190.189650, 0.001310, 0.042000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 182.872600, 0.000740, 0.095000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 303.358220, 0.000030, 0.360000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 68.446940, 0.000020, 0.039000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 89.387500, 0.000630, 0.082000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 256.046860, 0.000270, 0.996000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 250.618400, 0.000830, 0.070000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 251.917050, 0.000040, 0.036000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, -1, -1}, 63.461510, 0.000060, 0.075000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 67.304640, 0.000140, 0.075000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 1, -1}, 243.461510, 0.000060, 0.076000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 238.992540, 0.000320, 0.080000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 239.297320, 0.000500, 0.039000},
	{{0, 8, -12, 0, 1, 0, 0, 0, -2, 0, 0}, 129.130310, 0.000050, 0.042000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 25.671200, 0.000150, 0.044000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 15.119230, 0.000040, 0.106000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 231.872920, 0.000020, 0.265000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 346.015520, 0.000160, 0.089000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 138.518720, 0.000020, 0.499000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 166.424890, 0.000050, 4.345000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 346.015700, 0.000930, 0.074000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 336.357440, 0.000040, 0.075000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 163.803000, 0.000130, 0.037000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 258.443580, 0.000020, 0.118000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 274.199220, 0.000040, 0.098000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 254.245490, 0.000200, 0.333000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 257.243140, 0.000160, 0.062000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 78.884880, 0.000040, 0.035000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 75.847350, 0.000020, 0.083000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 84.131290, 0.000060, 0.813000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 260.882200, 0.001110, 0.069000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 83.167390, 0.000380, 0.036000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 1, 0}, 80.554940, 0.000040, 0.024000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 3, -1, -1}, 78.884980, 0.000040, 0.074000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 3, 0, -2}, 79.944390, 0.000110, 0.075000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 0.471260, 0.000120, 0.048000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 182.351710, 0.000080, 0.134000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 165.954570, 0.000090, 0.046000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 185.173330, 0.000030, 0.108000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 180.501420, 0.000510, 0.250000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 182.285440, 0.000570, 0.058000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 193.642670, 0.000020, 0.033000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 3, 0}, 183.020190, 0.000020, 0.023000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, -1, -1}, 165.952270, 0.000070, 0.097000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, -1, 1}, 165.980020, 0.000070, 0.060000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 345.978910, 0.000160, 0.339000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 2.112000, 0.000070, 0.061000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 345.980010, 0.000170, 0.034000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 1, -1}, 345.952270, 0.000070, 0.062000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 13.101830, 0.000060, 0.091000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 346.036750, 0.000120, 0.448000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 182.669420, 0.002860, 0.065000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 4.023130, 0.001890, 0.035000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 3.210280, 0.000140, 0.024000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 3, 0, 0}, 2.434990, 0.000040, 0.024000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 191.454310, 0.000050, 0.037000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 4, -1, 0}, 2.440900, 0.000050, 0.025000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 4, 0, 0}, 6.072320, 0.000040, 0.019000},
	{{0, 8, -9, 0, 1, 0, 0, 0, -2, 0, 0}, 282.749830, 0.000080, 0.048000},
	{{0, 8, -9, 0, 1, 0, 0, 0, 2, -1, 0}, 88.698900, 0.000050, 0.064000},
	{{0, 8, -8, 0, -1, 0, 0, 0, -2, 0, 0}, 275.459920, 0.000050, 0.050000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 270.593940, 0.000030, 0.030000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 270.443660, 0.000610, 0.051000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 270.044550, 0.000340, 0.154000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 270.038200, 0.000120, 0.148000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 89.935650, 0.000030, 0.136000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 271.230190, 0.000040, 0.046000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 269.999130, 0.000700, 0.121000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 90.067020, 0.003370, 0.200000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 90.015960, 0.001920, 0.055000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 89.249410, 0.000140, 0.032000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 270.011520, 0.000230, 0.058000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 100.976560, 0.000050, 0.032000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 2, 0}, 270.050780, 0.000020, 0.023000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 272.050430, 0.000030, 0.100000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 270.496270, 0.000410, 0.310000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, -2}, 270.011340, 0.000040, 0.097000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 90.010740, 0.009150, 0.061000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, -2}, 90.018100, 0.000090, 0.345000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 270.023450, 0.008190, 0.034000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 270.006490, 0.000540, 0.023000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 2, 0}, 270.005530, 0.000080, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 3, -1, 0}, 90.056850, 0.000060, 0.035000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 3, 0, 0}, 270.056820, 0.000190, 0.024000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, -2, 0}, 89.672410, 0.000100, 0.036000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, -1, 0}, 270.026890, 0.000060, 0.024000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 269.999680, 0.000130, 0.018000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 4, 1, 0}, 270.016220, 0.000020, 0.015000},
	{{0, 8, -8, 0, 1, 0, 0, 0, -2, 0, 0}, 76.333890, 0.000040, 0.051000},
	{{0, 8, -7, 0, -1, 0, 0, 0, 0, 0, 0}, 91.507980, 0.000070, 0.169000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 177.729340, 0.000020, 0.053000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 177.916590, 0.000020, 0.129000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 193.237330, 0.000240, 0.051000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 193.248710, 0.000070, 0.142000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 325.992900, 0.000040, 0.138000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 337.547440, 0.000030, 0.167000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 193.307070, 0.000060, 0.120000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 193.306680, 0.000060, 0.054000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 13.422230, 0.000220, 0.202000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 13.306240, 0.000070, 0.031000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 13.307070, 0.000060, 0.055000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 179.500400, 0.000380, 0.057000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 355.972490, 0.000420, 0.033000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 357.458390, 0.000040, 0.023000},
	{{0, 8, -6, 0, -2, 0, 0, 0, 0, -2, 0}, 89.886800, 0.000020, 0.051000},
	{{0, 8, -6, 0, -2, 0, 0, 0, 0, 0, 0}, 269.886800, 0.000020, 0.146000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 116.770740, 0.000280, 0.056000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 116.295900, 0.000060, 0.160000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 294.564760, 0.000310, 0.143000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 296.295900, 0.000060, 0.049000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 293.822320, 0.000140, 0.054000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 120.339000, 0.000170, 0.032000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 38.208210, 0.000020, 0.111000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 218.208210, 0.000020, 0.028000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 218.069310, 0.000020, 0.049000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 38.069310, 0.000020, 0.021000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 149.198340, 0.000030, 0.073000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 329.198340, 0.000030, 0.078000},
	{{0, 9, -15, 0, 2, 0, 0, 0, -2, 1, 0}, 141.587030, 0.000060, 0.086000},
	{{0, 9, -15, 0, 3, 0, 0, 0, 0, -1, 0}, 311.574630, 0.000030, 0.075000},
	{{0, 9, -15, 0, 3, 0, 0, 0, 0, 1, 0}, 131.574630, 0.000030, 0.076000},
	{{0, 9, -15, 2, 0, 0, 0, 0, -2, 0, 0}, 321.728000, 0.000020, 0.042000},
	{{0, 9, -15, 2, 0, 0, 0, 0, -2, 2, 0}, 141.728000, 0.000020, 0.405000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 22.962620, 0.000070, 0.041000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 202.962620, 0.000070, 0.416000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 2, -3, 0}, 147.879530, 0.000030, 0.069000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 327.879530, 0.000030, 0.083000},
	{{0, 9, -14, 0, 1, 0, 0, 0, -2, 1, 0}, 320.387250, 0.000020, 0.093000},
	{{0, 9, -14, 0, 1, 0, 0, 0, -2, 3, 0}, 320.387250, 0.000020, 0.064000},
	{{0, 9, -14, 0, 1, 0, 0, 0, 0, -1, 0}, 320.387250, 0.000030, 0.080000},
	{{0, 9, -14, 0, 1, 0, 0, 0, 0, 1, 0}, 140.387250, 0.000030, 0.072000},
	{{0, 9, -13, -3, 0, 0, 0, 0, 0, -1, 0}, 356.567940, 0.000030, 0.076000},
	{{0, 9, -13, -3, 0, 0, 0, 0, 0, 1, 0}, 176.567940, 0.000030, 0.075000},
	{{0, 9, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 331.627320, 0.000060, 0.043000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 131.951710, 0.000020, 0.043000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 321.778650, 0.000030, 0.102000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 311.951710, 0.000020, 0.294000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 141.778650, 0.000030, 0.060000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 276.678370, 0.000050, 0.086000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 141.778640, 0.000020, 0.067000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 151.182130, 0.000040, 0.075000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 250.441200, 0.000230, 0.076000},
	{{0, 9, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 128.879190, 0.000060, 0.043000},
	{{0, 9, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 143.652730, 0.000060, 0.045000},
	{{0, 9, -12, 0, -1, 0, 0, 0, -2, 2, 0}, 320.813350, 0.000020, 0.232000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 30.044240, 0.000030, 0.045000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 210.044240, 0.000030, 0.227000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 345.255180, 0.000050, 0.094000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 345.255190, 0.000260, 0.071000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 165.215580, 0.000170, 0.037000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 71.933590, 0.000020, 0.047000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 251.992820, 0.000020, 0.185000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 256.381030, 0.000180, 0.276000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 258.529940, 0.000120, 0.059000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 78.825430, 0.000040, 0.034000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 82.173110, 0.000040, 0.539000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 262.205120, 0.000720, 0.066000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 81.704240, 0.000340, 0.035000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 80.986630, 0.000020, 0.024000},
	{{0, 9, -11, 0, 2, 0, 0, 0, 2, -2, 0}, 269.827190, 0.000020, 0.494000},
	{{0, 9, -11, 0, 2, 0, 0, 0, 2, 0, 0}, 89.827190, 0.000020, 0.035000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 178.531870, 0.000040, 0.146000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 188.636210, 0.000020, 0.051000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 165.751370, 0.000070, 0.047000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 180.648790, 0.000460, 0.216000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 182.160020, 0.000400, 0.056000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 182.302140, 0.000030, 0.032000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, -1, -1}, 173.445310, 0.000050, 0.103000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, -1, 1}, 165.781690, 0.000040, 0.058000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 345.780350, 0.000140, 0.280000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 2.017320, 0.000050, 0.059000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 345.781680, 0.000140, 0.033000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 1, -1}, 353.445310, 0.000050, 0.059000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 8.482780, 0.000020, 0.096000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 346.565400, 0.000070, 0.350000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 182.637060, 0.001990, 0.062000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 3.540670, 0.001710, 0.034000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 1, 0}, 2.698490, 0.000120, 0.023000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 3, 0, 0}, 2.433340, 0.000040, 0.024000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 4, -2, 0}, 189.155410, 0.000030, 0.036000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 4, -1, 0}, 2.243090, 0.000040, 0.024000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 4, 0, 0}, 6.864080, 0.000040, 0.018000},
	{{0, 9, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 288.797420, 0.000060, 0.050000},
	{{0, 9, -10, 0, 1, 0, 0, 0, -2, 2, 0}, 268.367670, 0.000020, 0.154000},
	{{0, 9, -9, 0, -1, 0, 0, 0, -2, 0, 0}, 273.307380, 0.000050, 0.052000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 270.518760, 0.000030, 0.031000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 270.501290, 0.000390, 0.052000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 270.519640, 0.000230, 0.171000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 268.798770, 0.000110, 0.135000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 89.972570, 0.000050, 0.148000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 270.240080, 0.000600, 0.131000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 90.072470, 0.002620, 0.178000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 90.112590, 0.001370, 0.053000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 90.807060, 0.000110, 0.031000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 270.117400, 0.000160, 0.056000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 101.192000, 0.000040, 0.032000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 270.011500, 0.000280, 0.259000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 89.994730, 0.006140, 0.058000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, -2}, 90.005900, 0.000070, 0.284000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 270.009880, 0.006490, 0.033000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 1, 0}, 270.004480, 0.000410, 0.023000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 2, 0}, 269.982270, 0.000040, 0.018000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 3, -1, 0}, 90.048640, 0.000050, 0.034000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 3, 0, 0}, 270.048610, 0.000170, 0.023000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, -2, 0}, 90.002590, 0.000070, 0.035000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, -1, 0}, 269.996230, 0.000030, 0.024000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, 0, 0}, 270.001070, 0.000100, 0.018000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 4, 1, 0}, 90.006520, 0.000020, 0.015000},
	{{0, 9, -9, 0, 1, 0, 0, 0, -2, 0, 0}, 76.447440, 0.000040, 0.053000},
	{{0, 9, -8, 0, -1, 0, 0, 0, 0, -2, 0}, 270.963080, 0.000020, 0.050000},
	{{0, 9, -8, 0, -1, 0, 0, 0, 0, 0, 0}, 91.368000, 0.000080, 0.153000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 0, -1}, 193.242130, 0.000210, 0.052000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 193.206950, 0.000040, 0.130000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, -1, -1}, 193.295820, 0.000040, 0.130000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, -1, 1}, 193.295370, 0.000050, 0.052000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 13.304980, 0.000180, 0.179000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 13.294690, 0.000040, 0.031000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 1, -1}, 13.295820, 0.000040, 0.053000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 179.357120, 0.000340, 0.055000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 356.290020, 0.000390, 0.032000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 358.088040, 0.000040, 0.022000},
	{{0, 9, -7, 0, -2, 0, 0, 0, 0, 0, 0}, 269.885450, 0.000050, 0.134000},
	{{0, 9, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 115.927870, 0.000250, 0.058000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 102.696480, 0.000050, 0.178000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 296.274100, 0.000260, 0.131000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 282.696480, 0.000050, 0.048000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 295.845870, 0.000110, 0.052000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 118.841640, 0.000140, 0.031000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 218.005480, 0.000020, 0.127000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 38.223700, 0.000030, 0.016000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 74.968430, 0.000020, 0.043000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 254.968430, 0.000020, 0.330000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -3, 0}, 327.880510, 0.000030, 0.073000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 147.880510, 0.000030, 0.079000},
	{{0, 10, -15, 0, 1, 0, 0, 0, -2, 1, 0}, 140.392330, 0.000030, 0.099000},
	{{0, 10, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 331.621050, 0.000060, 0.044000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 144.904830, 0.000040, 0.044000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 324.904830, 0.000040, 0.248000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 65.561170, 0.000070, 0.073000},
	{{0, 10, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 128.840740, 0.000030, 0.045000},
	{{0, 10, -14, 0, 1, 0, 0, 0, -2, 2, 0}, 128.840740, 0.000030, 0.243000},
	{{0, 10, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 143.638890, 0.000050, 0.046000},
	{{0, 10, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 140.807970, 0.000020, 0.202000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 346.345750, 0.000140, 0.068000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 165.988450, 0.000150, 0.036000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 76.903870, 0.000030, 0.049000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 256.927450, 0.000030, 0.166000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 255.995920, 0.000160, 0.235000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 259.548700, 0.000090, 0.057000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 263.399000, 0.000520, 0.064000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 82.621310, 0.000320, 0.034000},
	{{0, 10, -12, 0, 2, 0, 0, 0, 2, -2, 0}, 269.804600, 0.000030, 0.377000},
	{{0, 10, -12, 0, 2, 0, 0, 0, 2, 0, 0}, 89.804600, 0.000030, 0.034000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 2.723480, 0.000030, 0.051000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 178.368220, 0.000030, 0.161000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 188.046010, 0.000020, 0.049000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 165.519870, 0.000060, 0.049000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 0.999070, 0.000020, 0.125000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 181.538720, 0.000400, 0.190000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 182.214560, 0.000320, 0.054000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 345.553170, 0.000090, 0.238000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 345.554980, 0.000100, 0.032000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 18.455560, 0.000020, 0.102000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 11.132490, 0.000030, 0.287000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 182.575870, 0.001430, 0.060000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 3.196700, 0.001490, 0.033000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 2.360500, 0.000260, 0.023000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 3, 0, 0}, 2.432050, 0.000040, 0.024000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 4, -1, 0}, 2.412980, 0.000060, 0.024000},
	{{0, 10, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 305.608640, 0.000040, 0.052000},
	{{0, 10, -11, 0, 1, 0, 0, 0, 2, 0, 0}, 268.676550, 0.000050, 0.033000},
	{{0, 10, -10, 0, -1, 0, 0, 0, -2, 0, 0}, 271.886000, 0.000030, 0.054000},
	{{0, 10, -10, 0, -1, 0, 0, 0, -2, 2, 0}, 91.886000, 0.000030, 0.126000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, -1, 0}, 270.214680, 0.000050, 0.032000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 270.311340, 0.000560, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 268.847120, 0.000110, 0.125000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 269.993980, 0.000450, 0.143000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 89.946610, 0.002120, 0.160000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 89.994500, 0.000980, 0.051000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 91.601510, 0.000030, 0.031000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 270.119430, 0.000110, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 101.379940, 0.000040, 0.031000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 271.688270, 0.000020, 0.114000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 270.215320, 0.000180, 0.223000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 89.987670, 0.004200, 0.056000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, -2}, 89.993920, 0.000060, 0.241000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 270.002510, 0.005040, 0.032000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 1, 0}, 270.002270, 0.000320, 0.023000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 2, 0}, 269.994420, 0.000060, 0.017000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 3, -1, 0}, 90.037940, 0.000050, 0.033000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 3, 0, 0}, 270.037910, 0.000140, 0.023000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, -2, 0}, 89.774880, 0.000050, 0.034000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, -1, 0}, 270.006900, 0.000060, 0.024000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, 0, 0}, 269.999690, 0.000080, 0.018000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 4, 1, 0}, 269.991100, 0.000020, 0.014000},
	{{0, 10, -10, 0, 1, 0, 0, 0, -2, 0, 0}, 76.546740, 0.000020, 0.054000},
	{{0, 10, -10, 0, 1, 0, 0, 0, -2, 2, 0}, 256.546740, 0.000020, 0.123000},
	{{0, 10, -9, 0, -1, 0, 0, 0, 0, -2, 0}, 270.952860, 0.000020, 0.052000},
	{{0, 10, -9, 0, -1, 0, 0, 0, 0, 0, 0}, 91.357500, 0.000080, 0.139000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 193.218580, 0.000170, 0.054000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 193.212280, 0.000050, 0.120000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 13.285600, 0.000180, 0.161000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 13.281650, 0.000150, 0.030000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 182.316720, 0.000230, 0.053000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 357.152520, 0.000330, 0.031000},
	{{0, 10, -8, 0, -2, 0, 0, 0, 0, -2, 0}, 89.857240, 0.000020, 0.054000},
	{{0, 10, -8, 0, -2, 0, 0, 0, 0, 0, 0}, 269.857240, 0.000020, 0.124000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 115.901970, 0.000230, 0.061000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 296.631990, 0.000230, 0.121000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 295.821030, 0.000090, 0.051000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 115.836120, 0.000120, 0.030000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 38.214880, 0.000030, 0.098000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 218.214880, 0.000030, 0.027000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 218.197410, 0.000020, 0.209000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 38.197410, 0.000020, 0.046000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 218.649260, 0.000020, 0.029000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 38.649260, 0.000020, 0.016000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 89.179370, 0.000030, 0.044000},
	{{0, 10, -4, 0, -2, 0, 0, 0, 2, -2, 0}, 38.311900, 0.000020, 0.097000},
	{{0, 10, -4, 0, -2, 0, 0, 0, 2, 0, 0}, 218.311900, 0.000020, 0.027000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 346.242440, 0.000080, 0.039000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 346.242440, 0.000030, 0.080000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -1, -1, 0}, 166.242440, 0.000020, 0.075000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 346.242440, 0.000140, 0.070000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 346.242440, 0.000180, 0.082000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 346.242440, 0.000020, 0.039000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 346.242440, 0.000210, 0.095000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 346.242440, 0.000560, 0.042000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 346.242440, 0.000050, 0.027000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, -1, 0}, 63.305510, 0.000060, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 63.305510, 0.000140, 0.028000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 63.305510, 0.000060, 0.044000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -3, 0}, 63.305510, 0.000060, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -2, 0}, 63.305510, 0.000700, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 63.305510, 0.008070, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 63.580190, 0.005020, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 63.305510, 0.000020, 0.067000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -1, -1, 0}, 243.305510, 0.000150, 0.081000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -4, 0}, 63.305510, 0.000100, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 63.305510, 0.001560, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 63.106230, 0.028540, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, 2}, 63.305510, 0.000110, 0.074000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 248.462070, 0.000280, 1911.695000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 243.305510, 0.000110, 0.074000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 243.034140, 0.028730, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 243.305510, 0.001560, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 243.305510, 0.000100, 0.025000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 63.305510, 0.000150, 0.081000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -4, 0}, 243.305510, 0.000020, 0.067000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 243.504700, 0.005050, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 243.305510, 0.008070, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 243.305510, 0.000700, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 243.305510, 0.000060, 0.020000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -3, 0}, 243.305510, 0.000060, 0.044000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -2, 0}, 243.305510, 0.000140, 0.028000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 243.305510, 0.000060, 0.020000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 320.368580, 0.000050, 0.027000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 320.368580, 0.000560, 0.042000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 320.368580, 0.000210, 0.095000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, -3, 0}, 320.368580, 0.000020, 0.039000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 320.368580, 0.000180, 0.082000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 320.368580, 0.000140, 0.070000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 140.368580, 0.000020, 0.075000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 320.368580, 0.000030, 0.080000},
	{{0, 10, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 320.368580, 0.000080, 0.039000},
	{{0, 10, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 217.431650, 0.000030, 0.044000},
	{{0, 11, -17, 0, 2, 0, 0, 0, -2, 0, 0}, 141.550620, 0.000030, 0.042000},
	{{0, 11, -17, 0, 2, 0, 0, 0, -2, 2, 0}, 321.550620, 0.000030, 0.354000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 23.374600, 0.000020, 0.044000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 203.374600, 0.000020, 0.274000},
	{{0, 11, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 319.945970, 0.000020, 0.044000},
	{{0, 11, -16, 0, 1, 0, 0, 0, -2, 2, 0}, 139.945970, 0.000020, 0.267000},
	{{0, 11, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 331.611750, 0.000020, 0.046000},
	{{0, 11, -15, 0, -1, 0, 0, 0, -2, 2, 0}, 331.611750, 0.000020, 0.219000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 146.303520, 0.000020, 0.046000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 326.303520, 0.000020, 0.215000},
	{{0, 11, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 145.451740, 0.000030, 0.048000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 345.720150, 0.000090, 0.065000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 166.725590, 0.000140, 0.035000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 79.446230, 0.000040, 0.050000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 259.446230, 0.000040, 0.150000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 259.424940, 0.000150, 0.205000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 261.667170, 0.000060, 0.055000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 263.261300, 0.000370, 0.061000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 83.237310, 0.000310, 0.034000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 3.578310, 0.000040, 0.053000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 185.485970, 0.000040, 0.179000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 3.573350, 0.000020, 0.131000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 165.258840, 0.000050, 0.050000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 26.156590, 0.000030, 0.136000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 181.438260, 0.000390, 0.170000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 185.281030, 0.000250, 0.052000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 345.296200, 0.000060, 0.207000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 345.298590, 0.000080, 0.032000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 182.583500, 0.001010, 0.058000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 3.661160, 0.001240, 0.033000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 2.552780, 0.000220, 0.023000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 4, -1, 0}, 2.321860, 0.000050, 0.024000},
	{{0, 11, -12, 0, 1, 0, 0, 0, -2, 0, 0}, 307.269580, 0.000040, 0.053000},
	{{0, 11, -12, 0, 1, 0, 0, 0, 2, 0, 0}, 268.661620, 0.000040, 0.033000},
	{{0, 11, -11, 0, -1, 0, 0, 0, -2, 0, 0}, 270.050040, 0.000050, 0.056000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, -1, 0}, 270.021570, 0.000020, 0.032000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 270.768730, 0.000220, 0.056000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 85.533100, 0.000030, 0.217000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 268.378370, 0.000070, 0.116000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 275.441130, 0.000030, 0.046000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 93.368980, 0.000020, 0.051000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 269.985920, 0.000360, 0.157000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 89.951900, 0.001610, 0.145000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 89.701800, 0.000740, 0.050000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 89.969240, 0.000050, 0.030000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 269.984210, 0.000080, 0.052000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -3, 0}, 270.954190, 0.000020, 0.123000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 270.609900, 0.000130, 0.196000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 89.972840, 0.002850, 0.054000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, -2}, 89.981070, 0.000050, 0.210000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 269.995740, 0.003900, 0.032000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 270.000960, 0.000310, 0.022000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 2, 0}, 269.991570, 0.000030, 0.017000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 3, 0, 0}, 270.024760, 0.000120, 0.023000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 4, -2, 0}, 89.516020, 0.000040, 0.034000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 4, -1, 0}, 269.991160, 0.000120, 0.023000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 4, 0, 0}, 270.002590, 0.000060, 0.018000},
	{{0, 11, -11, 0, 1, 0, 0, 0, -2, 0, 0}, 76.633120, 0.000020, 0.056000},
	{{0, 11, -11, 0, 1, 0, 0, 0, -2, 2, 0}, 256.633120, 0.000020, 0.114000},
	{{0, 11, -10, 0, -1, 0, 0, 0, 0, 0, 0}, 91.394650, 0.000050, 0.128000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 193.189790, 0.000130, 0.056000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, 1}, 193.190010, 0.000040, 0.112000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 214.295650, 0.000020, 0.029000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 13.264030, 0.000170, 0.146000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 13.265200, 0.000120, 0.030000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 182.410670, 0.000150, 0.052000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 357.878960, 0.000270, 0.031000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, 1, 0}, 180.563790, 0.000020, 0.022000},
	{{0, 11, -9, 0, -2, 0, 0, 0, 0, -2, 0}, 269.839690, 0.000020, 0.056000},
	{{0, 11, -9, 0, -2, 0, 0, 0, 0, 0, 0}, 269.839690, 0.000020, 0.115000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 115.782970, 0.000200, 0.063000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 298.449740, 0.000200, 0.113000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 295.799420, 0.000070, 0.049000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 115.812710, 0.000100, 0.030000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 38.621740, 0.000020, 0.092000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 218.621740, 0.000020, 0.027000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 218.621740, 0.000030, 0.241000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 38.621740, 0.000030, 0.045000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 211.899660, 0.000020, 0.078000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 31.899660, 0.000020, 0.073000},
	{{0, 12, -18, 0, 2, 0, 0, 0, -2, 0, 0}, 141.529440, 0.000060, 0.043000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 2, -3, 0}, 147.873340, 0.000030, 0.080000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 327.873340, 0.000030, 0.071000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 144.049780, 0.000040, 0.047000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 324.049780, 0.000040, 0.189000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 346.726730, 0.000050, 0.063000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 167.354720, 0.000120, 0.034000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 72.394340, 0.000050, 0.052000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 243.470310, 0.000020, 0.129000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 257.576450, 0.000120, 0.182000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 277.405710, 0.000030, 0.053000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 263.958120, 0.000280, 0.059000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 83.929270, 0.000260, 0.033000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 264.288560, 0.000020, 0.023000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 2.827840, 0.000040, 0.055000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 185.592410, 0.000030, 0.201000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 1.881010, 0.000020, 0.121000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 164.966890, 0.000040, 0.052000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 181.501260, 0.000020, 0.050000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 11.475950, 0.000060, 0.148000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 181.651370, 0.000340, 0.154000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 184.745610, 0.000240, 0.051000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 345.008540, 0.000050, 0.183000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, 1}, 345.011060, 0.000060, 0.031000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 182.616750, 0.000740, 0.056000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 3.378580, 0.000990, 0.032000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 2.390670, 0.000190, 0.022000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 4, -1, 0}, 2.406870, 0.000060, 0.023000},
	{{0, 12, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 308.848900, 0.000040, 0.055000},
	{{0, 12, -12, 0, -1, 0, 0, 0, -2, 0, 0}, 268.199690, 0.000030, 0.058000},
	{{0, 12, -12, 0, -1, 0, 0, 0, -2, 2, 0}, 88.199690, 0.000030, 0.109000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, -2, 0}, 90.032880, 0.000020, 0.023000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 270.616850, 0.000260, 0.058000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 89.956560, 0.000120, 0.252000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 268.455060, 0.000070, 0.108000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 89.999440, 0.000040, 0.044000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 92.893230, 0.000020, 0.053000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 269.998260, 0.000160, 0.174000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 89.951690, 0.001280, 0.133000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 89.958880, 0.000570, 0.048000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 89.987600, 0.000040, 0.029000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 269.973590, 0.000060, 0.050000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 269.546280, 0.000080, 0.174000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 89.953330, 0.001960, 0.053000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 269.949380, 0.002990, 0.031000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 269.958430, 0.000240, 0.022000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 3, 0, 0}, 270.009190, 0.000100, 0.022000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 4, -2, 0}, 90.081030, 0.000030, 0.033000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 4, -1, 0}, 269.954040, 0.000110, 0.023000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 4, 0, 0}, 269.961030, 0.000050, 0.018000},
	{{0, 12, -12, 0, 1, 0, 0, 0, -2, 0, 0}, 77.647260, 0.000030, 0.058000},
	{{0, 12, -12, 0, 1, 0, 0, 0, -2, 2, 0}, 257.647260, 0.000030, 0.107000},
	{{0, 12, -11, 0, -1, 0, 0, 0, 0, -2, 0}, 91.205330, 0.000020, 0.055000},
	{{0, 12, -11, 0, -1, 0, 0, 0, 0, 0, 0}, 91.256660, 0.000070, 0.119000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, -2, 1}, 193.165680, 0.000020, 0.059000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 193.165420, 0.000110, 0.058000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 0, 1}, 193.165680, 0.000020, 0.105000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 3.910410, 0.000030, 0.029000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 13.244770, 0.000110, 0.134000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 13.246260, 0.000090, 0.029000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 182.255940, 0.000130, 0.050000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 357.781860, 0.000230, 0.030000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 181.259670, 0.000020, 0.022000},
	{{0, 12, -10, 0, -2, 0, 0, 0, -2, 0, 0}, 90.247350, 0.000020, 0.065000},
	{{0, 12, -10, 0, -2, 0, 0, 0, -2, 2, 0}, 270.247350, 0.000020, 0.090000},
	{{0, 12, -10, 0, -2, 0, 0, 0, 0, -2, 0}, 269.819830, 0.000020, 0.058000},
	{{0, 12, -10, 0, -2, 0, 0, 0, 0, 0, 0}, 269.819830, 0.000020, 0.107000},
	{{0, 12, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 115.857570, 0.000200, 0.066000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 293.125410, 0.000170, 0.105000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 295.779820, 0.000060, 0.048000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 121.098910, 0.000080, 0.029000},
	{{0, 12, -9, 0, -2, 0, 0, 0, -2, 0, 0}, 176.024250, 0.000020, 0.069000},
	{{0, 12, -9, 0, -2, 0, 0, 0, -2, 2, 0}, 176.024250, 0.000020, 0.083000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 241.445320, 0.000030, 0.042000},
	{{0, 12, -8, 0, 0, 0, -2, 0, -2, 0, 0}, 2.382580, 0.000020, 0.075000},
	{{0, 12, -8, 0, 0, 0, -2, 0, -2, 2, 0}, 182.382580, 0.000020, 0.075000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 318.508390, 0.000040, 0.026000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 1, 0}, 318.508390, 0.000500, 0.040000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 318.389180, 0.000300, 0.087000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 318.155260, 0.000060, 0.038000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 318.155260, 0.001100, 0.076000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 318.994720, 0.000180, 40.749000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 138.618950, 0.001840, 0.075000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 138.618950, 0.000100, 0.038000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 138.666770, 0.000430, 0.087000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 138.508390, 0.000500, 0.040000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 138.508390, 0.000040, 0.026000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 218.191320, 0.000030, 0.284000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 38.191320, 0.000030, 0.044000},
	{{0, 12, -7, -2, 0, 0, 0, 0, -2, 0, 0}, 18.130490, 0.000020, 0.075000},
	{{0, 12, -7, -2, 0, 0, 0, 0, -2, 2, 0}, 198.130490, 0.000020, 0.076000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -4, 1, 0}, 215.571460, 0.000030, 0.042000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 239.227960, 0.000040, 0.075000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 2, -1}, 59.227960, 0.000040, 0.076000},
	{{0, 12, -6, 0, -3, 0, 0, 0, 0, -2, 0}, 98.307450, 0.000020, 0.075000},
	{{0, 12, -6, 0, -3, 0, 0, 0, 0, 0, 0}, 98.307450, 0.000020, 0.075000},
	{{0, 13, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 110.747870, 0.000030, 0.075000},
	{{0, 13, -23, 0, 0, 0, 0, 0, -2, 3, 0}, 290.747870, 0.000030, 0.076000},
	{{0, 13, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 19.610150, 0.000040, 0.081000},
	{{0, 13, -22, 0, 0, 0, 0, 0, -2, 3, 0}, 199.610150, 0.000040, 0.071000},
	{{0, 13, -19, 0, 2, 0, 0, 0, -2, 0, 0}, 141.506290, 0.000030, 0.045000},
	{{0, 13, -19, 0, 2, 0, 0, 0, -2, 2, 0}, 141.506290, 0.000030, 0.245000},
	{{0, 13, -18, 0, 1, 0, 0, 0, -2, 0, 0}, 320.297450, 0.000040, 0.046000},
	{{0, 13, -18, 0, 1, 0, 0, 0, -2, 2, 0}, 140.297450, 0.000040, 0.200000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 144.036760, 0.000040, 0.049000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 324.036760, 0.000040, 0.169000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 168.027230, 0.000110, 0.033000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 81.318250, 0.000060, 0.054000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 243.305390, 0.000020, 0.126000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 258.280140, 0.000100, 0.163000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 278.166110, 0.000020, 0.052000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 264.588590, 0.000200, 0.057000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 84.523250, 0.000170, 0.032000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, 2, 0}, 84.625190, 0.000030, 0.017000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 3.143150, 0.000030, 0.057000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 185.678000, 0.000020, 0.230000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 2.008740, 0.000020, 0.112000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 16.558960, 0.000030, 0.163000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 181.694640, 0.000310, 0.140000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 185.136210, 0.000170, 0.049000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 344.688160, 0.000050, 0.165000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 1, 0, 1}, 344.690770, 0.000050, 0.030000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 182.240510, 0.000530, 0.054000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 3.372660, 0.000810, 0.031000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 2.568890, 0.000150, 0.022000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 4, -1, 0}, 2.404330, 0.000050, 0.023000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 4, 0, 0}, 2.400610, 0.000060, 0.018000},
	{{0, 13, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 310.349180, 0.000030, 0.057000},
	{{0, 13, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 266.342350, 0.000030, 0.060000},
	{{0, 13, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 86.342350, 0.000030, 0.102000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, -2, 0}, 90.018770, 0.000020, 0.023000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 270.082210, 0.000400, 0.060000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 89.926570, 0.000070, 0.299000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 268.765220, 0.000090, 0.101000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 79.775600, 0.000030, 0.054000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 269.739230, 0.000130, 0.195000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 90.322970, 0.001020, 0.123000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 89.969320, 0.000540, 0.047000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 269.963730, 0.000040, 0.049000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 270.560230, 0.000050, 0.157000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 90.042080, 0.001400, 0.051000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 269.911260, 0.002280, 0.030000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 269.929140, 0.000200, 0.022000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 3, 0, 0}, 269.991250, 0.000090, 0.022000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 4, -2, 0}, 90.273980, 0.000020, 0.032000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 4, -1, 0}, 269.926600, 0.000070, 0.023000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 4, 0, 0}, 269.933720, 0.000040, 0.017000},
	{{0, 13, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 77.692530, 0.000030, 0.061000},
	{{0, 13, -13, 0, 1, 0, 0, 0, -2, 2, 0}, 257.692530, 0.000030, 0.100000},
	{{0, 13, -12, 0, -1, 0, 0, 0, 0, 0, 0}, 91.261450, 0.000040, 0.111000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 348.022230, 0.000030, 0.064000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 168.022230, 0.000030, 0.092000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 193.139100, 0.000100, 0.060000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 148.785490, 0.000020, 0.110000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 13.223480, 0.000100, 0.124000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 0, 1}, 13.224850, 0.000070, 0.029000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 182.636310, 0.000110, 0.049000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 358.299440, 0.000190, 0.030000},
	{{0, 13, -11, 0, -2, 0, 0, 0, -2, 0, 0}, 90.231840, 0.000020, 0.068000},
	{{0, 13, -11, 0, -2, 0, 0, 0, -2, 2, 0}, 270.231840, 0.000020, 0.085000},
	{{0, 13, -11, 0, -2, 0, 0, 0, 0, -2, 0}, 269.797970, 0.000020, 0.060000},
	{{0, 13, -11, 0, -2, 0, 0, 0, 0, 0, 0}, 269.797970, 0.000020, 0.100000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 116.723640, 0.000230, 0.068000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 112.329090, 0.000030, 0.084000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 292.847730, 0.000160, 0.099000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 295.761340, 0.000050, 0.046000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 115.788730, 0.000040, 0.029000},
	{{0, 13, -10, 0, -2, 0, 0, 0, -2, 0, 0}, 346.531630, 0.000020, 0.073000},
	{{0, 13, -10, 0, -2, 0, 0, 0, -2, 2, 0}, 346.531630, 0.000020, 0.079000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 15.895990, 0.000050, 0.073000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 195.895990, 0.000050, 0.077000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 129.418310, 0.000020, 0.107000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 309.418310, 0.000020, 0.028000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 44.572380, 0.000050, 0.075000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 224.572380, 0.000050, 0.076000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -3, 0}, 159.909060, 0.000030, 0.075000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 339.909060, 0.000030, 0.076000},
	{{0, 14, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 320.270610, 0.000060, 0.048000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 141.796250, 0.000040, 0.050000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 321.796250, 0.000040, 0.153000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 168.662980, 0.000090, 0.033000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 85.760180, 0.000050, 0.056000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 265.760180, 0.000050, 0.117000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 100.220860, 0.000030, 0.154000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 258.931180, 0.000090, 0.148000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 280.220860, 0.000030, 0.050000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 265.142540, 0.000150, 0.055000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 85.056870, 0.000120, 0.032000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 3.391210, 0.000030, 0.059000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 1.992670, 0.000020, 0.105000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 181.316150, 0.000280, 0.129000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 185.300600, 0.000130, 0.048000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 344.333240, 0.000040, 0.149000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 182.184650, 0.000390, 0.052000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 4.408700, 0.000660, 0.031000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 2.710830, 0.000130, 0.022000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 4, -1, 0}, 2.313390, 0.000020, 0.023000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 4, 0, 0}, 2.313390, 0.000070, 0.017000},
	{{0, 14, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 304.229870, 0.000020, 0.059000},
	{{0, 14, -15, 0, 1, 0, 0, 0, -2, 2, 0}, 124.229870, 0.000020, 0.104000},
	{{0, 14, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 288.721260, 0.000030, 0.062000},
	{{0, 14, -14, 0, -1, 0, 0, 0, -2, 2, 0}, 108.721260, 0.000030, 0.096000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 269.945650, 0.000340, 0.063000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 89.903780, 0.000050, 0.367000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 268.759050, 0.000090, 0.095000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 90.971600, 0.000020, 0.056000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 270.295070, 0.000100, 0.222000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 90.643320, 0.000840, 0.114000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 90.003770, 0.000400, 0.045000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 265.842900, 0.000040, 0.143000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 89.907860, 0.000970, 0.049000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 269.952690, 0.001770, 0.030000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 2, 1, 0}, 269.985820, 0.000090, 0.021000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 3, 0, 0}, 269.970970, 0.000070, 0.022000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 4, -1, 0}, 269.905130, 0.000050, 0.022000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 4, 0, 0}, 269.951730, 0.000030, 0.017000},
	{{0, 14, -14, 0, 1, 0, 0, 0, -2, 0, 0}, 76.827040, 0.000020, 0.063000},
	{{0, 14, -14, 0, 1, 0, 0, 0, -2, 2, 0}, 256.827040, 0.000020, 0.094000},
	{{0, 14, -13, 0, -1, 0, 0, 0, 0, -2, 0}, 91.242740, 0.000020, 0.059000},
	{{0, 14, -13, 0, -1, 0, 0, 0, 0, 0, 0}, 91.242740, 0.000020, 0.103000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 356.371480, 0.000020, 0.067000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 176.371480, 0.000020, 0.087000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 193.110890, 0.000090, 0.062000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 13.199740, 0.000090, 0.115000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, 1}, 13.201010, 0.000060, 0.028000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 178.865570, 0.000080, 0.047000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 1.447770, 0.000120, 0.029000},
	{{0, 14, -12, 0, -3, 0, 0, 0, -2, 0, 0}, 100.449180, 0.000040, 0.070000},
	{{0, 14, -12, 0, -2, 0, 0, 0, -2, 0, 0}, 90.284750, 0.000020, 0.071000},
	{{0, 14, -12, 0, -2, 0, 0, 0, -2, 2, 0}, 270.284750, 0.000020, 0.081000},
	{{0, 14, -12, 0, -2, 0, 0, 0, 0, -2, 0}, 269.774150, 0.000020, 0.063000},
	{{0, 14, -12, 0, -2, 0, 0, 0, 0, 0, 0}, 269.774150, 0.000020, 0.094000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 117.786420, 0.000340, 0.072000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 104.123200, 0.000040, 0.080000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 295.943670, 0.000140, 0.093000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 295.743270, 0.000040, 0.045000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 115.739660, 0.000160, 0.028000},
	{{0, 14, -11, 0, -3, 0, 0, 0, -2, 0, 0}, 198.639000, 0.000070, 0.076000},
	{{0, 14, -11, 0, -3, 0, 0, 0, -2, 2, 0}, 238.352500, 0.000020, 0.075000},
	{{0, 14, -11, 0, -2, 0, 0, 0, -2, 0, 0}, 161.867760, 0.000120, 0.076000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 195.107430, 0.000040, 0.077000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 15.107430, 0.000040, 0.074000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 129.585280, 0.000030, 0.100000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 309.585280, 0.000030, 0.027000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 19.295170, 0.000040, 0.073000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 204.197580, 0.000050, 0.078000},
	{{0, 14, -9, 0, -2, 0, 0, 0, -2, 1, -2}, 50.240460, 0.000030, 0.040000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 0, -2}, 30.636750, 0.000100, 0.075000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 0, 2, -2}, 228.800770, 0.000100, 0.075000},
	{{0, 14, -9, 0, -2, 0, 0, 0, 2, 1, -2}, 230.240460, 0.000030, 0.040000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 252.676730, 0.000020, 0.049000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 72.676730, 0.000020, 0.162000},
	{{0, 15, -20, 0, 1, 0, 0, 0, -2, 0, 0}, 320.242020, 0.000060, 0.049000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 141.768730, 0.000030, 0.052000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 321.768730, 0.000030, 0.140000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 169.263570, 0.000080, 0.032000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 87.893750, 0.000030, 0.058000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 267.893750, 0.000030, 0.109000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 0, 2, 0}, 83.769330, 0.000020, 0.030000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 265.640880, 0.000120, 0.053000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 85.553840, 0.000090, 0.031000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 2.030470, 0.000060, 0.061000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 0.111470, 0.000020, 0.098000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 181.534890, 0.000240, 0.119000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 182.309460, 0.000070, 0.046000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 182.301020, 0.000460, 0.050000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 3.567440, 0.000490, 0.030000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 2.596800, 0.000100, 0.022000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 4, 0, 0}, 2.309490, 0.000060, 0.017000},
	{{0, 15, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 305.401890, 0.000020, 0.061000},
	{{0, 15, -16, 0, 1, 0, 0, 0, -2, 2, 0}, 125.401890, 0.000020, 0.098000},
	{{0, 15, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 291.189630, 0.000050, 0.065000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -6, 1, 2}, 89.603860, 0.000030, 0.040000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 0, 2}, 89.603860, 0.000110, 0.075000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 2, 2}, 269.603860, 0.000110, 0.075000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 269.976880, 0.000330, 0.065000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 90.902100, 0.000030, 0.476000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 1, 2}, 269.603860, 0.000030, 0.040000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 268.764130, 0.000100, 0.090000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, -3, 0}, 90.735670, 0.000020, 0.033000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 273.686560, 0.000060, 0.258000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 90.689060, 0.000700, 0.107000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 91.065920, 0.000190, 0.044000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 272.692690, 0.000020, 0.131000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 89.845210, 0.000720, 0.048000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 269.931550, 0.001310, 0.029000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 269.928720, 0.000100, 0.021000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 3, 0, 0}, 269.948390, 0.000060, 0.022000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 4, -1, 0}, 269.917370, 0.000040, 0.022000},
	{{0, 15, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 76.873380, 0.000040, 0.065000},
	{{0, 15, -14, 0, -2, 0, 0, 0, -2, 0, 0}, 184.756090, 0.000050, 0.069000},
	{{0, 15, -14, 0, -1, 0, 0, 0, 0, -2, 0}, 91.220320, 0.000020, 0.062000},
	{{0, 15, -14, 0, -1, 0, 0, 0, 0, 0, 0}, 91.220320, 0.000020, 0.097000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 0, 1}, 13.388290, 0.000040, 0.075000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 2, 1}, 193.388290, 0.000040, 0.076000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 193.080900, 0.000080, 0.065000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 0, 1, 0}, 39.260080, 0.000020, 0.042000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 13.173620, 0.000080, 0.107000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, 0, 1}, 13.174800, 0.000040, 0.028000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 179.395880, 0.000060, 0.046000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 3.426660, 0.000060, 0.028000},
	{{0, 15, -13, 0, -3, 0, 0, 0, -2, 0, 0}, 143.022650, 0.000040, 0.073000},
	{{0, 15, -13, 0, -2, 0, 0, 0, -2, 0, 0}, 89.178010, 0.000030, 0.074000},
	{{0, 15, -13, 0, -2, 0, 0, 0, -2, 2, 0}, 269.178010, 0.000030, 0.077000},
	{{0, 15, -13, 0, -2, 0, 0, 0, 0, -2, 0}, 89.748330, 0.000020, 0.065000},
	{{0, 15, -13, 0, -2, 0, 0, 0, 0, 0, 0}, 269.748330, 0.000020, 0.089000},
	{{0, 15, -13, 0, -1, 0, 0, 0, -2, 0, 0}, 233.487360, 0.000040, 0.074000},
	{{0, 15, -13, 0, -1, 0, 0, 0, -2, 2, 0}, 322.621670, 0.000030, 0.076000},
	{{0, 15, -13, 0, 0, -2, 0, 0, -2, 0, 0}, 90.100780, 0.000020, 0.075000},
	{{0, 15, -13, 0, 0, -2, 0, 0, -2, 2, 0}, 270.100780, 0.000020, 0.076000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 0, 0}, 116.323150, 0.000030, 0.026000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 1, 0}, 116.318400, 0.000380, 0.040000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -4, 2, 0}, 116.396470, 0.000230, 0.086000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 116.241910, 0.000190, 0.038000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 116.238700, 0.003380, 0.075000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 104.786600, 0.000100, 10.112000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 296.245710, 0.001240, 0.076000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 296.245710, 0.000070, 0.038000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 296.193560, 0.000050, 0.534000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 298.925600, 0.000040, 0.088000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 296.328500, 0.000340, 0.041000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 296.323150, 0.000030, 0.026000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 115.721930, 0.000130, 0.028000},
	{{0, 15, -13, 0, 1, 0, 0, 0, -2, 0, 0}, 24.763900, 0.000030, 0.075000},
	{{0, 15, -13, 0, 1, 0, 0, 0, -2, 2, 0}, 24.763900, 0.000030, 0.076000},
	{{0, 15, -12, -4, 0, 0, 0, 0, -2, 0, 0}, 240.028140, 0.000020, 0.069000},
	{{0, 15, -12, -4, 0, 0, 0, 0, -2, 2, 0}, 60.028140, 0.000020, 0.083000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -4, 1, 0}, 13.386220, 0.000020, 0.042000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, 0, 0}, 189.701010, 0.000210, 0.040000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -3, 1, 0}, 189.701010, 0.000130, 0.087000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, -2, 0}, 189.701010, 0.000040, 0.038000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, -1, 0}, 189.701010, 0.000740, 0.076000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 39.316110, 0.000110, 0.075000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 1, 0}, 9.701010, 0.000740, 0.075000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 2, -1}, 219.251290, 0.000030, 0.076000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 2, 0}, 9.701010, 0.000040, 0.038000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, -1, 0}, 9.701010, 0.000130, 0.087000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 9.701010, 0.000210, 0.040000},
	{{0, 15, -11, 0, -1, 0, 0, 0, 0, -2, 0}, 234.736590, 0.000030, 0.076000},
	{{0, 15, -11, 0, -1, 0, 0, 0, 0, 0, 0}, 234.736590, 0.000030, 0.075000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 321.698450, 0.000040, 0.076000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 320.592280, 0.000030, 0.075000},
	{{0, 15, -9, -4, 0, 0, 0, 0, -2, -1, 0}, 297.177360, 0.000090, 0.040000},
	{{0, 15, -9, -4, 0, 0, 0, 0, -2, 0, 0}, 306.914710, 0.000080, 0.087000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, -2, 0}, 276.805970, 0.000210, 0.075000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 0, 0, 0}, 96.805970, 0.000210, 0.075000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 2, -2, 0}, 126.914710, 0.000080, 0.087000},
	{{0, 15, -9, -4, 0, 0, 0, 0, 2, -1, 0}, 117.177360, 0.000090, 0.040000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 278.359330, 0.000030, 0.051000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 98.359330, 0.000030, 0.147000},
	{{0, 16, -21, 0, 1, 0, 0, 0, -2, 0, 0}, 320.211690, 0.000050, 0.051000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 141.744780, 0.000030, 0.053000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 321.744780, 0.000030, 0.128000},
	{{0, 16, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 169.811080, 0.000050, 0.032000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 85.050790, 0.000050, 0.060000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 0, 2, 0}, 84.334920, 0.000020, 0.029000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 266.090900, 0.000090, 0.051000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 86.002750, 0.000070, 0.031000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 1.937220, 0.000070, 0.064000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 182.321860, 0.000230, 0.111000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, 1, 0}, 182.303860, 0.000050, 0.045000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 182.157350, 0.000310, 0.049000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 1.315530, 0.000380, 0.030000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, 1, 0}, 1.822200, 0.000050, 0.021000},
	{{0, 16, -16, 0, -1, 0, 0, 0, -2, 0, 0}, 295.014260, 0.000040, 0.068000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 269.929770, 0.000370, 0.068000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 89.853300, 0.000020, 0.679000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 268.279980, 0.000070, 0.085000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 89.272460, 0.000050, 0.061000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 269.838040, 0.000020, 0.308000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 90.930410, 0.000560, 0.100000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 89.850400, 0.000130, 0.043000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 89.851720, 0.000510, 0.047000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 269.835030, 0.000970, 0.029000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 269.854330, 0.000230, 0.021000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 3, 0, 0}, 269.923570, 0.000050, 0.021000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 4, -1, 0}, 269.848040, 0.000070, 0.022000},
	{{0, 16, -16, 0, 1, 0, 0, 0, -2, 0, 0}, 76.912020, 0.000050, 0.068000},
	{{0, 16, -15, -2, 0, 0, 0, 0, -2, 0, 0}, 2.700010, 0.000020, 0.068000},
	{{0, 16, -15, -2, 0, 0, 0, 0, -2, 2, 0}, 182.700010, 0.000020, 0.085000},
	{{0, 16, -15, 0, -1, 0, 0, 0, -2, 0, 0}, 268.304740, 0.000030, 0.072000},
	{{0, 16, -15, 0, -1, 0, 0, 0, -2, 2, 0}, 88.304740, 0.000030, 0.079000},
	{{0, 16, -15, 0, -1, 0, 0, 0, 0, -2, 0}, 91.195770, 0.000020, 0.064000},
	{{0, 16, -15, 0, -1, 0, 0, 0, 0, 0, 0}, 91.195770, 0.000020, 0.092000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 234.969290, 0.000040, 0.073000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 165.987030, 0.000030, 0.078000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 193.049220, 0.000090, 0.068000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 3.733260, 0.000040, 0.091000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 13.145150, 0.000080, 0.100000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 2, -3, 0}, 179.857320, 0.000020, 0.249000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 179.857320, 0.000020, 0.044000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 3.731130, 0.000040, 0.028000},
	{{0, 16, -15, 0, 1, 0, 0, 0, -2, 0, 0}, 136.299140, 0.000020, 0.073000},
	{{0, 16, -15, 0, 1, 0, 0, 0, -2, 2, 0}, 136.299140, 0.000020, 0.078000},
	{{0, 16, -14, -1, 0, 0, 0, 0, -2, 0, 0}, 175.336790, 0.000050, 0.075000},
	{{0, 16, -14, -1, 0, 0, 0, 0, -2, 2, 0}, 355.336790, 0.000050, 0.075000},
	{{0, 16, -14, 0, -3, 0, 0, 0, -2, 0, 0}, 317.511740, 0.000020, 0.077000},
	{{0, 16, -14, 0, -3, 0, 0, 0, -2, 2, 0}, 137.511740, 0.000020, 0.074000},
	{{0, 16, -14, 0, -2, 0, 0, 0, 0, 0, 0}, 269.697780, 0.000050, 0.084000},
	{{0, 16, -14, 0, -1, 0, 0, 0, -2, 0, 0}, 172.318780, 0.000020, 0.078000},
	{{0, 16, -14, 0, -1, 0, 0, 0, -2, 2, 0}, 352.318780, 0.000020, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 297.979380, 0.000260, 0.079000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 294.301460, 0.000090, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 90.719610, 0.000020, 0.069000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 295.750350, 0.000260, 0.083000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 115.703630, 0.000100, 0.027000},
	{{0, 16, -13, -3, 0, 0, 0, 0, -2, 0, 0}, 281.203470, 0.000030, 0.075000},
	{{0, 16, -13, -3, 0, 0, 0, 0, -2, 2, 0}, 101.203470, 0.000030, 0.076000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 311.438810, 0.000020, 0.074000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 145.778250, 0.000060, 0.077000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 17.058320, 0.000030, 0.052000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 197.058320, 0.000030, 0.135000},
	{{0, 17, -22, 11, 0, 0, 0, 0, -2, 0, 0}, 137.781670, 0.000040, 0.075000},
	{{0, 17, -22, 11, 0, 0, 0, 0, -2, 2, 0}, 317.781670, 0.000040, 0.075000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 89.255990, 0.000030, 0.062000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 269.255990, 0.000030, 0.096000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 86.409680, 0.000060, 0.030000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 1.890340, 0.000070, 0.066000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 0.191650, 0.000020, 0.088000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 182.294880, 0.000020, 0.276000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 182.204870, 0.000180, 0.104000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 182.298700, 0.000020, 0.044000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 182.290940, 0.000240, 0.047000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 2.296680, 0.000340, 0.029000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, 1, 0}, 2.261970, 0.000040, 0.021000},
	{{0, 17, -17, 0, -1, 0, 0, 0, -2, 0, 0}, 289.695640, 0.000060, 0.070000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 269.752810, 0.000540, 0.071000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 269.408530, 0.000030, 0.081000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 90.371980, 0.000040, 0.063000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 269.820340, 0.000020, 0.381000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 91.263520, 0.000440, 0.094000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, 1, 0}, 89.821900, 0.000120, 0.042000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 90.008020, 0.000040, 0.113000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 89.822150, 0.000380, 0.045000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 269.821780, 0.000750, 0.028000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 2, 1, 0}, 269.822560, 0.000170, 0.021000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 3, -2, 0}, 269.896540, 0.000020, 0.047000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 3, 0, 0}, 269.896540, 0.000020, 0.021000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 4, -2, 0}, 89.831130, 0.000020, 0.030000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 4, -1, 0}, 269.821620, 0.000050, 0.021000},
	{{0, 17, -17, 0, 1, 0, 0, 0, -2, 0, 0}, 76.943640, 0.000040, 0.071000},
	{{0, 17, -17, 0, 1, 0, 0, 0, -2, 2, 0}, 256.943640, 0.000040, 0.080000},
	{{0, 17, -16, 0, -2, 0, 0, 0, -2, 1, 0}, 205.598640, 0.000210, 60.783000},
	{{0, 17, -16, 0, -1, 0, 0, 0, -2, 0, 0}, 153.325300, 0.000020, 0.076000},
	{{0, 17, -16, 0, -1, 0, 0, 0, -2, 1, 0}, 91.156680, 0.000190, 14.738000},
	{{0, 17, -16, 0, -1, 0, 0, 0, -2, 2, 0}, 153.325300, 0.000020, 0.075000},
	{{0, 17, -16, 0, -1, 0, 0, 0, 0, 0, 0}, 91.273180, 0.000050, 0.087000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 12.386910, 0.000070, 0.076000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 1, -1}, 13.048470, 0.000040, 0.075000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 5.749940, 0.000110, 0.075000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 3, -1}, 193.048470, 0.000040, 0.076000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 193.041310, 0.000150, 0.071000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 0, 1}, 193.016420, 0.000060, 0.079000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 13.114390, 0.000070, 0.095000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 3.988240, 0.000190, 0.027000},
	{{0, 17, -15, -3, 0, 0, 0, 0, -2, 0, 0}, 58.793010, 0.000020, 0.073000},
	{{0, 17, -15, -3, 0, 0, 0, 0, -2, 2, 0}, 238.793010, 0.000020, 0.078000},
	{{0, 17, -15, -2, 0, 0, 0, 0, -2, 0, 0}, 92.887090, 0.000030, 0.076000},
	{{0, 17, -15, -2, 0, 0, 0, 0, -2, 2, 0}, 272.887090, 0.000030, 0.075000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 294.562410, 0.000130, 0.083000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, -1, 0}, 296.359800, 0.000020, 0.077000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 1, 0}, 116.359800, 0.000020, 0.074000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 120.352010, 0.000050, 0.072000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 297.799470, 0.000380, 0.079000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 115.684450, 0.000080, 0.027000},
	{{0, 17, -14, -4, 0, 0, 0, 0, -2, 0, 0}, 60.365720, 0.000050, 0.076000},
	{{0, 17, -14, -4, 0, 0, 0, 0, -2, 2, 0}, 240.365720, 0.000050, 0.075000},
	{{0, 17, -14, 0, -3, 0, 0, 0, 0, -2, 0}, 267.531330, 0.000020, 0.076000},
	{{0, 17, -14, 0, -3, 0, 0, 0, 0, 0, 0}, 87.531330, 0.000020, 0.075000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 325.925880, 0.000040, 0.054000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 145.925880, 0.000040, 0.124000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 89.798890, 0.000040, 0.065000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 269.798890, 0.000040, 0.091000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 86.779740, 0.000050, 0.029000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -5, 0, 2}, 0.038120, 0.000020, 0.040000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, -1, 2}, 0.038120, 0.000080, 0.075000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 1, 2}, 180.038120, 0.000080, 0.075000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 1.788640, 0.000070, 0.069000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 1.788640, 0.000070, 0.083000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -1, 0, 2}, 180.038120, 0.000020, 0.040000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 182.242390, 0.000160, 0.097000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, -1, 0}, 189.203560, 0.000210, 0.046000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 2.287850, 0.000260, 0.029000},
	{{0, 18, -19, 0, 1, 0, 0, 0, -2, 0, 0}, 299.728650, 0.000050, 0.069000},
	{{0, 18, -19, 2, 0, 0, 0, 0, -2, 0, 0}, 128.558960, 0.000020, 0.075000},
	{{0, 18, -19, 2, 0, 0, 0, 0, -2, 2, 0}, 308.558960, 0.000020, 0.076000},
	{{0, 18, -19, 3, 0, 0, 0, 0, -2, 0, 0}, 146.145400, 0.000020, 0.078000},
	{{0, 18, -19, 3, 0, 0, 0, 0, -2, 2, 0}, 326.145400, 0.000020, 0.073000},
	{{0, 18, -18, 0, -1, 0, 0, 0, -2, 0, 0}, 322.475550, 0.000040, 0.074000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -4, 1, 0}, 269.888100, 0.000130, 0.040000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -4, 2, 0}, 270.293280, 0.000080, 0.085000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, -1, 0}, 270.100770, 0.000130, 0.037000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 268.347390, 0.002160, 0.074000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 90.260710, 0.000100, 4.498000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 89.545460, 0.000510, 0.077000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 3, 0}, 89.545310, 0.000030, 0.038000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 121.949870, 0.000060, 0.066000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 90.135940, 0.000050, 0.501000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 101.192360, 0.000350, 0.089000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 89.847900, 0.000230, 0.041000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, -2, 0}, 141.524000, 0.000170, 0.105000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 128.251680, 0.000870, 0.044000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 263.717090, 0.000510, 0.028000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 2, 1, 0}, 269.790070, 0.000130, 0.020000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 4, -2, 0}, 142.583770, 0.000030, 0.029000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 4, 0, 0}, 269.788890, 0.000070, 0.016000},
	{{0, 18, -18, 0, 2, 0, 0, 0, -2, 0, 0}, 99.689710, 0.000020, 0.075000},
	{{0, 18, -18, 0, 2, 0, 0, 0, -2, 2, 0}, 99.689710, 0.000020, 0.076000},
	{{0, 18, -17, -2, 0, 0, 0, 0, -2, 0, 0}, 199.590900, 0.000030, 0.074000},
	{{0, 18, -17, -2, 0, 0, 0, 0, -2, 2, 0}, 19.590900, 0.000030, 0.077000},
	{{0, 18, -17, 0, -1, 0, 0, 0, 0, 0, 0}, 91.348070, 0.000060, 0.082000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -4, -1, 0}, 39.479540, 0.000030, 0.020000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -4, 0, 0}, 39.479540, 0.000060, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, -1, 1}, 13.019560, 0.000080, 0.041000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, 0, 1}, 12.976810, 0.000100, 0.088000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -3, 1, -1}, 192.949810, 0.000020, 0.040000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -3, 0}, 39.479540, 0.000030, 0.019000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -2, 0}, 39.479540, 0.000270, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 39.479540, 0.002130, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 39.476840, 0.000880, 0.080000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, 0}, 219.479540, 0.000060, 0.038000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, 1}, 13.019350, 0.000280, 0.076000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 0}, 220.425810, 0.000550, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 192.997650, 0.000440, 0.074000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 1, 0}, 196.163300, 0.000020, 0.076000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 2, -1}, 12.949990, 0.000080, 0.077000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -4, 0}, 39.479540, 0.000040, 0.025000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -3, 0}, 39.478470, 0.000410, 0.036000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 39.480160, 0.003650, 0.070000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 39.482530, 0.004230, 0.082000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 1, 0}, 39.480660, 0.000470, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 2, 0}, 39.479540, 0.000040, 0.026000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -2, 1}, 193.019750, 0.000050, 0.087000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -1, 1}, 193.019560, 0.000080, 0.040000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, 1, -1}, 12.949810, 0.000020, 0.041000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 39.478150, 0.005210, 0.095000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 39.479590, 0.014110, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 36.067660, 0.001440, 0.027000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 1, 0}, 39.479540, 0.000120, 0.020000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -3, 0}, 39.479540, 0.000130, 0.046000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -2, 0}, 39.479540, 0.000410, 0.028000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, -1, 0}, 39.479540, 0.000220, 0.021000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 4, 0, 0}, 39.479540, 0.000040, 0.016000},
	{{0, 18, -16, -3, 0, 0, 0, 0, -2, 0, 0}, 239.783810, 0.000020, 0.076000},
	{{0, 18, -16, -3, 0, 0, 0, 0, -2, 2, 0}, 59.783810, 0.000020, 0.074000},
	{{0, 18, -16, 0, -2, 0, 0, 0, -2, 0, 0}, 269.968490, 0.000030, 0.086000},
	{{0, 18, -16, 0, -2, 0, 0, 0, -2, 2, 0}, 89.968490, 0.000030, 0.067000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 0, 0}, 116.542610, 0.000050, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 1, 0}, 116.542610, 0.000060, 0.021000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -6, 2, 0}, 116.542610, 0.000020, 0.029000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -3, 0}, 116.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -2, 0}, 116.542610, 0.000250, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, 0}, 116.542610, 0.001610, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, 2}, 116.542610, 0.000040, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, 0}, 116.541630, 0.003680, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 1, 0}, 116.539930, 0.001580, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, -1, 0}, 116.542610, 0.000150, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, 0, 0}, 296.542610, 0.000230, 0.042000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -3, 1, 0}, 296.542610, 0.000030, 0.094000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -4, 0}, 116.542610, 0.000120, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, 0}, 116.542880, 0.001450, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, 2}, 296.542610, 0.000020, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 116.542760, 0.017770, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 2}, 296.542610, 0.000140, 0.090000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 116.542220, 0.204730, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, -2}, 296.542610, 0.000060, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 116.539780, 0.134770, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, 2}, 116.542610, 0.000300, 0.065000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, -2}, 296.542610, 0.000050, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 296.490830, 0.000930, 0.563000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, 2}, 116.542610, 0.000030, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 116.477640, 0.000440, 0.067000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 3, 0}, 116.542610, 0.000050, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -3, 0}, 296.542610, 0.000040, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -2, 0}, 296.542610, 0.000440, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, 0}, 296.542610, 0.003760, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, 2}, 296.542610, 0.000030, 0.069000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, 1, 0}, 296.542610, 0.000060, 0.071000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -5, 0}, 116.542610, 0.000150, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -4, 0}, 116.543240, 0.002420, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, 0}, 116.543240, 0.039680, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 116.543110, 0.727830, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 2}, 116.542340, 0.002670, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -2}, 116.542610, 0.000220, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 296.004610, 0.007240, 273.043000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 2}, 296.542610, 0.000220, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -2}, 296.540230, 0.002840, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 296.545740, 0.682560, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 296.545590, 0.037220, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 2, 0}, 296.545590, 0.002270, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 3, 0}, 296.542610, 0.000150, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -3, 0}, 116.542610, 0.000060, 0.071000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, -2}, 116.542610, 0.000030, 0.069000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, 0}, 116.542610, 0.003760, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 116.542610, 0.000440, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, 1, 0}, 116.542610, 0.000040, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -5, 0}, 296.542610, 0.000050, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -4, 0}, 296.544490, 0.000510, 0.067000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, -2}, 296.542610, 0.000030, 0.035000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, 0}, 296.624650, 0.000130, 0.565000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -3, 2}, 116.542610, 0.000050, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, -2}, 296.542610, 0.000300, 0.065000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 0}, 296.542380, 0.126710, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 2}, 116.542610, 0.000060, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 296.542990, 0.203670, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, -2}, 116.542610, 0.000140, 0.090000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 296.547090, 0.017270, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, -2}, 116.542610, 0.000020, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 296.544110, 0.001400, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 2, 0}, 296.542610, 0.000120, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -3, 0}, 116.542610, 0.000030, 0.094000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -2, 0}, 116.542610, 0.000230, 0.042000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 3, -1, 0}, 296.542610, 0.000150, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -3, 0}, 296.541960, 0.001480, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, 0}, 296.542440, 0.003590, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, -2}, 296.542610, 0.000040, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, 0}, 296.542610, 0.001610, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, 0, 0}, 296.542610, 0.000250, 0.016000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, 1, 0}, 296.542610, 0.000030, 0.013000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -4, 0}, 296.542610, 0.000020, 0.029000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -3, 0}, 296.542610, 0.000060, 0.021000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 6, -2, 0}, 296.542610, 0.000050, 0.016000},
	{{0, 18, -15, -4, 0, 0, 0, 0, -2, 0, 0}, 59.935690, 0.000020, 0.079000},
	{{0, 18, -15, -4, 0, 0, 0, 0, -2, 2, 0}, 239.935690, 0.000020, 0.072000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, -2, 0}, 13.605680, 0.000040, 0.016000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, -1, 0}, 13.605680, 0.000220, 0.021000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, 0, 0}, 13.605680, 0.000410, 0.028000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -4, 1, 0}, 13.605680, 0.000130, 0.046000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -3, 0}, 13.605680, 0.000120, 0.020000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, 0}, 13.605280, 0.001350, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, 0}, 13.605620, 0.014160, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 13.603000, 0.005540, 0.095000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 193.553910, 0.000040, 0.360000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -1, -1, -1}, 40.091230, 0.000050, 0.040000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 40.091230, 0.000030, 0.087000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -4, 0}, 13.605680, 0.000040, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -3, 0}, 13.604620, 0.000500, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 13.606310, 0.004510, 0.082000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 13.608680, 0.003420, 0.070000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 13.606810, 0.000380, 0.036000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 2, 0}, 13.605680, 0.000040, 0.025000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -2, -1}, 40.090980, 0.000170, 0.075000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, 0}, 193.605680, 0.000580, 0.075000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 220.110890, 0.000290, 0.076000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 193.605680, 0.000060, 0.038000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 13.605050, 0.000830, 0.080000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 13.605680, 0.002130, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 13.605680, 0.000270, 0.026000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 1, 0}, 13.605680, 0.000030, 0.019000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 3, -2, -1}, 220.091230, 0.000030, 0.087000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 3, -1, -1}, 220.091230, 0.000050, 0.041000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 4, -2, 0}, 13.605680, 0.000060, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 4, -1, 0}, 13.605680, 0.000030, 0.020000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -4, 0, 0}, 270.668750, 0.000030, 0.029000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, -2, 0}, 270.668750, 0.000070, 0.028000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 270.668750, 0.000680, 0.044000},
	{{0, 18, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 270.668750, 0.000170, 0.106000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 270.668750, 0.000070, 0.089000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 270.668750, 0.000040, 0.066000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 296.939150, 0.000070, 0.074000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 218.072550, 0.000040, 0.025000},
	{{0, 18, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 167.731820, 0.000030, 0.046000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 326.511530, 0.000050, 0.056000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 146.511530, 0.000050, 0.115000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -3, -1, 1}, 43.467140, 0.000050, 0.040000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -3, 0, 1}, 43.467140, 0.000030, 0.087000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, -2, 1}, 43.467140, 0.000190, 0.075000},
	{{0, 19, -24, 10, 0, 0, 0, 0, -1, 0, 1}, 223.467140, 0.000190, 0.075000},
	{{0, 19, -24, 10, 0, 0, 0, 0, 1, -2, 1}, 223.467140, 0.000030, 0.087000},
	{{0, 19, -24, 10, 0, 0, 0, 0, 1, -1, 1}, 223.467140, 0.000050, 0.040000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 96.704970, 0.000030, 0.067000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 276.704970, 0.000030, 0.086000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 261.370400, 0.000040, 0.101000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 87.254310, 0.000170, 0.029000},
	{{0, 19, -21, 2, 0, 0, 0, 0, -2, 0, 0}, 269.384410, 0.000030, 0.073000},
	{{0, 19, -21, 2, 0, 0, 0, 0, -2, 2, 0}, 89.384410, 0.000030, 0.079000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -4, 1, 0}, 104.987140, 0.000110, 0.040000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -4, 2, 0}, 104.987140, 0.000070, 0.087000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, -1, 0}, 104.987140, 0.000020, 0.038000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 0, 0}, 105.302230, 0.000450, 0.075000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 1, 0}, 59.712560, 0.000490, 573.318000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 2, 0}, 285.302230, 0.000450, 0.075000},
	{{0, 19, -21, 3, 0, 0, 0, 0, -2, 3, 0}, 284.987140, 0.000020, 0.038000},
	{{0, 19, -21, 3, 0, 0, 0, 0, 0, 0, 0}, 284.987140, 0.000070, 0.087000},
	{{0, 19, -21, 3, 0, 0, 0, 0, 0, 1, 0}, 284.987140, 0.000110, 0.040000},
	{{0, 19, -20, 0, -1, 0, 0, 0, -2, 0, 0}, 83.127530, 0.000020, 0.072000},
	{{0, 19, -20, 0, -1, 0, 0, 0, -2, 2, 0}, 263.127530, 0.000020, 0.080000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -4, 2, 0}, 1.812100, 0.000020, 0.083000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 2.050150, 0.000190, 0.072000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 0.127230, 0.000030, 0.079000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 185.456990, 0.000160, 0.092000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, -1, 0}, 182.277470, 0.000110, 0.045000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 2.277490, 0.000200, 0.028000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, 1, 0}, 182.277450, 0.000020, 0.020000},
	{{0, 19, -20, 0, 1, 0, 0, 0, -2, 0, 0}, 221.061440, 0.000070, 0.073000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -4, 1, 0}, 270.120400, 0.000030, 0.041000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 89.677220, 0.000650, 0.078000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 269.392140, 0.000040, 2.480000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 89.189040, 0.000120, 0.073000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 90.773080, 0.000700, 0.084000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 1, 0}, 89.881770, 0.000080, 0.040000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, -1, 0}, 89.753420, 0.000340, 0.043000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 269.752770, 0.000410, 0.027000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 2, 1, 0}, 269.753410, 0.000100, 0.020000},
	{{0, 19, -18, -3, 0, 0, 0, 0, -2, 0, 0}, 193.519200, 0.000020, 0.074000},
	{{0, 19, -18, -3, 0, 0, 0, 0, -2, 2, 0}, 13.519200, 0.000020, 0.077000},
	{{0, 19, -18, -2, 0, 0, 0, 0, -2, 0, 0}, 59.184830, 0.000020, 0.077000},
	{{0, 19, -18, -2, 0, 0, 0, 0, -2, 2, 0}, 239.184830, 0.000020, 0.074000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 0, -1}, 12.973310, 0.000180, 0.077000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 2, -1}, 12.971920, 0.000030, 0.074000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 13.023640, 0.000120, 0.085000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 4.374500, 0.000120, 0.027000},
	{{0, 19, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 117.671740, 0.000030, 0.092000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 117.789980, 0.000180, 0.072000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 115.642590, 0.000050, 0.026000},
	{{0, 19, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 38.045900, 0.000030, 0.071000},
	{{0, 19, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 218.045900, 0.000030, 0.025000},
	{{0, 20, -29, 15, 0, 0, 0, 0, -2, 0, 0}, 105.077270, 0.000020, 0.075000},
	{{0, 20, -29, 15, 0, 0, 0, 0, -2, 2, 0}, 285.077270, 0.000020, 0.075000},
	{{0, 20, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 326.640000, 0.000040, 0.058000},
	{{0, 20, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 146.640000, 0.000040, 0.108000},
	{{0, 20, -25, 0, 1, 0, 0, 0, -2, 0, 0}, 140.118690, 0.000030, 0.058000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 273.267900, 0.000080, 0.095000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, 1, 0}, 284.739200, 0.000110, 0.042000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 87.560150, 0.000140, 0.028000},
	{{0, 20, -22, 0, 1, 0, 0, 0, -2, 0, 0}, 359.801610, 0.000020, 0.071000},
	{{0, 20, -22, 0, 1, 0, 0, 0, -2, 2, 0}, 359.801610, 0.000020, 0.081000},
	{{0, 20, -21, 0, -1, 0, 0, 0, -2, 0, 0}, 29.927330, 0.000020, 0.075000},
	{{0, 20, -21, 0, -1, 0, 0, 0, -2, 2, 0}, 209.927330, 0.000020, 0.076000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -6, 2, 0}, 1.802270, 0.000030, 0.028000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 0, 0}, 1.802270, 0.000130, 0.026000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 1, 0}, 1.802950, 0.001500, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 2, 0}, 1.503490, 0.000920, 0.087000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -3, 1, 0}, 181.802270, 0.000030, 0.081000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, -1, 0}, 2.361610, 0.000160, 0.038000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 2.361610, 0.002960, 0.076000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 2}, 1.802270, 0.000020, 0.073000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 181.763600, 0.000260, 34.812000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, -2}, 181.802270, 0.000020, 0.074000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 182.079800, 0.005600, 0.075000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 3, 0}, 182.079800, 0.000310, 0.038000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 1, 0}, 1.802270, 0.000030, 0.081000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 1.123640, 0.000060, 0.573000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 181.913150, 0.001560, 0.087000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 1, 0}, 181.801610, 0.001550, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 2, 0}, 181.799860, 0.000130, 0.026000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 1, 1, -1}, 206.965210, 0.000040, 0.042000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 182.265630, 0.000100, 0.043000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 2.478140, 0.000060, 0.028000},
	{{0, 20, -21, 0, 1, 0, 0, 0, -2, 0, 0}, 50.286190, 0.000020, 0.076000},
	{{0, 20, -21, 0, 1, 0, 0, 0, -2, 2, 0}, 50.286190, 0.000020, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -4, 1, 0}, 258.865340, 0.000110, 0.042000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -4, 2, 0}, 248.528250, 0.000020, 0.096000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 0, -1}, 284.028290, 0.000050, 0.026000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 0, 0}, 90.003840, 0.000040, 0.041000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 1, -1}, 284.028290, 0.000610, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 1, 0}, 90.003840, 0.000020, 0.088000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -3, 2, -1}, 284.060080, 0.000380, 0.087000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 91.840210, 0.000270, 0.082000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -1, -1}, 283.806980, 0.000170, 0.038000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, -1, 0}, 90.003840, 0.000130, 0.076000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, -1}, 283.806980, 0.003140, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, -1}, 103.366690, 0.000050, 39.938000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, 0}, 270.003840, 0.000130, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 2, -1}, 103.997250, 0.002190, 0.076000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 3, -1}, 103.997250, 0.000120, 0.038000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -3, 0}, 90.963110, 0.000020, 0.037000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 271.514770, 0.000030, 0.071000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 270.963110, 0.000040, 1.342000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 91.311290, 0.000810, 0.080000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, -1, 0}, 270.003840, 0.000020, 0.086000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 104.606090, 0.000210, 0.087000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 0, 0}, 270.003840, 0.000040, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 1, -1}, 104.028290, 0.000610, 0.040000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 1, 2, -1}, 104.028290, 0.000050, 0.026000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, -1, 0}, 89.715810, 0.000210, 0.042000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 269.715830, 0.000340, 0.027000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 2, 1, 0}, 269.715800, 0.000040, 0.020000},
	{{0, 20, -19, -3, 0, 0, 0, 0, -2, 0, 0}, 213.996060, 0.000030, 0.078000},
	{{0, 20, -19, -3, 0, 0, 0, 0, -2, 2, 0}, 33.996060, 0.000030, 0.073000},
	{{0, 20, -19, 0, -3, 0, 0, 0, 0, -2, 0}, 197.855600, 0.000060, 0.075000},
	{{0, 20, -19, 0, -3, 0, 0, 0, 0, 0, 0}, 71.218550, 0.000040, 0.075000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -3, 1, -1}, 181.091360, 0.000040, 0.042000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -2, 0, -1}, 12.989350, 0.000030, 0.041000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, -1, -1}, 12.989350, 0.000100, 0.076000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 1, -1}, 192.989350, 0.000100, 0.075000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 1, 0, -1}, 13.008750, 0.000120, 0.080000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 2, 0, -1}, 192.989350, 0.000030, 0.040000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 2.988420, 0.000080, 0.026000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 110.965540, 0.000090, 0.069000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, -1, -2}, 296.453180, 0.000030, 0.076000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, 1, -2}, 116.453180, 0.000030, 0.075000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 115.619600, 0.000040, 0.025000},
	{{0, 20, -15, -8, 0, 0, 0, 0, 0, -2, 0}, 190.593760, 0.000030, 0.075000},
	{{0, 20, -15, -8, 0, 0, 0, 0, 0, 0, 0}, 10.593760, 0.000030, 0.075000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -3, 1, -1}, 84.137590, 0.000060, 0.040000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -3, 2, -1}, 84.137590, 0.000040, 0.087000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 0, -1}, 84.137590, 0.000210, 0.075000},
	{{0, 20, -12, -15, 0, 0, 0, 0, -1, 2, -1}, 264.137590, 0.000210, 0.075000},
	{{0, 20, -12, -15, 0, 0, 0, 0, 1, 0, -1}, 264.137590, 0.000040, 0.087000},
	{{0, 20, -12, -15, 0, 0, 0, 0, 1, 1, -1}, 264.137590, 0.000060, 0.040000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 326.747210, 0.000040, 0.060000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 146.747210, 0.000040, 0.101000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, -2, 2}, 256.674450, 0.000030, 0.075000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 65.369500, 0.000030, 0.074000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 0, 2}, 76.674450, 0.000030, 0.076000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 65.369500, 0.000030, 0.077000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 262.191910, 0.000040, 0.090000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 87.840660, 0.000110, 0.028000},
	{{0, 21, -23, 0, 0, 0, 1, 0, -2, -2, 2}, 105.436420, 0.000040, 0.075000},
	{{0, 21, -23, 0, 0, 0, 1, 0, -2, 0, 2}, 285.436420, 0.000040, 0.075000},
	{{0, 21, -23, 0, 1, 0, 0, 0, -2, 0, 0}, 3.667780, 0.000060, 0.074000},
	{{0, 21, -23, 0, 1, 0, 0, 0, -2, 2, 0}, 359.933390, 0.000020, 0.077000},
	{{0, 21, -23, 0, 4, 0, 0, 0, -2, 0, 0}, 70.828820, 0.000020, 0.075000},
	{{0, 21, -23, 0, 4, 0, 0, 0, -2, 2, 0}, 70.828820, 0.000020, 0.075000},
	{{0, 21, -23, 2, 0, 0, 0, 0, -2, 0, 0}, 66.461160, 0.000020, 0.080000},
	{{0, 21, -23, 2, 0, 0, 0, 0, -2, 2, 0}, 246.461160, 0.000020, 0.072000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 181.785870, 0.000060, 0.079000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 181.785870, 0.000060, 0.072000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -2, 1}, 340.552780, 0.000030, 0.075000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, -1}, 160.615120, 0.000030, 0.073000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, 1}, 160.570420, 0.000090, 0.076000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 184.754610, 0.000160, 0.082000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, -3, 0}, 182.250310, 0.000020, 0.346000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, -1, 0}, 186.044570, 0.000090, 0.042000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 2.252400, 0.000060, 0.027000},
	{{0, 21, -22, 0, 1, 0, 0, 0, -2, 0, 0}, 111.404100, 0.000040, 0.080000},
	{{0, 21, -21, -3, 0, 0, 0, 0, -2, 0, 0}, 103.848130, 0.000030, 0.076000},
	{{0, 21, -21, -3, 0, 0, 0, 0, -2, 2, 0}, 283.848130, 0.000030, 0.075000},
	{{0, 21, -21, 0, -1, 0, 0, 0, -2, 0, 0}, 192.260060, 0.000020, 0.086000},
	{{0, 21, -21, 0, -1, 0, 0, 0, -2, 2, 0}, 12.260060, 0.000020, 0.067000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, -2, 0}, 269.943930, 0.000040, 0.026000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, -1, 0}, 269.958420, 0.000430, 0.040000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 90.025240, 0.000350, 0.086000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 269.843040, 0.000080, 0.605000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 91.648130, 0.000050, 0.067000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -3, 0}, 270.128240, 0.000090, 0.038000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -2, 0}, 270.128240, 0.001580, 0.075000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 269.779580, 0.000550, 8.350000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 89.876280, 0.004950, 0.076000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 1, 0}, 89.876530, 0.000270, 0.038000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, -2, 0}, 89.773350, 0.000300, 0.088000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 89.865890, 0.000670, 0.041000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 269.624720, 0.000210, 0.026000},
	{{0, 21, -20, 0, -1, 0, 0, 0, 0, -2, 0}, 271.043290, 0.000020, 0.080000},
	{{0, 21, -20, 0, -1, 0, 0, 0, 0, 0, 0}, 271.043290, 0.000020, 0.071000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -2, -1, 0}, 167.007000, 0.000030, 0.042000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -1, -1, -1}, 192.932630, 0.000040, 0.040000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -1, 0, -1}, 13.865690, 0.000050, 0.086000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -2, -1}, 192.916880, 0.000150, 0.074000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 13.376970, 0.000580, 0.076000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 1.394550, 0.000060, 0.026000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 3, -2, -1}, 12.947800, 0.000030, 0.088000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 3, -1, -1}, 12.932630, 0.000040, 0.041000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 116.466420, 0.000040, 0.066000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 96.671940, 0.000040, 0.025000},
	{{0, 22, -28, 7, 0, 0, 0, 0, -2, 0, 0}, 66.340510, 0.000040, 0.075000},
	{{0, 22, -28, 7, 0, 0, 0, 0, -2, 2, 0}, 246.340510, 0.000040, 0.075000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 326.547340, 0.000030, 0.063000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 2, 0}, 146.547340, 0.000030, 0.095000},
	{{0, 22, -24, 0, -2, 0, 0, 0, -2, 0, 0}, 135.103650, 0.000050, 0.076000},
	{{0, 22, -24, 0, -2, 0, 0, 0, -2, 2, 0}, 306.920340, 0.000020, 0.075000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 244.067570, 0.000030, 0.077000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 244.067570, 0.000030, 0.074000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 262.565280, 0.000040, 0.085000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 88.098520, 0.000090, 0.027000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 193.806580, 0.000040, 0.084000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 26.794220, 0.000020, 0.069000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 0, -1}, 339.886680, 0.000040, 0.077000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 182.136890, 0.000200, 0.078000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 2, -2, 0}, 182.050440, 0.000020, 0.091000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 2.237730, 0.000050, 0.027000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 258.168130, 0.000100, 0.091000},
	{{0, 22, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 87.046460, 0.000040, 0.064000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, -2, 0}, 269.709420, 0.000110, 0.078000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 271.919830, 0.000420, 0.073000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 1, 0, -1}, 102.433940, 0.000050, 0.079000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 2, -1, 0}, 89.634390, 0.000090, 0.040000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 269.634410, 0.000180, 0.026000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 2, 1, 0}, 89.634360, 0.000020, 0.019000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, 0, -1}, 192.928800, 0.000100, 0.073000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 2, -2, 0}, 1.584620, 0.000020, 0.077000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 1.584620, 0.000020, 0.025000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 326.648600, 0.000040, 0.065000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 146.648600, 0.000040, 0.090000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 141.930700, 0.000020, 0.070000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 2, 0}, 321.930700, 0.000020, 0.082000},
	{{0, 23, -27, 2, 0, 0, 0, 0, -2, 0, 0}, 118.228560, 0.000040, 0.075000},
	{{0, 23, -27, 2, 0, 0, 0, 0, -2, 2, 0}, 298.228560, 0.000040, 0.076000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 155.717420, 0.000070, 0.075000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 355.288630, 0.000040, 0.076000},
	{{0, 23, -26, 0, 1, 0, 0, 0, -2, 0, 0}, 2.146840, 0.000070, 0.075000},
	{{0, 23, -26, 0, 1, 0, 0, 0, -2, 2, 0}, 75.265760, 0.000030, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, 0, 0}, 258.182450, 0.000180, 0.040000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -3, 1, 0}, 258.182450, 0.000110, 0.087000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, -2, 0}, 258.182450, 0.000030, 0.038000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, -1, 0}, 258.182450, 0.000630, 0.076000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 1, 0}, 78.182450, 0.000630, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 2, 0}, 78.182450, 0.000030, 0.038000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 262.916510, 0.000060, 0.081000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, -1, 0}, 78.182450, 0.000110, 0.087000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 1, 0, 0}, 78.182450, 0.000180, 0.040000},
	{{0, 23, -24, 0, -1, 0, 0, 0, 0, -2, 0}, 295.652840, 0.000020, 0.076000},
	{{0, 23, -24, 0, -1, 0, 0, 0, 0, 0, 0}, 73.840380, 0.000060, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, -1, 0}, 2.281100, 0.000090, 0.041000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 0, -1}, 339.195000, 0.000040, 0.040000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 2.750170, 0.000180, 0.088000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 1, -1}, 339.195000, 0.000020, 0.087000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 1.613690, 0.000330, 0.076000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, -1}, 339.195000, 0.000130, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 182.645470, 0.000040, 7.618000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 3.409180, 0.000420, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 1, -1}, 159.195000, 0.000130, 0.076000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 1, 0}, 2.963270, 0.000040, 0.038000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, -2, 0}, 182.993230, 0.000050, 0.086000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, -1, -1}, 159.195000, 0.000020, 0.087000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, -1, 0}, 182.281100, 0.000090, 0.040000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, 0, -1}, 159.195000, 0.000040, 0.040000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 2.221710, 0.000040, 0.026000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 259.159050, 0.000030, 0.097000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 79.159050, 0.000030, 0.062000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -1, -1, -1}, 282.753450, 0.000060, 0.041000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -1, 0, -1}, 283.227250, 0.000090, 0.088000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 270.488790, 0.000160, 0.070000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, 2, 0}, 89.586660, 0.000020, 0.024000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -2, -1}, 282.755990, 0.000220, 0.076000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, -1}, 286.150310, 0.000070, 0.075000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 2, -1, 0}, 89.532610, 0.000070, 0.039000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 269.590750, 0.000060, 0.026000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 3, -2, -1}, 102.751420, 0.000040, 0.087000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 3, -1, -1}, 102.753450, 0.000060, 0.040000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 0, -1, -2}, 4.980300, 0.000040, 0.040000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 0, 0, -2}, 4.980300, 0.000030, 0.087000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 1, 0, -1}, 192.884140, 0.000040, 0.070000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -2, -2}, 4.982140, 0.000150, 0.076000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, 0, -2}, 186.690030, 0.000100, 0.075000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 4, -2, -2}, 184.980300, 0.000030, 0.087000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 4, -1, -2}, 184.980300, 0.000040, 0.040000},
	{{0, 24, -29, 0, 1, 0, 0, 0, -2, 0, 0}, 139.959900, 0.000030, 0.068000},
	{{0, 24, -28, 0, 1, 0, 0, 0, -2, 0, 0}, 128.247150, 0.000060, 0.073000},
	{{0, 24, -27, 0, -1, 0, 0, 0, -2, 0, 0}, 324.923490, 0.000030, 0.078000},
	{{0, 24, -26, -3, 0, 0, 0, 0, -2, 0, 0}, 299.673910, 0.000020, 0.075000},
	{{0, 24, -26, -3, 0, 0, 0, 0, -2, 2, 0}, 119.673910, 0.000020, 0.076000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -2, 0}, 82.757280, 0.000040, 0.074000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 261.571660, 0.000150, 0.077000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 2.115200, 0.000120, 0.071000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 1, 0, -1}, 338.282890, 0.000050, 0.077000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 2, 0, 0}, 2.204310, 0.000170, 0.026000},
	{{0, 24, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 269.418310, 0.000020, 0.103000},
	{{0, 24, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 89.418310, 0.000020, 0.060000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -3, 0}, 269.431260, 0.000150, 0.040000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 269.681290, 0.000160, 0.067000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -5, 0}, 269.431260, 0.000030, 0.038000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -4, 0}, 269.429840, 0.000510, 0.075000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -2, 0}, 89.483590, 0.000970, 0.076000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -1, 0}, 89.431260, 0.000030, 0.038000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 269.545100, 0.000050, 0.025000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 4, -4, 0}, 89.432630, 0.000090, 0.087000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 4, -3, 0}, 89.431260, 0.000150, 0.040000},
	{{0, 25, -30, 0, 1, 0, 0, 0, -2, 0, 0}, 319.865820, 0.000050, 0.071000},
	{{0, 25, -29, 0, -2, 0, 0, 0, -2, 0, 0}, 42.152250, 0.000060, 0.075000},
	{{0, 25, -29, 0, -1, 0, 0, 0, -2, 0, 0}, 290.157840, 0.000020, 0.076000},
	{{0, 25, -29, 0, -1, 0, 0, 0, -2, 2, 0}, 110.157840, 0.000020, 0.075000},
	{{0, 25, -27, -4, 0, 0, 0, 0, -2, 0, 0}, 263.139050, 0.000020, 0.076000},
	{{0, 25, -27, -4, 0, 0, 0, 0, -2, 2, 0}, 83.139050, 0.000020, 0.075000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, -2, 0}, 269.513210, 0.000040, 0.078000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 0, 0}, 87.212720, 0.000090, 0.073000},
	{{0, 25, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 181.623360, 0.000020, 0.099000},
	{{0, 25, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 1.623360, 0.000020, 0.061000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 2.034890, 0.000070, 0.068000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 0, -3}, 157.085150, 0.000050, 0.075000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 2, -3}, 337.085150, 0.000050, 0.075000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 2, 0, 0}, 2.185680, 0.000130, 0.025000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 0, -2, 0}, 89.551830, 0.000020, 0.092000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 269.644650, 0.000110, 0.064000},
	{{0, 25, -25, 0, 0, 0, 0, 0, 2, 0, 0}, 269.497560, 0.000030, 0.025000},
	{{0, 26, -32, 2, 0, 0, 0, 0, -2, 0, 0}, 321.199790, 0.000040, 0.075000},
	{{0, 26, -32, 2, 0, 0, 0, 0, -2, 2, 0}, 141.199790, 0.000040, 0.076000},
	{{0, 26, -31, 0, 1, 0, 0, 0, -2, 0, 0}, 199.358860, 0.000070, 0.075000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 0, -2, 0}, 87.937670, 0.000030, 0.070000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 0, 0, 0}, 87.937670, 0.000030, 0.082000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 2, -2, 0}, 87.937670, 0.000040, 0.095000},
	{{0, 26, -30, 0, 0, 0, 0, 0, 2, -1, 0}, 87.937670, 0.000100, 0.042000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -4, 0, 0}, 165.000740, 0.000030, 0.028000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -2, 0}, 165.000740, 0.000130, 0.026000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, -1, 0}, 165.000740, 0.001500, 0.040000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 164.778450, 0.001060, 0.087000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -1, -1, 0}, 345.000740, 0.000030, 0.081000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -3, 0}, 165.047430, 0.000290, 0.038000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, 0}, 165.047430, 0.005350, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, 2}, 165.000740, 0.000020, 0.074000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, 0}, 343.418520, 0.000040, 127.422000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, -2}, 345.000740, 0.000020, 0.074000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, 0}, 345.284980, 0.004670, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 1, 0}, 345.284980, 0.000250, 0.038000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 1, -1, 0}, 165.000740, 0.000030, 0.081000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, -2, 0}, 344.953420, 0.000940, 0.087000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, -1, 0}, 345.000740, 0.001500, 0.040000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 2, 0, 0}, 345.000740, 0.000130, 0.026000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 4, -2, 0}, 345.000740, 0.000030, 0.028000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -2, -1, 0}, 62.063810, 0.000100, 0.042000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 62.063810, 0.000040, 0.095000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -1, -1, -1}, 256.278270, 0.000050, 0.040000},
	{{0, 26, -28, 0, 0, 0, 0, 0, -1, 0, -1}, 256.278270, 0.000030, 0.087000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, -2, 0}, 62.038210, 0.000030, 0.082000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 69.820970, 0.000060, 0.070000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -2, -1}, 256.264450, 0.000160, 0.075000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, 0, -1}, 76.307740, 0.000280, 0.076000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 3, -2, -1}, 76.278270, 0.000030, 0.087000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 3, -1, -1}, 76.278270, 0.000050, 0.041000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, -2, -2}, 2.163990, 0.000020, 0.075000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, 0, -2}, 182.163990, 0.000020, 0.076000},
	{{0, 26, -27, 0, 0, 0, 0, 0, 2, 0, 0}, 2.165800, 0.000100, 0.025000},
	{{0, 26, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 89.653600, 0.000020, 0.118000},
	{{0, 26, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 269.653600, 0.000020, 0.055000},
	{{0, 26, -26, 0, 0, 0, 0, 0, 0, -2, 0}, 89.699930, 0.000020, 0.098000},
	{{0, 26, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 269.699930, 0.000020, 0.061000},
	{{0, 26, -26, 0, 0, 0, 0, 0, 2, 0, 0}, 269.448050, 0.000180, 0.024000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 180.378600, 0.000020, 0.078000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 2, 0}, 27.218600, 0.000050, 0.073000},
	{{0, 27, -32, 0, 1, 0, 0, 0, -2, 0, 0}, 139.772800, 0.000020, 0.078000},
	{{0, 27, -32, 0, 1, 0, 0, 0, -2, 2, 0}, 139.772800, 0.000020, 0.073000},
	{{0, 27, -28, 0, 0, 0, 0, 0, 2, -2, 0}, 2.142600, 0.000020, 0.071000},
	{{0, 27, -28, 0, 0, 0, 0, 0, 2, 0, 0}, 2.145400, 0.000060, 0.025000},
	{{0, 27, -27, 0, 0, 0, 0, 0, 2, 0, 0}, 269.396850, 0.000130, 0.024000},
	{{0, 28, -35, 2, 0, 0, 0, 0, -2, 0, 0}, 233.308480, 0.000020, 0.076000},
	{{0, 28, -35, 2, 0, 0, 0, 0, -2, 2, 0}, 53.308480, 0.000020, 0.075000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 152.474350, 0.000070, 0.076000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -2, 2, 0}, 332.474350, 0.000070, 0.075000},
	{{0, 28, -34, 0, 1, 0, 0, 0, -2, 0, 0}, 231.546210, 0.000020, 0.076000},
	{{0, 28, -34, 0, 1, 0, 0, 0, -2, 2, 0}, 51.546210, 0.000020, 0.075000},
	{{0, 28, -34, 0, 2, 0, 0, 0, -2, 0, 0}, 320.949380, 0.000070, 0.077000},
	{{0, 28, -28, 0, 0, 0, 0, 0, 2, 0, 0}, 269.343880, 0.000100, 0.024000},
	{{0, 29, -36, 0, 4, 0, 0, 0, -2, 0, 0}, 316.914820, 0.000030, 0.075000},
	{{0, 29, -34, 0, 0, 0, 0, 0, 0, -2, 0}, 327.109440, 0.000050, 0.075000},
	{{0, 29, -34, 0, 0, 0, 0, 0, 0, 0, 0}, 147.109440, 0.000050, 0.076000},
	{{0, 29, -34, 0, 1, 0, 0, 0, 0, -2, 0}, 319.373120, 0.000020, 0.075000},
	{{0, 29, -34, 0, 1, 0, 0, 0, 0, 0, 0}, 139.373120, 0.000020, 0.076000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -3, 0}, 65.628310, 0.000020, 0.075000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -1, 0}, 245.628310, 0.000020, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, -1, -1, -1}, 252.705350, 0.000030, 0.040000},
	{{0, 29, -33, 0, 2, 0, 0, 0, -1, 0, -1}, 252.705350, 0.000020, 0.087000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, -2, -1}, 252.705350, 0.000110, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 1, 0, -1}, 72.705350, 0.000110, 0.075000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 3, -2, -1}, 72.705350, 0.000020, 0.087000},
	{{0, 29, -33, 0, 2, 0, 0, 0, 3, -1, -1}, 72.705350, 0.000030, 0.040000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -3, 0, -1}, 203.915420, 0.000020, 0.040000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -1, -1, -1}, 203.915420, 0.000070, 0.075000},
	{{0, 35, -31, 0, 0, -3, 0, 0, -1, 1, -1}, 23.915420, 0.000070, 0.075000},
	{{0, 35, -31, 0, 0, -3, 0, 0, 1, 0, -1}, 23.915420, 0.000020, 0.040000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, -1, 0}, 37.191290, 0.000030, 0.076000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, 1, 0}, 217.191290, 0.000030, 0.075000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -4, 0, 0}, 106.248810, 0.000030, 0.040000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -2, -1, 0}, 106.248810, 0.000090, 0.075000},
	{{0, 39, -36, -5, 0, 0, 0, 0, -2, 1, 0}, 286.248810, 0.000090, 0.075000},
	{{0, 39, -36, -5, 0, 0, 0, 0, 0, 0, 0}, 286.248810, 0.000030, 0.040000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, -1, 0}, 181.325960, 0.000020, 0.075000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, 1, 0}, 1.325960, 0.000020, 0.076000},
	{{0, 43, -42, 0, 0, 0, 0, 0, -1, 0, -3}, 11.555620, 0.000090, 0.040000},
	{{0, 43, -42, 0, 0, 0, 0, 0, -1, 1, -3}, 11.555620, 0.000060, 0.087000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, -1, -3}, 11.555620, 0.000330, 0.075000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 1, -3}, 191.555620, 0.000330, 0.075000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 3, -1, -3}, 191.555620, 0.000060, 0.087000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 3, 0, -3}, 191.555620, 0.000090, 0.040000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -4, 0, 0}, 26.452700, 0.000030, 0.040000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -2, -1, 0}, 26.452700, 0.000090, 0.075000},
	{{0, 44, -42, -9, 0, 0, 0, 0, -2, 1, 0}, 206.452700, 0.000090, 0.075000},
	{{0, 44, -42, -9, 0, 0, 0, 0, 0, 0, 0}, 206.452700, 0.000030, 0.040000},
	{{0, 47, -52, 0, 4, 0, 0, 0, -2, -1, 0}, 349.654280, 0.000030, 0.075000},
	{{0, 47, -52, 0, 4, 0, 0, 0, -2, 1, 0}, 169.654280, 0.000030, 0.075000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -2, 0, 2}, 167.182790, 0.000040, 0.075000},
	{{1, -28, 26, 0, 0, 0, 0, 0, -2, 2, 2}, 347.182790, 0.000040, 0.075000},
	{{1, -25, 25, 0, 0, 0, 0, 0, 2, -2, 0}, 162.866250, 0.000030, 0.075000},
	{{1, -25, 25, 0, 0, 0, 0, 0, 2, 0, 0}, 342.866250, 0.000030, 0.075000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 2, -3, 0}, 204.257370, 0.000050, 0.075000},
	{{1, -7, 9, 0, 0, 0, 0, 0, 2, -1, 0}, 24.257370, 0.000050, 0.075000},
	{{1, -6, 4, 0, 0, 0, 0, 0, -2, 1, 0}, 166.901060, 0.000020, 0.076000},
	{{1, -6, 4, 0, 0, 0, 0, 0, -2, 3, 0}, 346.901060, 0.000020, 0.074000},
	{{1, -5, 4, 0, 0, 0, 0, 0, -2, 0, 0}, 81.707690, 0.000030, 0.040000},
	{{1, -5, 4, 0, 0, 0, 0, 0, 0, -1, 0}, 78.536440, 0.000030, 0.076000},
	{{1, -5, 4, 0, 0, 0, 0, 0, 0, 1, 0}, 258.536440, 0.000030, 0.075000},
	{{1, 0, -10, 11, 0, 0, 0, 0, -2, 0, 0}, 216.934340, 0.000090, 0.040000},
	{{1, 0, -10, 11, 0, 0, 0, 0, -2, 1, 0}, 216.934340, 0.000130, 0.087000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 2, -1, 0}, 36.934340, 0.000130, 0.087000},
	{{1, 0, -10, 11, 0, 0, 0, 0, 2, 0, 0}, 36.934340, 0.000090, 0.040000},
	{{1, 0, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 218.873400, 0.000030, 0.075000},
	{{1, 0, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 38.873400, 0.000030, 0.076000},
	{{1, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 230.552050, 0.000050, 0.042000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 299.549500, 0.000040, 0.026000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 299.642340, 0.000440, 0.041000},
	{{1, 0, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 298.902420, 0.000320, 0.088000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 300.600850, 0.000030, 0.038000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 301.824190, 0.000630, 0.076000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 123.251050, 0.000040, 6.575000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 121.980010, 0.000620, 0.075000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 122.205010, 0.000030, 0.038000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 120.197330, 0.000290, 0.086000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 120.442670, 0.000330, 0.040000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 226.640500, 0.000060, 0.027000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 226.645370, 0.000490, 0.042000},
	{{1, 0, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 226.656450, 0.000250, 0.097000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 226.854710, 0.000220, 0.083000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 47.282210, 0.000100, 0.868000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 47.143940, 0.000200, 0.069000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 19.968380, 0.000020, 0.076000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 199.968380, 0.000020, 0.075000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 48.616840, 0.000150, 0.079000},
	{{1, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 48.599450, 0.000160, 0.039000},
	{{1, 0, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 2.381310, 0.000210, 0.044000},
	{{1, 0, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 357.205590, 0.000050, 0.107000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 347.316030, 0.000170, 0.090000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 352.124110, 0.000060, 0.465000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 337.915540, 0.000030, 0.065000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 165.679830, 0.000070, 2.645000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, -1, -2}, 167.592920, 0.000070, 0.076000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 345.756380, 0.001150, 0.073000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 174.362650, 0.000120, 0.037000},
	{{1, 0, -2, 0, 0, 0, 0, 0, 2, 1, -2}, 347.592920, 0.000070, 0.075000},
	{{1, 0, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 94.871680, 0.000090, 0.046000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 268.280310, 0.000030, 0.099000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 88.666980, 0.000110, 0.317000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 88.280310, 0.000030, 0.061000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 88.122670, 0.000130, 0.068000},
	{{1, 0, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 268.033580, 0.000130, 0.036000},
	{{1, 0, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 22.075960, 0.000070, 0.049000},
	{{1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 200.788290, 0.000030, 0.241000},
	{{1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 11.647580, 0.000050, 0.035000},
	{{1, 1, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 72.102630, 0.000030, 0.075000},
	{{1, 1, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 252.102630, 0.000030, 0.075000},
	{{1, 15, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 166.837700, 0.000020, 0.076000},
	{{1, 15, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 346.837700, 0.000020, 0.075000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -3, 1, -1}, 94.341160, 0.000040, 0.040000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -3, 2, -1}, 94.341160, 0.000030, 0.087000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 92.389690, 0.000180, 0.075000},
	{{1, 15, -16, 0, 0, 0, 0, 0, -1, 2, -1}, 272.389690, 0.000180, 0.075000},
	{{1, 15, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 274.341160, 0.000030, 0.087000},
	{{1, 15, -16, 0, 0, 0, 0, 0, 1, 1, -1}, 274.341160, 0.000040, 0.040000},
	{{2, -30, 29, 0, 0, 0, 0, 0, 2, -2, 0}, 81.367500, 0.000020, 0.076000},
	{{2, -30, 29, 0, 0, 0, 0, 0, 2, 0, 0}, 261.367500, 0.000020, 0.075000},
	{{2, -24, 21, 0, 0, 0, 0, 0, 4, -4, 0}, 117.444290, 0.000030, 0.075000},
	{{2, -24, 21, 0, 0, 0, 0, 0, 4, -2, 0}, 297.444290, 0.000030, 0.075000},
	{{2, -4, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 44.456850, 0.000030, 0.076000},
	{{2, -4, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 224.456850, 0.000030, 0.075000},
	{{2, -2, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 3.699420, 0.000030, 0.074000},
	{{2, -2, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 183.699420, 0.000030, 0.076000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 203.795420, 0.000140, 0.075000},
	{{2, -2, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 23.795420, 0.000140, 0.075000},
	{{2, 0, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 230.508910, 0.000040, 0.063000},
	{{2, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 50.519500, 0.000070, 0.034000},
	{{2, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 341.814160, 0.000060, 0.189000},
	{{2, 0, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 340.901660, 0.000090, 0.060000},
	{{2, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 160.901720, 0.000060, 0.033000},
	{{2, 0, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 270.225360, 0.000130, 0.054000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 270.048050, 0.000030, 0.144000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 90.388510, 0.000180, 0.159000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 90.048050, 0.000030, 0.051000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 89.892300, 0.000150, 0.056000},
	{{2, 0, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 269.911290, 0.000170, 0.032000},
	{{2, 13, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 129.867550, 0.000020, 0.075000},
	{{2, 13, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 309.867550, 0.000020, 0.076000},
	{{3, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 51.064330, 0.000040, 0.031000},
	{{3, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 162.968380, 0.000040, 0.061000},
	{{3, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 342.273460, 0.000040, 0.118000},
	{{3, 0, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 341.198090, 0.000030, 0.050000},
	{{3, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 161.198070, 0.000110, 0.030000},
	{{3, 0, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 271.310950, 0.000120, 0.065000},
	{{3, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 91.377430, 0.000140, 0.106000},
	{{3, 0, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 90.445520, 0.000050, 0.048000},
	{{3, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 270.445480, 0.000180, 0.029000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -3, 0, 1}, 42.755700, 0.000020, 0.076000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -3, 2, 1}, 222.755700, 0.000020, 0.075000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 185.688870, 0.000110, 0.070000},
	{{3, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 8.271200, 0.000050, 0.096000},
	{{3, 0, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 109.502290, 0.000030, 0.042000},
	{{3, 0, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 193.752210, 0.000050, 0.028000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 186.565360, 0.000040, 0.026000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 1, 0}, 186.565360, 0.000420, 0.040000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -4, 2, 0}, 186.654360, 0.000260, 0.087000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 186.294920, 0.000120, 0.038000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 186.294920, 0.002160, 0.075000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 5.864440, 0.000040, 39.271000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 6.480230, 0.001510, 0.076000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 6.480230, 0.000080, 0.038000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 7.297770, 0.000140, 0.087000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 6.565360, 0.000420, 0.040000},
	{{3, 0, -1, 0, 0, 0, 0, 0, 0, 2, 0}, 6.565360, 0.000040, 0.026000},
	{{3, 0, 0, 0, 0, 0, 0, 0, -4, 1, 0}, 83.628430, 0.000030, 0.042000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -4, 1, 0}, 83.962060, 0.000020, 0.040000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -2, 0, 0}, 83.962060, 0.000080, 0.075000},
	{{3, 0, 7, -15, 0, 0, 0, 0, -2, 2, 0}, 263.962060, 0.000080, 0.075000},
	{{3, 0, 7, -15, 0, 0, 0, 0, 0, 1, 0}, 263.962060, 0.000020, 0.040000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -2, 1, 0}, 100.247060, 0.000100, 0.075000},
	{{4, -15, 6, 0, 0, 0, 0, 0, -2, 3, 0}, 280.247060, 0.000100, 0.075000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -4, 1, 0}, 120.689450, 0.000020, 0.040000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 120.689450, 0.000080, 0.075000},
	{{4, -5, 3, 0, 0, 0, 0, 0, -2, 2, 0}, 300.689450, 0.000080, 0.075000},
	{{4, -5, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 300.689450, 0.000020, 0.040000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 163.477260, 0.000040, 0.041000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 163.470590, 0.000020, 0.088000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 343.749340, 0.000180, 0.076000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 343.483830, 0.000150, 0.075000},
	{{4, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 342.730850, 0.000130, 0.086000},
	{{4, 0, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 343.477260, 0.000040, 0.040000},
	{{4, 0, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 161.685340, 0.000050, 0.028000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 92.989440, 0.000080, 0.082000},
	{{4, 0, -4, 0, 0, 0, 0, 0, -1, 2, -1}, 294.760280, 0.000060, 0.075000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 92.681800, 0.000180, 0.079000},
	{{4, 0, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 271.506320, 0.000070, 0.027000},
	{{4, 0, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 189.342290, 0.000040, 0.090000},
	{{4, 0, -3, 0, 0, 0, 0, 0, -2, 1, -2}, 190.631050, 0.000060, 0.040000},
	{{4, 0, -3, 0, 0, 0, 0, 0, -2, 2, -2}, 190.631050, 0.000040, 0.087000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 189.283150, 0.000040, 0.078000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 0, -2}, 190.772670, 0.000140, 0.076000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 189.338140, 0.000200, 0.073000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, 2, -2}, 10.736010, 0.000220, 0.075000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 10.631050, 0.000040, 0.087000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 193.540970, 0.000040, 0.026000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 2, 1, -2}, 10.631050, 0.000060, 0.040000},
	{{5, 0, -13, 7, 0, 0, 0, 0, -2, 0, 0}, 33.081240, 0.000030, 0.075000},
	{{5, 0, -13, 7, 0, 0, 0, 0, -2, 2, 0}, 213.081240, 0.000030, 0.075000},
	{{5, 0, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 52.907800, 0.000030, 0.073000}
};

static const struct planet_pert plan_pert_elp13 [ELP13_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 270.000000, 0.000110, 99999.999000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 277.117190, 0.000020, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 3.012720, 0.000010, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 1}, 248.939510, 0.000010, 1.388000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 70.482400, 0.000060, 0.949000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 68.939510, 0.000010, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 187.475090, 0.000020, 0.067000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 79.955500, 0.000020, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 150.065810, 0.000040, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 16.679610, 0.000070, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 86.257530, 0.000020, 0.020000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 0}, 144.612130, 0.000060, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 1, 0}, 142.528920, 0.000070, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0}, 152.914820, 0.000090, 0.076000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0}, 19.393660, 0.000040, 29.457000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0}, 152.914820, 0.000090, 0.075000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -1, 0}, 142.408170, 0.000070, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 0}, 144.567350, 0.000050, 0.040000},
	{{0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0}, 59.800210, 0.000040, 14.729000},
	{{0, 0, 0, 0, 1, -5, 0, 0, 0, 0, 0}, 308.782410, 0.000020, 11.705000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, -1, 0}, 300.691880, 0.000030, 0.026000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 0}, 300.691830, 0.000180, 0.041000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, 0}, 307.210400, 0.000350, 0.088000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 2, 0}, 300.691880, 0.000010, 0.538000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -2, 0}, 223.335840, 0.000010, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 0}, 228.053410, 0.000180, 0.076000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0}, 334.248470, 0.000630, 11.862000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0}, 225.546580, 0.000180, 0.075000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 2, 0}, 223.627640, 0.000010, 0.038000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, -1}, 4.055020, 0.000020, 1.032000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -2, 0}, 300.722590, 0.000010, 0.592000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, 0}, 307.699150, 0.000320, 0.086000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 300.722750, 0.000170, 0.040000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 1, 0}, 300.722670, 0.000030, 0.026000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 0, 0}, 330.243530, 0.000050, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, 0}, 276.718600, 0.000320, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 2, 0}, 259.083330, 0.000020, 0.564000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, 0}, 79.171980, 0.000090, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 0}, 79.703280, 0.001310, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, 0}, 75.698740, 0.002930, 883.328000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, 0}, 79.702150, 0.001310, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, 0}, 79.172310, 0.000090, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -2, 0}, 259.081460, 0.000020, 0.563000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, 0}, 276.567010, 0.000320, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 0, 0}, 328.374350, 0.000050, 0.040000},
	{{0, 0, 0, 0, 2, -4, 0, 0, 0, 0, 0}, 354.940680, 0.000030, 30.473000},
	{{0, 0, 0, 0, 2, -3, 0, 0, 0, 0, 0}, 37.886280, 0.000010, 14.978000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 0, 0}, 315.925890, 0.000020, 0.041000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 1, 0}, 344.070430, 0.000020, 0.088000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -1, 0}, 236.499310, 0.000050, 0.076000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0}, 75.137950, 0.000070, 5.931000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0}, 236.499310, 0.000050, 0.074000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, -1, 0}, 319.617260, 0.000020, 0.086000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0}, 286.402170, 0.000020, 0.040000},
	{{0, 0, 0, 0, 3, -5, 0, 0, 0, 0, 0}, 188.040620, 0.000050, 12.023000},
	{{0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0}, 265.059370, 0.000010, 3.954000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, -2, 0}, 302.939420, 0.000020, 0.020000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 0}, 139.859250, 0.000010, 0.041000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 1, 0}, 303.083230, 0.000080, 0.091000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 2, 0}, 297.308740, 0.000020, 0.434000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 3, 0}, 122.698840, 0.000020, 0.064000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 1}, 270.932780, 0.000020, 0.631000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, -2, 0}, 57.151410, 0.000010, 0.038000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0}, 126.817890, 0.000050, 0.079000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0}, 283.032100, 0.000050, 1.881000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0}, 125.917830, 0.000070, 0.073000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0}, 119.853920, 0.000010, 0.037000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, -1}, 45.612180, 0.000040, 1.915000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -2, 0}, 240.344110, 0.000010, 0.805000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, -1, 0}, 300.354130, 0.000030, 0.083000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 2, 0, 0}, 68.027340, 0.000010, 0.040000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, -2, 0}, 152.027960, 0.000010, 0.020000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 0}, 105.916030, 0.000020, 0.042000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -2, 0}, 298.951460, 0.000020, 0.039000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 0}, 145.347070, 0.000030, 0.082000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 14.570360, 0.000070, 0.940000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0}, 147.254780, 0.000040, 0.070000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, -1}, 35.531100, 0.000020, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, -1}, 352.596900, 0.000160, 104.137000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, -1}, 35.531100, 0.000020, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -3, 0}, 132.431050, 0.000020, 0.072000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -2, 0}, 324.375760, 0.000050, 1.407000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -1, 0}, 150.242410, 0.000030, 0.080000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0}, 152.353730, 0.000060, 0.039000},
	{{0, 0, 0, 3, 0, 0, 0, 0, -2, 1, 0}, 0.959650, 0.000030, 0.101000},
	{{0, 0, 0, 3, 0, 0, 0, 0, -2, 3, 0}, 180.959650, 0.000030, 0.060000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 0, -1, 0}, 357.450760, 0.000040, 0.086000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0}, 193.735560, 0.000050, 0.627000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 1, 0, -1}, 327.004350, 0.000010, 1.847000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -3, 0}, 30.495350, 0.000030, 0.074000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -2, 0}, 6.359570, 0.000060, 5.588000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -1, 0}, 177.450460, 0.000210, 0.076000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, 0, 0}, 354.780560, 0.000040, 0.038000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 0, -1, 0}, 42.644150, 0.000020, 0.090000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0}, 222.644150, 0.000030, 0.470000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0}, 42.644150, 0.000020, 0.065000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, -3, 0}, 32.206690, 0.000010, 0.078000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, -1, -2}, 42.428500, 0.000040, 0.076000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, -1, 0}, 194.967570, 0.000050, 0.073000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, 0, -2}, 52.933990, 0.000100, 52.068000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, 0, 0}, 250.622180, 0.000030, 0.037000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, 1, -2}, 42.428500, 0.000040, 0.075000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 0, -1, 0}, 251.399280, 0.000030, 0.094000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0}, 71.350460, 0.000060, 0.376000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0}, 251.399260, 0.000040, 0.063000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 2, -3, 0}, 68.862250, 0.000020, 0.081000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 2, -1, 0}, 70.728380, 0.000080, 0.071000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 2, 0, -2}, 71.399200, 0.000010, 1.815000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 2, 0, 0}, 60.784400, 0.000050, 0.037000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 3, -3, 0}, 71.263400, 0.000010, 383.916000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 0, -1, 0}, 280.227370, 0.000010, 0.099000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0}, 100.068680, 0.000050, 0.313000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0}, 280.227370, 0.000010, 0.061000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0}, 280.775060, 0.000010, 0.034000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 2, -3, 0}, 275.276110, 0.000010, 0.084000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 2, -2, 0}, 97.948100, 0.000020, 0.706000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 2, -1, 0}, 99.508220, 0.000100, 0.068000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 2, 0, 0}, 278.721050, 0.000070, 0.036000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 0, -1, 0}, 129.655570, 0.000010, 0.105000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0}, 309.655570, 0.000020, 0.269000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 0, 1, 0}, 129.655570, 0.000010, 0.059000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 0, 2, 0}, 309.655570, 0.000020, 0.033000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 2, -1, 0}, 309.281280, 0.000020, 0.066000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 2, 0, 0}, 129.745060, 0.000020, 0.035000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 2, 2, 0}, 309.655570, 0.000010, 0.018000},
	{{0, 0, 0, 8, 0, 0, 0, 0, 2, -1, 0}, 338.397980, 0.000040, 0.064000},
	{{0, 0, 0, 8, 0, 0, 0, 0, 2, 0, 0}, 338.397980, 0.000020, 0.034000},
	{{0, 0, 1, -10, 0, 0, 0, 0, -2, 0, 0}, 352.436470, 0.000030, 0.034000},
	{{0, 0, 1, -10, 0, 0, 0, 0, -2, 1, 0}, 352.270710, 0.000030, 0.063000},
	{{0, 0, 1, -10, 0, 0, 0, 0, -2, 2, 0}, 172.541190, 0.000020, 0.393000},
	{{0, 0, 1, -9, 0, 0, 0, 0, -2, 0, 0}, 201.550340, 0.000020, 0.035000},
	{{0, 0, 1, -8, 0, 0, 0, 0, -2, -2, 0}, 230.302500, 0.000010, 0.018000},
	{{0, 0, 1, -8, 0, 0, 0, 0, -2, 0, 0}, 50.414250, 0.000030, 0.036000},
	{{0, 0, 1, -8, 0, 0, 0, 0, -2, 1, 0}, 230.404690, 0.000030, 0.068000},
	{{0, 0, 1, -8, 0, 0, 0, 0, 0, -2, 0}, 230.302500, 0.000020, 0.034000},
	{{0, 0, 1, -8, 0, 0, 0, 0, 0, -1, 0}, 50.302500, 0.000020, 0.061000},
	{{0, 0, 1, -8, 0, 0, 0, 0, 0, 1, 0}, 50.302500, 0.000020, 0.100000},
	{{0, 0, 1, -7, 0, 0, 0, 0, -2, 0, 0}, 260.414320, 0.000060, 0.036000},
	{{0, 0, 1, -7, 0, 0, 0, 0, -2, 0, 2}, 79.413460, 0.000010, 1.628000},
	{{0, 0, 1, -7, 0, 0, 0, 0, -2, 1, 0}, 78.825970, 0.000040, 0.070000},
	{{0, 0, 1, -7, 0, 0, 0, 0, -2, 2, 0}, 79.413460, 0.000020, 1.055000},
	{{0, 0, 1, -7, 0, 0, 0, 0, -2, 3, 0}, 77.162190, 0.000010, 0.081000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, -2, 0}, 259.184930, 0.000010, 0.034000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, -1, 0}, 259.467900, 0.000030, 0.063000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, 0, 0}, 79.541300, 0.000040, 0.367000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, 1, 0}, 259.467900, 0.000030, 0.095000},
	{{0, 0, 1, -6, 0, 0, 0, 0, -2, 0, 0}, 108.468610, 0.000030, 0.037000},
	{{0, 0, 1, -6, 0, 0, 0, 0, -2, 0, 2}, 159.827320, 0.000010, 12.111000},
	{{0, 0, 1, -6, 0, 0, 0, 0, -2, 1, 0}, 113.717200, 0.000040, 0.073000},
	{{0, 0, 1, -6, 0, 0, 0, 0, -2, 3, 0}, 123.293770, 0.000020, 0.078000},
	{{0, 0, 1, -6, 0, 0, 0, 0, 0, -1, 0}, 288.499670, 0.000030, 0.065000},
	{{0, 0, 1, -6, 0, 0, 0, 0, 0, 0, 0}, 108.514200, 0.000050, 0.457000},
	{{0, 0, 1, -6, 0, 0, 0, 0, 0, 1, 0}, 288.499670, 0.000030, 0.090000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -4, 3, 0}, 324.097060, 0.000010, 0.088000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 0, 0}, 318.135180, 0.000050, 0.038000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 1, 0}, 328.803290, 0.000120, 0.076000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 3, 0}, 124.597700, 0.000040, 0.075000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -1, 0, 1}, 234.964800, 0.000010, 1.654000},
	{{0, 0, 1, -5, 0, 0, 0, 0, 0, 0, 0}, 334.956050, 0.000060, 0.603000},
	{{0, 0, 1, -5, 0, 0, 0, 0, 0, 1, 0}, 141.399480, 0.000020, 0.086000},
	{{0, 0, 1, -5, 0, 0, 0, 0, 2, -3, 0}, 330.118670, 0.000010, 0.060000},
	{{0, 0, 1, -5, 0, 0, 0, 0, 2, -1, 0}, 150.118670, 0.000010, 0.102000},
	{{0, 0, 1, -5, 0, 0, 0, 0, 2, 0, 0}, 330.201890, 0.000030, 0.043000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -4, 2, 0}, 357.953330, 0.000010, 0.042000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 0, 0}, 164.877000, 0.000110, 0.039000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 1, 0}, 184.469060, 0.000040, 0.079000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 2, 0}, 193.262700, 0.000020, 1.545000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 0, 1}, 251.396000, 0.000050, 13.704000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 0, 0}, 270.335300, 0.000010, 0.888000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 0, 2, 0}, 328.814150, 0.000010, 0.039000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, -2, 0}, 174.200520, 0.000010, 0.345000},
	{{0, 0, 1, -4, 0, 0, 0, 0, 2, 0, 0}, 74.147060, 0.000010, 0.042000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 0, 0}, 32.502340, 0.000140, 0.039000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 1, 0}, 35.520630, 0.000060, 0.083000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 2, 0}, 42.120030, 0.000020, 0.848000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 0, 1}, 70.254630, 0.000030, 2.180000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, -1, 0}, 28.247310, 0.000110, 0.072000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 0, 0}, 336.701570, 0.000070, 1.681000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 1, 0}, 27.211440, 0.000080, 0.079000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 2, 0}, 208.619540, 0.000020, 0.039000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, -1, 0}, 208.247310, 0.000020, 0.092000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 0, 0}, 29.928750, 0.000060, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -2, 0}, 244.877140, 0.000010, 0.019000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, -1, 0}, 53.077310, 0.000020, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 0}, 54.173790, 0.000200, 0.040000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, 0}, 59.522040, 0.000300, 0.087000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 3, 0}, 64.012690, 0.000020, 0.067000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 1}, 58.749540, 0.000020, 1.010000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -2, 0}, 29.752390, 0.000030, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 0}, 43.108530, 0.000570, 0.075000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, 0}, 57.645030, 0.002350, 15.781000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, 0}, 43.405320, 0.000590, 0.076000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, 0}, 45.513860, 0.000050, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, -1}, 60.693040, 0.000030, 0.895000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, 0}, 57.993040, 0.000350, 0.088000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, 0}, 43.739730, 0.000070, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 1, 0}, 51.090440, 0.000020, 0.026000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 2, 0}, 237.075530, 0.000020, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 0}, 259.944980, 0.000030, 0.041000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 1, 0}, 92.914900, 0.000140, 0.091000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 2, 0}, 93.107580, 0.000020, 0.446000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 0, 1}, 241.924860, 0.000010, 0.657000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -2, 0}, 271.869780, 0.000030, 0.038000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0}, 252.576610, 0.000110, 2.135000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 1, 0}, 242.569720, 0.000020, 0.073000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 2, 0}, 291.534840, 0.000010, 0.037000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 0, -1}, 13.041170, 0.000040, 1.708000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -2, 0}, 266.194310, 0.000010, 0.766000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, 0}, 87.237440, 0.000120, 0.040000},
	{{0, 0, 1, 0, -4, 0, 0, 0, 0, 0, 0}, 25.582420, 0.000040, 1.509000},
	{{0, 0, 1, 0, -4, 5, 0, 0, 0, 0, 0}, 10.410900, 0.000010, 1.201000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, 0}, 32.652080, 0.000060, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 1, 0}, 32.652060, 0.000070, 0.093000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -1, 0}, 30.964020, 0.000050, 0.080000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 0, 0}, 30.477280, 0.000260, 1.339000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 1, 0}, 30.964020, 0.000050, 0.071000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -1, 0}, 59.949150, 0.000030, 0.082000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 0, 0}, 33.685240, 0.000010, 0.039000},
	{{0, 0, 1, 0, -3, 5, 0, 0, -2, 0, 0}, 75.823460, 0.000010, 0.042000},
	{{0, 0, 1, 0, -3, 5, 0, 0, 0, 0, 0}, 75.687570, 0.000060, 1.091000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, -1, 0}, 43.949310, 0.000030, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 0}, 43.912630, 0.000260, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, 0}, 44.094990, 0.000360, 0.094000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 2, 0}, 43.947460, 0.000010, 0.384000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 1}, 337.444730, 0.000010, 0.530000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -2, 0}, 42.296670, 0.000010, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, 0}, 42.826290, 0.000270, 0.080000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 0}, 43.209420, 0.001080, 1.203000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, 0}, 42.153310, 0.000190, 0.071000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 2, 0}, 42.382330, 0.000010, 0.037000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 0}, 44.427290, 0.000020, 17.980000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 1}, 337.454460, 0.000030, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, -1}, 337.455810, 0.000070, 4.497000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 0}, 44.694750, 0.000040, 0.076000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, 0}, 42.508520, 0.000120, 0.081000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, 0}, 42.717860, 0.000050, 0.039000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 0, 0}, 120.766810, 0.000010, 0.042000},
	{{0, 0, 1, 0, -2, 5, 0, 0, -2, 1, 0}, 177.481750, 0.000010, 0.095000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 0, 0, 0}, 104.548000, 0.000020, 0.999000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 0}, 112.458370, 0.000020, 0.042000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0}, 40.875910, 0.000030, 1.092000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, -1}, 169.723120, 0.000020, 7.243000},
	{{0, 0, 1, 0, 0, -5, 0, 0, -2, 0, 0}, 50.855860, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, -5, 0, 0, 0, 0, 0}, 49.084440, 0.000040, 1.204000},
	{{0, 0, 1, 0, 0, -3, 0, 0, -2, 0, 0}, 136.154380, 0.000020, 0.042000},
	{{0, 0, 1, 0, 0, -3, 0, 0, 0, 0, 0}, 136.366610, 0.000030, 1.113000},
	{{0, 0, 1, 0, 0, -2, 0, 0, -2, 0, 0}, 36.682480, 0.000010, 0.042000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 0, 0, 0}, 37.089850, 0.000040, 1.073000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, -1}, 14.881670, 0.000030, 8.220000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0}, 256.608560, 0.000010, 1.035000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 0, 0}, 345.876980, 0.000020, 0.021000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -4, 1, 0}, 341.536920, 0.000010, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -2, 0}, 303.062800, 0.000030, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -1, 0}, 342.268290, 0.000090, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 14.976700, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 134.611830, 0.000110, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 135.680300, 0.000040, 0.360000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -1, 1}, 192.417370, 0.000020, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, -1}, 234.359230, 0.000040, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 1}, 256.251260, 0.000030, 0.487000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, -1}, 29.148160, 0.000040, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, 1}, 192.417370, 0.000020, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 133.396250, 0.000100, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 302.136780, 0.000170, 1.000000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 91.563070, 0.000070, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 241.256380, 0.000020, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -3, 1}, 173.925350, 0.000020, 0.077000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -2, 1}, 318.868110, 0.000010, 3.575000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, -1}, 127.390750, 0.000080, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 1}, 96.394590, 0.000050, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 18.106130, 0.000080, 18.600000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1}, 218.350070, 0.000040, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, -1}, 127.390750, 0.000080, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 351.560400, 0.000010, 0.071000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 330.946550, 0.000060, 1.292000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 316.388010, 0.000090, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -2}, 161.065050, 0.000010, 0.903000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 28.093970, 0.000090, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 1, 0}, 161.065050, 0.000010, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 2, 0}, 156.248890, 0.000020, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 3, -1, -1}, 307.390750, 0.000020, 0.088000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0}, 41.594230, 0.000010, 0.967000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 0, -1}, 160.863340, 0.000040, 50.462000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 0, -1}, 131.670400, 0.000090, 70.769000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 0, 0}, 108.351930, 0.000020, 0.042000},
	{{0, 0, 1, 0, 1, -5, 0, 0, 0, 0, 0}, 107.320900, 0.000060, 1.093000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 0, -1}, 347.104920, 0.000070, 293.315000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, 0}, 173.944460, 0.000030, 0.042000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 1, 0}, 173.944460, 0.000020, 0.096000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0}, 158.220830, 0.000070, 0.922000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, -1}, 165.375570, 0.000110, 32.746000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, 0}, 164.340260, 0.000080, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 1, 0}, 163.705820, 0.000120, 0.095000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -1, 0}, 164.337780, 0.000070, 0.082000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 0, 0}, 162.460500, 0.000370, 1.001000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 1, 0}, 163.607360, 0.000080, 0.070000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 2, 0, 0}, 160.779280, 0.000010, 0.039000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 1, 0, -1}, 141.083800, 0.000070, 8.708000},
	{{0, 0, 1, 0, 4, 0, 0, 0, 2, -3, 0}, 67.725020, 0.000020, 0.073000},
	{{0, 0, 1, 0, 4, 0, 0, 0, 2, -1, 0}, 67.725020, 0.000020, 0.078000},
	{{0, 0, 1, 1, 0, 0, 0, 0, -2, 0, 0}, 152.827040, 0.000030, 0.043000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, -2, 0}, 266.155230, 0.000010, 0.040000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, -1, 0}, 332.717450, 0.000050, 0.085000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0}, 269.604070, 0.000030, 0.653000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0}, 331.798120, 0.000040, 0.068000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 1, 0, -1}, 284.630960, 0.000030, 2.092000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -3, 0}, 307.896950, 0.000030, 0.074000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -2, 0}, 318.850070, 0.000030, 4.127000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -1, 0}, 164.641490, 0.000080, 0.077000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, 0, 0}, 313.687620, 0.000030, 0.038000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -2, 0, 0}, 355.873530, 0.000010, 0.044000},
	{{0, 0, 1, 2, 0, 0, 0, 0, -2, 2, 0}, 355.873530, 0.000010, 0.261000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 0, -2, 0}, 180.528670, 0.000010, 0.041000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 0, -1, 0}, 180.249270, 0.000010, 0.089000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0}, 194.771570, 0.000070, 0.485000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, -3, 0}, 182.737670, 0.000020, 0.077000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, -2, 0}, 27.015930, 0.000060, 3.456000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, -1, 0}, 359.676670, 0.000100, 0.074000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, 0, -2}, 342.589370, 0.000040, 22.644000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, 0, 0}, 221.128710, 0.000030, 0.037000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 4, -3, 0}, 0.249270, 0.000010, 0.085000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 0, -1, 0}, 43.590020, 0.000010, 0.094000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0}, 222.360030, 0.000030, 0.385000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 0, 1, 0}, 42.360030, 0.000020, 0.063000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, -3, 0}, 47.357740, 0.000010, 0.080000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, -2, 0}, 42.360030, 0.000010, 1.218000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, -1, 0}, 38.662780, 0.000050, 0.071000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, 0, -2}, 42.360030, 0.000010, 2.051000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, 0, 0}, 219.355980, 0.000030, 0.037000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, 2, 0}, 222.360030, 0.000010, 0.019000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 0, -1, 0}, 251.267420, 0.000030, 0.099000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 0, 0, 0}, 67.916280, 0.000110, 0.320000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 0, 1, 0}, 251.280080, 0.000040, 0.061000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 2, -3, 0}, 73.170350, 0.000020, 0.084000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 2, -1, 0}, 71.663320, 0.000080, 0.068000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 0, 0, 0}, 100.195700, 0.000080, 0.273000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 0, 2, 0}, 280.734020, 0.000010, 0.033000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 2, -3, 0}, 280.340460, 0.000010, 0.088000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 2, -2, 0}, 98.464570, 0.000050, 0.531000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 2, -1, 0}, 100.464970, 0.000010, 0.066000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 2, 0, 0}, 278.768150, 0.000060, 0.035000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 2, 2, 0}, 100.496710, 0.000020, 0.018000},
	{{0, 0, 1, 6, 0, 0, 0, 0, 0, 0, 0}, 309.600110, 0.000030, 0.239000},
	{{0, 0, 1, 6, 0, 0, 0, 0, 2, -1, 0}, 309.600110, 0.000010, 0.064000},
	{{0, 0, 1, 7, 0, 0, 0, 0, 2, 0, 0}, 338.325670, 0.000020, 0.034000},
	{{0, 0, 1, 8, 0, 0, 0, 0, 2, 0, 0}, 187.402720, 0.000010, 0.033000},
	{{0, 0, 2, -12, 0, 0, 0, 0, -2, 0, 0}, 143.255380, 0.000010, 0.034000},
	{{0, 0, 2, -12, 0, 0, 0, 0, -2, 2, 0}, 323.255380, 0.000010, 0.384000},
	{{0, 0, 2, -11, 0, 0, 0, 0, -2, 0, 0}, 352.330440, 0.000060, 0.035000},
	{{0, 0, 2, -11, 0, 0, 0, 0, -2, 2, 0}, 171.984870, 0.000010, 0.482000},
	{{0, 0, 2, -10, 0, 0, 0, 0, -2, 0, 0}, 201.291610, 0.000030, 0.036000},
	{{0, 0, 2, -10, 0, 0, 0, 0, 0, 0, 0}, 201.191160, 0.000010, 0.301000},
	{{0, 0, 2, -9, 0, 0, 0, 0, -2, -2, 0}, 230.259290, 0.000010, 0.019000},
	{{0, 0, 2, -9, 0, 0, 0, 0, -2, 2, 0}, 50.332680, 0.000020, 0.989000},
	{{0, 0, 2, -9, 0, 0, 0, 0, 0, -2, 0}, 230.259290, 0.000020, 0.034000},
	{{0, 0, 2, -9, 0, 0, 0, 0, 0, -1, 0}, 50.259290, 0.000020, 0.062000},
	{{0, 0, 2, -9, 0, 0, 0, 0, 0, 0, 0}, 50.095230, 0.000010, 0.359000},
	{{0, 0, 2, -9, 0, 0, 0, 0, 0, 1, 0}, 50.259290, 0.000020, 0.096000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 0, 0}, 260.143890, 0.000070, 0.037000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 0, 2}, 259.376640, 0.000030, 6.852000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 1, 0}, 79.376650, 0.000030, 0.073000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, -2, 0}, 259.392860, 0.000020, 0.035000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, -1, 0}, 259.376640, 0.000030, 0.064000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, 0, 0}, 84.632280, 0.000080, 0.444000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, 1, 0}, 259.376640, 0.000030, 0.091000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 0, 0}, 108.790250, 0.000050, 0.038000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 0, 2}, 288.281040, 0.000010, 2.592000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 1, 0}, 295.081510, 0.000160, 0.076000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 2, 0}, 317.335010, 0.000050, 19.147000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 3, 0}, 103.395790, 0.000030, 0.075000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 0, -2, 0}, 288.281040, 0.000020, 0.035000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 0, -1, 0}, 288.304930, 0.000040, 0.067000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 0, 0, 0}, 293.721620, 0.000050, 0.581000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 2, -2, 0}, 301.079660, 0.000020, 0.286000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 2, 0, 0}, 121.031130, 0.000010, 0.043000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 0, 0}, 317.229730, 0.000080, 0.039000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 1, 0}, 141.134740, 0.000010, 0.079000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 3, 0}, 141.134740, 0.000010, 0.072000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -1, 0, 1}, 165.420970, 0.000030, 7.335000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 0, 0, 0}, 332.882350, 0.000040, 0.840000},
	{{0, 0, 2, -6, 0, 0, 0, 0, 2, 0, 0}, 329.946020, 0.000040, 0.042000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -4, 2, 0}, 177.961330, 0.000010, 0.042000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -4, 3, 0}, 177.971220, 0.000010, 0.096000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 0, 0}, 180.757680, 0.000080, 0.039000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 1, 0}, 180.783410, 0.000120, 0.082000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 2, 0}, 344.650330, 0.000020, 0.896000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 3, 0}, 344.500890, 0.000020, 0.070000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 0, 1}, 31.748220, 0.000020, 2.529000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 1, -1}, 200.998080, 0.000050, 0.076000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 3, -1}, 28.438520, 0.000020, 0.075000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, -2, 0}, 178.633660, 0.000020, 0.037000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, -1, 0}, 5.188620, 0.000050, 0.072000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 0, 0}, 161.583810, 0.000020, 1.519000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 1, 0}, 3.622720, 0.000060, 0.079000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, -2, 0}, 174.190520, 0.000010, 0.411000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 2, 0, 0}, 354.190520, 0.000010, 0.042000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, -1, 0}, 29.537890, 0.000020, 0.026000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, 0}, 32.064950, 0.000210, 0.040000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 1, 0}, 27.157220, 0.000140, 0.086000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 2, 0}, 176.052240, 0.000010, 0.607000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 3, 0}, 212.381630, 0.000030, 0.067000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -1, 0, 1}, 107.782260, 0.000020, 1.079000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -2, 0}, 20.119310, 0.000010, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, 0}, 21.962170, 0.000230, 0.075000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, 0}, 27.887770, 0.001430, 7.890000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, 0}, 22.325730, 0.000230, 0.076000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 2, 0}, 212.740960, 0.000020, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, 0}, 29.524900, 0.000240, 0.088000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, 0}, 26.908510, 0.000130, 0.041000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 1, 0}, 27.359390, 0.000010, 0.026000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, -2, 0}, 244.543680, 0.000010, 0.020000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, 0}, 56.720330, 0.000060, 0.041000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 1, 0}, 52.264060, 0.000060, 0.090000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 2, 0}, 59.150260, 0.000010, 0.459000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 0, 1}, 56.867280, 0.000020, 0.686000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, 0}, 64.869360, 0.000090, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, 0}, 62.194890, 0.000310, 2.470000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, 0}, 67.471740, 0.000060, 0.073000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -3, 0}, 52.191230, 0.000010, 0.068000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -1, 0}, 44.957460, 0.000010, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, 0}, 240.116230, 0.000050, 0.040000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 2, 0}, 236.849840, 0.000030, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 0}, 274.303280, 0.000090, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 1, 0}, 88.996180, 0.000060, 0.095000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 2, 0}, 93.291900, 0.000020, 0.369000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -2, 0}, 286.685670, 0.000020, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, 0}, 266.580590, 0.000050, 0.081000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0}, 216.680980, 0.000050, 1.068000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, 0}, 264.143150, 0.000040, 0.070000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 2, 0}, 86.932390, 0.000020, 0.036000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, -1}, 262.151760, 0.000030, 8.537000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 0}, 266.079590, 0.000030, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -3, 0}, 90.397850, 0.000020, 0.071000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -2, 0}, 86.948690, 0.000030, 1.194000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -1, 0}, 260.638450, 0.000010, 0.081000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, 0}, 91.130930, 0.000020, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 4, -2, 0}, 266.615000, 0.000010, 0.042000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 0, 0}, 301.550630, 0.000030, 0.043000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 2, 0}, 302.559120, 0.000030, 0.308000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, -1, 0}, 114.612440, 0.000020, 0.085000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 0, 0}, 275.881510, 0.000030, 0.681000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 1, 0}, 114.612440, 0.000020, 0.068000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 0, 2, 0}, 114.926350, 0.000010, 0.036000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 0, -1}, 218.121440, 0.000040, 2.412000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -3, 0}, 320.705820, 0.000010, 0.074000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -2, 0}, 296.610570, 0.000060, 3.271000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -1, 0}, 299.197430, 0.000050, 0.077000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, 0, 0}, 105.978570, 0.000070, 0.038000},
	{{0, 0, 2, 0, -5, 0, 0, 0, 0, 0, 0}, 261.050350, 0.000020, 0.634000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 0, 0, 0}, 313.231210, 0.000010, 0.572000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -2, 0}, 132.811610, 0.000020, 38.763000},
	{{0, 0, 2, 0, -5, 5, 0, 0, 2, -1, 0}, 133.123600, 0.000030, 0.076000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 0, 0}, 251.456570, 0.000030, 0.043000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 1, 0}, 251.456290, 0.000030, 0.102000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, -1, 0}, 249.644640, 0.000030, 0.086000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 0, 0, 0}, 251.147600, 0.000070, 0.601000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, 0}, 69.644640, 0.000130, 0.076000},
	{{0, 0, 2, 0, -4, 3, 0, 0, 2, -2, 0}, 320.980650, 0.000020, 106.494000},
	{{0, 0, 2, 0, -4, 5, 0, 0, -2, 0, 0}, 254.345940, 0.000020, 0.044000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 0, 0, 0}, 254.287970, 0.000040, 0.546000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -2, 0}, 74.600490, 0.000010, 17.093000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -1, 0}, 254.546740, 0.000050, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, 0}, 243.088320, 0.000090, 0.043000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, 0}, 243.088320, 0.000100, 0.103000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -2, 0}, 239.230330, 0.000010, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 0}, 239.683410, 0.000520, 0.087000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 0}, 240.996680, 0.000280, 0.572000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, 0}, 242.237230, 0.000050, 0.067000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, 0}, 60.431080, 0.000060, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 0}, 59.314570, 0.001570, 37.133000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 0}, 59.337740, 0.002440, 0.076000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, 0}, 59.338600, 0.000160, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -3, 0}, 58.717420, 0.000020, 0.087000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, 0}, 59.311760, 0.000050, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -1, 0}, 59.335800, 0.000020, 0.026000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 0}, 310.394870, 0.000030, 0.044000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 1, 0}, 310.394870, 0.000030, 0.104000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, -1, 0}, 176.549290, 0.000020, 0.088000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 0, 0, 0}, 326.978400, 0.000040, 0.546000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -2, 0}, 111.114980, 0.000020, 17.430000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, 0}, 356.549140, 0.000110, 0.075000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 0, 0, 0}, 290.901620, 0.000010, 0.573000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -2, 0}, 110.806320, 0.000020, 35.635000},
	{{0, 0, 2, 0, -1, -5, 0, 0, 2, -1, 0}, 110.814940, 0.000030, 0.076000},
	{{0, 0, 2, 0, -1, -4, 0, 0, 2, -2, 0}, 358.773890, 0.000020, 169.910000},
	{{0, 0, 2, 0, -1, 0, 0, 0, -2, 0, 0}, 300.553850, 0.000020, 0.044000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 0, 0, 0}, 295.794890, 0.000020, 0.522000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, -1}, 184.183590, 0.000020, 1.160000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -3, 0}, 50.692970, 0.000020, 0.076000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 2, -1, 0}, 304.944160, 0.000030, 0.075000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 0, 0}, 284.910520, 0.000020, 0.044000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 0, 0, 0}, 284.340660, 0.000040, 0.546000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -1, 0}, 284.696840, 0.000060, 0.075000},
	{{0, 0, 2, 0, 0, -3, 0, 0, -2, 0, 0}, 34.991590, 0.000020, 0.044000},
	{{0, 0, 2, 0, 0, -3, 0, 0, 0, 0, 0}, 35.021350, 0.000020, 0.527000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, -2, 0}, 50.014870, 0.000030, 0.020000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 82.814070, 0.000040, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 1, 0}, 331.608910, 0.000030, 0.105000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -1, 0, 1}, 246.741240, 0.000040, 0.327000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, -2, 0}, 294.880300, 0.000020, 0.041000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 131.278680, 0.000040, 0.089000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 148.351540, 0.000180, 0.500000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 77.065840, 0.000030, 0.066000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 2, 0}, 247.638250, 0.000010, 0.035000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 0, -1}, 317.710870, 0.000030, 1.057000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 354.210170, 0.000030, 0.077000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 317.396460, 0.000080, 4.425000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 2.837110, 0.000170, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 312.806380, 0.000200, 0.037000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 1, 0}, 312.908140, 0.000020, 0.025000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, 0, -2}, 77.606400, 0.000020, 43.055000},
	{{0, 0, 2, 0, 2, -5, 0, 0, -2, 0, 0}, 60.546100, 0.000020, 0.044000},
	{{0, 0, 2, 0, 2, -5, 0, 0, 0, 0, 0}, 59.666520, 0.000010, 0.500000},
	{{0, 0, 2, 0, 3, 0, 0, 0, 2, -1, 0}, 247.759070, 0.000040, 0.073000},
	{{0, 0, 2, 1, 0, 0, 0, 0, -2, 1, 0}, 0.061170, 0.000010, 0.112000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 0, -1, 0}, 13.325930, 0.000010, 0.093000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0}, 187.656760, 0.000060, 0.395000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 0, 1, 0}, 13.325930, 0.000010, 0.063000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, -3, 0}, 172.861380, 0.000010, 0.080000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, -1, 0}, 182.333640, 0.000060, 0.071000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, 0, 0}, 188.449950, 0.000090, 0.037000},
	{{0, 0, 2, 2, 0, 0, 0, 0, -2, 0, 0}, 28.055570, 0.000020, 0.046000},
	{{0, 0, 2, 2, 0, 0, 0, 0, -2, 2, 0}, 208.055570, 0.000020, 0.207000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 0, -1, 0}, 220.502330, 0.000020, 0.098000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 0}, 46.041820, 0.000030, 0.326000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 0, 2, 0}, 221.996790, 0.000010, 0.034000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 2, -2, 0}, 42.171290, 0.000010, 0.776000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 2, -1, 0}, 41.149050, 0.000140, 0.069000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 2, 0, 0}, 220.816050, 0.000100, 0.036000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 0, -1, 0}, 250.953420, 0.000020, 0.104000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 0}, 91.283490, 0.000030, 0.278000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 0, 1, 0}, 251.085320, 0.000030, 0.059000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 2, -1, 0}, 70.563420, 0.000070, 0.066000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 2, 0, 0}, 252.894290, 0.000030, 0.035000},
	{{0, 0, 2, 4, 0, 0, 0, 0, 0, 0, 0}, 100.332270, 0.000040, 0.242000},
	{{0, 0, 2, 4, 0, 0, 0, 0, 0, 2, 0}, 280.137520, 0.000020, 0.033000},
	{{0, 0, 2, 4, 0, 0, 0, 0, 2, 2, 0}, 100.456790, 0.000020, 0.018000},
	{{0, 0, 2, 5, 0, 0, 0, 0, 0, 0, 0}, 309.510710, 0.000040, 0.215000},
	{{0, 0, 2, 5, 0, 0, 0, 0, 2, -1, 0}, 309.510710, 0.000010, 0.062000},
	{{0, 0, 2, 6, 0, 0, 0, 0, 2, -3, 0}, 158.398270, 0.000010, 0.102000},
	{{0, 0, 2, 6, 0, 0, 0, 0, 2, -1, 0}, 158.398270, 0.000010, 0.060000},
	{{0, 0, 2, 6, 0, 0, 0, 0, 2, 0, 0}, 338.213940, 0.000020, 0.033000},
	{{0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0}, 7.117820, 0.000020, 0.033000},
	{{0, 0, 3, -13, 0, 0, 0, 0, -2, 0, 0}, 143.151200, 0.000030, 0.035000},
	{{0, 0, 3, -12, 0, 0, 0, 0, -2, 0, 0}, 352.206880, 0.000080, 0.036000},
	{{0, 0, 3, -12, 0, 0, 0, 0, -2, 1, 0}, 172.426420, 0.000030, 0.067000},
	{{0, 0, 3, -11, 0, 0, 0, 0, -2, 0, 0}, 201.233000, 0.000030, 0.036000},
	{{0, 0, 3, -11, 0, 0, 0, 0, -2, 1, 0}, 201.491780, 0.000020, 0.070000},
	{{0, 0, 3, -11, 0, 0, 0, 0, 0, 0, 0}, 201.146160, 0.000010, 0.351000},
	{{0, 0, 3, -10, 0, 0, 0, 0, -2, 0, 0}, 50.620990, 0.000010, 0.037000},
	{{0, 0, 3, -10, 0, 0, 0, 0, -2, 0, 2}, 230.310070, 0.000010, 4.778000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 0, 0}, 267.226230, 0.000070, 0.038000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 0, 2}, 259.229340, 0.000020, 3.102000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 1, 0}, 60.125550, 0.000020, 0.075000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 2, 0}, 8.892700, 0.000030, 89.761000},
	{{0, 0, 3, -9, 0, 0, 0, 0, 0, -1, 0}, 259.231330, 0.000030, 0.066000},
	{{0, 0, 3, -9, 0, 0, 0, 0, 0, 0, 0}, 248.198790, 0.000010, 0.560000},
	{{0, 0, 3, -9, 0, 0, 0, 0, 0, 1, 0}, 259.231330, 0.000030, 0.087000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 0, 0}, 130.520720, 0.000020, 0.038000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 1, 0}, 289.486610, 0.000050, 0.079000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 2, 0}, 288.047470, 0.000020, 1.921000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 3, 0}, 289.709170, 0.000040, 0.073000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -1, 0, 1}, 103.566770, 0.000020, 5.007000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, -1, 0}, 288.231980, 0.000050, 0.069000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, 0, 0}, 282.260130, 0.000100, 0.798000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, 1, 0}, 287.932780, 0.000040, 0.083000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 2, -1, 0}, 108.231980, 0.000010, 0.098000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 2, 0, 0}, 120.707980, 0.000050, 0.043000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 0, 0}, 105.006880, 0.000120, 0.999000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 1, 0}, 104.669140, 0.000040, 0.082000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -1, 0}, 105.045850, 0.000120, 0.095000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, 0}, 104.952750, 0.000100, 0.042000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -2, 0, 0}, 159.671960, 0.000080, 0.039000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -2, 1, 0}, 151.501780, 0.000120, 0.082000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -2, 2, 0}, 1.120490, 0.000020, 0.950000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -2, 3, 0}, 177.608570, 0.000010, 0.070000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 0, 1}, 342.978500, 0.000010, 3.012000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 1, -1}, 183.573800, 0.000060, 0.075000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, -1}, 289.290030, 0.000300, 650.233000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, -1, 0}, 318.182610, 0.000030, 0.072000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, 0, 0}, 306.529290, 0.000030, 1.385000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, 1, 0}, 323.956320, 0.000060, 0.080000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, -3, 0}, 329.523240, 0.000030, 0.063000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, -1, 0}, 149.592640, 0.000050, 0.093000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, 0, 0}, 329.987920, 0.000040, 0.042000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 0, 0}, 214.474770, 0.000010, 0.040000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 1, 0}, 12.903210, 0.000020, 0.086000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -2, 2, 0}, 214.474770, 0.000010, 0.631000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -1, 0, 1}, 22.387300, 0.000030, 1.158000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -2, 0}, 147.684560, 0.000010, 0.037000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -1, 0}, 349.814050, 0.000150, 0.074000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, 0}, 357.994420, 0.000450, 5.260000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 1, 0}, 349.814050, 0.000150, 0.077000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -1, 0}, 23.785220, 0.000010, 0.089000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 0, 0}, 359.685090, 0.000050, 0.041000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 2, 0}, 178.652180, 0.000010, 0.020000},
	{{0, 0, 3, -6, 2, 0, 0, 0, 0, 0, 0}, 55.236300, 0.000040, 46.520000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, 0}, 29.836200, 0.000170, 0.041000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 1, 0}, 199.737800, 0.000010, 0.090000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -1, 0, 1}, 24.262040, 0.000020, 0.717000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -2, 0}, 27.818790, 0.000010, 0.038000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -1, 0}, 52.635470, 0.000050, 0.077000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 0, 0}, 32.633860, 0.000210, 2.928000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, -2}, 203.992160, 0.000040, 0.075000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, 0}, 53.109190, 0.000050, 0.074000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 2, -2}, 29.600340, 0.000050, 123.995000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 2, 0}, 110.059930, 0.000010, 0.037000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 3, -2}, 211.817350, 0.000020, 0.075000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 0, -1}, 234.945000, 0.000020, 1.404000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -3, 0}, 206.156260, 0.000030, 0.068000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -2, 0}, 207.755570, 0.000010, 0.698000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -1, 0}, 22.592760, 0.000050, 0.085000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 0, 0}, 26.772030, 0.000070, 0.040000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 4, -3, 0}, 26.789990, 0.000010, 0.100000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, 0}, 47.033070, 0.000070, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 1, 0}, 49.816890, 0.000100, 0.094000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 3, 0}, 59.998410, 0.000010, 0.063000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -2, 0}, 85.880440, 0.000040, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, 0}, 56.513110, 0.000050, 0.081000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 0, 0}, 59.522300, 0.000200, 1.145000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, -1, 0}, 47.682920, 0.000100, 72.752000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, -1}, 243.805300, 0.000020, 5.540000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 0}, 56.280750, 0.000040, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -3, 0}, 95.337210, 0.000010, 0.071000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, -2, 0}, 236.884260, 0.000020, 1.110000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, 0}, 246.575730, 0.000050, 0.039000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 0, 0}, 273.191260, 0.000090, 0.043000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 1, 0}, 93.004430, 0.000040, 0.099000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -2, 0}, 253.954510, 0.000030, 0.040000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 0, 0}, 307.745180, 0.000030, 0.712000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 1, 0}, 96.816620, 0.000010, 0.068000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 2, 0}, 265.892250, 0.000020, 0.036000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -3, 0}, 95.262760, 0.000040, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -2, 0}, 265.920800, 0.000050, 2.710000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -1, 0}, 260.803680, 0.000090, 0.078000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, 0}, 103.302630, 0.000040, 0.038000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, 0}, 296.834460, 0.000030, 0.044000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, 0}, 288.476730, 0.000040, 0.516000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 1, 0}, 305.587390, 0.000030, 0.066000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 2, 0}, 49.498900, 0.000020, 0.035000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, 0, -1}, 274.993720, 0.000010, 1.133000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -3, 0}, 133.941770, 0.000010, 0.076000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -2, 0}, 128.332380, 0.000070, 6.150000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, -1}, 21.911900, 0.000010, 241.391000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, 0}, 308.103140, 0.000120, 0.075000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, -2}, 294.581700, 0.000010, 5.851000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, 0}, 118.745890, 0.000130, 0.037000},
	{{0, 0, 3, -1, 0, 0, 0, 0, -2, 1, 0}, 331.126000, 0.000030, 0.111000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 0, 0, 0}, 173.725470, 0.000020, 0.405000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, -3, 0}, 249.816610, 0.000010, 0.080000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, -2, 0}, 333.164670, 0.000030, 1.440000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, -1, 0}, 131.029300, 0.000040, 0.072000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, 0, 0}, 339.728420, 0.000120, 0.037000},
	{{0, 0, 3, 0, -4, 0, 0, 0, -2, 0, 0}, 224.989500, 0.000020, 0.045000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 0, 0, 0}, 231.698340, 0.000020, 0.376000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -3, 0}, 60.527260, 0.000010, 0.081000},
	{{0, 0, 3, 0, -4, 0, 0, 0, 2, -1, 0}, 240.527260, 0.000010, 0.071000},
	{{0, 0, 3, 0, -3, 0, 0, 0, -2, 0, 0}, 137.358400, 0.000020, 0.045000},
	{{0, 0, 3, 0, -3, 0, 0, 0, 0, -1, 0}, 136.401630, 0.000020, 0.095000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -2, -1}, 193.678850, 0.000270, 277.143000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, -1}, 14.855370, 0.000060, 0.075000},
	{{0, 0, 3, 0, 0, 0, 0, 0, -2, 1, 0}, 357.655170, 0.000020, 0.118000},
	{{0, 0, 3, 0, 0, 0, 0, 0, -2, 3, 0}, 177.655170, 0.000010, 0.055000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, -2, 0}, 177.655170, 0.000010, 0.043000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 21.949750, 0.000030, 0.098000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 176.532430, 0.000090, 0.333000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 59.477980, 0.000030, 0.062000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -3, 0}, 191.190580, 0.000010, 0.083000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 33.293750, 0.000020, 0.816000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, -1, 0}, 187.320760, 0.000050, 0.069000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, -2}, 323.971840, 0.000020, 1.121000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 45.967590, 0.000030, 0.036000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 1, 0}, 147.187240, 0.000010, 0.024000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0}, 36.290380, 0.000070, 0.283000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 0, 2, 0}, 222.105860, 0.000030, 0.033000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 2, -3, 0}, 221.224030, 0.000010, 0.087000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 2, -1, 0}, 219.933620, 0.000060, 0.067000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 2, 0, 0}, 219.796450, 0.000090, 0.035000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 0, 0, 0}, 201.250500, 0.000030, 0.246000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, -2, 0}, 252.191070, 0.000030, 0.437000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, -1, 0}, 251.018170, 0.000020, 0.064000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, 0, 0}, 252.261650, 0.000040, 0.035000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 0, -1, 0}, 100.393570, 0.000010, 0.115000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0}, 100.284570, 0.000020, 0.218000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 0, 1, 0}, 100.393570, 0.000010, 0.056000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 2, -1, 0}, 100.097600, 0.000020, 0.062000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 2, 0, 0}, 100.162170, 0.000030, 0.034000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 2, 2, 0}, 100.393570, 0.000010, 0.018000},
	{{0, 0, 3, 4, 0, 0, 0, 0, 2, -1, 0}, 309.196410, 0.000050, 0.060000},
	{{0, 0, 3, 5, 0, 0, 0, 0, 2, 0, 0}, 158.059950, 0.000050, 0.033000},
	{{0, 0, 4, -14, 0, 0, 0, 0, -2, 0, 0}, 143.075360, 0.000010, 0.035000},
	{{0, 0, 4, -14, 0, 0, 0, 0, -2, 1, 0}, 323.075360, 0.000020, 0.067000},
	{{0, 0, 4, -14, 0, 0, 0, 0, -2, 2, 0}, 143.075360, 0.000010, 0.599000},
	{{0, 0, 4, -13, 0, 0, 0, 0, -2, 0, 0}, 352.134340, 0.000050, 0.036000},
	{{0, 0, 4, -13, 0, 0, 0, 0, -2, 2, 0}, 352.163060, 0.000030, 0.879000},
	{{0, 0, 4, -12, 0, 0, 0, 0, -2, 0, 0}, 201.171490, 0.000030, 0.037000},
	{{0, 0, 4, -12, 0, 0, 0, 0, -2, 0, 2}, 21.097770, 0.000010, 3.667000},
	{{0, 0, 4, -12, 0, 0, 0, 0, -2, 2, 0}, 21.097770, 0.000010, 1.650000},
	{{0, 0, 4, -12, 0, 0, 0, 0, 0, -1, 0}, 21.097770, 0.000010, 0.064000},
	{{0, 0, 4, -12, 0, 0, 0, 0, 0, 1, 0}, 21.097770, 0.000010, 0.092000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 0, 0}, 50.452550, 0.000030, 0.038000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 0, 2}, 230.130260, 0.000020, 3.861000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 1, 0}, 237.072050, 0.000080, 0.075000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 2, 0}, 48.757060, 0.000060, 13.421000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 3, 0}, 166.458040, 0.000010, 0.076000},
	{{0, 0, 4, -11, 0, 0, 0, 0, 0, -1, 0}, 230.176780, 0.000030, 0.066000},
	{{0, 0, 4, -11, 0, 0, 0, 0, 0, 1, 0}, 230.176780, 0.000030, 0.088000},
	{{0, 0, 4, -10, 0, 0, 0, 0, -2, -2, 0}, 259.082970, 0.000010, 0.019000},
	{{0, 0, 4, -10, 0, 0, 0, 0, -2, 0, 0}, 268.704270, 0.000060, 0.038000},
	{{0, 0, 4, -10, 0, 0, 0, 0, -2, 1, 0}, 259.082970, 0.000020, 0.078000},
	{{0, 0, 4, -10, 0, 0, 0, 0, -2, 2, 0}, 143.427600, 0.000010, 2.187000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 0, -1, 0}, 259.115090, 0.000040, 0.069000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 0, 0, 0}, 263.392630, 0.000050, 0.759000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 0, 1, 0}, 259.115090, 0.000040, 0.084000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 2, 0, 0}, 91.868820, 0.000020, 0.043000},
	{{0, 0, 4, -9, 0, 0, 0, 0, -2, 0, 0}, 107.453790, 0.000020, 0.039000},
	{{0, 0, 4, -9, 0, 0, 0, 0, -1, 0, 1}, 325.532340, 0.000030, 3.723000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 0, 0, 0}, 291.677800, 0.000100, 1.274000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, -3, 0}, 300.654160, 0.000010, 0.063000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, -2, 0}, 120.506410, 0.000030, 0.391000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, -1, 0}, 120.654160, 0.000010, 0.093000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, 0, 0}, 120.506410, 0.000030, 0.042000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 0, 0}, 146.951060, 0.000150, 0.040000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 1, 0}, 146.753280, 0.000050, 0.085000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 2, 0}, 210.196940, 0.000010, 0.658000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 3, 0}, 324.067820, 0.000030, 0.068000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -1, 0}, 331.557170, 0.000090, 0.074000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 0, 0}, 326.764970, 0.000200, 3.945000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 1, 0}, 331.557170, 0.000090, 0.077000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 2, 0}, 329.567440, 0.000010, 0.038000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, -1, 0}, 150.648640, 0.000040, 0.089000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 0, 0}, 331.169550, 0.000030, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 0, 0}, 1.931480, 0.000020, 0.020000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 2, 0}, 1.931440, 0.000020, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, 0}, 1.870560, 0.000110, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 0}, 1.970380, 0.001070, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 2}, 1.931480, 0.000030, 0.475000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, 0}, 2.127150, 0.001670, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, 0}, 1.931320, 0.000070, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 0, 0}, 181.931820, 0.000010, 0.081000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -1, 2, 0}, 181.931820, 0.000010, 0.071000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 0}, 1.258580, 0.000120, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 0}, 1.327150, 0.002020, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, 0}, 2.274630, 0.010560, 1783.359000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, 0}, 1.327450, 0.002020, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, 0}, 1.258890, 0.000120, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, -2, 0}, 181.932330, 0.000010, 0.071000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 1, 0, 0}, 181.932330, 0.000010, 0.081000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, 0}, 1.932830, 0.000070, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 0}, 2.128400, 0.001680, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, -2}, 1.932670, 0.000030, 0.474000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, 0}, 1.971400, 0.001070, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, 0}, 1.871510, 0.000110, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -2, 0}, 1.932720, 0.000020, 0.044000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, 0, 0}, 1.932670, 0.000020, 0.020000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -4, 2, 0}, 358.702570, 0.000010, 0.044000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 0, 0}, 2.868410, 0.000030, 0.041000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 1, 0}, 353.789270, 0.000030, 0.089000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 2, 0}, 178.876090, 0.000030, 0.487000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -2, 0}, 147.640760, 0.000010, 0.038000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -1, 0}, 359.739370, 0.000060, 0.077000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, 0}, 7.376190, 0.000260, 3.594000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 1, 0}, 359.739370, 0.000060, 0.074000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 2, 0}, 36.675310, 0.000020, 0.037000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -3, 0}, 179.154600, 0.000020, 0.068000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -2, 0}, 5.866410, 0.000010, 0.669000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -1, 0}, 358.679640, 0.000030, 0.085000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 0, 0}, 355.628470, 0.000030, 0.040000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 2, 0}, 178.596710, 0.000010, 0.019000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, 0}, 30.596980, 0.000170, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 1, 0}, 352.761440, 0.000030, 0.094000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 2, 0}, 33.039880, 0.000010, 0.387000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 3, 0}, 90.417960, 0.000010, 0.063000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, -1, 0}, 25.377190, 0.000010, 0.080000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 0, 0, 0}, 21.763120, 0.000090, 1.235000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -3, 1}, 80.383630, 0.000010, 0.076000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, -1, 1}, 260.383630, 0.000010, 0.075000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, -1}, 40.405670, 0.000010, 4.101000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, 0}, 27.718470, 0.000030, 0.076000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -2, 0}, 212.036900, 0.000010, 1.037000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, -1, 0}, 206.397850, 0.000020, 0.081000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, 0}, 27.061900, 0.000100, 0.039000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 2, 0}, 27.717440, 0.000020, 0.019000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 0, 0}, 52.129840, 0.000020, 0.043000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -2, 1, 0}, 247.831960, 0.000020, 0.099000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -2, 0}, 66.654960, 0.000010, 0.040000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, -1, 0}, 239.964990, 0.000020, 0.084000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 0, 0}, 242.845460, 0.000170, 0.745000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 1, 0}, 238.633010, 0.000030, 0.069000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 2, 0}, 213.033740, 0.000010, 0.036000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 0, -1}, 142.702930, 0.000020, 3.475000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -3, 0}, 239.197170, 0.000050, 0.073000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -2, 0}, 237.913760, 0.000050, 2.313000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -1, 0}, 236.820500, 0.000050, 0.078000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, 0}, 234.831460, 0.000040, 0.038000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 2, 0}, 56.853080, 0.000020, 0.019000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 0, 0}, 281.634100, 0.000070, 0.044000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 2, 0}, 86.590590, 0.000010, 0.274000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -2, 0}, 295.980260, 0.000030, 0.041000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 0, 0}, 276.793120, 0.000080, 0.534000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 1, 0, -1}, 227.526820, 0.000010, 1.220000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -3, 0}, 111.244710, 0.000030, 0.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -2, 0}, 277.133500, 0.000080, 10.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, 0}, 267.143230, 0.000130, 0.075000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, -2}, 265.608130, 0.000020, 4.269000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, 0}, 85.132410, 0.000030, 0.038000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 4, -3, 0}, 272.272320, 0.000010, 0.086000},
	{{0, 0, 4, -3, 0, 0, 0, 0, -2, 0, 0}, 299.530210, 0.000030, 0.045000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, -2, 0}, 303.002360, 0.000020, 0.041000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, -1, 0}, 302.521330, 0.000040, 0.092000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 0, 0}, 176.401170, 0.000020, 0.416000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 1, 0}, 302.538690, 0.000030, 0.064000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 2, 0}, 147.710240, 0.000030, 0.035000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 1, 0, -1}, 303.811040, 0.000030, 0.740000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, -3, 0}, 40.070850, 0.000020, 0.079000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, -2, 0}, 295.109240, 0.000020, 1.585000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, -1, 0}, 220.070850, 0.000020, 0.072000},
	{{0, 0, 4, -2, 0, 0, 0, 0, -2, 0, 0}, 330.702920, 0.000020, 0.046000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, -1, 0}, 333.336090, 0.000010, 0.097000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, 0, 0}, 159.661350, 0.000050, 0.341000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, -3, 0}, 158.007200, 0.000030, 0.083000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, -2, 0}, 349.463730, 0.000010, 0.860000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, -1, 0}, 151.405530, 0.000070, 0.069000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, 0, 0}, 333.197310, 0.000120, 0.036000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 4, -3, 0}, 333.336090, 0.000010, 0.079000},
	{{0, 0, 4, -1, 0, 0, 0, 0, 0, -1, 0}, 12.940820, 0.000010, 0.102000},
	{{0, 0, 4, -1, 0, 0, 0, 0, 0, 0, 0}, 181.982170, 0.000060, 0.288000},
	{{0, 0, 4, -1, 0, 0, 0, 0, 0, 1, 0}, 12.940820, 0.000010, 0.060000},
	{{0, 0, 4, -1, 0, 0, 0, 0, 2, -3, 0}, 10.921610, 0.000010, 0.086000},
	{{0, 0, 4, -1, 0, 0, 0, 0, 2, -2, 0}, 10.921610, 0.000010, 0.590000},
	{{0, 0, 4, -1, 0, 0, 0, 0, 2, -1, 0}, 192.042710, 0.000030, 0.067000},
	{{0, 0, 4, 0, -1, 0, 0, 0, 1, 0, -1}, 322.983190, 0.000020, 0.349000},
	{{0, 0, 4, 0, 0, 0, 0, 0, -2, 0, 0}, 271.501750, 0.000030, 0.048000},
	{{0, 0, 4, 0, 0, 0, 0, 0, -2, 2, 0}, 31.065480, 0.000010, 0.173000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0}, 23.445610, 0.000110, 0.250000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 0, 2, 0}, 210.867890, 0.000050, 0.033000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -3, 0}, 109.974950, 0.000010, 0.091000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -1, 0}, 23.033590, 0.000130, 0.065000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 105.111730, 0.000060, 0.035000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 2, 0}, 20.415790, 0.000020, 0.018000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 0, -1, 0}, 71.191720, 0.000020, 0.115000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0}, 71.533930, 0.000040, 0.221000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 2, -1, 0}, 250.991330, 0.000010, 0.062000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 2, 0, 0}, 250.951120, 0.000010, 0.034000},
	{{0, 0, 4, 2, 0, 0, 0, 0, 0, -1, 0}, 100.280240, 0.000010, 0.122000},
	{{0, 0, 4, 2, 0, 0, 0, 0, 0, 1, 0}, 100.280240, 0.000010, 0.055000},
	{{0, 0, 4, 2, 0, 0, 0, 0, 2, -1, 0}, 280.280240, 0.000010, 0.060000},
	{{0, 0, 4, 2, 0, 0, 0, 0, 2, 0, 0}, 100.280240, 0.000020, 0.034000},
	{{0, 0, 5, -15, 0, 0, 0, 0, -2, 2, 0}, 143.015620, 0.000020, 0.832000},
	{{0, 0, 5, -14, 0, 0, 0, 0, -2, 0, 0}, 352.102800, 0.000040, 0.037000},
	{{0, 0, 5, -14, 0, 0, 0, 0, -2, 2, 0}, 352.102800, 0.000040, 1.494000},
	{{0, 0, 5, -13, 0, 0, 0, 0, -2, 0, 0}, 201.100460, 0.000030, 0.038000},
	{{0, 0, 5, -13, 0, 0, 0, 0, -2, 0, 2}, 201.038740, 0.000010, 5.112000},
	{{0, 0, 5, -13, 0, 0, 0, 0, -2, 1, 0}, 197.874010, 0.000030, 0.075000},
	{{0, 0, 5, -13, 0, 0, 0, 0, -2, 3, 0}, 16.442350, 0.000020, 0.076000},
	{{0, 0, 5, -13, 0, 0, 0, 0, 0, -1, 0}, 21.038740, 0.000010, 0.066000},
	{{0, 0, 5, -13, 0, 0, 0, 0, 0, 1, 0}, 21.038740, 0.000010, 0.088000},
	{{0, 0, 5, -12, 0, 0, 0, 0, -2, 1, 0}, 232.770120, 0.000040, 0.078000},
	{{0, 0, 5, -12, 0, 0, 0, 0, -2, 2, 0}, 50.250160, 0.000020, 2.539000},
	{{0, 0, 5, -12, 0, 0, 0, 0, 0, -1, 0}, 230.067520, 0.000030, 0.068000},
	{{0, 0, 5, -12, 0, 0, 0, 0, 0, 0, 0}, 66.219210, 0.000030, 0.725000},
	{{0, 0, 5, -12, 0, 0, 0, 0, 0, 1, 0}, 230.067520, 0.000030, 0.084000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -2, 0, 0}, 273.063130, 0.000040, 0.039000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -2, 2, 0}, 101.362500, 0.000030, 1.081000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -1, 0, 0}, 78.894690, 0.000030, 0.076000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -1, 0, 1}, 356.511570, 0.000010, 4.872000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -1, 1, 0}, 78.892900, 0.000010, 25.987000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 0, -1, 0}, 259.367380, 0.000020, 0.071000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 0, 0, 0}, 264.771800, 0.000070, 1.179000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 0, 1, 0}, 259.367380, 0.000020, 0.081000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 2, -2, 0}, 91.656100, 0.000010, 0.381000},
	{{0, 0, 5, -11, 0, 0, 0, 0, 2, 0, 0}, 91.656100, 0.000010, 0.042000},
	{{0, 0, 5, -10, 0, 0, 0, 0, -2, 0, 0}, 286.284700, 0.000050, 0.040000},
	{{0, 0, 5, -10, 0, 0, 0, 0, -2, 1, 0}, 287.287880, 0.000020, 0.085000},
	{{0, 0, 5, -10, 0, 0, 0, 0, -2, 2, 0}, 283.378660, 0.000010, 0.686000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, -2, 0}, 107.287880, 0.000010, 0.037000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, -1, 0}, 124.317830, 0.000030, 0.074000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, 0, 0}, 264.315200, 0.000060, 3.156000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, 1, 0}, 124.317830, 0.000030, 0.077000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 0, 0}, 143.294950, 0.000060, 0.041000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 1, 0}, 326.555130, 0.000080, 0.089000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 3, 0}, 133.576990, 0.000010, 0.066000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -1, 0}, 142.563400, 0.000070, 0.077000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 0, 0}, 342.324470, 0.000180, 4.655000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 1, 0}, 142.563400, 0.000070, 0.074000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 2, 0}, 329.495120, 0.000010, 0.037000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -1, 0}, 326.230400, 0.000030, 0.085000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 0, 0}, 329.698760, 0.000040, 0.040000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 0, 0}, 5.384310, 0.000040, 0.042000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 2, 0}, 165.107620, 0.000010, 0.397000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 0, 0, 0}, 3.159650, 0.000190, 1.340000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -3, 1}, 101.516070, 0.000020, 0.076000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -2, 1}, 118.340730, 0.000030, 38.061000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -1, 1}, 231.883260, 0.000040, 0.075000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, 0, -1}, 298.340550, 0.000030, 3.255000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -2, 0}, 178.554790, 0.000010, 0.973000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, -1, 0}, 178.395670, 0.000030, 0.082000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 0, 0}, 358.554790, 0.000010, 0.039000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 2, 0}, 178.554790, 0.000010, 0.019000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, 0}, 259.642330, 0.000100, 0.042000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 1, 0}, 259.855230, 0.000120, 0.095000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -1, 0}, 259.818930, 0.000040, 0.082000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 0, 0}, 261.172600, 0.000120, 1.001000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 1, 0}, 260.728770, 0.000020, 0.070000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 0, 0}, 33.561530, 0.000090, 0.043000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 1, 0}, 215.434990, 0.000080, 0.098000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 2, 0}, 30.671980, 0.000040, 0.328000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 3, 0}, 215.585130, 0.000010, 0.061000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 0, 0}, 207.528320, 0.000200, 0.782000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 1, 0}, 207.665750, 0.000010, 0.069000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 2, 0}, 207.286200, 0.000020, 0.036000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, 0, -1}, 161.226300, 0.000010, 4.456000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -3, 0}, 268.060640, 0.000010, 0.073000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -2, 0}, 200.719450, 0.000020, 2.017000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -1, 0}, 218.724300, 0.000090, 0.078000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, 0}, 26.615750, 0.000090, 0.038000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 4, -2, 0}, 207.888750, 0.000010, 0.041000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, -2, 0}, 244.403600, 0.000010, 0.020000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 0, 0}, 64.696110, 0.000030, 0.044000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 1, 0}, 244.914980, 0.000030, 0.103000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 3, 0}, 243.811960, 0.000010, 0.059000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -1, 0}, 68.417470, 0.000070, 0.087000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 0, 0}, 242.273630, 0.000130, 0.553000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 1, 0}, 242.327840, 0.000010, 0.066000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, 0, -1}, 236.365590, 0.000030, 1.323000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -3, 0}, 182.052460, 0.000020, 0.076000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, 0}, 66.471920, 0.000190, 27.873000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, 0}, 246.465780, 0.000410, 0.075000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, -2}, 236.705620, 0.000020, 3.360000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, 0}, 236.155670, 0.000050, 0.038000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, -2, 0}, 93.428600, 0.000010, 0.020000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 0, 0}, 92.260780, 0.000040, 0.045000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 2, 0}, 92.101410, 0.000040, 0.243000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -2, 0}, 290.499540, 0.000030, 0.041000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -1, 0}, 277.839170, 0.000030, 0.092000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 0, 0}, 52.863850, 0.000030, 0.427000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 1, 0}, 281.101190, 0.000020, 0.064000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 2, 0}, 85.228040, 0.000010, 0.035000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 1, 0, -1}, 272.837070, 0.000030, 0.777000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -3, 0}, 273.011570, 0.000020, 0.079000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -1, 0}, 270.266620, 0.000040, 0.072000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 0, -2}, 85.209410, 0.000010, 4.273000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, 0, 0}, 87.090840, 0.000070, 0.037000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, 0, 0}, 122.228010, 0.000020, 0.046000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, 1, 0}, 302.306070, 0.000060, 0.116000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, -1, 0}, 302.344910, 0.000020, 0.096000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, 0, 0}, 124.325860, 0.000080, 0.348000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, -3, 0}, 315.089060, 0.000020, 0.082000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, -2, 0}, 134.153160, 0.000010, 0.910000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, -1, 0}, 122.344730, 0.000120, 0.070000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, 0, 0}, 301.898350, 0.000060, 0.036000},
	{{0, 0, 5, -3, 0, 0, 0, 0, -2, 0, 0}, 325.897480, 0.000020, 0.047000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 0, -2, 0}, 84.444590, 0.000020, 0.043000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 0, -1, 0}, 340.063290, 0.000020, 0.102000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 0, 0, 0}, 184.220730, 0.000030, 0.294000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 2, -3, 0}, 183.532260, 0.000010, 0.086000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 2, -2, 0}, 40.515550, 0.000010, 0.613000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 2, -1, 0}, 160.063490, 0.000110, 0.067000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 2, 0, 0}, 172.135040, 0.000070, 0.036000},
	{{0, 0, 5, -2, 0, 0, 0, 0, -2, 0, 0}, 356.867510, 0.000010, 0.048000},
	{{0, 0, 5, -2, 0, 0, 0, 0, -2, 2, 0}, 357.286920, 0.000020, 0.175000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 0, -1, 0}, 12.851430, 0.000010, 0.107000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 0, 0, 0}, 191.251700, 0.000060, 0.254000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 0, 1, 0}, 12.851430, 0.000010, 0.058000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 2, -2, 0}, 10.266920, 0.000010, 0.462000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 2, -1, 0}, 191.921630, 0.000050, 0.065000},
	{{0, 0, 5, -2, 0, 0, 0, 0, 2, 0, 0}, 190.903730, 0.000050, 0.035000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 0, -1, 0}, 41.954820, 0.000020, 0.114000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 0, 0, 0}, 44.566890, 0.000040, 0.224000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 0, 1, 0}, 41.954820, 0.000020, 0.056000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 0, 2, 0}, 221.598090, 0.000020, 0.032000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 2, -3, 0}, 221.514000, 0.000030, 0.095000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 2, -1, 0}, 41.866540, 0.000030, 0.063000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 2, 0, 0}, 294.087650, 0.000010, 0.034000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 2, 2, 0}, 41.954820, 0.000020, 0.018000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, -2, 0}, 109.789200, 0.000020, 0.046000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 78.323170, 0.000090, 0.200000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 1, 0}, 280.247480, 0.000030, 0.055000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 2, 0}, 251.328940, 0.000010, 0.032000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 3, 0}, 109.789200, 0.000020, 0.022000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, -3, 0}, 71.358770, 0.000020, 0.100000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, -2, 0}, 294.129260, 0.000010, 0.310000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, -1, 0}, 115.655430, 0.000030, 0.061000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, 0, -2}, 108.015090, 0.000010, 0.346000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, 0, 0}, 259.857270, 0.000160, 0.034000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, 1, 0}, 108.015100, 0.000020, 0.023000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, 2, 0}, 103.545310, 0.000020, 0.018000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, 3, 0}, 109.789200, 0.000010, 0.014000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 4, -1, 0}, 289.789200, 0.000010, 0.024000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 4, 0, 0}, 108.015100, 0.000040, 0.018000},
	{{0, 0, 5, 1, 0, 0, 0, 0, 2, -2, 0}, 95.491190, 0.000010, 0.266000},
	{{0, 0, 5, 1, 0, 0, 0, 0, 2, 2, 0}, 280.091510, 0.000010, 0.018000},
	{{0, 0, 6, -16, 0, 0, 0, 0, -2, 0, 0}, 322.962790, 0.000010, 0.037000},
	{{0, 0, 6, -16, 0, 0, 0, 0, -2, 1, 0}, 143.054940, 0.000070, 0.071000},
	{{0, 0, 6, -15, 0, 0, 0, 0, -2, 0, 0}, 352.016320, 0.000050, 0.037000},
	{{0, 0, 6, -15, 0, 0, 0, 0, -2, 0, 2}, 171.965080, 0.000010, 7.561000},
	{{0, 0, 6, -15, 0, 0, 0, 0, -2, 1, 0}, 176.222580, 0.000020, 0.074000},
	{{0, 0, 6, -15, 0, 0, 0, 0, -2, 2, 0}, 352.038470, 0.000070, 4.969000},
	{{0, 0, 6, -15, 0, 0, 0, 0, -2, 3, 0}, 356.222580, 0.000020, 0.077000},
	{{0, 0, 6, -15, 0, 0, 0, 0, 0, 0, 0}, 171.965080, 0.000010, 0.506000},
	{{0, 0, 6, -14, 0, 0, 0, 0, -2, 0, 0}, 201.014890, 0.000070, 0.038000},
	{{0, 0, 6, -14, 0, 0, 0, 0, -2, 1, 0}, 229.654870, 0.000040, 0.077000},
	{{0, 0, 6, -14, 0, 0, 0, 0, -2, 3, 0}, 205.646930, 0.000040, 0.074000},
	{{0, 0, 6, -14, 0, 0, 0, 0, 0, -1, 0}, 20.963780, 0.000020, 0.068000},
	{{0, 0, 6, -14, 0, 0, 0, 0, 0, 0, 0}, 17.610080, 0.000020, 0.693000},
	{{0, 0, 6, -14, 0, 0, 0, 0, 0, 1, 0}, 20.963780, 0.000020, 0.085000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -2, 0, 0}, 229.784110, 0.000020, 0.039000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -2, 1, 0}, 50.305030, 0.000010, 0.081000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -1, 0, 0}, 229.903970, 0.000040, 0.075000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -1, 1, 0}, 229.931370, 0.000020, 40.183000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, -1, 0}, 229.906720, 0.000040, 0.071000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, 0, 0}, 229.903970, 0.000020, 1.097000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, 1, 0}, 229.906720, 0.000040, 0.081000},
	{{0, 0, 6, -12, 0, 0, 0, 0, -2, 0, 0}, 258.660180, 0.000040, 0.040000},
	{{0, 0, 6, -12, 0, 0, 0, 0, -2, 1, 0}, 258.653760, 0.000030, 0.084000},
	{{0, 0, 6, -12, 0, 0, 0, 0, -2, 2, 0}, 78.614580, 0.000020, 0.717000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, -1, 0}, 81.400000, 0.000020, 0.073000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 0, 0}, 265.669550, 0.000130, 2.630000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 1, 0}, 81.400000, 0.000020, 0.078000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 0, 0}, 291.369720, 0.000090, 0.041000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 1, 0}, 75.123040, 0.000020, 0.088000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -1, 0}, 105.851260, 0.000010, 0.076000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 0, 0}, 314.628120, 0.000170, 6.602000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 1, 0}, 105.851260, 0.000010, 0.075000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, -3, 0}, 300.263570, 0.000030, 0.067000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 0, 0}, 300.086660, 0.000020, 0.040000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 0, 0}, 329.010060, 0.000030, 0.042000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, -1, 0}, 355.189260, 0.000020, 0.080000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 0, 0}, 4.677750, 0.000050, 1.464000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 1, 0}, 355.189260, 0.000020, 0.072000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 2, 0}, 329.443440, 0.000010, 0.037000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, -1, 0}, 332.152680, 0.000010, 0.082000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 1, 0}, 186.266480, 0.000030, 0.097000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 2, 0}, 172.801360, 0.000020, 0.335000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, -2, 0}, 178.956150, 0.000020, 0.040000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 0, 0, 0}, 170.432570, 0.000050, 0.823000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -3, 0}, 5.181660, 0.000040, 0.072000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -2, 0}, 178.511580, 0.000010, 1.788000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -1, 0}, 185.181660, 0.000040, 0.079000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, 2, 0}, 178.511580, 0.000010, 0.019000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -4, 2, 0}, 211.897900, 0.000010, 0.047000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 0, 0}, 31.370400, 0.000080, 0.043000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 2, 0}, 34.016490, 0.000030, 0.284000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -1, 0}, 229.735510, 0.000080, 0.087000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 0, 0}, 227.926240, 0.000040, 0.573000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 1, 0}, 25.990060, 0.000030, 0.067000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 2, 0}, 27.800360, 0.000010, 0.035000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 1, 0, -1}, 148.895430, 0.000020, 1.444000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -3, 0}, 242.890690, 0.000020, 0.075000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, 0}, 35.566340, 0.000340, 36.376000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, 0}, 44.630310, 0.000530, 0.076000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, 0}, 37.098450, 0.000110, 0.038000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, -2, 0}, 244.329510, 0.000010, 0.020000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 0, 0}, 65.983670, 0.000020, 0.045000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 1, 0}, 244.493950, 0.000090, 0.109000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 2, 0}, 63.265090, 0.000020, 0.247000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 3, 0}, 244.519310, 0.000010, 0.058000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, -1, 0}, 54.123000, 0.000020, 0.091000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 0, 0}, 256.670980, 0.000050, 0.439000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 1, 0}, 54.123000, 0.000020, 0.064000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 2, 0}, 236.533320, 0.000020, 0.035000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -3, 0}, 61.753960, 0.000010, 0.078000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, -1, 0}, 234.120070, 0.000020, 0.073000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, -2}, 56.530130, 0.000030, 5.859000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, 0}, 60.026140, 0.000030, 0.037000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 0, 0}, 96.067440, 0.000040, 0.046000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 1, 0}, 273.423030, 0.000060, 0.115000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 2, 0}, 88.177250, 0.000010, 0.218000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -2, 0}, 351.495790, 0.000020, 0.042000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, 0, 0}, 23.671530, 0.000030, 0.356000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -3, 0}, 78.666810, 0.000030, 0.082000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -1, 0}, 258.666810, 0.000030, 0.070000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 0, 0}, 86.605400, 0.000070, 0.036000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 3, -2, -1}, 115.156010, 0.000030, 55.903000},
	{{0, 0, 6, -5, 0, 0, 0, 0, -2, 1, 0}, 301.925580, 0.000030, 0.123000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 0, -2, 0}, 343.487440, 0.000020, 0.043000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 0, 0, 0}, 127.908650, 0.000060, 0.299000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, -1, 0}, 113.379570, 0.000060, 0.067000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, 0, 0}, 300.363000, 0.000100, 0.036000},
	{{0, 0, 6, -4, 0, 0, 0, 0, -2, 0, 0}, 148.482990, 0.000020, 0.048000},
	{{0, 0, 6, -4, 0, 0, 0, 0, 0, -1, 0}, 342.196930, 0.000020, 0.107000},
	{{0, 0, 6, -4, 0, 0, 0, 0, 0, 0, 0}, 155.269320, 0.000020, 0.258000},
	{{0, 0, 6, -4, 0, 0, 0, 0, 2, -2, 0}, 342.860180, 0.000020, 0.476000},
	{{0, 0, 6, -4, 0, 0, 0, 0, 2, -1, 0}, 162.196930, 0.000100, 0.065000},
	{{0, 0, 6, -4, 0, 0, 0, 0, 2, 0, 0}, 162.399020, 0.000120, 0.035000},
	{{0, 0, 6, -3, 0, 0, 0, 0, 0, 0, 0}, 248.968030, 0.000010, 0.227000},
	{{0, 0, 6, -3, 0, 0, 0, 0, 2, -3, 0}, 191.344130, 0.000030, 0.094000},
	{{0, 0, 6, -3, 0, 0, 0, 0, 2, -2, 0}, 10.219770, 0.000010, 0.380000},
	{{0, 0, 6, -3, 0, 0, 0, 0, 2, -1, 0}, 191.714450, 0.000080, 0.063000},
	{{0, 0, 6, -3, 0, 0, 0, 0, 2, 0, 0}, 190.940020, 0.000050, 0.034000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 0, -1, 0}, 41.916690, 0.000010, 0.120000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 0, 0, 0}, 41.844460, 0.000040, 0.203000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 0, 1, 0}, 41.916690, 0.000010, 0.055000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 0, 2, 0}, 221.566010, 0.000020, 0.032000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, -3, 0}, 221.327810, 0.000010, 0.099000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, -2, 0}, 221.322040, 0.000020, 0.316000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, -1, 0}, 221.256710, 0.000020, 0.061000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, 0, 0}, 223.999630, 0.000030, 0.034000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, 2, 0}, 41.916690, 0.000020, 0.018000},
	{{0, 0, 6, -1, 0, 0, 0, 0, 0, -1, 0}, 71.052330, 0.000010, 0.128000},
	{{0, 0, 6, -1, 0, 0, 0, 0, 0, 0, 0}, 70.779760, 0.000020, 0.183000},
	{{0, 0, 6, -1, 0, 0, 0, 0, 0, 1, 0}, 71.052330, 0.000010, 0.053000},
	{{0, 0, 6, -1, 0, 0, 0, 0, 0, 2, 0}, 250.779760, 0.000020, 0.031000},
	{{0, 0, 6, -1, 0, 0, 0, 0, 2, -1, 0}, 71.305020, 0.000010, 0.059000},
	{{0, 0, 6, -1, 0, 0, 0, 0, 2, 0, 0}, 250.454400, 0.000010, 0.033000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0}, 226.152280, 0.000050, 0.167000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 0, 1, 0}, 18.960650, 0.000010, 0.052000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 2, -1, 0}, 305.053650, 0.000030, 0.057000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 0}, 237.920290, 0.000040, 0.033000},
	{{0, 0, 7, -18, 0, 0, 0, 0, -2, 1, 0}, 293.927090, 0.000030, 0.071000},
	{{0, 0, 7, -17, 0, 0, 0, 0, -2, 0, 0}, 322.909960, 0.000010, 0.037000},
	{{0, 0, 7, -17, 0, 0, 0, 0, -2, 0, 2}, 142.909960, 0.000010, 14.514000},
	{{0, 0, 7, -17, 0, 0, 0, 0, -2, 1, 0}, 143.650720, 0.000010, 0.074000},
	{{0, 0, 7, -17, 0, 0, 0, 0, -2, 3, 0}, 143.650720, 0.000010, 0.077000},
	{{0, 0, 7, -16, 0, 0, 0, 0, -2, 0, 0}, 351.953960, 0.000090, 0.038000},
	{{0, 0, 7, -16, 0, 0, 0, 0, -2, 1, 0}, 173.371280, 0.000040, 0.077000},
	{{0, 0, 7, -16, 0, 0, 0, 0, -2, 2, 0}, 171.901960, 0.000010, 3.744000},
	{{0, 0, 7, -16, 0, 0, 0, 0, -2, 3, 0}, 353.371280, 0.000040, 0.074000},
	{{0, 0, 7, -16, 0, 0, 0, 0, 0, 0, 0}, 171.901960, 0.000010, 0.664000},
	{{0, 0, 7, -15, 0, 0, 0, 0, -2, 0, 0}, 200.910870, 0.000060, 0.039000},
	{{0, 0, 7, -15, 0, 0, 0, 0, -2, 1, 0}, 21.349140, 0.000040, 0.080000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, -1, 0}, 200.910860, 0.000030, 0.070000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, 0, 0}, 3.443340, 0.000050, 1.025000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, 1, 0}, 200.910860, 0.000030, 0.081000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 2, 0, 0}, 343.986030, 0.000020, 0.042000},
	{{0, 0, 7, -14, 0, 0, 0, 0, -2, 0, 0}, 229.713740, 0.000020, 0.040000},
	{{0, 0, 7, -14, 0, 0, 0, 0, -2, 1, 0}, 51.249840, 0.000010, 0.084000},
	{{0, 0, 7, -14, 0, 0, 0, 0, 0, -2, 0}, 49.743810, 0.000010, 0.037000},
	{{0, 0, 7, -14, 0, 0, 0, 0, 0, 0, 0}, 238.143740, 0.000050, 2.254000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 0, 0}, 264.772440, 0.000070, 0.041000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 1, 0}, 40.119040, 0.000020, 0.088000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, -2, 0}, 78.359720, 0.000010, 0.038000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, 0}, 274.012880, 0.000330, 11.350000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -3, 0}, 271.148370, 0.000020, 0.067000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, -1, 0}, 271.148370, 0.000020, 0.086000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 0, 0}, 271.148370, 0.000030, 0.040000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, 0, 0}, 96.034160, 0.000010, 0.041000},
	{{0, 0, 7, -12, 0, 0, 0, 0, -2, 1, 0}, 286.133950, 0.000030, 0.092000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, -1, 0}, 292.049250, 0.000020, 0.079000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, 0, 0}, 323.091490, 0.000020, 1.613000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 0, 1, 0}, 292.049250, 0.000020, 0.072000},
	{{0, 0, 7, -12, 0, 0, 0, 0, 2, 0, 0}, 300.202080, 0.000030, 0.039000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 2, 0}, 357.697030, 0.000010, 0.342000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, -1, 0}, 329.217390, 0.000020, 0.083000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 0, 0}, 136.229600, 0.000080, 0.868000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 1, 0}, 329.217390, 0.000020, 0.069000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 2, 0}, 329.398450, 0.000010, 0.036000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 0, -1}, 37.842490, 0.000040, 10.235000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, -2, 0}, 149.735750, 0.000020, 1.606000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, -1, 0}, 149.398450, 0.000020, 0.079000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, 0, 0}, 329.490920, 0.000030, 0.039000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, 0, 0}, 6.375920, 0.000030, 0.043000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, 1, 0}, 186.217690, 0.000020, 0.102000},
	{{0, 0, 7, -10, 0, 0, 0, 0, -2, 2, 0}, 184.041330, 0.000030, 0.289000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 0, 0}, 144.505310, 0.000020, 0.594000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 1, 0}, 358.438470, 0.000020, 0.067000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 2, 0}, 178.456630, 0.000020, 0.035000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -2, 0}, 201.420220, 0.000020, 11.006000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -1, 0}, 336.609200, 0.000120, 0.076000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 0, -2}, 178.456630, 0.000010, 2.356000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, 2, 0}, 178.456630, 0.000010, 0.019000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, 0, 0}, 41.948110, 0.000060, 0.044000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, 2, 0}, 32.726510, 0.000010, 0.251000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, -1, 0}, 18.174820, 0.000010, 0.091000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 0, 0}, 183.563610, 0.000100, 0.452000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 1, 0}, 18.174820, 0.000010, 0.065000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 0, 2, 0}, 207.699470, 0.000010, 0.035000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -3, 0}, 214.467950, 0.000010, 0.078000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -2, 0}, 32.051250, 0.000010, 2.269000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, -1, 0}, 204.640200, 0.000030, 0.073000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, -2}, 207.884310, 0.000030, 9.319000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, 0}, 26.898100, 0.000070, 0.037000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 0, 0}, 76.197020, 0.000030, 0.045000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 1, 0}, 244.390840, 0.000050, 0.114000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 2, 0}, 44.986570, 0.000010, 0.221000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 3, 0}, 64.390840, 0.000030, 0.056000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, 0, 0}, 242.855540, 0.000100, 0.364000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, -1, 0}, 229.820020, 0.000060, 0.070000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 0, 0}, 56.697320, 0.000010, 0.036000},
	{{0, 0, 7, -7, 0, 0, 0, 0, -2, 0, 0}, 92.703820, 0.000040, 0.047000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, -2, 0}, 93.871020, 0.000020, 0.043000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, -1, 0}, 273.092150, 0.000010, 0.100000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 1, 0}, 273.092150, 0.000010, 0.060000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 0, 2, 0}, 225.941670, 0.000010, 0.034000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -2, 0}, 262.850000, 0.000020, 0.665000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -1, 0}, 86.356430, 0.000090, 0.068000},
	{{0, 0, 7, -6, 0, 0, 0, 0, -2, 0, 0}, 296.908510, 0.000010, 0.048000},
	{{0, 0, 7, -6, 0, 0, 0, 0, -2, 1, 0}, 301.487130, 0.000010, 0.130000},
	{{0, 0, 7, -6, 0, 0, 0, 0, -2, 2, 0}, 116.908510, 0.000010, 0.179000},
	{{0, 0, 7, -6, 0, 0, 0, 0, -2, 3, 0}, 301.487130, 0.000010, 0.053000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 0, 0, 0}, 135.160880, 0.000020, 0.262000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, -3, 0}, 70.031460, 0.000010, 0.089000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, -2, 0}, 306.876150, 0.000020, 0.491000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, -1, 0}, 300.338640, 0.000040, 0.065000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, 0, 0}, 304.734690, 0.000190, 0.035000},
	{{0, 0, 7, -5, 0, 0, 0, 0, 0, -1, 0}, 342.434560, 0.000020, 0.112000},
	{{0, 0, 7, -5, 0, 0, 0, 0, 0, 0, 0}, 155.453950, 0.000010, 0.230000},
	{{0, 0, 7, -5, 0, 0, 0, 0, 2, -2, 0}, 342.270430, 0.000030, 0.389000},
	{{0, 0, 7, -5, 0, 0, 0, 0, 2, -1, 0}, 162.434560, 0.000110, 0.063000},
	{{0, 0, 7, -5, 0, 0, 0, 0, 2, 0, 0}, 162.754970, 0.000090, 0.034000},
	{{0, 0, 7, -4, 0, 0, 0, 0, 0, 0, 0}, 192.754040, 0.000040, 0.205000},
	{{0, 0, 7, -4, 0, 0, 0, 0, 2, -3, 0}, 7.245840, 0.000010, 0.098000},
	{{0, 0, 7, -4, 0, 0, 0, 0, 2, -1, 0}, 191.489710, 0.000060, 0.061000},
	{{0, 0, 7, -4, 0, 0, 0, 0, 2, 0, 0}, 191.671760, 0.000070, 0.034000},
	{{0, 0, 7, -3, 0, 0, 0, 0, 0, -1, 0}, 41.865000, 0.000010, 0.127000},
	{{0, 0, 7, -3, 0, 0, 0, 0, 0, 1, 0}, 41.865000, 0.000010, 0.054000},
	{{0, 0, 7, -3, 0, 0, 0, 0, 2, -1, 0}, 221.256720, 0.000040, 0.059000},
	{{0, 0, 7, -3, 0, 0, 0, 0, 2, 0, 0}, 220.624710, 0.000070, 0.033000},
	{{0, 0, 7, -3, 0, 0, 0, 0, 2, 2, 0}, 41.865000, 0.000010, 0.018000},
	{{0, 0, 7, -2, 0, 0, 0, 0, 0, -1, 0}, 70.920150, 0.000010, 0.137000},
	{{0, 0, 7, -2, 0, 0, 0, 0, 0, 1, 0}, 70.920150, 0.000010, 0.052000},
	{{0, 0, 7, -2, 0, 0, 0, 0, 2, -1, 0}, 250.920150, 0.000010, 0.057000},
	{{0, 0, 7, -2, 0, 0, 0, 0, 2, 2, 0}, 70.920150, 0.000010, 0.017000},
	{{0, 0, 7, -1, 0, 0, 0, 0, 2, 0, 0}, 279.448220, 0.000020, 0.032000},
	{{0, 0, 7, 0, 0, 0, 0, 0, 2, 0, 0}, 303.098100, 0.000020, 0.032000},
	{{0, 0, 8, -18, 0, 0, 0, 0, -2, 0, 0}, 322.852020, 0.000010, 0.038000},
	{{0, 0, 8, -17, 0, 0, 0, 0, -2, 0, 0}, 351.869660, 0.000080, 0.039000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 0, -1, 0}, 351.825150, 0.000010, 0.070000},
	{{0, 0, 8, -17, 0, 0, 0, 0, 0, 1, 0}, 351.825150, 0.000010, 0.082000},
	{{0, 0, 8, -16, 0, 0, 0, 0, -2, 0, 0}, 200.785200, 0.000060, 0.040000},
	{{0, 0, 8, -16, 0, 0, 0, 0, 0, -1, 0}, 200.535280, 0.000020, 0.073000},
	{{0, 0, 8, -16, 0, 0, 0, 0, 0, 1, 0}, 200.535280, 0.000020, 0.078000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, -1, 0}, 243.194780, 0.000030, 0.026000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, 0}, 239.626750, 0.000190, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 1, 0}, 248.113970, 0.000190, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -2, 0}, 234.691620, 0.000020, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, 0}, 235.925410, 0.000280, 0.076000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, 0}, 240.859110, 0.001430, 40.427000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, 0}, 235.555080, 0.000300, 0.075000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 2, 0}, 234.705820, 0.000020, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -1, 0}, 243.743800, 0.000230, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, 0}, 242.154680, 0.000140, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 1, 0}, 242.319460, 0.000010, 0.026000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 0, 0}, 258.008970, 0.000060, 0.041000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 1, 0}, 78.008980, 0.000020, 0.092000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 3, 0}, 258.008980, 0.000020, 0.064000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, -1, 0}, 73.303890, 0.000040, 0.079000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 0, 0}, 86.426630, 0.000040, 1.797000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 1, 0}, 73.303890, 0.000040, 0.072000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 2, 0, 0}, 271.327640, 0.000010, 0.040000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 0, 0}, 106.045190, 0.000110, 0.042000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 0, 0, 0}, 119.926100, 0.000130, 0.919000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 1, 0, -1}, 23.252200, 0.000050, 29.122000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 2, -3, 0}, 121.093350, 0.000020, 0.072000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 2, -1, 0}, 301.093350, 0.000020, 0.080000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 2, 0, 0}, 300.157190, 0.000030, 0.039000},
	{{0, 0, 8, -12, 0, 0, 0, 0, -2, 0, 0}, 155.222410, 0.000030, 0.043000},
	{{0, 0, 8, -12, 0, 0, 0, 0, -2, 2, 0}, 157.407730, 0.000010, 0.295000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, 0, 0}, 152.065260, 0.000050, 0.617000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 0, 2, 0}, 329.350050, 0.000010, 0.036000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 1, 0, -1}, 1.356720, 0.000020, 1.767000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -3, 0}, 352.067950, 0.000020, 0.075000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, -1, 0}, 163.667270, 0.000030, 0.076000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, 0, 0}, 329.256730, 0.000030, 0.038000},
	{{0, 0, 8, -11, 0, 0, 0, 0, -2, 0, 0}, 33.097560, 0.000030, 0.044000},
	{{0, 0, 8, -11, 0, 0, 0, 0, -2, 1, 0}, 186.164330, 0.000010, 0.107000},
	{{0, 0, 8, -11, 0, 0, 0, 0, -2, 2, 0}, 148.373670, 0.000020, 0.255000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 0, 0, 0}, 180.610650, 0.000050, 0.465000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -3, 0}, 5.405960, 0.000030, 0.078000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, 0}, 14.863000, 0.000020, 0.073000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, 0}, 358.704830, 0.000030, 0.037000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 0, 0}, 39.881070, 0.000050, 0.045000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 1, 0}, 215.163040, 0.000010, 0.114000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 2, 0}, 185.865150, 0.000010, 0.224000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 3, 0}, 215.163040, 0.000010, 0.056000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, -1, 0}, 27.335250, 0.000020, 0.095000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, 0, 0}, 211.852460, 0.000090, 0.373000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, 1, 0}, 27.335250, 0.000020, 0.063000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -2, 0}, 207.999910, 0.000020, 1.100000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -1, 0}, 207.335250, 0.000030, 0.071000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, 0}, 27.506100, 0.000050, 0.036000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 2, 0}, 207.335250, 0.000010, 0.019000},
	{{0, 0, 8, -9, 0, 0, 0, 0, -2, 0, 0}, 50.189800, 0.000030, 0.046000},
	{{0, 0, 8, -9, 0, 0, 0, 0, -2, 1, 0}, 244.251740, 0.000030, 0.121000},
	{{0, 0, 8, -9, 0, 0, 0, 0, -2, 2, 0}, 357.105670, 0.000010, 0.200000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, 0, 0}, 220.680000, 0.000110, 0.311000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -3, 0}, 54.166420, 0.000020, 0.085000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -2, 0}, 56.769590, 0.000010, 0.694000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -1, 0}, 234.780250, 0.000040, 0.068000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, 0}, 54.039050, 0.000060, 0.036000},
	{{0, 0, 8, -8, 0, 0, 0, 0, -2, 0, 0}, 91.687720, 0.000030, 0.048000},
	{{0, 0, 8, -8, 0, 0, 0, 0, -2, 1, 0}, 272.939860, 0.000030, 0.129000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, -2, 0}, 272.776590, 0.000030, 0.044000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, 0, 0}, 238.295820, 0.000020, 0.267000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -2, 0}, 77.578570, 0.000030, 0.507000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -1, 0}, 72.759510, 0.000040, 0.066000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, 0, 0}, 102.788520, 0.000010, 0.035000},
	{{0, 0, 8, -7, 0, 0, 0, 0, -2, 0, 0}, 121.721070, 0.000020, 0.049000},
	{{0, 0, 8, -7, 0, 0, 0, 0, -2, 1, 0}, 300.838600, 0.000020, 0.139000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 0, -2, 0}, 301.130820, 0.000010, 0.045000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, -2, 0}, 86.455540, 0.000020, 0.399000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, -1, 0}, 314.633550, 0.000030, 0.063000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, 0, 0}, 307.891990, 0.000130, 0.034000},
	{{0, 0, 8, -6, 0, 0, 0, 0, -2, 0, 0}, 327.448060, 0.000010, 0.050000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 0, -2, 0}, 252.455510, 0.000010, 0.046000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 0, 0, 0}, 352.046580, 0.000020, 0.208000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, -3, 0}, 343.561150, 0.000020, 0.098000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, -2, 0}, 341.914610, 0.000060, 0.329000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, -1, 0}, 163.429030, 0.000050, 0.061000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, 0, 0}, 163.827420, 0.000040, 0.034000},
	{{0, 0, 8, -5, 0, 0, 0, 0, 0, 0, 0}, 192.710830, 0.000040, 0.187000},
	{{0, 0, 8, -5, 0, 0, 0, 0, 2, -2, 0}, 32.530550, 0.000010, 0.280000},
	{{0, 0, 8, -5, 0, 0, 0, 0, 2, -1, 0}, 192.173900, 0.000030, 0.059000},
	{{0, 0, 8, -5, 0, 0, 0, 0, 2, 0, 0}, 197.305650, 0.000070, 0.033000},
	{{0, 0, 8, -4, 0, 0, 0, 0, 2, -1, 0}, 221.788990, 0.000010, 0.058000},
	{{0, 0, 8, -4, 0, 0, 0, 0, 2, 0, 0}, 220.677150, 0.000070, 0.033000},
	{{0, 0, 8, -3, 0, 0, 0, 0, 0, 0, 0}, 250.732580, 0.000010, 0.156000},
	{{0, 0, 8, -3, 0, 0, 0, 0, 2, 0, 0}, 70.732580, 0.000010, 0.032000},
	{{0, 0, 8, -3, 0, 0, 0, 0, 2, 2, 0}, 250.732580, 0.000010, 0.017000},
	{{0, 0, 8, -2, 0, 0, 0, 0, 2, -3, 0}, 98.872610, 0.000010, 0.124000},
	{{0, 0, 8, -2, 0, 0, 0, 0, 2, -1, 0}, 98.872610, 0.000010, 0.054000},
	{{0, 0, 9, -21, 0, 0, 0, 0, -2, 1, 0}, 264.848590, 0.000030, 0.073000},
	{{0, 0, 9, -19, 0, 0, 0, 0, -2, 1, 0}, 322.849270, 0.000070, 0.079000},
	{{0, 0, 9, -19, 0, 0, 0, 0, -2, 2, 0}, 142.785050, 0.000020, 1.488000},
	{{0, 0, 9, -19, 0, 0, 0, 0, 0, 0, 0}, 142.785050, 0.000010, 0.907000},
	{{0, 0, 9, -18, 0, 0, 0, 0, -2, 0, 0}, 351.769550, 0.000080, 0.040000},
	{{0, 0, 9, -18, 0, 0, 0, 0, -2, 1, 0}, 351.777770, 0.000060, 0.083000},
	{{0, 0, 9, -18, 0, 0, 0, 0, 0, -1, 0}, 171.777760, 0.000030, 0.072000},
	{{0, 0, 9, -18, 0, 0, 0, 0, 0, 0, 0}, 348.505600, 0.000030, 1.753000},
	{{0, 0, 9, -18, 0, 0, 0, 0, 0, 1, 0}, 171.777760, 0.000030, 0.079000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 0, 0}, 213.331630, 0.000060, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 1, 0}, 1.006790, 0.000020, 0.087000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -1, 0}, 178.108370, 0.000030, 0.075000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 0, 0}, 208.796690, 0.000230, 25.886000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 1, 0}, 178.108370, 0.000030, 0.076000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -1, 0}, 213.599950, 0.000040, 0.087000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 0, 0}, 213.600020, 0.000030, 0.040000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 0, 0}, 228.419780, 0.000020, 0.041000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 3, 0}, 229.340230, 0.000030, 0.064000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, -1, 0}, 49.367470, 0.000040, 0.078000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, 0, 0}, 60.328860, 0.000050, 2.028000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, 1, 0}, 49.367470, 0.000040, 0.073000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 0, 0}, 144.440460, 0.000020, 0.042000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 1, 0}, 109.885460, 0.000020, 0.096000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 0, 0, 0}, 97.280760, 0.000130, 0.976000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, -1}, 328.310050, 0.000030, 34.449000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 2, -1, 0}, 91.134000, 0.000050, 0.080000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 2, 0, 0}, 271.267900, 0.000010, 0.039000},
	{{0, 0, 9, -14, 0, 0, 0, 0, -2, 0, 0}, 104.366710, 0.000010, 0.043000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 0, 0, 0}, 104.629850, 0.000070, 0.643000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, -2, 0}, 120.162550, 0.000050, 4.596000},
	{{0, 0, 9, -13, 0, 0, 0, 0, -2, 0, 0}, 178.347680, 0.000030, 0.044000},
	{{0, 0, 9, -13, 0, 0, 0, 0, -2, 2, 0}, 214.402300, 0.000010, 0.259000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, -1, 0}, 329.291020, 0.000010, 0.090000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 0, 0}, 144.362110, 0.000040, 0.479000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 0, 1, 0}, 329.291020, 0.000010, 0.065000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -3, 0}, 176.578600, 0.000030, 0.077000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -2, 0}, 149.213430, 0.000020, 3.184000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, -2}, 330.451590, 0.000010, 0.075000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, 0}, 323.113710, 0.000040, 0.074000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, -2}, 346.764710, 0.000050, 51.478000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, 0}, 329.213430, 0.000020, 0.037000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 1, -2}, 330.451590, 0.000010, 0.076000},
	{{0, 0, 9, -12, 0, 0, 0, 0, -2, 0, 0}, 8.073920, 0.000030, 0.045000},
	{{0, 0, 9, -12, 0, 0, 0, 0, -2, 1, 0}, 186.101210, 0.000010, 0.113000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, -1, 0}, 358.283850, 0.000010, 0.094000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, 0, 0}, 172.975750, 0.000040, 0.382000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 0, 1, 0}, 358.283850, 0.000010, 0.063000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -3, 0}, 358.506310, 0.000040, 0.081000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -2, 0}, 358.943850, 0.000010, 1.182000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -1, 0}, 178.418710, 0.000060, 0.071000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 0, 0}, 358.659750, 0.000030, 0.037000},
	{{0, 0, 9, -11, 0, 0, 0, 0, -2, 0, 0}, 36.942890, 0.000030, 0.046000},
	{{0, 0, 9, -11, 0, 0, 0, 0, -2, 1, 0}, 215.068170, 0.000020, 0.120000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, -1, 0}, 27.145180, 0.000010, 0.099000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, 0, 0}, 210.987030, 0.000050, 0.317000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 0, 1, 0}, 27.145180, 0.000010, 0.061000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, -1, 0}, 207.125760, 0.000050, 0.068000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 0, 0}, 27.120220, 0.000050, 0.036000},
	{{0, 0, 9, -10, 0, 0, 0, 0, -2, 0, 0}, 61.742190, 0.000080, 0.047000},
	{{0, 0, 9, -10, 0, 0, 0, 0, -2, 1, 0}, 243.943070, 0.000030, 0.128000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, 0, 0}, 218.305080, 0.000070, 0.272000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -3, 0}, 55.617770, 0.000030, 0.088000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -1, 0}, 55.617770, 0.000030, 0.066000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, 0, 0}, 55.586500, 0.000050, 0.035000},
	{{0, 0, 9, -9, 0, 0, 0, 0, -2, 0, 0}, 91.090890, 0.000030, 0.049000},
	{{0, 0, 9, -9, 0, 0, 0, 0, -2, 1, 0}, 272.558970, 0.000010, 0.138000},
	{{0, 0, 9, -9, 0, 0, 0, 0, -2, 3, 0}, 92.558970, 0.000010, 0.052000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 0, -2, 0}, 194.545830, 0.000010, 0.045000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 0, 0, 0}, 297.552100, 0.000020, 0.237000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 2, 0, 0}, 244.164790, 0.000020, 0.035000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 0, -2, 0}, 41.365260, 0.000020, 0.046000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 0, 0, 0}, 104.253460, 0.000040, 0.211000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 2, -1, 0}, 314.570080, 0.000030, 0.062000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 2, 0, 0}, 313.303150, 0.000120, 0.034000},
	{{0, 0, 9, -7, 0, 0, 0, 0, 0, 0, 0}, 208.006480, 0.000030, 0.189000},
	{{0, 0, 9, -7, 0, 0, 0, 0, 2, -3, 0}, 343.283510, 0.000010, 0.103000},
	{{0, 0, 9, -7, 0, 0, 0, 0, 2, -2, 0}, 341.823230, 0.000030, 0.285000},
	{{0, 0, 9, -7, 0, 0, 0, 0, 2, -1, 0}, 163.283510, 0.000010, 0.060000},
	{{0, 0, 9, -6, 0, 0, 0, 0, 0, 0, 0}, 192.655890, 0.000040, 0.172000},
	{{0, 0, 9, -6, 0, 0, 0, 0, 2, -1, 0}, 192.564270, 0.000080, 0.058000},
	{{0, 0, 9, -6, 0, 0, 0, 0, 2, 0, 0}, 193.190030, 0.000060, 0.033000},
	{{0, 0, 9, -5, 0, 0, 0, 0, 0, 0, 0}, 221.680880, 0.000010, 0.158000},
	{{0, 0, 9, -5, 0, 0, 0, 0, 2, -2, 0}, 41.118960, 0.000020, 0.219000},
	{{0, 0, 9, -5, 0, 0, 0, 0, 2, 0, 0}, 41.519870, 0.000020, 0.032000},
	{{0, 0, 9, -5, 0, 0, 0, 0, 2, 2, 0}, 221.680880, 0.000010, 0.017000},
	{{0, 0, 9, -4, 0, 0, 0, 0, 0, 0, 0}, 250.480290, 0.000020, 0.145000},
	{{0, 0, 9, -4, 0, 0, 0, 0, 2, -3, 0}, 70.373400, 0.000020, 0.123000},
	{{0, 0, 9, -4, 0, 0, 0, 0, 2, -1, 0}, 250.373400, 0.000020, 0.054000},
	{{0, 0, 10, -22, 0, 0, 0, 0, -2, 1, 0}, 89.727990, 0.000010, 0.076000},
	{{0, 0, 10, -22, 0, 0, 0, 0, -2, 2, 0}, 264.877230, 0.000030, 12.993000},
	{{0, 0, 10, -22, 0, 0, 0, 0, -2, 3, 0}, 269.727990, 0.000010, 0.075000},
	{{0, 0, 10, -20, 0, 0, 0, 0, -2, 1, 0}, 142.706060, 0.000020, 0.083000},
	{{0, 0, 10, -20, 0, 0, 0, 0, -2, 2, 0}, 142.706060, 0.000020, 0.877000},
	{{0, 0, 10, -20, 0, 0, 0, 0, -2, 3, 0}, 142.706060, 0.000020, 0.069000},
	{{0, 0, 10, -20, 0, 0, 0, 0, 0, -1, 0}, 322.706060, 0.000010, 0.072000},
	{{0, 0, 10, -20, 0, 0, 0, 0, 0, 1, 0}, 322.706060, 0.000010, 0.079000},
	{{0, 0, 10, -19, 0, 0, 0, 0, -2, 0, 0}, 351.645380, 0.000090, 0.040000},
	{{0, 0, 10, -19, 0, 0, 0, 0, -2, 1, 0}, 171.618980, 0.000030, 0.086000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, -1, 0}, 354.880510, 0.000020, 0.075000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, 0, 0}, 191.581580, 0.000100, 9.804000},
	{{0, 0, 10, -19, 0, 0, 0, 0, 0, 1, 0}, 354.880510, 0.000020, 0.076000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 0, 0}, 162.297790, 0.000050, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 1, 0}, 162.297790, 0.000090, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -1, 0}, 162.297790, 0.000090, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 0, 0}, 162.297790, 0.000050, 0.040000},
	{{0, 0, 10, -18, 0, 0, 0, 0, -2, 0, 0}, 20.458140, 0.000080, 0.041000},
	{{0, 0, 10, -18, 0, 0, 0, 0, -2, 1, 0}, 200.435320, 0.000030, 0.090000},
	{{0, 0, 10, -18, 0, 0, 0, 0, 0, -1, 0}, 20.429740, 0.000040, 0.078000},
	{{0, 0, 10, -18, 0, 0, 0, 0, 0, 1, 0}, 20.429740, 0.000040, 0.073000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 0, 0}, 50.096700, 0.000030, 0.042000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 1, 0}, 229.032960, 0.000030, 0.095000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 2, 0}, 49.840200, 0.000020, 0.366000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, -1, 0}, 229.032960, 0.000020, 0.081000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, 0, 0}, 238.557410, 0.000030, 1.040000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 0, 1, 0}, 229.032960, 0.000020, 0.070000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 2, -1, 0}, 62.238250, 0.000030, 0.080000},
	{{0, 0, 10, -16, 0, 0, 0, 0, -2, 0, 0}, 77.051280, 0.000100, 0.043000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 0, 0, 0}, 86.221180, 0.000050, 0.670000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 2, -3, 0}, 276.102780, 0.000010, 0.074000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 2, -1, 0}, 96.102780, 0.000010, 0.077000},
	{{0, 0, 10, -16, 0, 0, 0, 0, 2, 0, 0}, 271.215070, 0.000010, 0.038000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 0, 0, 0}, 117.995730, 0.000060, 0.494000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -3, 0}, 121.207400, 0.000020, 0.077000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -2, 0}, 120.029520, 0.000010, 3.989000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -1, 0}, 119.390070, 0.000060, 0.074000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, 0, -2}, 300.124080, 0.000020, 12.078000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, 0, 0}, 120.010130, 0.000010, 0.037000},
	{{0, 0, 10, -14, 0, 0, 0, 0, -2, 2, 0}, 327.522990, 0.000010, 0.231000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 0, 0, 0}, 127.421610, 0.000050, 0.391000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, -3, 0}, 149.868000, 0.000010, 0.080000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, -1, 0}, 149.664630, 0.000040, 0.071000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, 0, 0}, 329.152130, 0.000050, 0.037000},
	{{0, 0, 10, -13, 0, 0, 0, 0, -2, 0, 0}, 7.505470, 0.000030, 0.046000},
	{{0, 0, 10, -13, 0, 0, 0, 0, -2, 1, 0}, 186.024400, 0.000010, 0.119000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 0, 0, 0}, 158.477270, 0.000060, 0.324000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 0, 2, 0}, 358.156250, 0.000010, 0.034000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, -3, 0}, 178.610890, 0.000020, 0.084000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, -1, 0}, 178.439550, 0.000030, 0.069000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, 0, 0}, 358.413230, 0.000060, 0.036000},
	{{0, 0, 10, -12, 0, 0, 0, 0, -2, 0, 0}, 34.920550, 0.000030, 0.047000},
	{{0, 0, 10, -12, 0, 0, 0, 0, -2, 2, 0}, 216.587560, 0.000020, 0.185000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 0, -2, 0}, 34.950220, 0.000010, 0.044000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 0, 0, 0}, 203.091280, 0.000050, 0.276000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, -1, 0}, 207.316530, 0.000040, 0.066000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, 0, 0}, 26.501240, 0.000030, 0.035000},
	{{0, 0, 10, -11, 0, 0, 0, 0, -2, 0, 0}, 63.168010, 0.000040, 0.049000},
	{{0, 0, 10, -11, 0, 0, 0, 0, -2, 1, 0}, 243.859930, 0.000030, 0.136000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 0, 0, 0}, 203.595980, 0.000050, 0.241000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -3, 0}, 234.922400, 0.000030, 0.092000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -2, 0}, 235.128350, 0.000030, 0.421000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -1, 0}, 54.922400, 0.000030, 0.064000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 0, -2, 0}, 272.145030, 0.000010, 0.046000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 0, 0, 0}, 270.991300, 0.000030, 0.214000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 2, 0, 0}, 105.526890, 0.000030, 0.034000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 0, 0, 0}, 133.172630, 0.000020, 0.192000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 2, -1, 0}, 314.518770, 0.000020, 0.060000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 2, 0, 0}, 313.311860, 0.000120, 0.033000},
	{{0, 0, 10, -8, 0, 0, 0, 0, -2, 0, 0}, 143.732630, 0.000020, 0.053000},
	{{0, 0, 10, -8, 0, 0, 0, 0, 2, 0, 0}, 341.662210, 0.000040, 0.033000},
	{{0, 0, 10, -7, 0, 0, 0, 0, 0, 0, 0}, 192.581790, 0.000020, 0.159000},
	{{0, 0, 10, -7, 0, 0, 0, 0, 2, -2, 0}, 11.592320, 0.000010, 0.222000},
	{{0, 0, 10, -7, 0, 0, 0, 0, 2, -1, 0}, 192.372840, 0.000050, 0.056000},
	{{0, 0, 10, -7, 0, 0, 0, 0, 2, 0, 0}, 7.447040, 0.000020, 0.032000},
	{{0, 0, 10, -6, 0, 0, 0, 0, 0, 0, 0}, 221.534500, 0.000030, 0.147000},
	{{0, 0, 10, -6, 0, 0, 0, 0, 2, -1, 0}, 221.321700, 0.000040, 0.055000},
	{{0, 0, 10, -5, 0, 0, 0, 0, 2, 0, 0}, 250.036390, 0.000030, 0.031000},
	{{0, 0, 11, -21, 0, 0, 0, 0, -2, 0, 0}, 142.612710, 0.000030, 0.040000},
	{{0, 0, 11, -21, 0, 0, 0, 0, -2, 1, 0}, 142.612710, 0.000010, 0.086000},
	{{0, 0, 11, -21, 0, 0, 0, 0, -2, 3, 0}, 322.612710, 0.000010, 0.067000},
	{{0, 0, 11, -21, 0, 0, 0, 0, 0, -1, 0}, 142.417520, 0.000020, 0.075000},
	{{0, 0, 11, -21, 0, 0, 0, 0, 0, 0, 0}, 70.892160, 0.000020, 6.047000},
	{{0, 0, 11, -21, 0, 0, 0, 0, 0, 1, 0}, 142.417520, 0.000020, 0.076000},
	{{0, 0, 11, -21, 2, 0, 0, 0, -2, 0, 0}, 213.451270, 0.000020, 0.040000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 0, 0, 0}, 214.369690, 0.000080, 308.674000},
	{{0, 0, 11, -21, 2, 0, 0, 0, 2, 0, 0}, 213.451080, 0.000020, 0.040000},
	{{0, 0, 11, -20, 0, 0, 0, 0, -2, 0, 0}, 351.507630, 0.000080, 0.041000},
	{{0, 0, 11, -20, 0, 0, 0, 0, -2, 1, 0}, 171.485110, 0.000020, 0.090000},
	{{0, 0, 11, -20, 0, 0, 0, 0, 0, -1, 0}, 351.518380, 0.000030, 0.078000},
	{{0, 0, 11, -20, 0, 0, 0, 0, 0, 0, 0}, 169.402230, 0.000020, 2.730000},
	{{0, 0, 11, -20, 0, 0, 0, 0, 0, 1, 0}, 351.518380, 0.000030, 0.073000},
	{{0, 0, 11, -19, 0, 0, 0, 0, -2, 0, 0}, 20.245700, 0.000100, 0.042000},
	{{0, 0, 11, -19, 0, 0, 0, 0, -2, 1, 0}, 200.232780, 0.000020, 0.094000},
	{{0, 0, 11, -19, 0, 0, 0, 0, 0, -1, 0}, 200.232780, 0.000010, 0.081000},
	{{0, 0, 11, -19, 0, 0, 0, 0, 0, 1, 0}, 200.232780, 0.000010, 0.071000},
	{{0, 0, 11, -18, 0, 0, 0, 0, -2, 0, 0}, 48.713500, 0.000100, 0.043000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 0, 0, 0}, 48.706270, 0.000010, 0.699000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 2, -3, 0}, 62.051050, 0.000030, 0.074000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 2, -1, 0}, 62.051050, 0.000030, 0.077000},
	{{0, 0, 11, -17, 0, 0, 0, 0, -2, 0, 0}, 76.552940, 0.000060, 0.044000},
	{{0, 0, 11, -17, 0, 0, 0, 0, -2, 2, 0}, 256.122670, 0.000010, 0.268000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 0, 0, 0}, 91.242430, 0.000030, 0.510000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 2, 0, 0}, 271.162250, 0.000010, 0.037000},
	{{0, 0, 11, -16, 0, 0, 0, 0, -2, 0, 0}, 128.014270, 0.000030, 0.045000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 0, 0, 0}, 123.390820, 0.000080, 0.401000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, 0, 0}, 120.044300, 0.000040, 0.037000},
	{{0, 0, 11, -15, 0, 0, 0, 0, -2, 2, 0}, 157.146020, 0.000030, 0.208000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 0, 0, 0}, 148.623210, 0.000070, 0.331000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 2, -2, 0}, 148.455520, 0.000010, 0.800000},
	{{0, 0, 11, -15, 0, 0, 0, 0, 2, 0, 0}, 329.645670, 0.000010, 0.036000},
	{{0, 0, 11, -14, 0, 0, 0, 0, -2, 0, 0}, 351.982470, 0.000040, 0.047000},
	{{0, 0, 11, -14, 0, 0, 0, 0, -2, 1, 0}, 185.930890, 0.000010, 0.126000},
	{{0, 0, 11, -14, 0, 0, 0, 0, -2, 2, 0}, 327.869150, 0.000020, 0.188000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 0, 0, 0}, 173.784520, 0.000040, 0.281000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, -3, 0}, 357.970540, 0.000030, 0.087000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, -2, 0}, 178.475670, 0.000020, 0.561000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, -1, 0}, 357.970540, 0.000030, 0.066000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, 0, 0}, 358.092810, 0.000070, 0.035000},
	{{0, 0, 11, -13, 0, 0, 0, 0, -2, 0, 0}, 31.409350, 0.000050, 0.048000},
	{{0, 0, 11, -13, 0, 0, 0, 0, -2, 1, 0}, 214.806500, 0.000010, 0.135000},
	{{0, 0, 11, -13, 0, 0, 0, 0, -2, 2, 0}, 33.654910, 0.000010, 0.171000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, -1, 0}, 26.606460, 0.000050, 0.064000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, 0, 0}, 26.606450, 0.000050, 0.035000},
	{{0, 0, 11, -12, 0, 0, 0, 0, -2, 0, 0}, 62.471450, 0.000030, 0.050000},
	{{0, 0, 11, -12, 0, 0, 0, 0, -2, 1, 0}, 243.599980, 0.000030, 0.146000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 0, 0, 0}, 234.073610, 0.000040, 0.216000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, -2, 0}, 56.486830, 0.000010, 0.351000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, -1, 0}, 54.386230, 0.000030, 0.062000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, 0, 0}, 233.473710, 0.000020, 0.034000},
	{{0, 0, 11, -11, 0, 0, 0, 0, -2, 1, 0}, 271.723200, 0.000020, 0.158000},
	{{0, 0, 11, -11, 0, 0, 0, 0, 0, 0, 0}, 145.392310, 0.000020, 0.194000},
	{{0, 0, 11, -11, 0, 0, 0, 0, 2, 0, 0}, 105.467160, 0.000030, 0.033000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, -3, 0}, 134.469970, 0.000010, 0.107000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, -2, 0}, 184.407240, 0.000010, 0.256000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, -1, 0}, 314.469970, 0.000010, 0.058000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, 0, 0}, 318.947950, 0.000100, 0.033000},
	{{0, 0, 11, -9, 0, 0, 0, 0, 2, -3, 0}, 343.490280, 0.000020, 0.113000},
	{{0, 0, 11, -9, 0, 0, 0, 0, 2, -1, 0}, 343.490280, 0.000020, 0.057000},
	{{0, 0, 11, -9, 0, 0, 0, 0, 2, 0, 0}, 350.704710, 0.000050, 0.032000},
	{{0, 0, 11, -8, 0, 0, 0, 0, 2, -1, 0}, 192.483100, 0.000010, 0.055000},
	{{0, 0, 11, -7, 0, 0, 0, 0, 0, 0, 0}, 221.344440, 0.000010, 0.137000},
	{{0, 0, 11, -7, 0, 0, 0, 0, 0, 2, 0}, 41.344440, 0.000010, 0.030000},
	{{0, 0, 11, -7, 0, 0, 0, 0, 2, -1, 0}, 221.344440, 0.000010, 0.053000},
	{{0, 0, 11, -6, 0, 0, 0, 0, 2, -3, 0}, 249.739420, 0.000010, 0.139000},
	{{0, 0, 11, -6, 0, 0, 0, 0, 2, -1, 0}, 69.739420, 0.000010, 0.052000},
	{{0, 0, 11, -6, 0, 0, 0, 0, 2, 0, 0}, 69.616880, 0.000020, 0.031000},
	{{0, 0, 12, -26, 0, 0, 0, 0, -2, 1, 0}, 26.869900, 0.000060, 0.075000},
	{{0, 0, 12, -23, 0, 0, 0, 0, 0, -1, 0}, 293.601180, 0.000020, 0.074000},
	{{0, 0, 12, -23, 0, 0, 0, 0, 0, 0, 0}, 293.495370, 0.000030, 4.372000},
	{{0, 0, 12, -23, 0, 0, 0, 0, 0, 1, 0}, 293.601180, 0.000020, 0.077000},
	{{0, 0, 12, -22, 0, 0, 0, 0, -2, 0, 0}, 142.503040, 0.000030, 0.041000},
	{{0, 0, 12, -22, 0, 0, 0, 0, 0, 0, 0}, 138.879610, 0.000030, 3.301000},
	{{0, 0, 12, -21, 0, 0, 0, 0, -2, 0, 0}, 351.342800, 0.000050, 0.042000},
	{{0, 0, 12, -21, 0, 0, 0, 0, -2, 2, 0}, 171.356540, 0.000020, 0.383000},
	{{0, 0, 12, -21, 0, 0, 0, 0, 0, 0, 0}, 351.328180, 0.000010, 1.198000},
	{{0, 0, 12, -20, 0, 0, 0, 0, -2, 0, 0}, 20.008340, 0.000090, 0.043000},
	{{0, 0, 12, -20, 0, 0, 0, 0, 0, 0, 0}, 19.997160, 0.000010, 0.732000},
	{{0, 0, 12, -20, 0, 0, 0, 0, 2, -1, 0}, 33.160460, 0.000030, 0.078000},
	{{0, 0, 12, -19, 0, 0, 0, 0, -2, 0, 0}, 48.335110, 0.000080, 0.044000},
	{{0, 0, 12, -19, 0, 0, 0, 0, 2, -2, 0}, 61.968250, 0.000030, 8.066000},
	{{0, 0, 12, -18, 0, 0, 0, 0, -2, 0, 0}, 255.760840, 0.000020, 0.045000},
	{{0, 0, 12, -18, 0, 0, 0, 0, -2, 2, 0}, 255.760840, 0.000020, 0.238000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, -3, 0}, 271.011290, 0.000030, 0.079000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, -2, 0}, 91.104300, 0.000020, 1.525000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, -1, 0}, 271.011290, 0.000030, 0.072000},
	{{0, 0, 12, -17, 0, 0, 0, 0, -2, 0, 0}, 127.952130, 0.000030, 0.046000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 0, 0, 0}, 119.847460, 0.000030, 0.338000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, -1, 0}, 300.009370, 0.000050, 0.069000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, 0, 0}, 119.983900, 0.000030, 0.036000},
	{{0, 0, 12, -16, 0, 0, 0, 0, -2, 0, 0}, 157.631800, 0.000020, 0.047000},
	{{0, 0, 12, -16, 0, 0, 0, 0, -2, 2, 0}, 156.719860, 0.000020, 0.190000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 0, 0, 0}, 148.552440, 0.000040, 0.286000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, -2, 0}, 149.219910, 0.000020, 0.582000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, -1, 0}, 328.960650, 0.000050, 0.067000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, 0, 0}, 148.702130, 0.000020, 0.035000},
	{{0, 0, 12, -15, 0, 0, 0, 0, -2, 0, 0}, 3.242940, 0.000070, 0.048000},
	{{0, 0, 12, -15, 0, 0, 0, 0, -2, 1, 0}, 185.818230, 0.000010, 0.134000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, -2, 0}, 177.780520, 0.000040, 0.444000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, -1, 0}, 357.780520, 0.000050, 0.064000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, 0, 0}, 177.780530, 0.000010, 0.035000},
	{{0, 0, 12, -14, 0, 0, 0, 0, -2, 0, 0}, 34.465850, 0.000090, 0.050000},
	{{0, 0, 12, -14, 0, 0, 0, 0, -2, 1, 0}, 214.634570, 0.000010, 0.144000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, -3, 0}, 26.256260, 0.000020, 0.095000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, -2, 0}, 207.291930, 0.000010, 0.359000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, -1, 0}, 26.256260, 0.000020, 0.062000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, 0, 0}, 205.308440, 0.000010, 0.034000},
	{{0, 0, 12, -13, 0, 0, 0, 0, -2, 0, 0}, 61.994290, 0.000020, 0.051000},
	{{0, 0, 12, -13, 0, 0, 0, 0, -2, 1, 0}, 243.291830, 0.000020, 0.156000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 0, 0, 0}, 61.602760, 0.000020, 0.197000},
	{{0, 0, 12, -13, 0, 0, 0, 0, 2, -2, 0}, 233.597800, 0.000020, 0.302000},
	{{0, 0, 12, -12, 0, 0, 0, 0, -2, 0, 0}, 91.146950, 0.000020, 0.052000},
	{{0, 0, 12, -12, 0, 0, 0, 0, 0, 0, 0}, 89.325430, 0.000010, 0.178000},
	{{0, 0, 12, -12, 0, 0, 0, 0, 2, 0, 0}, 105.414320, 0.000030, 0.033000},
	{{0, 0, 12, -11, 0, 0, 0, 0, 2, -2, 0}, 134.289890, 0.000020, 0.228000},
	{{0, 0, 12, -11, 0, 0, 0, 0, 2, 0, 0}, 314.220990, 0.000070, 0.032000},
	{{0, 0, 12, -10, 0, 0, 0, 0, 2, -1, 0}, 343.415320, 0.000030, 0.055000},
	{{0, 0, 12, -9, 0, 0, 0, 0, 2, 0, 0}, 11.245390, 0.000020, 0.031000},
	{{0, 0, 12, -8, 0, 0, 0, 0, 2, -3, 0}, 41.105300, 0.000010, 0.137000},
	{{0, 0, 12, -8, 0, 0, 0, 0, 2, -1, 0}, 41.105300, 0.000010, 0.052000},
	{{0, 0, 12, -7, 0, 0, 0, 0, 2, 0, 0}, 249.380240, 0.000020, 0.030000},
	{{0, 0, 13, -24, 0, 0, 0, 0, 0, -1, 0}, 113.507370, 0.000020, 0.077000},
	{{0, 0, 13, -24, 0, 0, 0, 0, 0, 0, 0}, 113.375050, 0.000020, 4.174000},
	{{0, 0, 13, -24, 0, 0, 0, 0, 0, 1, 0}, 113.507370, 0.000020, 0.074000},
	{{0, 0, 13, -23, 0, 0, 0, 0, -2, 0, 0}, 142.375420, 0.000030, 0.042000},
	{{0, 0, 13, -22, 0, 0, 0, 0, -2, 2, 0}, 171.146410, 0.000020, 0.325000},
	{{0, 0, 13, -21, 0, 0, 0, 0, -2, 0, 0}, 19.733540, 0.000050, 0.044000},
	{{0, 0, 13, -21, 0, 0, 0, 0, -2, 2, 0}, 199.740600, 0.000030, 0.277000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 2, -3, 0}, 209.685010, 0.000030, 0.076000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 2, -1, 0}, 209.685010, 0.000030, 0.075000},
	{{0, 0, 13, -20, 0, 0, 0, 0, -2, 0, 0}, 47.888170, 0.000010, 0.045000},
	{{0, 0, 13, -20, 0, 0, 0, 0, 0, 0, 0}, 242.415340, 0.000030, 0.423000},
	{{0, 0, 13, -19, 0, 0, 0, 0, -2, 0, 0}, 254.913840, 0.000030, 0.046000},
	{{0, 0, 13, -19, 0, 0, 0, 0, 2, 0, 0}, 91.037330, 0.000030, 0.036000},
	{{0, 0, 13, -18, 0, 0, 0, 0, -2, 0, 0}, 127.881640, 0.000030, 0.047000},
	{{0, 0, 13, -18, 0, 0, 0, 0, 2, 0, 0}, 119.817870, 0.000010, 0.036000},
	{{0, 0, 13, -17, 0, 0, 0, 0, -2, 0, 0}, 157.081510, 0.000030, 0.048000},
	{{0, 0, 13, -17, 0, 0, 0, 0, -2, 2, 0}, 156.991070, 0.000010, 0.174000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 0, 0, 0}, 153.605170, 0.000060, 0.252000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 2, 0, 0}, 148.800730, 0.000020, 0.035000},
	{{0, 0, 13, -16, 0, 0, 0, 0, -2, 0, 0}, 4.957710, 0.000040, 0.049000},
	{{0, 0, 13, -16, 0, 0, 0, 0, -2, 1, 0}, 185.684360, 0.000010, 0.143000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 0, 0, 0}, 241.507510, 0.000020, 0.223000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 2, -1, 0}, 357.564250, 0.000030, 0.063000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 2, 0, 0}, 177.538170, 0.000020, 0.034000},
	{{0, 0, 13, -15, 0, 0, 0, 0, -2, 0, 0}, 34.151230, 0.000090, 0.051000},
	{{0, 0, 13, -15, 0, 0, 0, 0, -2, 2, 0}, 33.674620, 0.000010, 0.147000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 0, 0, 0}, 201.539230, 0.000030, 0.199000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, -1, 0}, 25.830540, 0.000020, 0.061000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, 0, 0}, 205.816890, 0.000030, 0.034000},
	{{0, 0, 13, -14, 0, 0, 0, 0, -2, 0, 0}, 62.930460, 0.000050, 0.052000},
	{{0, 0, 13, -14, 0, 0, 0, 0, -2, 1, 0}, 242.905520, 0.000010, 0.169000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 0, 0, 0}, 60.172560, 0.000010, 0.180000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 2, -2, 0}, 52.618990, 0.000010, 0.264000},
	{{0, 0, 13, -14, 0, 0, 0, 0, 2, 0, 0}, 232.618990, 0.000010, 0.033000},
	{{0, 0, 13, -13, 0, 0, 0, 0, 0, 0, 0}, 273.121600, 0.000030, 0.164000},
	{{0, 0, 13, -13, 0, 0, 0, 0, 2, 0, 0}, 105.361500, 0.000030, 0.032000},
	{{0, 0, 13, -12, 0, 0, 0, 0, 2, 0, 0}, 314.131010, 0.000040, 0.032000},
	{{0, 0, 13, -11, 0, 0, 0, 0, 2, -3, 0}, 163.320450, 0.000010, 0.127000},
	{{0, 0, 13, -11, 0, 0, 0, 0, 2, -2, 0}, 162.645970, 0.000020, 0.186000},
	{{0, 0, 13, -11, 0, 0, 0, 0, 2, -1, 0}, 343.320450, 0.000010, 0.054000},
	{{0, 0, 13, -10, 0, 0, 0, 0, 2, -1, 0}, 12.195350, 0.000020, 0.052000},
	{{0, 0, 14, -26, 0, 0, 0, 0, 0, 0, 0}, 264.506920, 0.000020, 5.675000},
	{{0, 0, 14, -24, 0, 0, 0, 0, -2, 0, 0}, 142.228370, 0.000030, 0.043000},
	{{0, 0, 14, -23, 0, 0, 0, 0, -2, 0, 0}, 170.938040, 0.000030, 0.044000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, 0}, 187.226670, 0.000570, 362.998000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -1, 0}, 136.537140, 0.000040, 0.075000},
	{{0, 0, 14, -22, 0, 0, 0, 0, -2, 0, 0}, 199.415520, 0.000020, 0.045000},
	{{0, 0, 14, -22, 0, 0, 0, 0, -2, 2, 0}, 199.415520, 0.000020, 0.245000},
	{{0, 0, 14, -22, 0, 0, 0, 0, 2, -3, 0}, 33.042730, 0.000010, 0.079000},
	{{0, 0, 14, -22, 0, 0, 0, 0, 2, -1, 0}, 213.042730, 0.000010, 0.073000},
	{{0, 0, 14, -21, 0, 0, 0, 0, -2, 0, 0}, 227.382860, 0.000030, 0.046000},
	{{0, 0, 14, -20, 0, 0, 0, 0, 0, 0, 0}, 271.321800, 0.000030, 0.297000},
	{{0, 0, 14, -20, 0, 0, 0, 0, 2, -1, 0}, 270.958350, 0.000020, 0.067000},
	{{0, 0, 14, -20, 0, 0, 0, 0, 2, 0, 0}, 90.958350, 0.000030, 0.036000},
	{{0, 0, 14, -19, 0, 0, 0, 0, -2, 0, 0}, 127.800440, 0.000030, 0.048000},
	{{0, 0, 14, -19, 0, 0, 0, 0, 2, -1, 0}, 299.871260, 0.000030, 0.065000},
	{{0, 0, 14, -19, 0, 0, 0, 0, 2, 0, 0}, 299.871260, 0.000010, 0.035000},
	{{0, 0, 14, -18, 0, 0, 0, 0, -2, 0, 0}, 156.938010, 0.000040, 0.049000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 0, 0, 0}, 130.845160, 0.000030, 0.226000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 2, -1, 0}, 328.687600, 0.000030, 0.063000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 2, 0, 0}, 148.604260, 0.000020, 0.034000},
	{{0, 0, 14, -17, 0, 0, 0, 0, -2, 0, 0}, 4.771440, 0.000020, 0.051000},
	{{0, 0, 14, -17, 0, 0, 0, 0, -2, 1, 0}, 185.527430, 0.000010, 0.153000},
	{{0, 0, 14, -17, 0, 0, 0, 0, -2, 2, 0}, 184.771440, 0.000020, 0.148000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 0, 0, 0}, 183.582130, 0.000060, 0.202000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 2, -1, 0}, 357.285250, 0.000020, 0.061000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 2, 0, 0}, 177.245730, 0.000010, 0.034000},
	{{0, 0, 14, -16, 0, 0, 0, 0, -2, 0, 0}, 33.465440, 0.000030, 0.052000},
	{{0, 0, 14, -16, 0, 0, 0, 0, -2, 2, 0}, 213.044760, 0.000010, 0.138000},
	{{0, 0, 14, -16, 0, 0, 0, 0, 0, 0, 0}, 296.879620, 0.000020, 0.182000},
	{{0, 0, 14, -16, 0, 0, 0, 0, 2, -2, 0}, 205.324450, 0.000020, 0.269000},
	{{0, 0, 14, -15, 0, 0, 0, 0, -2, 0, 0}, 62.379590, 0.000010, 0.053000},
	{{0, 0, 14, -15, 0, 0, 0, 0, -2, 2, 0}, 62.379590, 0.000010, 0.128000},
	{{0, 0, 14, -15, 0, 0, 0, 0, 0, 0, 0}, 269.642430, 0.000040, 0.166000},
	{{0, 0, 14, -14, 0, 0, 0, 0, 0, 0, 0}, 233.260560, 0.000020, 0.153000},
	{{0, 0, 14, -14, 0, 0, 0, 0, 2, 0, 0}, 105.303550, 0.000030, 0.032000},
	{{0, 0, 14, -13, 0, 0, 0, 0, 2, -2, 0}, 133.994310, 0.000020, 0.188000},
	{{0, 0, 14, -13, 0, 0, 0, 0, 2, 0, 0}, 313.994310, 0.000020, 0.031000},
	{{0, 0, 14, -12, 0, 0, 0, 0, 2, -2, 0}, 343.092620, 0.000030, 0.171000},
	{{0, 0, 14, -12, 0, 0, 0, 0, 2, 0, 0}, 343.222820, 0.000020, 0.031000},
	{{0, 0, 14, -11, 0, 0, 0, 0, 2, 0, 0}, 191.836170, 0.000020, 0.030000},
	{{0, 0, 14, -9, 0, 0, 0, 0, 2, 0, 0}, 67.797060, 0.000010, 0.029000},
	{{0, 0, 15, -28, 0, 0, 0, 0, 0, 0, 0}, 235.506220, 0.000010, 8.862000},
	{{0, 0, 15, -25, 0, 0, 0, 0, -2, 0, 0}, 142.060530, 0.000020, 0.043000},
	{{0, 0, 15, -24, 0, 0, 0, 0, -2, 0, 0}, 170.701210, 0.000030, 0.044000},
	{{0, 0, 15, -23, 0, 0, 0, 0, -2, 0, 0}, 199.062960, 0.000030, 0.046000},
	{{0, 0, 15, -22, 0, 0, 0, 0, -2, 0, 0}, 226.801190, 0.000020, 0.047000},
	{{0, 0, 15, -21, 0, 0, 0, 0, 2, 0, 0}, 90.864990, 0.000020, 0.035000},
	{{0, 0, 15, -20, 0, 0, 0, 0, -2, 0, 0}, 127.706620, 0.000030, 0.049000},
	{{0, 0, 15, -20, 0, 0, 0, 0, 2, 0, 0}, 119.737390, 0.000020, 0.034000},
	{{0, 0, 15, -19, 0, 0, 0, 0, -2, 0, 0}, 156.719980, 0.000060, 0.050000},
	{{0, 0, 15, -19, 0, 0, 0, 0, 2, -2, 0}, 148.485070, 0.000020, 0.320000},
	{{0, 0, 15, -18, 0, 0, 0, 0, -2, 1, 0}, 185.345670, 0.000010, 0.165000},
	{{0, 0, 15, -18, 0, 0, 0, 0, 0, 0, 0}, 185.068840, 0.000040, 0.184000},
	{{0, 0, 15, -18, 0, 0, 0, 0, 2, -2, 0}, 176.958550, 0.000020, 0.274000},
	{{0, 0, 15, -17, 0, 0, 0, 0, -2, 0, 0}, 33.536730, 0.000020, 0.053000},
	{{0, 0, 15, -17, 0, 0, 0, 0, 0, 0, 0}, 213.837060, 0.000040, 0.168000},
	{{0, 0, 15, -17, 0, 0, 0, 0, 2, 0, 0}, 204.724560, 0.000020, 0.033000},
	{{0, 0, 15, -16, 0, 0, 0, 0, -2, 0, 0}, 62.076780, 0.000020, 0.055000},
	{{0, 0, 15, -16, 0, 0, 0, 0, 0, 0, 0}, 242.337970, 0.000040, 0.154000},
	{{0, 0, 15, -15, 0, 0, 0, 0, 2, 0, 0}, 105.236580, 0.000020, 0.031000},
	{{0, 0, 15, -13, 0, 0, 0, 0, 2, 0, 0}, 342.892440, 0.000050, 0.030000},
	{{0, 0, 15, -12, 0, 0, 0, 0, 2, -2, 0}, 11.640010, 0.000020, 0.146000},
	{{0, 0, 15, -12, 0, 0, 0, 0, 2, 0, 0}, 11.684050, 0.000030, 0.030000},
	{{0, 0, 16, -30, 0, 0, 0, 0, 0, 0, 0}, 206.507630, 0.000010, 20.213000},
	{{0, 0, 16, -25, 0, 0, 0, 0, -2, 0, 0}, 170.433900, 0.000020, 0.045000},
	{{0, 0, 16, -24, 0, 0, 0, 0, -2, 0, 0}, 198.663940, 0.000020, 0.047000},
	{{0, 0, 16, -22, 0, 0, 0, 0, 2, -2, 0}, 270.755320, 0.000010, 0.395000},
	{{0, 0, 16, -22, 0, 0, 0, 0, 2, 0, 0}, 90.755320, 0.000010, 0.034000},
	{{0, 0, 16, -21, 0, 0, 0, 0, -2, 0, 0}, 127.598640, 0.000030, 0.050000},
	{{0, 0, 16, -21, 0, 0, 0, 0, 2, 0, 0}, 119.580460, 0.000030, 0.034000},
	{{0, 0, 16, -20, 0, 0, 0, 0, -2, 0, 0}, 156.564470, 0.000030, 0.052000},
	{{0, 0, 16, -20, 0, 0, 0, 0, -2, 2, 0}, 336.564470, 0.000030, 0.140000},
	{{0, 0, 16, -20, 0, 0, 0, 0, 2, 0, 0}, 148.249440, 0.000020, 0.033000},
	{{0, 0, 16, -19, 0, 0, 0, 0, -2, 0, 0}, 5.137300, 0.000020, 0.053000},
	{{0, 0, 16, -19, 0, 0, 0, 0, -2, 1, 0}, 185.137300, 0.000010, 0.179000},
	{{0, 0, 16, -19, 0, 0, 0, 0, 2, 0, 0}, 176.579030, 0.000030, 0.033000},
	{{0, 0, 16, -17, 0, 0, 0, 0, -2, 0, 0}, 61.639200, 0.000020, 0.056000},
	{{0, 0, 16, -16, 0, 0, 0, 0, 2, -2, 0}, 285.157600, 0.000010, 0.175000},
	{{0, 0, 16, -16, 0, 0, 0, 0, 2, 0, 0}, 105.157600, 0.000010, 0.031000},
	{{0, 0, 16, -15, 0, 0, 0, 0, 2, 0, 0}, 314.070510, 0.000010, 0.031000},
	{{0, 0, 16, -12, 0, 0, 0, 0, 2, 0, 0}, 39.523710, 0.000010, 0.029000},
	{{0, 0, 17, -32, 0, 0, 0, 0, 0, 0, 0}, 177.432810, 0.000030, 71.966000},
	{{0, 0, 17, -30, 0, 0, 0, 0, 1, 0, -1}, 127.791950, 0.000040, 232.951000},
	{{0, 0, 17, -26, 0, 0, 0, 0, -2, 0, 0}, 170.133860, 0.000010, 0.046000},
	{{0, 0, 17, -26, 0, 0, 0, 0, -2, 2, 0}, 350.133860, 0.000010, 0.202000},
	{{0, 0, 17, -22, 0, 0, 0, 0, -2, 0, 0}, 127.475140, 0.000030, 0.051000},
	{{0, 0, 17, -22, 0, 0, 0, 0, 2, 0, 0}, 119.398700, 0.000020, 0.033000},
	{{0, 0, 17, -21, 0, 0, 0, 0, 2, 0, 0}, 147.978040, 0.000030, 0.033000},
	{{0, 0, 17, -20, 0, 0, 0, 0, -2, 0, 0}, 184.987760, 0.000030, 0.054000},
	{{0, 0, 17, -20, 0, 0, 0, 0, -2, 1, 0}, 184.900460, 0.000010, 0.195000},
	{{0, 0, 17, -20, 0, 0, 0, 0, -2, 2, 0}, 184.987760, 0.000030, 0.123000},
	{{0, 0, 17, -20, 0, 0, 0, 0, 2, -2, 0}, 356.140450, 0.000010, 0.218000},
	{{0, 0, 17, -20, 0, 0, 0, 0, 2, 0, 0}, 176.140450, 0.000010, 0.032000},
	{{0, 0, 17, -19, 0, 0, 0, 0, -2, 0, 0}, 33.262210, 0.000010, 0.056000},
	{{0, 0, 17, -16, 0, 0, 0, 0, 2, -2, 0}, 133.936650, 0.000010, 0.149000},
	{{0, 0, 17, -15, 0, 0, 0, 0, 2, 0, 0}, 342.684320, 0.000010, 0.030000},
	{{0, 0, 17, -11, 0, 0, 0, 0, -2, -1, 2}, 255.259250, 0.000010, 307.754000},
	{{0, 0, 18, -23, 0, 0, 0, 0, -2, 0, 0}, 127.334910, 0.000020, 0.053000},
	{{0, 0, 18, -21, 0, 0, 0, 0, -2, 0, 0}, 184.700380, 0.000050, 0.056000},
	{{0, 0, 18, -21, 0, 0, 0, 0, -2, 1, 0}, 184.633150, 0.000010, 0.215000},
	{{0, 0, 18, -20, 0, 0, 0, 0, -2, 0, 0}, 212.831220, 0.000030, 0.058000},
	{{0, 0, 18, -20, 0, 0, 0, 0, -2, 2, 0}, 212.831220, 0.000030, 0.109000},
	{{0, 0, 18, -17, 0, 0, 0, 0, 2, 0, 0}, 133.779710, 0.000020, 0.030000},
	{{0, 0, 18, -16, 0, 0, 0, 0, 2, -2, 0}, 162.448700, 0.000010, 0.130000},
	{{0, 0, 18, -16, 0, 0, 0, 0, 2, 0, 0}, 162.448700, 0.000010, 0.029000},
	{{0, 0, 18, -15, 0, 0, 0, 0, 2, 0, 0}, 190.778280, 0.000020, 0.029000},
	{{0, 0, 19, -24, 0, 0, 0, 0, -2, 0, 0}, 127.176850, 0.000010, 0.054000},
	{{0, 0, 19, -24, 0, 0, 0, 0, -2, 2, 0}, 307.176850, 0.000010, 0.125000},
	{{0, 0, 19, -21, 0, 0, 0, 0, -2, 0, 0}, 212.337670, 0.000020, 0.059000},
	{{0, 0, 19, -21, 0, 0, 0, 0, -2, 2, 0}, 32.337670, 0.000020, 0.104000},
	{{0, 0, 20, -25, 0, 0, 0, 0, -2, 0, 0}, 126.999890, 0.000010, 0.055000},
	{{0, 0, 20, -25, 0, 0, 0, 0, -2, 2, 0}, 306.999890, 0.000010, 0.118000},
	{{0, 0, 20, -18, 0, 0, 0, 0, -3, 0, 1}, 208.412120, 0.000010, 0.075000},
	{{0, 0, 20, -18, 0, 0, 0, 0, -3, 1, 1}, 208.412120, 0.000200, 584.305000},
	{{0, 0, 20, -18, 0, 0, 0, 0, -3, 2, 1}, 208.412120, 0.000010, 0.075000},
	{{0, 0, 20, -16, 0, 0, 0, 0, -2, 1, 0}, 273.881900, 0.000020, 88.385000},
	{{0, 0, 21, -24, 0, 0, 0, 0, -2, 1, 0}, 183.624260, 0.000010, 0.308000},
	{{0, 0, 21, -18, 0, 0, 0, 0, -2, 1, 0}, 2.123340, 0.000060, 19.211000},
	{{0, 0, 22, -26, 0, 0, 0, 0, -2, 0, 0}, 155.059400, 0.000010, 0.060000},
	{{0, 0, 22, -26, 0, 0, 0, 0, -2, 2, 0}, 155.059400, 0.000010, 0.101000},
	{{0, 0, 22, -25, 0, 0, 0, 0, -2, 1, 0}, 183.209070, 0.000010, 0.361000},
	{{0, 0, 22, -20, 0, 0, 0, 0, -2, 1, 0}, 158.948150, 0.000040, 8.664000},
	{{0, 0, 23, -27, 0, 0, 0, 0, -2, 0, 0}, 154.735870, 0.000020, 0.062000},
	{{0, 0, 23, -23, 0, 0, 0, 0, -2, 1, 0}, 72.250490, 0.000010, 1.408000},
	{{0, 0, 23, -22, 0, 0, 0, 0, -2, 1, 0}, 309.155530, 0.000020, 5.593000},
	{{0, 0, 23, -20, 0, 0, 0, 0, -1, 0, 0}, 2.105780, 0.000020, 411.317000},
	{{0, 0, 24, -28, 0, 0, 0, 0, -2, 0, 0}, 154.379910, 0.000010, 0.064000},
	{{0, 0, 24, -28, 0, 0, 0, 0, -2, 2, 0}, 334.379910, 0.000010, 0.092000},
	{{0, 0, 24, -27, 0, 0, 0, 0, -2, 0, 0}, 182.236740, 0.000010, 0.066000},
	{{0, 0, 24, -27, 0, 0, 0, 0, -2, 2, 0}, 182.236740, 0.000010, 0.088000},
	{{0, 0, 24, -24, 0, 0, 0, 0, -2, 1, 0}, 238.975600, 0.000030, 4.130000},
	{{0, 0, 24, -23, 0, 0, 0, 0, -2, 1, 0}, 132.629080, 0.000020, 3.454000},
	{{0, 0, 25, -29, 0, 0, 0, 0, -2, 1, 0}, 153.989020, 0.000010, 0.526000},
	{{0, 0, 25, -28, 0, 0, 0, 0, -2, 0, 0}, 181.668920, 0.000010, 0.068000},
	{{0, 0, 25, -28, 0, 0, 0, 0, -2, 2, 0}, 181.668920, 0.000010, 0.084000},
	{{0, 0, 25, -26, 0, 0, 0, 0, -2, 1, 0}, 230.756040, 0.000020, 3.273000},
	{{0, 0, 25, -25, 0, 0, 0, 0, -2, 1, 0}, 225.885790, 0.000020, 4.422000},
	{{0, 0, 25, -22, 0, 0, 0, 0, 0, -1, 0}, 2.976190, 0.000030, 21.191000},
	{{0, 0, 26, -27, 0, 0, 0, 0, -2, 1, 0}, 226.390430, 0.000020, 6.143000},
	{{0, 0, 26, -24, 0, 0, 0, 0, 0, -1, 0}, 162.609530, 0.000060, 61.818000},
	{{0, 0, 26, -20, 0, 0, 0, 0, 2, -1, -2}, 110.289920, 0.000050, 330.156000},
	{{0, 0, 27, -32, 0, 0, 0, 0, -2, 1, 0}, 125.133900, 0.000010, 0.669000},
	{{0, 0, 27, -31, 0, 0, 0, 0, -2, 0, 0}, 153.090180, 0.000010, 0.070000},
	{{0, 0, 27, -31, 0, 0, 0, 0, -2, 2, 0}, 153.090180, 0.000010, 0.081000},
	{{0, 0, 27, -30, 0, 0, 0, 0, -2, 1, 0}, 356.800000, 0.000010, 2.313000},
	{{0, 0, 27, -26, 0, 0, 0, 0, 0, -1, 0}, 352.516680, 0.000010, 12.572000},
	{{0, 0, 28, -32, 0, 0, 0, 0, -2, 1, 0}, 331.749360, 0.000030, 2.018000},
	{{0, 0, 28, -31, 0, 0, 0, 0, -2, 1, 0}, 163.299910, 0.000050, 27.739000},
	{{0, 0, 28, -29, 0, 0, 0, 0, -1, 1, -1}, 310.995970, 0.000020, 21.904000},
	{{0, 0, 28, -28, 0, 0, 0, 0, 0, -1, 0}, 283.324500, 0.000020, 6.997000},
	{{0, 0, 29, -35, 0, 0, 0, 0, -2, 1, 0}, 96.221380, 0.000010, 0.917000},
	{{0, 0, 29, -34, 0, 0, 0, 0, -2, 0, 0}, 124.355090, 0.000010, 0.072000},
	{{0, 0, 29, -34, 0, 0, 0, 0, -2, 1, 0}, 302.765160, 0.000010, 1.789000},
	{{0, 0, 29, -34, 0, 0, 0, 0, -2, 2, 0}, 124.355090, 0.000010, 0.079000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 0, 0}, 335.124520, 0.000020, 0.075000},
	{{0, 0, 29, -33, 0, 0, 0, 0, -2, 1, 0}, 164.618050, 0.000100, 36.607000},
	{{0, 0, 29, -31, 0, 0, 0, 0, -1, 1, -1}, 325.102200, 0.000040, 56.451000},
	{{0, 0, 29, -29, 0, 0, 0, 0, 0, 1, -2}, 276.743040, 0.000040, 123.278000},
	{{0, 0, 30, -35, 0, 0, 0, 0, -2, 0, 0}, 302.147900, 0.000030, 0.075000},
	{{0, 0, 30, -35, 0, 0, 0, 0, -2, 1, 0}, 100.846310, 0.000040, 11.027000},
	{{0, 0, 30, -32, 0, 0, 0, 0, 0, -1, 0}, 203.305410, 0.000020, 3.709000},
	{{0, 0, 31, -37, 0, 0, 0, 0, -2, 1, 0}, 87.288540, 0.000070, 6.491000},
	{{0, 0, 31, -36, 0, 0, 0, 0, -2, 0, 0}, 303.436650, 0.000010, 0.078000},
	{{0, 0, 31, -36, 0, 0, 0, 0, -2, 1, 0}, 301.505380, 0.000010, 2.648000},
	{{0, 0, 31, -36, 0, 0, 0, 0, -2, 2, 0}, 123.436650, 0.000010, 0.073000},
	{{0, 0, 31, -35, 0, 0, 0, 0, -1, 0, 0}, 139.980110, 0.000010, 44.834000},
	{{0, 0, 31, -34, 0, 0, 0, 0, 0, -1, 0}, 283.090210, 0.000010, 3.003000},
	{{0, 0, 32, -39, 0, 0, 0, 0, -2, 0, 0}, 66.968410, 0.000010, 0.074000},
	{{0, 0, 32, -39, 0, 0, 0, 0, -2, 1, 0}, 246.306680, 0.000020, 4.599000},
	{{0, 0, 32, -39, 0, 0, 0, 0, -2, 2, 0}, 66.968410, 0.000010, 0.077000},
	{{0, 0, 32, -38, 0, 0, 0, 0, -2, 1, 0}, 270.871460, 0.000030, 3.182000},
	{{0, 0, 33, -40, 0, 0, 0, 0, -2, 1, 0}, 247.004130, 0.000040, 3.986000},
	{{0, 0, 33, -37, 0, 0, 0, 0, 0, -1, 0}, 3.939180, 0.000010, 13.903000},
	{{0, 0, 34, -43, 0, 0, 0, 0, -2, -1, 2}, 348.901920, 0.000020, 93.931000},
	{{0, 0, 34, -43, 0, 0, 0, 0, -2, 1, 0}, 9.645590, 0.000020, 2.906000},
	{{0, 0, 34, -42, 0, 0, 0, 0, -2, 1, 0}, 216.142310, 0.000060, 5.333000},
	{{0, 0, 34, -41, 0, 0, 0, 0, -1, -2, 1}, 145.608260, 0.000010, 0.075000},
	{{0, 0, 34, -41, 0, 0, 0, 0, -1, -1, 1}, 145.608260, 0.000230, 958.407000},
	{{0, 0, 34, -41, 0, 0, 0, 0, -1, 0, 1}, 145.608260, 0.000010, 0.075000},
	{{0, 0, 34, -39, 0, 0, 0, 0, 0, -1, 0}, 321.594150, 0.000060, 116.831000},
	{{0, 0, 34, -39, 0, 0, 0, 0, 0, 0, 0}, 121.945080, 0.000020, 0.075000},
	{{0, 0, 34, -37, 0, 0, 0, 0, 1, -1, -1}, 192.007360, 0.000010, 55.060000},
	{{0, 0, 35, -44, 0, 0, 0, 0, -2, 1, 0}, 146.091530, 0.000010, 8.055000},
	{{0, 0, 35, -41, 0, 0, 0, 0, 0, -1, 0}, 291.694800, 0.000010, 18.245000},
	{{0, 0, 36, -46, 0, 0, 0, 0, -2, 1, 0}, 330.912510, 0.000020, 16.451000},
	{{0, 0, 37, -48, 0, 0, 0, 0, -2, 0, 0}, 130.628470, 0.000030, 0.075000},
	{{0, 0, 37, -48, 0, 0, 0, 0, -2, 1, 0}, 338.037150, 0.000090, 387.400000},
	{{0, 0, 37, -46, 0, 0, 0, 0, -1, 1, -1}, 339.492770, 0.000020, 142.421000},
	{{0, 0, 37, -44, 0, 0, 0, 0, 0, 1, -2}, 57.344470, 0.000020, 60.153000},
	{{0, 0, 38, -50, 0, 0, 0, 0, -2, 1, 0}, 97.768010, 0.000040, 15.163000},
	{{0, 0, 39, -52, 0, 0, 0, 0, -2, 1, 0}, 230.783600, 0.000040, 7.733000},
	{{0, 0, 40, -54, 0, 0, 0, 0, -2, 1, 0}, 20.795250, 0.000010, 5.190000},
	{{0, 0, 42, -54, 0, 0, 0, 0, 0, -1, 0}, 246.217240, 0.000040, 30.034000},
	{{0, 0, 43, -56, 0, 0, 0, 0, 0, -1, 0}, 228.920270, 0.000020, 33.253000},
	{{0, 0, 44, -61, 0, 0, 0, 0, -2, 1, 0}, 295.182010, 0.000020, 11.693000},
	{{0, 0, 45, -63, 0, 0, 0, 0, -2, 1, 0}, 104.453530, 0.000010, 45.137000},
	{{0, 0, 46, -65, 0, 0, 0, 0, -2, 1, 0}, 57.939690, 0.000030, 24.264000},
	{{0, 0, 51, -71, 0, 0, 0, 0, 0, -1, 0}, 68.689640, 0.000010, 187.401000},
	{{0, 1, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 237.934640, 0.000020, 0.032000},
	{{0, 1, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 55.127600, 0.000020, 0.056000},
	{{0, 1, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 159.046830, 0.000010, 0.031000},
	{{0, 1, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 161.069900, 0.000010, 0.054000},
	{{0, 1, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 340.204970, 0.000060, 0.186000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 70.472710, 0.000060, 0.019000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -4, 1, 0}, 250.210610, 0.000010, 0.025000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, -2, 0}, 76.451940, 0.000020, 0.018000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 70.472710, 0.000030, 0.024000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 264.945650, 0.000040, 0.034000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 0, 2}, 70.472710, 0.000030, 0.441000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 9.148430, 0.000010, 0.063000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 98.350520, 0.000040, 0.385000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, -3, 0}, 70.210610, 0.000010, 0.023000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 251.983610, 0.000010, 0.057000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 70.210610, 0.000030, 0.229000},
	{{0, 1, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 256.451900, 0.000020, 0.113000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 18.086490, 0.000010, 0.036000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 190.680140, 0.000070, 0.067000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 61.731090, 0.000010, 0.625000},
	{{0, 1, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 339.421810, 0.000020, 0.033000},
	{{0, 1, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 161.150860, 0.000050, 0.296000},
	{{0, 1, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 268.951820, 0.000020, 0.047000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 32.812570, 0.000010, 0.025000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 144.924660, 0.000020, 0.037000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 2}, 177.262290, 0.000030, 3.746000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 36.058920, 0.000080, 0.072000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 29.128750, 0.000010, 0.079000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 167.942210, 0.000020, 0.035000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 92.270870, 0.000020, 0.064000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 282.339740, 0.000030, 0.421000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 172.050460, 0.000020, 0.092000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 3.379890, 0.000010, 0.041000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 348.007500, 0.000010, 0.241000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 183.379890, 0.000040, 0.110000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 348.007500, 0.000010, 0.045000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 4.712530, 0.000030, 0.038000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 339.108250, 0.000070, 0.078000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 81.706390, 0.000010, 2.503000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 3, 0}, 241.381440, 0.000020, 0.073000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 298.162970, 0.000040, 0.074000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 3.763140, 0.000040, 3.118000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 298.162970, 0.000040, 0.077000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 241.217950, 0.000050, 0.068000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 60.311760, 0.000120, 0.728000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 231.961040, 0.000050, 0.084000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 295.290560, 0.000040, 0.412000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 69.640380, 0.000030, 0.061000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 253.241310, 0.000020, 0.099000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 108.218080, 0.000030, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 253.070770, 0.000010, 0.019000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 222.041820, 0.000010, 0.026000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 138.240400, 0.000090, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 272.643090, 0.000060, 0.084000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 202.218620, 0.000050, 0.715000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -2, 1}, 304.160840, 0.000020, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, 1}, 180.386290, 0.000020, 0.080000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 73.179370, 0.000020, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 13.948590, 0.000050, 1.472000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 18.178520, 0.000060, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, 1}, 180.386290, 0.000020, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, -1}, 3.984630, 0.000030, 2.892000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, 1}, 3.984630, 0.000020, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -3, 2}, 199.506090, 0.000020, 0.075000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 359.106060, 0.000010, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -2, 2}, 191.666640, 0.000030, 24.413000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 300.364880, 0.000060, 0.073000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 2}, 191.553000, 0.000070, 0.076000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 248.849960, 0.000270, 2.670000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 231.624490, 0.000030, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -2, -1}, 184.009080, 0.000010, 0.036000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -2, 1}, 77.484860, 0.000020, 0.913000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 203.704080, 0.000040, 0.068000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 41.860210, 0.000060, 0.082000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 344.362810, 0.000050, 0.700000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 188.423320, 0.000020, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 203.704080, 0.000040, 0.085000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 2, -1}, 180.115530, 0.000030, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 188.839840, 0.000020, 0.465000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 26.450870, 0.000060, 0.090000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, -2}, 18.116140, 0.000020, 0.403000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 10.041360, 0.000020, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 1, 0}, 198.186720, 0.000050, 0.027000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 2, 0}, 15.656810, 0.000020, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 3, 0}, 18.462890, 0.000010, 0.016000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 198.116140, 0.000030, 0.044000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, -1, 0}, 198.462890, 0.000010, 0.028000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, 0, 0}, 198.116140, 0.000030, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -4, 3, 0}, 268.785420, 0.000010, 0.110000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 147.677390, 0.000070, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 271.264180, 0.000110, 0.092000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 283.900580, 0.000020, 0.417000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 75.175210, 0.000010, 0.064000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 111.057390, 0.000010, 0.040000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 193.515030, 0.000010, 0.596000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 2, -1}, 291.057390, 0.000010, 0.743000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 112.716720, 0.000040, 0.079000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 321.665060, 0.000090, 1.599000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 97.460750, 0.000050, 0.072000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -2, 1}, 78.493360, 0.000030, 10.557000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 248.385400, 0.000010, 0.073000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, -1, 1}, 305.588510, 0.000020, 0.076000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 90.429220, 0.000110, 2.335000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 68.970060, 0.000010, 0.038000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 1, -1}, 248.385400, 0.000010, 0.078000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 287.458290, 0.000010, 0.871000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 291.101290, 0.000140, 0.083000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 36.831570, 0.000030, 0.039000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 0, 0}, 159.600290, 0.000060, 0.021000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 1, 0}, 159.762620, 0.000010, 0.029000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, -1, 0}, 159.600290, 0.000030, 0.027000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 330.261910, 0.000040, 0.043000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 2}, 339.762620, 0.000010, 0.268000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 20.427470, 0.000040, 0.101000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 302.515150, 0.000060, 0.294000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 3, 0}, 355.543090, 0.000020, 0.060000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -1, 1}, 359.885290, 0.000030, 0.095000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, -1}, 154.902620, 0.000040, 0.041000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 1, 1}, 359.885290, 0.000030, 0.063000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 2, 1}, 359.885290, 0.000020, 0.034000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 339.879500, 0.000110, 0.086000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 283.955440, 0.000050, 0.615000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 133.287510, 0.000090, 0.067000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 227.463910, 0.000010, 0.036000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, -1}, 185.411960, 0.000010, 0.039000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 1}, 75.043380, 0.000030, 0.071000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 211.051270, 0.000030, 1.749000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 241.340060, 0.000040, 0.036000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 2, -1}, 158.110770, 0.000020, 0.037000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 195.448190, 0.000020, 0.075000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 243.634670, 0.000060, 6.734000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 183.681790, 0.000150, 0.076000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, -2}, 52.113060, 0.000010, 2.075000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 101.471100, 0.000020, 0.038000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 161.064850, 0.000010, 0.025000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, -2, 0}, 71.871000, 0.000030, 0.021000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 114.512570, 0.000100, 0.045000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 282.184110, 0.000120, 0.113000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, 1}, 244.777090, 0.000030, 0.272000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, -2, 0}, 270.172060, 0.000020, 0.042000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 278.996840, 0.000020, 0.094000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 145.620270, 0.000050, 0.381000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 278.996840, 0.000020, 0.063000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 204.005000, 0.000010, 0.636000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 352.989010, 0.000020, 1.174000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 83.258370, 0.000040, 0.071000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 316.799850, 0.000020, 0.104000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 73.234390, 0.000030, 0.276000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 192.494460, 0.000010, 0.059000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 0, 2, 0}, 123.067700, 0.000030, 0.033000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 35.564970, 0.000020, 0.540000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 261.413760, 0.000060, 0.066000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 337.628550, 0.000070, 0.035000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 2, 0}, 5.555110, 0.000030, 0.018000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 4, 0, 0}, 173.471290, 0.000010, 0.019000},
	{{0, 1, 3, 0, 0, 0, 0, 0, -2, 0, 0}, 271.883070, 0.000010, 0.050000},
	{{0, 1, 3, 0, 0, 0, 0, 0, -2, 2, 0}, 271.883070, 0.000010, 0.156000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 20.457690, 0.000090, 0.216000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 200.621690, 0.000010, 0.056000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, -3, 0}, 194.631390, 0.000010, 0.096000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 58.643200, 0.000010, 0.351000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, -1, 0}, 336.692420, 0.000040, 0.062000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 52.012810, 0.000030, 0.034000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 0, 0, 0}, 288.014910, 0.000020, 0.178000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 0, 1, 0}, 288.014910, 0.000030, 0.053000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 0, 3, 0}, 108.014910, 0.000010, 0.022000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, -1, 0}, 103.544010, 0.000020, 0.058000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 0, -2}, 108.014910, 0.000010, 0.284000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 273.585770, 0.000050, 0.033000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 1, 0}, 108.014910, 0.000010, 0.023000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 2, 0}, 283.544020, 0.000020, 0.018000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 0, -1, 0}, 198.957550, 0.000010, 0.151000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 218.650090, 0.000040, 0.151000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 0, 1, 0}, 198.957550, 0.000010, 0.050000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 0, 2, 0}, 17.186360, 0.000020, 0.030000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 2, -1, 0}, 67.704910, 0.000030, 0.055000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 2, 0, 0}, 81.959010, 0.000050, 0.032000},
	{{0, 1, 6, 0, 0, 0, 0, 0, 2, -2, 0}, 126.184340, 0.000030, 0.171000},
	{{0, 1, 6, 0, 0, 0, 0, 0, 2, 0, 0}, 128.152190, 0.000020, 0.031000},
	{{0, 2, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 236.756800, 0.000030, 0.033000},
	{{0, 2, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 56.160340, 0.000030, 0.058000},
	{{0, 2, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 341.511050, 0.000030, 0.032000},
	{{0, 2, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 161.119800, 0.000010, 0.056000},
	{{0, 2, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 341.511050, 0.000030, 0.211000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -4, 0, 0}, 70.429180, 0.000060, 0.019000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -4, 1, 0}, 250.209320, 0.000010, 0.025000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 70.429180, 0.000030, 0.024000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 232.981300, 0.000020, 0.035000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 65.163710, 0.000040, 0.066000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 70.209320, 0.000010, 0.506000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 70.209320, 0.000020, 0.267000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 256.447440, 0.000020, 0.105000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 241.133890, 0.000030, 0.070000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 159.016990, 0.000010, 1.026000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 191.343400, 0.000010, 0.081000},
	{{0, 2, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 190.352340, 0.000030, 0.364000},
	{{0, 2, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 269.466140, 0.000020, 0.045000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 137.748350, 0.000070, 0.038000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 0, 2}, 328.897880, 0.000020, 2.789000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 165.980860, 0.000060, 39.899000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 281.386930, 0.000020, 0.075000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 41.229230, 0.000040, 1.438000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 41.270980, 0.000020, 0.067000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 347.312280, 0.000060, 0.572000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, -3, 0}, 184.412620, 0.000020, 0.060000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 349.933040, 0.000020, 0.284000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 184.412620, 0.000040, 0.103000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 349.933040, 0.000020, 0.044000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 347.361660, 0.000030, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 265.391570, 0.000070, 0.082000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 42.615520, 0.000010, 0.976000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 307.974420, 0.000010, 0.070000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 120.036000, 0.000030, 0.077000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 94.893820, 0.000010, 0.038000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 180.064410, 0.000020, 3.281000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 30.869640, 0.000020, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 120.036000, 0.000030, 0.074000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 2, -1}, 61.075400, 0.000040, 34.842000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 3, -1}, 68.726210, 0.000040, 0.076000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 339.709470, 0.000040, 0.071000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 57.533850, 0.000140, 1.335000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 339.709470, 0.000040, 0.080000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 250.115170, 0.000040, 0.063000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 214.418640, 0.000030, 0.093000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 227.693620, 0.000040, 0.042000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 0, 0}, 37.762460, 0.000010, 0.020000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -4, 1, 0}, 28.393180, 0.000020, 0.028000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 20.610940, 0.000050, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 23.496230, 0.000320, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 10.828130, 0.000510, 0.089000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 4.723720, 0.000060, 0.494000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 67.081620, 0.000020, 0.084000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 26.567200, 0.000060, 0.039000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 156.403110, 0.000030, 0.766000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 67.081620, 0.000020, 0.069000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 4.786860, 0.000040, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 19.076300, 0.000610, 0.077000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 17.468130, 0.003530, 3.983000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, -2}, 184.106870, 0.000020, 0.075000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 19.769250, 0.000500, 0.074000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 17.571160, 0.000040, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 3, -2}, 184.106870, 0.000020, 0.076000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 3, 0}, 18.461600, 0.000020, 0.025000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, -1}, 183.794180, 0.000010, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, 0}, 18.461600, 0.000010, 0.072000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, 1}, 163.801570, 0.000020, 2.131000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 342.692590, 0.000040, 0.071000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 196.137500, 0.000030, 1.246000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 198.461600, 0.000010, 0.079000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 95.509900, 0.000030, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 342.692590, 0.000040, 0.080000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 45.963150, 0.000020, 0.068000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 97.442460, 0.000020, 0.657000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 16.766410, 0.000340, 0.085000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 18.172970, 0.000030, 0.539000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 17.093780, 0.000180, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 198.529330, 0.000020, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 195.098050, 0.000020, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, -1, 0}, 198.461600, 0.000010, 0.027000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 198.172970, 0.000050, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 253.296250, 0.000030, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 237.281320, 0.000080, 0.043000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 285.540600, 0.000030, 0.098000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 2, 0}, 350.350160, 0.000010, 0.331000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 32.685110, 0.000030, 0.434000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 122.187800, 0.000020, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 133.438110, 0.000020, 0.083000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 280.495170, 0.000080, 0.799000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -3, 1}, 65.854230, 0.000010, 0.079000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 59.567590, 0.000020, 0.077000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 245.854230, 0.000010, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 342.410170, 0.000030, 5.069000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 59.567590, 0.000020, 0.074000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 296.400140, 0.000040, 1.912000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 308.757570, 0.000110, 0.079000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 27.436040, 0.000060, 0.038000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 342.099210, 0.000060, 0.021000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 1, 0}, 341.537760, 0.000010, 0.029000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, -1, 0}, 341.437830, 0.000090, 0.028000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 16.290360, 0.000080, 0.044000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 2}, 161.537760, 0.000010, 0.229000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 151.190640, 0.000040, 0.108000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 145.985060, 0.000020, 0.248000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 3, 0}, 140.009580, 0.000020, 0.058000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, -1}, 230.714320, 0.000050, 0.042000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 359.885120, 0.000050, 0.303000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, -1}, 179.885110, 0.000050, 0.097000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 2, 1}, 359.885100, 0.000020, 0.034000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 82.192460, 0.000060, 0.091000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 261.812830, 0.000170, 0.444000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 93.692960, 0.000050, 0.064000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -2, -1}, 277.286710, 0.000010, 0.040000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -2, 1}, 59.216600, 0.000010, 0.653000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, -1}, 205.755120, 0.000020, 0.083000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -1, 1}, 45.563390, 0.000030, 0.068000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 218.943350, 0.000090, 0.835000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 277.725480, 0.000020, 0.036000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 1, -1}, 205.755120, 0.000020, 0.069000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 343.865970, 0.000020, 0.078000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 110.765440, 0.000030, 2.096000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 270.069380, 0.000050, 0.073000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, -2}, 48.252090, 0.000060, 6.968000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 279.718700, 0.000020, 0.037000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 74.811020, 0.000030, 0.047000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 130.120670, 0.000020, 0.121000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 62.937290, 0.000030, 0.100000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 130.458320, 0.000050, 0.308000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 71.802000, 0.000030, 0.061000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 270.978200, 0.000010, 0.034000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 272.554750, 0.000030, 0.455000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 265.853840, 0.000030, 0.085000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 65.936610, 0.000010, 0.677000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 189.253730, 0.000070, 0.068000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 347.445910, 0.000050, 0.036000},
	{{0, 2, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 1.309140, 0.000030, 0.138000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 8.415560, 0.000040, 0.111000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 184.815610, 0.000040, 0.235000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 49.836670, 0.000040, 0.057000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 164.487390, 0.000010, 0.033000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 1, 0, -1}, 321.510740, 0.000010, 0.313000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 74.267740, 0.000020, 0.093000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 78.878450, 0.000010, 0.404000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 208.977760, 0.000080, 0.064000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 353.482090, 0.000060, 0.034000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, 1, 0}, 147.188080, 0.000010, 0.024000},
	{{0, 2, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 272.183420, 0.000010, 0.051000},
	{{0, 2, 2, 0, 0, 0, 0, 0, -2, 2, 0}, 272.183420, 0.000010, 0.142000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 20.364670, 0.000090, 0.190000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 200.618590, 0.000010, 0.054000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 61.497540, 0.000030, 0.102000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 168.663160, 0.000030, 0.288000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 327.662060, 0.000020, 0.060000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 200.875840, 0.000020, 0.033000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 109.790040, 0.000010, 0.143000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 109.790040, 0.000040, 0.160000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 109.710050, 0.000060, 0.051000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, -2, 0}, 103.229660, 0.000050, 0.223000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, -1, 0}, 292.229830, 0.000040, 0.056000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 0, -2}, 289.790040, 0.000010, 0.241000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 278.004600, 0.000040, 0.032000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 1, 0}, 289.478710, 0.000080, 0.023000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 2, 0}, 283.543840, 0.000020, 0.017000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 4, -2, 0}, 291.878510, 0.000010, 0.034000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 4, 0, 0}, 111.878510, 0.000010, 0.018000},
	{{0, 2, 4, 0, 0, 0, 0, 0, 2, -2, 0}, 224.766100, 0.000040, 0.183000},
	{{0, 2, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 238.177620, 0.000040, 0.031000},
	{{0, 2, 5, 0, 0, 0, 0, 0, 2, -2, 0}, 125.144790, 0.000020, 0.154000},
	{{0, 2, 5, 0, 0, 0, 0, 0, 2, 0, 0}, 125.144790, 0.000020, 0.030000},
	{{0, 2, 10, 0, 0, 0, 0, 0, 0, -1, 0}, 74.708660, 0.000030, 212.377000},
	{{0, 3, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 237.711390, 0.000030, 0.033000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 339.410760, 0.000060, 0.064000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 315.172390, 0.000040, 0.092000},
	{{0, 3, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 341.526310, 0.000030, 0.033000},
	{{0, 3, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 162.233740, 0.000030, 0.058000},
	{{0, 3, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 326.413460, 0.000040, 0.243000},
	{{0, 3, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 158.149030, 0.000020, 0.110000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 70.969430, 0.000040, 0.019000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -4, 1, 0}, 250.206560, 0.000010, 0.025000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 248.227960, 0.000010, 0.038000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, -1, 0}, 71.976390, 0.000010, 0.024000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 67.788140, 0.000030, 0.068000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 244.271820, 0.000030, 0.741000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 56.985500, 0.000010, 0.084000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 76.549340, 0.000010, 0.034000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 251.893820, 0.000020, 0.061000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 73.454000, 0.000020, 0.320000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 256.441110, 0.000020, 0.099000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 250.206560, 0.000010, 0.043000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, -2, 0}, 338.754880, 0.000010, 0.019000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, -1, 2}, 137.637460, 0.000040, 0.075000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 351.368720, 0.000020, 0.037000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 25.806220, 0.000010, 0.074000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 1, 2}, 137.637460, 0.000040, 0.076000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 3, 0}, 277.729400, 0.000010, 0.077000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 338.754880, 0.000020, 0.035000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 330.170140, 0.000020, 0.065000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 216.112160, 0.000020, 0.471000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 330.170140, 0.000020, 0.090000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 90.028310, 0.000010, 0.257000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 270.028310, 0.000010, 0.044000},
	{{0, 3, -7, 4, 0, 0, 0, 0, 0, 0, 0}, 56.722500, 0.000010, 302.434000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 118.178910, 0.000050, 0.039000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 2}, 32.808520, 0.000010, 1.016000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 177.148590, 0.000020, 0.079000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 6.706880, 0.000050, 1.537000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 171.358810, 0.000010, 0.072000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, 1}, 37.196070, 0.000050, 0.075000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 236.984880, 0.000020, 0.037000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 54.258680, 0.000210, 14.355000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 37.196070, 0.000050, 0.076000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 279.383940, 0.000010, 0.036000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 47.416580, 0.000040, 0.070000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 15.390280, 0.000060, 0.890000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 56.133010, 0.000010, 0.082000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 351.797270, 0.000010, 0.345000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 185.420970, 0.000020, 0.097000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 345.064970, 0.000060, 0.042000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 223.811270, 0.000040, 0.040000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 199.480960, 0.000150, 0.086000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 5.169210, 0.000020, 0.606000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 87.304130, 0.000010, 1.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 221.456810, 0.000010, 0.038000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 219.076590, 0.000170, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 169.132820, 0.000490, 8.102000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 215.864010, 0.000180, 0.076000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 215.443160, 0.000030, 0.038000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 6.098850, 0.000010, 0.527000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 190.508650, 0.000180, 0.088000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 209.728520, 0.000100, 0.041000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 1, 0}, 195.227220, 0.000020, 0.026000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 108.726590, 0.000030, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 0, 0}, 199.103600, 0.000020, 0.021000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -4, 1, 0}, 21.019100, 0.000010, 0.028000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 24.708380, 0.000040, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 35.030370, 0.000350, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 0.360840, 0.000310, 0.094000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 162.913850, 0.000010, 0.088000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, -1}, 335.921750, 0.000030, 0.040000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 190.894090, 0.000070, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 155.993940, 0.000040, 0.518000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 210.399610, 0.000030, 0.086000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 162.913850, 0.000010, 0.066000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 9.393270, 0.000020, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 13.814780, 0.000380, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 18.084920, 0.001570, 1.141000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 16.615270, 0.000280, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 8.363030, 0.000020, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 25.738220, 0.000040, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 108.362390, 0.000020, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 14.202980, 0.000570, 95.796000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 135.936460, 0.000040, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 174.056700, 0.000120, 5.644000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 11.165680, 0.000380, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 138.907170, 0.000050, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, -1}, 108.362390, 0.000020, 0.076000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 1, 0}, 10.894550, 0.000020, 0.038000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 356.881650, 0.000010, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 165.591880, 0.000020, 1.114000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 55.368020, 0.000040, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 150.426100, 0.000030, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 198.221050, 0.000020, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, -1, 0}, 198.458840, 0.000010, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 198.221050, 0.000040, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 121.416070, 0.000050, 0.044000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, 1}, 301.618430, 0.000050, 0.341000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 102.676890, 0.000030, 0.041000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 90.819090, 0.000030, 0.088000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 289.539520, 0.000190, 0.533000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 167.278290, 0.000020, 0.066000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 288.503820, 0.000010, 0.035000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 260.535960, 0.000010, 1.215000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 194.122910, 0.000020, 0.076000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 134.811270, 0.000040, 9.751000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 247.827180, 0.000180, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -2}, 287.041450, 0.000020, 4.330000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 21.360010, 0.000080, 0.038000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 287.007160, 0.000010, 0.019000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 341.158540, 0.000060, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 99.629150, 0.000020, 0.046000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 2}, 161.537570, 0.000010, 0.201000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 144.118200, 0.000060, 0.116000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 3, 0}, 172.774690, 0.000010, 0.056000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 337.734510, 0.000040, 0.044000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 313.280690, 0.000020, 0.254000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 179.883820, 0.000020, 0.104000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 322.148560, 0.000100, 0.096000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 258.754360, 0.000150, 0.348000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 227.393350, 0.000010, 0.062000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -3, 1}, 158.547260, 0.000010, 0.090000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -2, 1}, 346.437170, 0.000020, 0.464000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 324.110390, 0.000020, 0.087000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 139.217600, 0.000030, 0.065000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 246.199490, 0.000070, 0.549000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 109.053880, 0.000020, 0.035000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 324.110390, 0.000020, 0.066000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 175.384720, 0.000020, 0.082000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 206.022170, 0.000050, 0.907000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 317.376260, 0.000050, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, -2}, 338.355610, 0.000020, 1.300000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 117.811780, 0.000020, 0.036000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -2, -1}, 347.722810, 0.000020, 20.498000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -1, -1}, 65.371180, 0.000040, 0.075000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 359.724820, 0.000040, 0.048000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 311.604660, 0.000030, 0.131000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 200.955920, 0.000050, 0.258000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 1, 0, -1}, 237.578420, 0.000010, 0.354000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 74.309250, 0.000010, 0.476000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 171.507240, 0.000050, 0.065000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 38.037150, 0.000060, 0.035000},
	{{0, 3, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 2.200650, 0.000030, 0.151000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 19.397530, 0.000010, 0.119000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 194.484180, 0.000050, 0.205000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 70.596660, 0.000010, 0.055000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 178.611470, 0.000100, 0.061000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 137.069540, 0.000030, 0.034000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 221.756880, 0.000010, 0.018000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 20.649140, 0.000020, 0.136000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 23.984280, 0.000070, 0.170000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 260.888700, 0.000010, 0.244000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 20.350550, 0.000030, 0.058000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 34.400260, 0.000010, 0.033000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 108.067800, 0.000030, 0.157000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 103.469850, 0.000080, 0.145000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 109.196850, 0.000020, 0.050000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 0, 3, 0}, 109.789850, 0.000010, 0.021000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 108.015750, 0.000020, 0.196000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 99.931350, 0.000010, 0.054000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, 0, -2}, 289.789850, 0.000010, 0.210000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 283.544260, 0.000020, 0.032000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, 1, 0}, 108.015750, 0.000020, 0.022000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, 2, 0}, 103.544260, 0.000020, 0.017000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 4, -2, 0}, 291.734430, 0.000010, 0.034000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 4, -1, 0}, 289.789850, 0.000010, 0.023000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 4, 0, 0}, 108.821080, 0.000050, 0.018000},
	{{0, 3, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 18.785240, 0.000010, 0.127000},
	{{0, 3, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 25.556890, 0.000020, 0.031000},
	{{0, 3, 3, 0, 0, 0, 0, 0, 2, 2, 0}, 198.785240, 0.000010, 0.017000},
	{{0, 3, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 126.718020, 0.000050, 0.030000},
	{{0, 4, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 238.626400, 0.000030, 0.034000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 175.035900, 0.000010, 0.035000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 355.465170, 0.000040, 0.067000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 311.630640, 0.000020, 0.580000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 321.471670, 0.000020, 0.087000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 341.547580, 0.000030, 0.033000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 161.458460, 0.000040, 0.060000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 325.053270, 0.000040, 0.286000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 161.547580, 0.000030, 0.102000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -4, 0, 0}, 70.350890, 0.000030, 0.019000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -4, 2, 0}, 250.350890, 0.000030, 0.039000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, -1, 0}, 250.202090, 0.000020, 0.025000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, -1, 2}, 69.939550, 0.000010, 0.073000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 59.562730, 0.000020, 0.037000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 0, 2}, 70.350890, 0.000030, 2.562000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 18.234060, 0.000030, 0.072000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 1, 2}, 69.939550, 0.000010, 0.078000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 254.872570, 0.000030, 1.381000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 200.049390, 0.000010, 0.080000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 55.471220, 0.000020, 0.034000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 20.345110, 0.000030, 0.400000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 70.202090, 0.000010, 0.057000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 250.202090, 0.000010, 0.111000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 332.936180, 0.000060, 0.077000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 124.208410, 0.000060, 3.622000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 327.460610, 0.000030, 0.068000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 89.247070, 0.000050, 0.668000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 327.460610, 0.000030, 0.085000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 90.625350, 0.000010, 0.306000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 270.625350, 0.000010, 0.043000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 127.715390, 0.000050, 0.040000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 69.560400, 0.000090, 0.083000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 19.485430, 0.000040, 0.784000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 224.887690, 0.000030, 1.799000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 279.445660, 0.000010, 0.037000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 227.172110, 0.000020, 0.073000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 79.119370, 0.000040, 2.008000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 224.593840, 0.000040, 0.078000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 31.296560, 0.000010, 0.644000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 170.406740, 0.000020, 0.440000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 189.891430, 0.000040, 0.091000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 358.708860, 0.000040, 0.041000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 210.644960, 0.000030, 0.041000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 157.430850, 0.000030, 0.091000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 255.595960, 0.000030, 0.439000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 173.325750, 0.000010, 0.064000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 180.133660, 0.000010, 0.643000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 249.888910, 0.000090, 0.078000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 211.784280, 0.000210, 1.992000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 249.888910, 0.000090, 0.073000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 216.649220, 0.000050, 0.077000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 110.568740, 0.000010, 0.786000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 107.267610, 0.000040, 0.083000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 108.491900, 0.000030, 0.019000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 6.164590, 0.000010, 0.047000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 136.275170, 0.000050, 0.043000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 216.262250, 0.000070, 0.100000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 156.218440, 0.000020, 0.305000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 214.196940, 0.000010, 0.060000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, -1}, 324.414260, 0.000040, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 137.519780, 0.000020, 0.391000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 2, -1}, 303.804960, 0.000010, 0.450000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 3, -1}, 160.474820, 0.000010, 0.065000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 332.992580, 0.000100, 0.085000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 188.198950, 0.000130, 0.666000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 312.386220, 0.000050, 0.068000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 177.245950, 0.000020, 0.036000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 246.720780, 0.000020, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 321.136910, 0.000070, 0.071000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 353.589670, 0.000110, 2.231000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 157.205320, 0.000070, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 246.720780, 0.000020, 0.073000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 2, -1}, 0.111290, 0.000020, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 180.749960, 0.000040, 3.678000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 174.174570, 0.000280, 0.077000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, -2}, 199.015540, 0.000020, 1.652000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 179.456200, 0.000090, 0.038000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 18.260960, 0.000020, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 198.260960, 0.000020, 0.020000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 96.992570, 0.000100, 0.045000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 258.342450, 0.000020, 0.111000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 103.746350, 0.000020, 0.234000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 0, 1}, 275.736630, 0.000030, 0.281000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 91.359720, 0.000030, 0.042000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 241.053090, 0.000020, 0.093000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 292.638670, 0.000150, 0.400000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 241.053090, 0.000020, 0.063000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 255.534470, 0.000010, 0.034000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 354.783410, 0.000030, 0.690000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 249.202740, 0.000080, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, -2}, 106.670670, 0.000010, 2.535000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 47.876010, 0.000090, 0.037000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, -3, 0}, 161.536270, 0.000010, 0.016000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 342.389780, 0.000040, 0.029000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 17.840220, 0.000040, 0.047000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 148.841170, 0.000070, 0.125000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 162.689560, 0.000030, 0.190000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, -1}, 227.549020, 0.000050, 0.045000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 291.937130, 0.000040, 0.103000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 275.386930, 0.000110, 0.286000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 260.009090, 0.000030, 0.060000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 88.822080, 0.000010, 0.033000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, -2, 1}, 247.831060, 0.000010, 0.359000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 272.540250, 0.000050, 0.408000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 34.802330, 0.000010, 0.034000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 206.793850, 0.000010, 0.087000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 341.056340, 0.000010, 0.579000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 332.246740, 0.000030, 0.067000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 194.392280, 0.000040, 0.035000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 22.403520, 0.000020, 0.018000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, -3, -1}, 176.014540, 0.000010, 0.079000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 3, -1, -1}, 176.014540, 0.000010, 0.072000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 75.768350, 0.000030, 0.049000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 5.818060, 0.000040, 0.143000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 3, 0}, 114.493890, 0.000010, 0.051000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 70.343950, 0.000010, 0.114000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 189.454650, 0.000020, 0.222000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 70.343950, 0.000010, 0.056000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 91.208930, 0.000010, 0.032000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 226.876210, 0.000040, 0.290000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 56.259970, 0.000030, 0.095000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 45.753320, 0.000040, 0.367000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 56.259970, 0.000030, 0.063000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 49.342360, 0.000090, 0.034000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 216.906850, 0.000010, 0.036000},
	{{0, 4, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 202.616510, 0.000020, 0.052000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 332.519750, 0.000020, 0.129000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 225.616770, 0.000050, 0.182000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, -3, 0}, 93.002430, 0.000010, 0.105000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 191.344330, 0.000050, 0.059000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 16.001940, 0.000040, 0.033000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 20.699040, 0.000010, 0.148000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 23.110110, 0.000060, 0.154000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 202.740430, 0.000010, 0.030000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 235.486160, 0.000010, 0.212000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 20.346170, 0.000030, 0.056000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 44.614520, 0.000050, 0.032000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 109.788550, 0.000010, 0.174000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 103.294330, 0.000020, 0.133000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 109.788550, 0.000030, 0.048000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 108.015560, 0.000020, 0.175000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 283.544690, 0.000020, 0.031000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, 1, 0}, 108.015560, 0.000020, 0.022000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, 2, 0}, 283.544690, 0.000020, 0.017000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 4, 0, 0}, 108.015560, 0.000040, 0.018000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 213.435900, 0.000030, 0.153000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 33.435900, 0.000030, 0.050000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 52.498070, 0.000030, 0.030000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, 2, 0}, 18.596230, 0.000010, 0.017000},
	{{0, 4, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 127.588690, 0.000050, 0.029000},
	{{0, 4, 5, 0, 0, 0, 0, 0, -2, 1, 0}, 171.492470, 0.000050, 49.129000},
	{{0, 5, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 239.492830, 0.000030, 0.035000},
	{{0, 5, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 240.325700, 0.000040, 0.065000},
	{{0, 5, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 56.037960, 0.000010, 0.090000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 215.934220, 0.000020, 0.036000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, 0, 2}, 341.302820, 0.000010, 1.307000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 342.188530, 0.000050, 0.070000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 161.501700, 0.000050, 0.062000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 341.571560, 0.000070, 0.348000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 161.571560, 0.000040, 0.096000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, -1, 0}, 250.195750, 0.000010, 0.025000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 67.812550, 0.000040, 0.075000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 216.626590, 0.000020, 10.166000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 196.290990, 0.000010, 0.076000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 0, -3, 0}, 250.195750, 0.000010, 0.024000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 70.195750, 0.000010, 0.066000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 54.685450, 0.000040, 0.534000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 70.195750, 0.000010, 0.059000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 250.195750, 0.000010, 0.104000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 226.255020, 0.000020, 0.039000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 39.512970, 0.000010, 0.081000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 130.529900, 0.000020, 0.071000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 316.486160, 0.000060, 0.076000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 283.795150, 0.000030, 5.513000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 1, 0}, 275.018170, 0.000020, 68.379000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 304.188550, 0.000040, 0.071000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 111.721630, 0.000010, 1.146000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 304.188550, 0.000040, 0.081000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, -2, 0}, 263.237690, 0.000010, 0.020000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 120.871020, 0.000060, 0.041000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 222.342880, 0.000020, 0.088000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 67.710880, 0.000020, 0.526000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 137.379910, 0.000010, 0.066000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 212.570910, 0.000020, 0.846000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 279.494450, 0.000010, 0.038000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 318.174430, 0.000040, 0.076000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 277.453560, 0.000180, 7.836000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 282.466650, 0.000040, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 115.474770, 0.000020, 1.080000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 198.474440, 0.000020, 0.067000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 194.997500, 0.000040, 0.086000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 348.755280, 0.000050, 0.040000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 307.152470, 0.000030, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 109.292710, 0.000050, 0.097000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 189.336490, 0.000010, 0.345000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 140.491380, 0.000030, 0.458000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 86.925220, 0.000080, 0.082000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 341.883060, 0.000060, 0.887000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 90.380180, 0.000090, 0.070000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 62.586600, 0.000010, 0.036000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -3, 1}, 271.146060, 0.000030, 0.078000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 45.400230, 0.000040, 0.076000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 271.146060, 0.000030, 0.073000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 76.225410, 0.000010, 13.541000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 45.400230, 0.000040, 0.075000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 111.230400, 0.000010, 0.072000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 227.760820, 0.000010, 1.547000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 198.546600, 0.000040, 0.079000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 137.598180, 0.000020, 0.039000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, -2, 0}, 261.998280, 0.000020, 0.020000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 99.020060, 0.000020, 0.044000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 260.633080, 0.000080, 0.107000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 207.048740, 0.000010, 0.256000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 311.258200, 0.000010, 0.058000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 322.972020, 0.000040, 0.042000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 13.291650, 0.000020, 0.314000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 1, -1}, 201.885640, 0.000010, 0.096000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 2, -1}, 303.671190, 0.000010, 0.351000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 97.594300, 0.000010, 0.041000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 214.432290, 0.000040, 0.090000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 249.370200, 0.000070, 0.470000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 242.277710, 0.000040, 0.065000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 3, 0}, 198.448040, 0.000010, 0.024000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, -2, -1}, 160.526130, 0.000010, 0.039000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 16.513620, 0.000060, 0.931000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 145.111890, 0.000050, 0.036000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 101.524690, 0.000010, 0.078000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 33.856690, 0.000030, 2.828000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -2}, 16.754910, 0.000070, 0.076000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 359.374640, 0.000160, 0.073000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -2}, 16.370970, 0.000430, 49.790000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 187.265990, 0.000090, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -2}, 16.754910, 0.000070, 0.075000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, 0}, 198.448040, 0.000010, 0.025000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 252.506020, 0.000010, 0.029000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 97.401590, 0.000050, 0.046000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 255.432480, 0.000020, 0.120000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 116.207730, 0.000010, 0.204000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 301.166530, 0.000020, 0.239000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 169.593310, 0.000020, 0.043000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 253.188090, 0.000060, 0.099000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 314.576090, 0.000070, 0.320000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 253.057650, 0.000030, 0.061000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 106.229540, 0.000010, 0.034000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 343.408760, 0.000030, 0.482000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 194.441980, 0.000040, 0.068000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 59.981320, 0.000090, 0.036000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 342.727330, 0.000030, 0.030000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 64.347370, 0.000030, 0.049000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 145.905880, 0.000040, 0.136000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 3, 0}, 332.243810, 0.000020, 0.052000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 93.397960, 0.000020, 0.045000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 341.479660, 0.000050, 0.110000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 243.131960, 0.000040, 0.242000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 354.932140, 0.000030, 0.058000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 93.042280, 0.000010, 0.033000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 275.046860, 0.000050, 0.325000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 23.809090, 0.000020, 0.092000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 171.434510, 0.000020, 0.425000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 119.692020, 0.000050, 0.064000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 176.008260, 0.000040, 0.035000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 265.026830, 0.000010, 0.018000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 105.480030, 0.000030, 0.051000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 296.682800, 0.000040, 0.157000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 162.538480, 0.000060, 0.195000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 251.381580, 0.000010, 0.032000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 243.247480, 0.000020, 0.245000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 55.740310, 0.000030, 0.060000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 45.752420, 0.000090, 0.033000},
	{{0, 5, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 202.064320, 0.000020, 0.054000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 326.281510, 0.000020, 0.140000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 217.281900, 0.000040, 0.163000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 169.872740, 0.000020, 0.112000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 115.216560, 0.000060, 0.057000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 7.164330, 0.000020, 0.032000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, 2, 0}, 277.377660, 0.000010, 0.017000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 20.758300, 0.000010, 0.163000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 19.752490, 0.000050, 0.140000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, 2, 0}, 202.815880, 0.000010, 0.030000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, -2, 0}, 60.257140, 0.000010, 0.187000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 20.358300, 0.000030, 0.054000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 45.909230, 0.000040, 0.031000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 0, -2, 0}, 108.114580, 0.000020, 0.054000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 109.785800, 0.000010, 0.195000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 109.785800, 0.000040, 0.047000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 272.957380, 0.000030, 0.030000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 103.544510, 0.000020, 0.017000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 4, -2, 0}, 288.014260, 0.000020, 0.032000},
	{{0, 5, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 108.014260, 0.000020, 0.017000},
	{{0, 5, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 18.334120, 0.000010, 0.110000},
	{{0, 5, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 18.334120, 0.000010, 0.028000},
	{{0, 5, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 44.887640, 0.000060, 0.030000},
	{{0, 5, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 307.825900, 0.000020, 0.120000},
	{{0, 5, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 127.825900, 0.000020, 0.029000},
	{{0, 6, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 240.305790, 0.000030, 0.036000},
	{{0, 6, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 240.305790, 0.000040, 0.068000},
	{{0, 6, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 240.305790, 0.000040, 0.085000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 215.012080, 0.000020, 0.037000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 341.596130, 0.000030, 2.115000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 352.058110, 0.000020, 0.078000},
	{{0, 6, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 161.361410, 0.000010, 0.065000},
	{{0, 6, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 346.347450, 0.000060, 0.445000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -4, 0, 0}, 250.187440, 0.000020, 0.020000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -4, 2, 0}, 250.187440, 0.000020, 0.041000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, -1, 0}, 250.241130, 0.000070, 0.025000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 62.551920, 0.000010, 0.038000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 198.968420, 0.000050, 0.079000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 70.187440, 0.000030, 0.073000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 50.720550, 0.000030, 0.802000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 250.187440, 0.000020, 0.098000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 294.119990, 0.000030, 0.040000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 21.147710, 0.000040, 0.085000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 102.931390, 0.000020, 0.068000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 157.514970, 0.000010, 0.037000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 269.465670, 0.000020, 0.074000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 96.495420, 0.000030, 4.051000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 269.465670, 0.000020, 0.077000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, -2, 0}, 318.520180, 0.000010, 0.020000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 108.307440, 0.000080, 0.042000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 202.501620, 0.000030, 0.093000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 6.301220, 0.000010, 0.396000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 279.532590, 0.000010, 0.039000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 1.897510, 0.000020, 0.080000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 285.663500, 0.000080, 1.328000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 306.981400, 0.000010, 0.071000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -3, 1}, 7.103100, 0.000010, 0.076000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -2, 1}, 171.602050, 0.000030, 30.407000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -1, 1}, 31.700230, 0.000070, 0.075000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 4.107160, 0.000030, 3.326000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 7.637930, 0.000020, 0.039000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 245.410750, 0.000050, 0.044000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 111.435110, 0.000020, 0.103000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 3, 0}, 292.799770, 0.000010, 0.060000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 177.492430, 0.000020, 0.356000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 63.728600, 0.000020, 0.040000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 203.971120, 0.000100, 0.087000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 294.937130, 0.000030, 0.570000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 27.735810, 0.000050, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 359.480880, 0.000420, 47.898000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 16.690610, 0.000510, 0.076000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, -2}, 109.303450, 0.000020, 2.822000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 50.366380, 0.000020, 0.038000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 329.282930, 0.000030, 0.045000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 277.516670, 0.000090, 0.115000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 289.831890, 0.000040, 0.043000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 211.243220, 0.000010, 0.263000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 201.881170, 0.000030, 0.102000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 3, -1}, 201.881170, 0.000010, 0.060000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 148.786420, 0.000010, 0.042000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 68.141380, 0.000030, 0.095000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 31.632780, 0.000070, 0.363000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 54.976160, 0.000030, 0.062000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -2, -1}, 21.881170, 0.000010, 0.040000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 345.609650, 0.000020, 0.087000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 180.100490, 0.000050, 0.065000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 5.549900, 0.000020, 0.588000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 173.155780, 0.000050, 0.035000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 345.609650, 0.000020, 0.067000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 85.404380, 0.000010, 0.081000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 10.600530, 0.000050, 1.021000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 15.084770, 0.000100, 0.070000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 164.934370, 0.000020, 0.036000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 3, -1, -1}, 229.522470, 0.000020, 0.076000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, -2, 0}, 198.439720, 0.000020, 0.039000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 4, 0, 0}, 198.439720, 0.000020, 0.019000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 252.568280, 0.000010, 0.029000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 88.261820, 0.000070, 0.048000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 255.225810, 0.000020, 0.129000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 62.116590, 0.000010, 0.181000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -1, 0, 1}, 331.201800, 0.000010, 0.208000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 207.277430, 0.000020, 0.044000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 258.407840, 0.000090, 0.105000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 327.808510, 0.000030, 0.266000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 253.691100, 0.000030, 0.059000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 215.235100, 0.000010, 0.033000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 245.743580, 0.000020, 0.370000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 229.855870, 0.000020, 0.505000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 94.373050, 0.000110, 0.066000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 74.043470, 0.000090, 0.035000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 342.759960, 0.000030, 0.022000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -4, 1, 0}, 341.529050, 0.000010, 0.032000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 342.759960, 0.000030, 0.055000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, -1, 0}, 342.759960, 0.000060, 0.030000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 64.918920, 0.000040, 0.050000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 146.783350, 0.000040, 0.149000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, 1}, 174.749240, 0.000010, 0.172000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 332.004100, 0.000080, 0.118000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 178.773570, 0.000040, 0.210000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 340.845610, 0.000060, 0.056000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 202.102210, 0.000020, 0.032000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -2, -1}, 97.272220, 0.000010, 0.044000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 176.007310, 0.000010, 0.105000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 356.007310, 0.000020, 0.058000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 326.984580, 0.000040, 0.270000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 326.899380, 0.000010, 0.033000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 176.007310, 0.000010, 0.059000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 146.075460, 0.000050, 0.062000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 16.509480, 0.000030, 0.034000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 341.110660, 0.000020, 0.018000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 106.496610, 0.000050, 0.053000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 296.235610, 0.000050, 0.175000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 203.175720, 0.000050, 0.174000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 261.290300, 0.000010, 0.108000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 65.333690, 0.000040, 0.058000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 17.333610, 0.000040, 0.033000},
	{{0, 6, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 190.905070, 0.000050, 0.056000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 327.446020, 0.000030, 0.154000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 227.029610, 0.000010, 0.148000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 319.776970, 0.000020, 0.050000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 195.589970, 0.000020, 0.030000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 277.725390, 0.000010, 0.121000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 136.744510, 0.000030, 0.055000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 3.576270, 0.000040, 0.032000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 20.820570, 0.000010, 0.182000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 18.934320, 0.000040, 0.129000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 20.820570, 0.000010, 0.048000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 319.741010, 0.000010, 0.167000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 20.380030, 0.000030, 0.052000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 55.752750, 0.000050, 0.031000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 0, -2, 0}, 108.110670, 0.000020, 0.056000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 108.761190, 0.000030, 0.222000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 106.474220, 0.000010, 0.045000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 327.365450, 0.000010, 0.030000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 2, 1, 0}, 289.781330, 0.000010, 0.021000},
	{{0, 6, -1, 0, 0, 0, 0, 0, 2, 2, 0}, 103.543220, 0.000020, 0.017000},
	{{0, 7, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 243.227620, 0.000020, 0.037000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 214.521570, 0.000020, 0.038000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 341.619990, 0.000030, 0.076000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 140.509030, 0.000010, 6.550000},
	{{0, 7, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 161.415970, 0.000010, 0.067000},
	{{0, 7, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 345.984090, 0.000050, 0.617000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -4, 0, 0}, 250.177090, 0.000030, 0.020000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 250.217470, 0.000060, 0.026000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 239.697900, 0.000020, 0.039000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 243.823960, 0.000050, 0.083000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 250.177090, 0.000030, 0.077000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 63.633030, 0.000020, 0.072000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 41.246130, 0.000020, 1.609000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 63.633030, 0.000020, 0.079000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 250.177090, 0.000030, 0.092000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 294.014030, 0.000050, 0.041000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 123.285360, 0.000070, 0.090000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 271.821560, 0.000020, 0.065000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 120.764340, 0.000020, 0.078000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 356.910650, 0.000020, 2.641000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 120.141090, 0.000010, 0.073000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, -2, 0}, 251.225280, 0.000020, 0.020000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 113.703790, 0.000080, 0.043000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 41.680210, 0.000010, 0.099000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 210.546270, 0.000010, 0.317000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 340.579360, 0.000020, 0.084000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 343.050740, 0.000040, 0.725000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 340.579360, 0.000020, 0.068000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 177.772180, 0.000040, 3.078000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 124.521350, 0.000020, 0.073000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 304.521350, 0.000020, 0.078000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 8.496730, 0.000020, 0.038000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 246.564660, 0.000040, 0.045000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 110.027820, 0.000010, 0.110000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 299.945040, 0.000010, 0.241000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 292.981900, 0.000010, 0.043000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 115.566720, 0.000030, 0.291000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -1, 2, -1}, 292.981900, 0.000010, 0.323000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 62.752330, 0.000020, 0.041000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 289.399930, 0.000030, 0.092000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 118.964070, 0.000080, 0.420000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 289.223610, 0.000020, 0.064000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 104.251940, 0.000010, 0.035000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 93.259880, 0.000050, 0.755000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 291.344930, 0.000010, 0.079000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 302.726740, 0.000030, 1.654000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 50.410770, 0.000030, 0.072000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, -2}, 289.481620, 0.000040, 3.688000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 258.761690, 0.000010, 0.037000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 2, 0}, 289.668260, 0.000020, 0.019000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 335.168360, 0.000040, 0.047000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 279.165560, 0.000060, 0.123000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, -1}, 274.748800, 0.000030, 0.045000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 125.467260, 0.000020, 0.226000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 1, -1}, 201.874830, 0.000020, 0.109000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 2, 1}, 21.874830, 0.000010, 0.032000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 3, -1}, 21.874830, 0.000010, 0.058000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 149.099650, 0.000010, 0.043000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 22.595760, 0.000070, 0.101000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 40.229520, 0.000010, 0.296000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 29.225200, 0.000070, 0.060000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 331.854210, 0.000010, 0.430000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 180.092180, 0.000020, 0.034000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 321.218750, 0.000020, 0.086000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 11.720410, 0.000020, 0.623000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 351.477610, 0.000040, 0.067000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, -2}, 198.338890, 0.000020, 0.787000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 11.720410, 0.000010, 0.036000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 18.234900, 0.000010, 0.024000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 4, 0, 0}, 198.429380, 0.000030, 0.019000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 72.010010, 0.000060, 0.049000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 257.302970, 0.000010, 0.141000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 120.978390, 0.000020, 0.163000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 0, 1}, 319.025510, 0.000010, 0.184000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 241.740200, 0.000030, 0.045000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 257.711870, 0.000060, 0.113000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 140.573120, 0.000020, 0.228000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 76.383310, 0.000030, 0.301000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 242.078880, 0.000030, 0.384000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 86.023350, 0.000100, 0.063000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 342.787350, 0.000030, 0.023000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -4, 1, 0}, 341.522710, 0.000010, 0.032000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -4, 2, 0}, 342.787350, 0.000030, 0.057000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, -1, 0}, 342.787350, 0.000050, 0.031000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 62.769900, 0.000050, 0.052000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 150.608180, 0.000040, 0.164000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 121.884960, 0.000010, 0.140000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 347.564520, 0.000090, 0.127000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 144.147960, 0.000080, 0.186000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 2.180390, 0.000060, 0.054000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 145.160530, 0.000020, 0.031000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, -1}, 338.448040, 0.000020, 0.231000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 319.186000, 0.000040, 0.032000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 2, -1}, 176.000970, 0.000010, 0.032000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 291.997690, 0.000010, 0.104000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 223.334540, 0.000010, 0.277000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 160.037350, 0.000120, 0.059000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 13.135810, 0.000050, 0.033000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 161.272420, 0.000010, 0.018000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 97.019600, 0.000060, 0.054000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 305.735770, 0.000040, 0.196000},
	{{0, 7, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 249.332930, 0.000010, 0.047000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 85.600220, 0.000020, 0.050000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 69.332930, 0.000010, 0.145000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 143.400480, 0.000030, 0.157000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 113.151650, 0.000010, 0.188000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 12.185580, 0.000030, 0.032000},
	{{0, 7, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 191.237880, 0.000060, 0.058000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 327.197700, 0.000030, 0.170000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 33.848830, 0.000020, 0.136000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 327.197700, 0.000030, 0.048000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 0, 2, 0}, 97.273990, 0.000010, 0.030000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 77.198100, 0.000020, 0.178000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 139.249430, 0.000030, 0.053000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 61.500930, 0.000040, 0.031000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 326.949900, 0.000020, 0.017000},
	{{0, 7, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 272.393300, 0.000010, 0.322000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 19.009450, 0.000020, 0.119000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 199.009450, 0.000020, 0.029000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 108.105880, 0.000020, 0.058000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 103.405820, 0.000010, 0.107000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 103.540440, 0.000020, 0.028000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 289.774990, 0.000010, 0.132000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 66.586430, 0.000020, 0.029000},
	{{0, 7, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 68.629180, 0.000010, 0.028000},
	{{0, 7, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 212.103520, 0.000010, 100.849000},
	{{0, 7, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 147.992960, 0.000010, 8.136000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 60.434070, 0.000020, 0.037000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 104.432140, 0.000020, 0.074000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 61.766650, 0.000070, 4.509000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 3, 0}, 189.853460, 0.000010, 0.077000},
	{{0, 8, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 241.576710, 0.000020, 0.501000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, -2, 0}, 341.466020, 0.000020, 0.019000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 182.315350, 0.000020, 0.039000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 319.566800, 0.000050, 0.080000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 146.869510, 0.000020, 1.285000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 161.466020, 0.000010, 0.070000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 308.895540, 0.000040, 1.004000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 195.660780, 0.000040, 0.095000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 195.660780, 0.000030, 0.042000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -4, 0, 0}, 250.164680, 0.000030, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, -1, 0}, 163.758310, 0.000020, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 95.737600, 0.000290, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 2}, 70.164680, 0.000010, 0.474000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 96.665420, 0.000480, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 220.994300, 0.000020, 0.562000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 64.718510, 0.000010, 0.067000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 103.778300, 0.000030, 0.038000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 84.370670, 0.000550, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 93.282210, 0.003200, 238.919000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 84.428240, 0.000550, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 85.024760, 0.000040, 0.038000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 92.752240, 0.000020, 0.565000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 96.016330, 0.000490, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 92.983840, 0.000310, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 1, 0}, 92.752240, 0.000050, 0.026000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 280.591050, 0.000040, 0.042000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 14.746590, 0.000030, 0.095000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 247.336960, 0.000010, 0.360000},
	{{0, 8, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 281.103480, 0.000010, 0.062000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 227.462670, 0.000080, 0.996000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 260.014260, 0.000030, 20.170000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, -3, 0}, 93.145960, 0.000010, 0.071000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 273.145960, 0.000010, 0.080000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 89.645400, 0.000070, 0.044000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 23.187010, 0.000020, 0.106000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 211.416290, 0.000010, 0.265000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -1, 0, 1}, 192.801980, 0.000010, 0.327000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 322.330870, 0.000020, 0.089000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 342.092590, 0.000040, 0.499000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 322.330870, 0.000020, 0.066000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 312.702160, 0.000020, 1.052000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 193.699610, 0.000040, 4.345000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 6.257240, 0.000060, 0.074000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 111.069070, 0.000020, 0.118000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 116.168530, 0.000020, 0.209000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 293.040490, 0.000010, 0.044000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -1, 0, 1}, 121.570930, 0.000020, 0.246000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -1, 2, -1}, 293.040490, 0.000010, 0.269000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 36.710670, 0.000010, 0.043000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 288.815060, 0.000030, 0.098000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 114.652480, 0.000120, 0.333000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 288.815060, 0.000030, 0.062000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 109.455880, 0.000020, 0.034000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 213.466060, 0.000030, 0.513000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 88.107090, 0.000020, 0.083000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 100.752660, 0.000040, 0.069000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 280.965650, 0.000040, 0.036000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 351.695350, 0.000030, 0.048000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 285.451530, 0.000040, 0.134000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 243.609240, 0.000020, 0.053000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 253.170030, 0.000040, 0.046000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, 1}, 96.855490, 0.000020, 0.198000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 2, -1}, 192.789340, 0.000020, 0.212000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 116.021310, 0.000020, 0.044000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 1.905220, 0.000060, 0.108000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 263.587440, 0.000030, 0.250000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 9.374210, 0.000060, 0.058000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 0.081830, 0.000060, 0.034000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 196.114620, 0.000040, 0.448000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 18.353140, 0.000020, 0.065000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, -2}, 198.416960, 0.000010, 0.527000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 192.417970, 0.000010, 0.035000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 4, 0, 0}, 198.416960, 0.000020, 0.019000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, -2, 0}, 253.880680, 0.000030, 0.022000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 64.534800, 0.000020, 0.051000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 268.112630, 0.000030, 0.154000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 116.322170, 0.000010, 0.148000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 171.045740, 0.000010, 0.046000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 253.880680, 0.000030, 0.121000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 71.913860, 0.000050, 0.200000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 84.141810, 0.000030, 0.032000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 66.286900, 0.000020, 0.253000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 89.763210, 0.000050, 0.061000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 282.012940, 0.000050, 0.034000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -4, 0, 0}, 342.809590, 0.000030, 0.023000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -4, 2, 0}, 162.809590, 0.000030, 0.059000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, -2, 0}, 161.369260, 0.000020, 0.022000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, -1, 0}, 338.144350, 0.000010, 0.031000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 54.408750, 0.000040, 0.053000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 108.779920, 0.000020, 0.183000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 185.608740, 0.000020, 0.129000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 330.275220, 0.000030, 0.138000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 125.655570, 0.000140, 0.167000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 353.038580, 0.000010, 0.052000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 155.695490, 0.000020, 0.031000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, -1}, 250.981630, 0.000020, 0.202000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 305.389660, 0.000050, 0.031000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 162.593000, 0.000040, 0.057000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 311.354080, 0.000060, 0.033000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 2, 0}, 161.018920, 0.000010, 0.017000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 88.958610, 0.000040, 0.056000},
	{{0, 8, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 294.528570, 0.000030, 0.223000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 67.755550, 0.000020, 0.051000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 109.367430, 0.000030, 0.143000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 17.731990, 0.000020, 0.032000},
	{{0, 8, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 196.049490, 0.000040, 0.060000},
	{{0, 8, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 179.329970, 0.000020, 0.102000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 3.888870, 0.000010, 0.054000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 113.255550, 0.000020, 0.125000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 324.716180, 0.000020, 0.029000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, -3, 0}, 191.861530, 0.000010, 0.142000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 86.522290, 0.000020, 0.161000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 167.401080, 0.000010, 0.051000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 39.938820, 0.000040, 0.031000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 358.676180, 0.000010, 0.017000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 200.940650, 0.000010, 0.111000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 199.107770, 0.000020, 0.166000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 204.993980, 0.000030, 0.138000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 199.107770, 0.000020, 0.049000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 204.993980, 0.000030, 0.030000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 108.099870, 0.000020, 0.061000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 337.521150, 0.000010, 0.100000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 283.535980, 0.000020, 0.027000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 294.224640, 0.000010, 0.047000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 288.000700, 0.000020, 0.021000},
	{{0, 8, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 62.115250, 0.000020, 2.094000},
	{{0, 8, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 75.129290, 0.000020, 0.028000},
	{{0, 8, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 132.141150, 0.000010, 0.027000},
	{{0, 8, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 220.436670, 0.000010, 3.975000},
	{{0, 9, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 145.517220, 0.000030, 0.072000},
	{{0, 9, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 62.333930, 0.000050, 0.038000},
	{{0, 9, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 62.417070, 0.000040, 2.477000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 341.662720, 0.000060, 0.084000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 176.512810, 0.000020, 0.712000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 170.243360, 0.000040, 0.073000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 341.662720, 0.000060, 2.701000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 173.117960, 0.000030, 0.078000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -4, 0, 0}, 250.150190, 0.000020, 0.020000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 250.181310, 0.000030, 0.027000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 244.710420, 0.000030, 0.041000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 250.181310, 0.000030, 0.092000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 239.708740, 0.000030, 0.039000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 70.150190, 0.000020, 0.079000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 174.757240, 0.000120, 0.043000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 178.895110, 0.000010, 0.294000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 335.951090, 0.000020, 0.614000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 72.890700, 0.000020, 0.075000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 273.769510, 0.000010, 6.930000},
	{{0, 9, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 72.890700, 0.000020, 0.076000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 100.789750, 0.000060, 0.045000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 348.075870, 0.000050, 0.113000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 208.987980, 0.000020, 0.227000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 351.052240, 0.000020, 0.042000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 4.221080, 0.000030, 0.094000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 287.604790, 0.000050, 0.380000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 4.221080, 0.000030, 0.063000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 171.406010, 0.000020, 0.635000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 36.688040, 0.000020, 0.071000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 189.924880, 0.000040, 0.037000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 110.042200, 0.000040, 0.047000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 111.689490, 0.000010, 0.127000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 315.312410, 0.000010, 0.185000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 293.095050, 0.000010, 0.045000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -1, 0, 1}, 251.955310, 0.000010, 0.214000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -1, 2, -1}, 293.095050, 0.000010, 0.230000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 72.878260, 0.000010, 0.044000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 289.763670, 0.000020, 0.104000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 120.843250, 0.000090, 0.276000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 289.763670, 0.000020, 0.059000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 100.855260, 0.000020, 0.033000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 212.931450, 0.000020, 0.388000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 109.654910, 0.000030, 0.066000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 289.763670, 0.000030, 0.035000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 351.369990, 0.000030, 0.050000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 326.077920, 0.000030, 0.146000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 231.034410, 0.000050, 0.047000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, 1}, 96.849010, 0.000010, 0.176000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 154.785600, 0.000020, 0.046000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 1.508850, 0.000010, 0.116000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 220.684060, 0.000030, 0.216000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 18.362410, 0.000020, 0.056000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 17.297880, 0.000020, 0.280000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 0.069420, 0.000050, 0.033000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 192.962700, 0.000010, 0.034000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, -2, 0}, 253.965210, 0.000030, 0.022000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 292.332760, 0.000020, 0.052000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 253.965210, 0.000060, 0.171000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 176.390390, 0.000010, 0.048000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 256.034400, 0.000050, 0.131000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 119.546300, 0.000050, 0.178000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 252.742930, 0.000010, 0.053000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, -1}, 53.576950, 0.000020, 0.219000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 69.783670, 0.000010, 0.259000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 310.814490, 0.000020, 0.033000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 46.482920, 0.000070, 0.055000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 0.211450, 0.000050, 0.206000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 0, 1}, 277.199530, 0.000010, 0.130000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, -3, 0}, 161.504050, 0.000010, 0.030000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 227.961580, 0.000010, 0.151000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 146.510290, 0.000090, 0.151000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 182.019030, 0.000020, 0.050000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, -2, 1}, 111.373150, 0.000020, 0.169000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, -1}, 250.975150, 0.000010, 0.179000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, 1}, 315.011850, 0.000020, 0.031000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 269.983400, 0.000010, 0.119000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 172.621740, 0.000010, 0.206000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 136.517920, 0.000030, 0.055000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 239.358040, 0.000020, 0.032000},
	{{0, 9, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 69.936570, 0.000030, 0.058000},
	{{0, 9, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 328.209640, 0.000020, 0.260000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 231.692440, 0.000010, 0.053000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 99.613140, 0.000060, 0.131000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 334.764040, 0.000020, 0.031000},
	{{0, 9, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 196.978120, 0.000050, 0.062000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 4.363310, 0.000010, 0.056000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 140.853620, 0.000030, 0.116000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 147.416090, 0.000020, 0.028000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 248.588710, 0.000010, 0.146000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 13.932760, 0.000030, 0.050000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 56.360700, 0.000090, 0.030000},
	{{0, 9, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 272.814450, 0.000020, 0.540000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 200.995210, 0.000010, 0.104000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 199.166360, 0.000040, 0.047000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 200.854810, 0.000070, 0.029000},
	{{0, 9, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 207.181750, 0.000030, 1.174000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 288.097640, 0.000020, 0.063000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 297.326130, 0.000040, 0.094000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 283.529660, 0.000040, 0.045000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 2, 1, 0}, 289.756330, 0.000010, 0.021000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 4, -2, 0}, 289.756330, 0.000010, 0.030000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 289.756330, 0.000010, 0.017000},
	{{0, 9, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 45.903040, 0.000010, 6.758000},
	{{0, 9, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 30.741310, 0.000020, 0.027000},
	{{0, 9, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 312.615590, 0.000020, 0.027000},
	{{0, 9, -1, 0, 0, 0, 0, 0, 0, 1, -2}, 40.147380, 0.000010, 24.729000},
	{{0, 10, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 272.530340, 0.000030, 0.076000},
	{{0, 10, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 215.939810, 0.000010, 34.189000},
	{{0, 10, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 62.974370, 0.000080, 0.039000},
	{{0, 10, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 63.017660, 0.000040, 0.082000},
	{{0, 10, -17, 0, 0, 0, 0, 0, -2, 3, 0}, 63.017660, 0.000040, 0.070000},
	{{0, 10, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 63.004970, 0.000030, 1.343000},
	{{0, 10, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 341.812150, 0.000070, 0.089000},
	{{0, 10, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 355.949080, 0.000020, 0.493000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 161.680880, 0.000030, 0.038000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 353.084850, 0.000040, 0.077000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 312.002970, 0.000020, 3.918000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 353.084850, 0.000040, 0.074000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 245.144570, 0.000030, 0.043000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 76.339790, 0.000040, 0.098000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 70.133620, 0.000010, 0.330000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 250.264730, 0.000020, 0.797000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 76.339710, 0.000020, 0.069000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -3, 0}, 70.148250, 0.000040, 0.073000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 250.133620, 0.000010, 1.928000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 70.148250, 0.000040, 0.079000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 163.214910, 0.000110, 0.044000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 18.348750, 0.000010, 0.248000},
	{{0, 10, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 94.379980, 0.000030, 0.073000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 93.739000, 0.000060, 0.047000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 359.860210, 0.000080, 0.122000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 213.019630, 0.000010, 0.199000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 83.376380, 0.000010, 0.043000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 44.634430, 0.000010, 0.100000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 304.407900, 0.000020, 0.307000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 44.634430, 0.000010, 0.061000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 8.295960, 0.000010, 0.085000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 17.901750, 0.000040, 0.068000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 190.590410, 0.000030, 0.036000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 66.361610, 0.000050, 0.049000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 111.349510, 0.000010, 0.138000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 293.145100, 0.000020, 0.046000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 308.868890, 0.000010, 0.045000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 289.804430, 0.000010, 0.111000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 94.849450, 0.000120, 0.235000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 289.804430, 0.000010, 0.057000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 111.637480, 0.000010, 0.033000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 109.804430, 0.000010, 0.064000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 289.155640, 0.000010, 0.034000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, -2, 0}, 18.037200, 0.000010, 0.022000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 49.099380, 0.000010, 0.051000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 305.902370, 0.000040, 0.161000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 277.206480, 0.000010, 0.142000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 230.644350, 0.000040, 0.049000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, 1}, 108.653250, 0.000020, 0.159000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 198.367140, 0.000030, 0.125000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 217.922010, 0.000090, 0.190000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 198.367150, 0.000010, 0.054000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 240.903070, 0.000010, 0.031000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, -2, 1}, 180.054920, 0.000020, 0.221000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 162.241250, 0.000020, 0.238000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 0.054920, 0.000020, 0.032000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 198.385910, 0.000010, 0.287000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 18.385910, 0.000020, 0.060000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 205.252920, 0.000010, 0.033000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 1, 0}, 18.385910, 0.000020, 0.023000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 2, 0}, 198.367140, 0.000030, 0.018000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 256.502760, 0.000030, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 254.042590, 0.000030, 0.191000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 103.834020, 0.000030, 0.125000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 74.042590, 0.000030, 0.047000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 96.350590, 0.000020, 0.049000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 257.430680, 0.000040, 0.143000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 143.546040, 0.000050, 0.160000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 24.827580, 0.000020, 0.192000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 176.436970, 0.000010, 0.223000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 287.552780, 0.000050, 0.032000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, -2, 0}, 341.224900, 0.000020, 0.023000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 35.237830, 0.000080, 0.057000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 56.144990, 0.000030, 0.237000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 94.509890, 0.000020, 0.054000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 2, -1}, 94.509890, 0.000020, 0.125000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, -3, 0}, 341.491640, 0.000010, 0.031000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 273.278570, 0.000010, 0.052000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 267.364180, 0.000010, 0.167000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 137.776590, 0.000040, 0.138000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 178.844230, 0.000020, 0.049000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 18.643910, 0.000010, 0.030000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 355.969900, 0.000010, 0.030000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 343.457780, 0.000010, 0.182000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 40.914320, 0.000020, 0.053000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 313.510760, 0.000030, 0.031000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 69.961850, 0.000030, 0.061000},
	{{0, 10, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 326.091830, 0.000020, 0.310000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 95.475580, 0.000070, 0.121000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 2, -2, 0}, 189.305430, 0.000010, 0.154000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 278.504260, 0.000010, 0.030000},
	{{0, 10, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 197.905160, 0.000050, 0.065000},
	{{0, 10, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 349.759540, 0.000020, 0.449000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 4.785750, 0.000010, 0.058000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 150.923320, 0.000040, 0.108000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 147.661340, 0.000020, 0.173000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 284.217240, 0.000020, 0.134000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 2, 2, 0}, 170.261230, 0.000010, 0.017000},
	{{0, 10, -6, 0, 0, 0, 0, 0, -3, 0, 2}, 163.327750, 0.000020, 167.135000},
	{{0, 10, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 279.175700, 0.000010, 0.069000},
	{{0, 10, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 279.175700, 0.000010, 0.083000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 17.699000, 0.000020, 0.118000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 201.907410, 0.000030, 0.029000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 21.045260, 0.000010, 0.016000},
	{{0, 10, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 265.001650, 0.000010, 0.074000},
	{{0, 10, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 192.778080, 0.000020, 4.415000},
	{{0, 10, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 265.001650, 0.000010, 0.077000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 287.982040, 0.000020, 0.041000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 106.341290, 0.000010, 0.028000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 106.341290, 0.000010, 0.016000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 4, -2, 0}, 109.743920, 0.000010, 0.029000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 4, 0, 0}, 289.743920, 0.000010, 0.016000},
	{{0, 10, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 196.190480, 0.000010, 8.810000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 163.599650, 0.000010, 0.042000},
	{{0, 10, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 65.323540, 0.000010, 0.027000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -2, 0}, 60.662720, 0.000020, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 60.662720, 0.000170, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 60.999290, 0.000190, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 60.662720, 0.000050, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 59.608620, 0.000790, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, -2}, 240.662720, 0.000030, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 60.662720, 0.014430, 1911.695000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 2}, 240.662720, 0.000030, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 60.179990, 0.000650, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 60.662720, 0.000050, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 65.137000, 0.000170, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 60.662720, 0.000170, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 30.276570, 0.000020, 0.026000},
	{{0, 10, -2, 0, 0, 0, 0, 0, -2, -1, 0}, 317.725790, 0.000010, 0.042000},
	{{0, 11, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 63.533490, 0.000080, 0.040000},
	{{0, 11, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 104.017110, 0.000010, 0.075000},
	{{0, 11, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 250.837910, 0.000020, 8.386000},
	{{0, 11, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 104.017110, 0.000010, 0.076000},
	{{0, 11, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 340.985940, 0.000010, 0.042000},
	{{0, 11, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 341.696700, 0.000050, 0.094000},
	{{0, 11, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 163.394810, 0.000010, 0.039000},
	{{0, 11, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 346.710950, 0.000030, 1.135000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 70.114680, 0.000040, 0.020000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 70.115000, 0.000020, 0.028000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 82.880050, 0.000010, 0.044000},
	{{0, 11, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 250.113700, 0.000030, 0.088000},
	{{0, 11, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 254.197510, 0.000020, 0.532000},
	{{0, 11, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 114.320490, 0.000040, 0.075000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 146.756470, 0.000080, 0.046000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 40.725150, 0.000020, 0.215000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 159.111930, 0.000030, 0.048000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 21.995870, 0.000070, 0.132000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 259.679240, 0.000040, 0.177000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 3, 0}, 1.913400, 0.000010, 0.053000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 182.883320, 0.000020, 0.258000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 11.314100, 0.000020, 0.475000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 11.605380, 0.000030, 0.065000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 17.557430, 0.000050, 0.050000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 309.749780, 0.000030, 0.150000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 293.190470, 0.000020, 0.048000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 288.759210, 0.000010, 0.046000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 88.970960, 0.000050, 0.205000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 91.456880, 0.000030, 0.261000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 278.458790, 0.000020, 0.322000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 109.840730, 0.000020, 0.061000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 350.752980, 0.000020, 0.053000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 349.424500, 0.000020, 0.179000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, -2, 1}, 21.829270, 0.000020, 0.051000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 230.299140, 0.000040, 0.050000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, 1}, 38.219340, 0.000040, 0.144000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 1, -1}, 201.829270, 0.000010, 0.150000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 131.567550, 0.000020, 0.048000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 170.844550, 0.000020, 0.170000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 198.367690, 0.000020, 0.052000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 24.037460, 0.000020, 0.031000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 118.330110, 0.000020, 0.207000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, -3, 0}, 18.364430, 0.000010, 0.109000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 18.366820, 0.000050, 0.058000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 202.352260, 0.000030, 0.033000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 1, 0}, 18.367280, 0.000010, 0.023000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 211.345840, 0.000020, 0.056000},
	{{0, 11, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 91.862180, 0.000010, 0.116000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 68.414570, 0.000030, 0.051000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 257.748690, 0.000040, 0.157000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 58.438050, 0.000050, 0.145000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 265.846990, 0.000060, 0.032000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 33.408840, 0.000100, 0.059000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 77.653000, 0.000020, 0.278000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 151.780670, 0.000030, 0.056000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, 1}, 329.075060, 0.000020, 0.112000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 2, -1}, 94.278450, 0.000020, 0.116000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 327.027160, 0.000010, 0.186000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 153.048560, 0.000010, 0.127000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, -2, 1}, 175.955410, 0.000020, 0.140000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, -1}, 342.140620, 0.000020, 0.146000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 161.222660, 0.000010, 0.140000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 125.362000, 0.000010, 0.164000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 341.044510, 0.000040, 0.052000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 307.992380, 0.000040, 0.031000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 93.685740, 0.000040, 0.063000},
	{{0, 11, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 335.166250, 0.000020, 0.384000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 278.972140, 0.000010, 0.057000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 91.248950, 0.000070, 0.113000},
	{{0, 11, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 57.658590, 0.000020, 0.141000},
	{{0, 11, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 209.433300, 0.000030, 0.067000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 5.161910, 0.000010, 0.060000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 127.521990, 0.000010, 0.101000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 338.928570, 0.000020, 0.027000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 357.955130, 0.000010, 0.194000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 330.337810, 0.000020, 0.047000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 223.759580, 0.000020, 0.029000},
	{{0, 11, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 148.918960, 0.000030, 0.072000},
	{{0, 11, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 28.954430, 0.000010, 0.079000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 201.090630, 0.000010, 0.092000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 201.090630, 0.000010, 0.027000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 21.090630, 0.000010, 0.028000},
	{{0, 11, -7, 0, 0, 0, 0, 0, 2, 2, 0}, 201.090630, 0.000010, 0.016000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 95.180490, 0.000010, 0.078000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 37.427020, 0.000020, 2.506000},
	{{0, 11, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 275.180490, 0.000010, 0.073000},
	{{0, 11, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 286.317020, 0.000010, 0.084000},
	{{0, 11, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 286.317020, 0.000010, 0.026000},
	{{0, 11, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 287.969630, 0.000020, 0.043000},
	{{0, 11, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 109.801920, 0.000010, 2.667000},
	{{0, 11, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 244.633020, 0.000020, 0.027000},
	{{0, 12, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 64.021450, 0.000090, 0.041000},
	{{0, 12, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 243.889860, 0.000020, 0.091000},
	{{0, 12, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 244.050760, 0.000030, 1.975000},
	{{0, 12, -18, 0, 0, 0, 0, 0, -2, -2, 0}, 161.620520, 0.000010, 0.020000},
	{{0, 12, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 341.620520, 0.000010, 0.043000},
	{{0, 12, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 341.710150, 0.000120, 0.100000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 341.710150, 0.000030, 0.085000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 159.311090, 0.000020, 0.664000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 341.710150, 0.000030, 0.068000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 341.620520, 0.000030, 0.077000},
	{{0, 12, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 70.094340, 0.000010, 0.028000},
	{{0, 12, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 69.839690, 0.000020, 0.045000},
	{{0, 12, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 249.969730, 0.000020, 0.111000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 250.070340, 0.000020, 0.093000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 70.094340, 0.000030, 0.071000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 11.820090, 0.000030, 0.047000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 358.873620, 0.000020, 0.189000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 196.772300, 0.000080, 0.049000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 8.976530, 0.000050, 0.143000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 200.600170, 0.000020, 0.159000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 294.722550, 0.000010, 0.222000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 12.142150, 0.000010, 0.034000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 355.595950, 0.000060, 0.052000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 14.509140, 0.000020, 0.137000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 293.231220, 0.000020, 0.049000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 147.193610, 0.000010, 0.048000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 97.336800, 0.000060, 0.182000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 91.493180, 0.000020, 0.225000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 289.714000, 0.000040, 0.059000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 289.970610, 0.000040, 0.033000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 66.489220, 0.000020, 0.055000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 292.932990, 0.000010, 0.201000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 214.670140, 0.000030, 0.052000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 0, 1}, 19.212020, 0.000040, 0.132000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 2, -1}, 93.687670, 0.000010, 0.138000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 133.177630, 0.000020, 0.050000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 358.730170, 0.000140, 0.154000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 18.346620, 0.000010, 0.051000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 1.962840, 0.000010, 0.030000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 118.135750, 0.000020, 0.183000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 192.597400, 0.000020, 0.211000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 18.364370, 0.000020, 0.056000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 197.445200, 0.000040, 0.032000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 225.069300, 0.000020, 0.058000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 91.842490, 0.000010, 0.108000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 258.089990, 0.000040, 0.174000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 340.676140, 0.000030, 0.133000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 72.676380, 0.000010, 0.174000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 252.533130, 0.000040, 0.031000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -4, 0, 0}, 341.460580, 0.000010, 0.024000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -4, 2, 0}, 287.702210, 0.000010, 0.069000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, -1, 0}, 341.460580, 0.000010, 0.034000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 45.532950, 0.000070, 0.062000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 52.007790, 0.000020, 0.336000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 27.261150, 0.000040, 0.097000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 3, 0}, 338.041250, 0.000010, 0.042000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 201.240760, 0.000020, 0.058000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 306.700280, 0.000020, 0.211000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 131.468500, 0.000010, 0.118000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, -2, -1}, 175.938840, 0.000020, 0.052000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, -1}, 238.977560, 0.000010, 0.134000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 175.938840, 0.000030, 0.029000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 342.403330, 0.000030, 0.030000},
	{{0, 12, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 97.720130, 0.000050, 0.066000},
	{{0, 12, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 343.405800, 0.000020, 0.506000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 279.087050, 0.000030, 0.059000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 153.415610, 0.000020, 0.105000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 221.186070, 0.000020, 0.029000},
	{{0, 12, -9, 0, 0, 0, 0, 0, -3, 1, 1}, 23.218690, 0.000010, 12.771000},
	{{0, 12, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 304.262110, 0.000020, 1.025000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 5.497020, 0.000010, 0.364000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 147.085080, 0.000010, 0.221000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 312.536690, 0.000010, 0.115000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 342.835620, 0.000030, 0.045000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 306.311440, 0.000030, 0.028000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 1, 0}, 321.115230, 0.000010, 0.040000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 356.088750, 0.000020, 0.087000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 2.931000, 0.000100, 0.076000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 321.115230, 0.001220, 40.749000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 294.965940, 0.000070, 0.075000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 232.882720, 0.000030, 0.087000},
	{{0, 12, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 321.115230, 0.000010, 0.040000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 194.414480, 0.000010, 0.976000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 305.690010, 0.000020, 7.271000},
	{{0, 12, -7, 0, 0, 0, 0, 0, -1, 1, -1}, 304.554230, 0.000040, 34.218000},
	{{0, 12, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 109.582770, 0.000010, 0.042000},
	{{0, 12, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 109.712860, 0.000010, 0.020000},
	{{0, 12, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 186.775930, 0.000010, 0.077000},
	{{0, 12, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 186.775930, 0.000010, 0.074000},
	{{0, 12, -6, 0, 0, 0, 0, 0, 0, 1, -2}, 224.757920, 0.000020, 12.050000},
	{{0, 12, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 13.462750, 0.000010, 0.085000},
	{{0, 12, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 273.028620, 0.000020, 0.026000},
	{{0, 13, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 327.854850, 0.000020, 0.076000},
	{{0, 13, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 328.095940, 0.000030, 7.587000},
	{{0, 13, -21, 0, 0, 0, 0, 0, 0, 1, 0}, 327.854850, 0.000020, 0.075000},
	{{0, 13, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 64.501090, 0.000080, 0.042000},
	{{0, 13, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 64.384680, 0.000010, 0.884000},
	{{0, 13, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 341.721250, 0.000080, 0.107000},
	{{0, 13, -19, 0, 0, 0, 0, 0, 0, -2, 0}, 161.648600, 0.000020, 0.041000},
	{{0, 13, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 161.648600, 0.000020, 0.090000},
	{{0, 13, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 161.665560, 0.000040, 0.469000},
	{{0, 13, -19, 0, 0, 0, 0, 0, 0, 1, 0}, 161.648600, 0.000020, 0.065000},
	{{0, 13, -18, 0, 0, 0, 0, 0, -2, -1, 0}, 70.071680, 0.000010, 0.029000},
	{{0, 13, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 66.024830, 0.000010, 0.204000},
	{{0, 13, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 250.039670, 0.000050, 0.099000},
	{{0, 13, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 250.045600, 0.000040, 0.061000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 350.371840, 0.000070, 0.049000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 11.699960, 0.000010, 0.169000},
	{{0, 13, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 190.326320, 0.000060, 0.051000},
	{{0, 13, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 10.546170, 0.000040, 0.157000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 32.908660, 0.000030, 0.047000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 32.908660, 0.000030, 0.195000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 192.636970, 0.000020, 0.033000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 359.499400, 0.000060, 0.054000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 5.176770, 0.000010, 0.126000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 293.267530, 0.000010, 0.051000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -1, 0, 1}, 113.267530, 0.000010, 0.139000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -1, 2, -1}, 113.267530, 0.000010, 0.146000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 66.526760, 0.000040, 0.163000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 109.900880, 0.000010, 0.057000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 289.806810, 0.000020, 0.032000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 124.248640, 0.000050, 0.057000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 293.445390, 0.000010, 0.230000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 178.820960, 0.000030, 0.112000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -1, 0, 1}, 21.794080, 0.000030, 0.122000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -1, 2, -1}, 49.713360, 0.000020, 0.127000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 185.531450, 0.000020, 0.052000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 212.980620, 0.000040, 0.163000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 355.677670, 0.000070, 0.140000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 18.344170, 0.000040, 0.054000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 190.912760, 0.000030, 0.031000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 224.830180, 0.000020, 0.060000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 268.345490, 0.000030, 0.299000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 256.623470, 0.000060, 0.195000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 313.434770, 0.000030, 0.123000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 267.393670, 0.000010, 0.141000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 72.502840, 0.000010, 0.157000},
	{{0, 13, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 252.502840, 0.000010, 0.030000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -4, 0, 0}, 341.441960, 0.000010, 0.025000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -4, 2, 0}, 161.441960, 0.000010, 0.072000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 162.852250, 0.000030, 0.035000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 58.211260, 0.000040, 0.064000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 126.564030, 0.000020, 0.426000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 200.613690, 0.000010, 0.092000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 155.163460, 0.000030, 0.060000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 1, -1}, 148.077830, 0.000020, 0.294000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 2, -1}, 273.904820, 0.000020, 0.102000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 3.799180, 0.000030, 0.110000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 0, -1}, 223.882030, 0.000030, 0.124000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 343.004180, 0.000040, 0.030000},
	{{0, 13, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 121.929250, 0.000050, 0.068000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 295.350370, 0.000010, 0.061000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 294.516510, 0.000010, 0.320000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 295.350370, 0.000010, 0.099000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 250.119300, 0.000050, 0.029000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, -2, 2}, 187.345800, 0.000030, 0.075000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 288.218590, 0.000040, 0.073000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 2}, 187.345800, 0.000030, 0.076000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 181.903810, 0.000010, 0.077000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 216.847380, 0.000020, 0.065000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 36.847380, 0.000020, 0.471000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 36.847380, 0.000020, 0.090000},
	{{0, 13, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 238.025670, 0.000020, 0.028000},
	{{0, 13, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 197.037430, 0.000020, 1.538000},
	{{0, 13, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 21.167690, 0.000010, 0.042000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 50.043070, 0.000040, 8.068000},
	{{0, 13, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 283.484110, 0.000020, 0.026000},
	{{0, 13, -6, 0, 0, 0, 0, 0, 2, -3, 0}, 134.048020, 0.000010, 9.801000},
	{{0, 14, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 64.943710, 0.000080, 0.044000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -3, 0}, 277.026330, 0.000010, 0.075000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -2, 0}, 265.839310, 0.000020, 59.908000},
	{{0, 14, -21, 0, 0, 0, 0, 0, 2, -1, 0}, 97.026330, 0.000010, 0.076000},
	{{0, 14, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 137.736680, 0.000010, 0.045000},
	{{0, 14, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 317.736680, 0.000010, 0.221000},
	{{0, 14, -20, 0, 0, 0, 0, 0, -2, 3, 0}, 161.672920, 0.000020, 0.056000},
	{{0, 14, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 161.672920, 0.000020, 0.363000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, -2, 0}, 250.009770, 0.000020, 0.021000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 249.953090, 0.000050, 0.129000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, 3, 0}, 250.009770, 0.000040, 0.053000},
	{{0, 14, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 70.047040, 0.000010, 0.105000},
	{{0, 14, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 69.854070, 0.000030, 0.266000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 351.217660, 0.000070, 0.050000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 312.309190, 0.000020, 0.153000},
	{{0, 14, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 187.772960, 0.000070, 0.053000},
	{{0, 14, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 11.140210, 0.000040, 0.175000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 201.321640, 0.000010, 0.048000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 23.497140, 0.000050, 0.174000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 193.093390, 0.000030, 0.033000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 357.910930, 0.000050, 0.056000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 6.680670, 0.000010, 0.117000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 293.299600, 0.000010, 0.053000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -1, 2, -1}, 113.299600, 0.000010, 0.134000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 122.134120, 0.000080, 0.148000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 289.925210, 0.000030, 0.055000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 289.851340, 0.000020, 0.032000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 113.792730, 0.000040, 0.059000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 169.875780, 0.000010, 0.105000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 21.773420, 0.000030, 0.055000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -1, 0, 1}, 21.773420, 0.000030, 0.113000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 221.946860, 0.000020, 0.182000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 11.052080, 0.000040, 0.129000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 359.976410, 0.000030, 0.149000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 198.369050, 0.000030, 0.052000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 198.471190, 0.000020, 0.031000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, -2, 0}, 72.947480, 0.000010, 0.024000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 243.922500, 0.000030, 0.063000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 115.219890, 0.000010, 0.367000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 109.311820, 0.000010, 0.095000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 252.322060, 0.000050, 0.222000},
	{{0, 14, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 74.673760, 0.000010, 0.114000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -4, 2, 0}, 157.994080, 0.000020, 0.076000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -4, 3, 0}, 66.057140, 0.000030, 20.160000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -3, 1, 1}, 201.205560, 0.000030, 1.491000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 67.530600, 0.000040, 0.067000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 2.940340, 0.000030, 0.580000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 75.219970, 0.000010, 0.087000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, -1}, 174.460980, 0.000020, 0.062000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, 1}, 201.205570, 0.000020, 0.092000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 1, -1}, 147.641160, 0.000030, 0.360000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 2, -1}, 275.193870, 0.000010, 0.095000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 325.836230, 0.000020, 0.286000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 255.228140, 0.000020, 0.102000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 161.421300, 0.000010, 0.043000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 124.079400, 0.000010, 0.028000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, -1}, 215.304440, 0.000020, 0.115000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 301.655220, 0.000030, 0.029000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -3, 3, -1}, 233.503540, 0.000040, 240.318000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 147.485670, 0.000020, 0.072000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 49.415720, 0.000050, 1.380000},
	{{0, 14, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 249.243900, 0.000010, 0.080000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 294.961660, 0.000020, 0.063000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 294.961660, 0.000010, 0.400000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 294.961660, 0.000020, 0.093000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 70.211180, 0.000020, 0.111000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 250.211180, 0.000020, 0.028000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 155.842190, 0.000090, 0.077000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 9.665140, 0.000030, 3.629000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -1, -1, 1}, 70.655900, 0.000010, 2.249000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -1, 1, -1}, 285.162330, 0.000010, 1.285000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 48.645720, 0.000040, 0.085000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 131.994850, 0.000010, 0.026000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 298.355690, 0.000010, 0.100000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 331.541630, 0.000030, 0.027000},
	{{0, 14, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 89.193840, 0.000010, 0.083000},
	{{0, 14, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 269.193840, 0.000010, 0.069000},
	{{0, 14, -10, 0, 0, 0, 0, 0, -1, 1, -1}, 252.172040, 0.000020, 4.508000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 223.545550, 0.000030, 2.006000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 2, -2, 0}, 17.754880, 0.000010, 0.091000},
	{{0, 14, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 199.578410, 0.000020, 0.027000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 287.919950, 0.000020, 0.073000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 287.919950, 0.000020, 0.025000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 109.673580, 0.000010, 0.040000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 107.919940, 0.000020, 0.026000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 2, 2, 0}, 287.919940, 0.000020, 0.015000},
	{{0, 15, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 65.351100, 0.000040, 0.045000},
	{{0, 15, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 245.391720, 0.000020, 0.241000},
	{{0, 15, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 342.073390, 0.000010, 0.047000},
	{{0, 15, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 342.073390, 0.000010, 0.194000},
	{{0, 15, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 161.693730, 0.000020, 0.296000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, -2, 0}, 250.020460, 0.000020, 0.021000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 250.020460, 0.000020, 0.049000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 249.922010, 0.000070, 0.141000},
	{{0, 15, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 70.020460, 0.000030, 0.113000},
	{{0, 15, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 69.805160, 0.000020, 0.228000},
	{{0, 15, -20, 0, 0, 0, 0, 0, 0, 1, 0}, 70.020460, 0.000020, 0.057000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 354.246100, 0.000060, 0.052000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 148.113540, 0.000010, 0.140000},
	{{0, 15, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 212.155300, 0.000080, 0.054000},
	{{0, 15, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 2.043630, 0.000010, 0.196000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 223.962420, 0.000010, 0.050000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 43.962420, 0.000010, 0.157000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 2, -2, 0}, 13.514840, 0.000010, 0.217000},
	{{0, 15, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 193.514840, 0.000010, 0.032000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 347.099840, 0.000050, 0.058000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 315.652360, 0.000010, 0.109000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 293.327680, 0.000010, 0.054000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -1, 2, -1}, 113.327680, 0.000010, 0.123000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 107.866630, 0.000070, 0.135000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 289.946010, 0.000020, 0.053000},
	{{0, 15, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 289.890630, 0.000020, 0.031000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 134.570260, 0.000020, 0.061000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 21.750750, 0.000010, 0.057000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -1, 0, 1}, 28.241540, 0.000030, 0.106000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 141.156180, 0.000010, 0.055000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 14.053380, 0.000060, 0.119000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 359.951770, 0.000020, 0.136000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 198.333740, 0.000040, 0.050000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 198.121700, 0.000040, 0.030000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -4, 1, 2}, 83.378170, 0.000060, 115.724000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, -2, 0}, 252.975550, 0.000010, 0.024000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 251.973660, 0.000080, 0.065000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 257.257140, 0.000040, 0.476000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 116.097830, 0.000010, 0.090000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 254.332250, 0.000020, 0.258000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -3, 1, 1}, 280.975790, 0.000020, 22.161000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 7.282450, 0.000030, 0.070000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 111.586130, 0.000030, 0.910000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 14.152220, 0.000020, 0.082000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 93.613470, 0.000020, 0.065000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 2, -1}, 93.613470, 0.000020, 0.090000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 299.259950, 0.000010, 0.062000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, 0, -1}, 175.876890, 0.000030, 0.107000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 277.538550, 0.000020, 0.028000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 86.726220, 0.000080, 0.075000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 108.328360, 0.000520, 10.112000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 131.534400, 0.000030, 0.076000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -1, 1, -1}, 91.232610, 0.000030, 0.868000},
	{{0, 15, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 84.601420, 0.000020, 0.534000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 225.182670, 0.000030, 1.110000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 355.147180, 0.000050, 0.075000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 276.353620, 0.000040, 70.915000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 1, -1}, 23.972470, 0.000020, 6.551000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 162.967840, 0.000040, 1.146000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 155.006240, 0.000010, 0.094000},
	{{0, 15, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 299.855020, 0.000030, 0.027000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 148.988440, 0.000010, 0.076000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 313.508140, 0.000050, 7.868000},
	{{0, 15, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 64.693650, 0.000020, 0.075000},
	{{0, 15, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 288.074330, 0.000020, 0.887000},
	{{0, 15, -10, 0, 0, 0, 0, 0, 1, -1, -1}, 346.613090, 0.000020, 13.638000},
	{{0, 15, -9, 0, 0, 0, 0, 0, 2, -2, -2}, 62.729510, 0.000010, 0.076000},
	{{0, 15, -9, 0, 0, 0, 0, 0, 2, 0, -2}, 242.729510, 0.000010, 0.075000},
	{{0, 16, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 341.975690, 0.000020, 0.048000},
	{{0, 16, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 161.711240, 0.000030, 0.249000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 249.991990, 0.000030, 0.051000},
	{{0, 16, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 69.991990, 0.000010, 0.121000},
	{{0, 16, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 249.944310, 0.000090, 0.200000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 28.699500, 0.000050, 0.053000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 86.228440, 0.000010, 0.128000},
	{{0, 16, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 190.798170, 0.000060, 0.056000},
	{{0, 16, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 22.279240, 0.000040, 0.224000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 350.014050, 0.000050, 0.060000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 313.480450, 0.000010, 0.288000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 83.670000, 0.000040, 0.125000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 109.896100, 0.000020, 0.031000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 87.326490, 0.000030, 0.064000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 175.585670, 0.000030, 0.093000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 21.726110, 0.000010, 0.060000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -1, 0, 1}, 21.726110, 0.000040, 0.099000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 25.134420, 0.000010, 0.057000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 9.111050, 0.000010, 0.235000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 347.023710, 0.000050, 0.111000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, -3, 0}, 198.244270, 0.000020, 0.166000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 198.178780, 0.000040, 0.030000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 249.011720, 0.000100, 0.068000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 178.902840, 0.000030, 0.679000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 294.477920, 0.000020, 0.085000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 112.739170, 0.000020, 0.063000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -1, 2, -1}, 292.739170, 0.000020, 0.093000},
	{{0, 16, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 254.373480, 0.000020, 0.308000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -3, 1, 1}, 201.162240, 0.000020, 1.723000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, -1, 2}, 285.477890, 0.000030, 7.151000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 131.675680, 0.000020, 0.073000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 0, 2}, 157.795940, 0.000020, 0.076000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 94.906260, 0.000020, 2.113000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 311.675680, 0.000020, 0.078000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 119.587450, 0.000010, 0.445000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 355.500990, 0.000050, 0.091000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 175.852260, 0.000040, 0.100000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 166.836040, 0.000050, 0.028000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 109.054790, 0.000050, 0.079000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 79.737150, 0.000020, 1.899000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 245.503650, 0.000010, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, -1, 1}, 61.496100, 0.000030, 5.165000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 91.209940, 0.000060, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 107.648130, 0.000010, 2.775000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, 1}, 271.209940, 0.000050, 0.077000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 1, -1}, 75.174120, 0.000020, 1.897000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 0, -2, 0}, 104.967310, 0.000020, 0.069000},
	{{0, 16, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 284.967310, 0.000020, 0.083000},
	{{0, 16, -13, 0, 0, 0, 0, 0, -1, 1, -1}, 279.809270, 0.000020, 2.115000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 312.451830, 0.000030, 4.042000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 167.777360, 0.000100, 0.077000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 335.412590, 0.000030, 0.089000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 148.792930, 0.000020, 0.026000},
	{{0, 16, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 103.428260, 0.000020, 0.076000},
	{{0, 16, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 105.465250, 0.000010, 0.025000},
	{{0, 17, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 161.694620, 0.000050, 0.050000},
	{{0, 17, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 341.766560, 0.000010, 0.146000},
	{{0, 17, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 161.725650, 0.000020, 0.216000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 69.367290, 0.000020, 0.052000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 70.223500, 0.000020, 0.171000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 76.141070, 0.000020, 0.135000},
	{{0, 17, -22, 0, 0, 0, 0, 0, 0, -1, 0}, 69.961670, 0.000010, 0.131000},
	{{0, 17, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 249.905080, 0.000080, 0.178000},
	{{0, 17, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 29.881690, 0.000050, 0.055000},
	{{0, 17, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 86.544070, 0.000010, 0.119000},
	{{0, 17, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 187.843480, 0.000060, 0.058000},
	{{0, 17, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 9.707510, 0.000030, 0.260000},
	{{0, 17, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 353.596320, 0.000010, 0.106000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 336.381580, 0.000040, 0.062000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 39.213860, 0.000020, 0.351000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 108.915580, 0.000020, 0.096000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 0, -2, 0}, 278.673810, 0.000010, 0.056000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 108.589380, 0.000030, 0.116000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 109.946920, 0.000030, 0.030000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 17.379570, 0.000030, 0.066000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 326.065130, 0.000040, 0.541000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -1, 0, 1}, 21.699540, 0.000020, 0.094000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 9.301950, 0.000010, 0.276000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 351.748900, 0.000040, 0.104000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, -1, 0}, 198.213950, 0.000020, 0.047000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 198.298150, 0.000020, 0.029000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 154.586650, 0.000050, 0.071000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 133.068430, 0.000040, 1.179000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 112.763500, 0.000020, 0.066000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -1, 2, -1}, 112.763500, 0.000020, 0.088000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 254.410010, 0.000030, 0.381000},
	{{0, 17, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 94.407390, 0.000010, 0.094000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 162.818680, 0.000020, 0.025000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 342.818680, 0.000020, 0.076000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 236.248070, 0.000040, 6.572000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 2, -1}, 21.309800, 0.000010, 68.493000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 3, 0}, 161.347420, 0.000010, 0.038000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, -2, 1}, 326.519830, 0.000030, 0.072000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, -1, 1}, 175.781980, 0.000010, 1.760000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 0, 1}, 326.519830, 0.000030, 0.079000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 1, -1}, 51.751360, 0.000020, 1.109000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 91.033990, 0.000020, 0.617000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 58.190370, 0.000030, 0.086000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 1, 0, -1}, 175.825680, 0.000030, 0.095000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 2, -2, 0}, 340.815910, 0.000010, 0.101000},
	{{0, 17, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 160.815910, 0.000010, 0.027000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 216.613000, 0.000010, 0.083000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 0, -1}, 237.584490, 0.000030, 0.076000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 0, 0}, 189.289430, 0.000010, 3.772000},
	{{0, 17, -15, 0, 0, 0, 0, 0, -1, 1, -1}, 157.912200, 0.000030, 10.164000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 283.055760, 0.000010, 0.072000},
	{{0, 17, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 283.055760, 0.000010, 0.079000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 0, -1, 0}, 269.648710, 0.000020, 2.645000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 0, 1, -2}, 315.292660, 0.000020, 22.409000},
	{{0, 17, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 148.403430, 0.000020, 0.084000},
	{{0, 17, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 109.599700, 0.000010, 0.064000},
	{{0, 17, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 109.599700, 0.000010, 0.024000},
	{{0, 17, -12, 0, 0, 0, 0, 0, 2, -3, 0}, 289.599700, 0.000010, 1.655000},
	{{0, 17, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 283.405600, 0.000020, 0.072000},
	{{0, 17, -12, 0, 0, 0, 0, 0, 2, -1, -2}, 283.405600, 0.000020, 3.695000},
	{{0, 17, -12, 0, 0, 0, 0, 0, 2, -1, 0}, 289.599700, 0.000010, 0.037000},
	{{0, 17, -12, 0, 0, 0, 0, 0, 2, 2, 0}, 109.599700, 0.000010, 0.015000},
	{{0, 18, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 246.346660, 0.000020, 0.049000},
	{{0, 18, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 246.346660, 0.000020, 0.166000},
	{{0, 18, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 161.735580, 0.000050, 0.051000},
	{{0, 18, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 341.750590, 0.000010, 0.161000},
	{{0, 18, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 341.737150, 0.000010, 0.047000},
	{{0, 18, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 161.737150, 0.000010, 0.190000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 74.881580, 0.000050, 0.054000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 249.694170, 0.000040, 0.191000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 3, 0}, 249.929530, 0.000010, 0.047000},
	{{0, 18, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 69.929530, 0.000010, 0.143000},
	{{0, 18, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 249.855890, 0.000060, 0.160000},
	{{0, 18, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 41.999360, 0.000030, 0.057000},
	{{0, 18, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 124.339120, 0.000010, 0.237000},
	{{0, 18, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 124.737780, 0.000020, 0.111000},
	{{0, 18, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 190.729160, 0.000060, 0.061000},
	{{0, 18, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 10.681110, 0.000020, 0.310000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 338.389340, 0.000040, 0.065000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 330.182050, 0.000020, 0.450000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 109.047750, 0.000020, 0.091000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 278.688220, 0.000010, 0.058000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 98.688220, 0.000010, 0.108000},
	{{0, 18, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 289.989440, 0.000020, 0.029000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 0, 1}, 21.671070, 0.000010, 0.074000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 0, 2}, 206.913730, 0.000170, 556.277000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 1, 1}, 97.568580, 0.000020, 5.933000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -3, 2, 1}, 201.671070, 0.000010, 0.076000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 359.502070, 0.000030, 0.069000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 310.811940, 0.000030, 0.818000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -1, -1, 1}, 21.671070, 0.000010, 0.515000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -1, 0, 1}, 21.671070, 0.000030, 0.088000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 0, -2, 0}, 210.115300, 0.000010, 0.062000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 6.336900, 0.000040, 0.097000},
	{{0, 18, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 198.276300, 0.000030, 0.029000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, -2, 2}, 253.038190, 0.000010, 0.076000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 142.662070, 0.000040, 0.074000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 2}, 253.038190, 0.000010, 0.075000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 244.713130, 0.000020, 4.498000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 97.789480, 0.000020, 0.077000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -1, 1, -1}, 240.752670, 0.000020, 0.784000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 252.233330, 0.000020, 0.066000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 63.521350, 0.000030, 0.501000},
	{{0, 18, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 289.160490, 0.000010, 0.089000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 37.502430, 0.000030, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 231.664850, 0.000050, 0.080000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 132.533220, 0.000020, 1.286000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, 1}, 2.411800, 0.000010, 0.076000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 0}, 217.502430, 0.000010, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -1, 1}, 16.939260, 0.000050, 17.413000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 122.406570, 0.000010, 0.074000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 0}, 282.859720, 0.000030, 9.147000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 1}, 166.019740, 0.000040, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 1, -1}, 178.812620, 0.000050, 3.622000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 2, -1}, 122.406570, 0.000010, 0.077000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 37.404800, 0.000070, 0.070000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 146.936780, 0.000020, 1.004000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 202.447370, 0.000070, 0.082000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 1, 0}, 217.502430, 0.000010, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, -1, -1}, 175.797210, 0.000010, 0.488000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, 0, -1}, 175.797210, 0.000030, 0.089000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 217.502430, 0.000130, 0.095000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 217.502430, 0.000200, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 217.502430, 0.000030, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, 0}, 114.565500, 0.000030, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, 0}, 114.565500, 0.000070, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 1, 0}, 114.565500, 0.000040, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, 0}, 114.565500, 0.000040, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 114.565500, 0.000350, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, -2}, 294.565500, 0.000010, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 114.551140, 0.002930, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, -2}, 294.565500, 0.000020, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 114.559670, 0.002980, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 65.486760, 0.000020, 0.563000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 178.906580, 0.000010, 0.067000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -2, 0}, 294.565500, 0.000010, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, 0}, 294.565500, 0.000080, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -4, 0}, 114.565500, 0.000070, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, 0}, 114.553940, 0.000960, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, -2}, 294.565500, 0.000080, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 114.553880, 0.014100, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 2}, 294.565500, 0.000020, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -2}, 294.565500, 0.000510, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 114.565500, 0.254250, 273.043000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 2}, 294.565500, 0.000510, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -2}, 294.565500, 0.000020, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 114.795440, 0.013260, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 2}, 294.565500, 0.000080, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 114.795370, 0.000900, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 2, 0}, 114.565500, 0.000070, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, 0}, 294.565500, 0.000080, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 294.565500, 0.000010, 0.039000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 0}, 114.577400, 0.002800, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 2}, 294.565500, 0.000020, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 114.579980, 0.002910, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 2}, 294.565500, 0.000010, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 114.565500, 0.000350, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 114.565500, 0.000040, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -3, 0}, 114.565500, 0.000040, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, 0}, 114.565500, 0.000070, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, 0}, 114.565500, 0.000030, 0.020000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, 0}, 11.628570, 0.000030, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, 0}, 11.628570, 0.000200, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 12.544560, 0.000100, 0.095000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 188.410310, 0.000030, 0.062000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -3, 0}, 11.628570, 0.000010, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 11.628570, 0.000090, 0.082000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 220.174590, 0.000010, 0.996000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 191.628570, 0.000070, 0.070000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, -1}, 22.726950, 0.000140, 19.959000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, -1, 0}, 11.628570, 0.000010, 0.075000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 134.230700, 0.000040, 0.076000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -2, 0}, 191.763100, 0.000020, 0.080000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 191.628570, 0.000030, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 155.902940, 0.000040, 0.026000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 199.498670, 0.000020, 0.074000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, -1, -2}, 20.715450, 0.000010, 9.628000},
	{{0, 18, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 19.498670, 0.000020, 0.025000},
	{{0, 18, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 107.825410, 0.000020, 0.024000},
	{{0, 19, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 246.656550, 0.000030, 0.050000},
	{{0, 19, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 161.742060, 0.000050, 0.053000},
	{{0, 19, -25, 0, 0, 0, 0, 0, -2, 1, 0}, 341.738700, 0.000010, 0.179000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 76.068140, 0.000030, 0.056000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 249.680920, 0.000040, 0.218000},
	{{0, 19, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 69.814550, 0.000030, 0.051000},
	{{0, 19, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 249.814550, 0.000030, 0.145000},
	{{0, 19, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 69.097460, 0.000040, 0.059000},
	{{0, 19, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 124.347890, 0.000010, 0.278000},
	{{0, 19, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 161.568520, 0.000020, 0.104000},
	{{0, 19, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 201.002280, 0.000050, 0.063000},
	{{0, 19, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 344.888700, 0.000020, 0.385000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 356.492000, 0.000050, 0.067000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 135.341200, 0.000020, 0.626000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 257.552050, 0.000020, 0.086000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 0, -2, 0}, 278.699730, 0.000010, 0.060000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 98.699730, 0.000010, 0.101000},
	{{0, 19, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 109.998210, 0.000020, 0.029000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -3, 1, 1}, 21.640740, 0.000020, 2.188000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 338.298180, 0.000020, 0.072000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 253.094340, 0.000040, 1.676000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -1, 0, 1}, 21.640740, 0.000030, 0.084000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -1, 1, -1}, 228.468070, 0.000020, 0.606000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 341.436730, 0.000020, 0.064000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 341.558250, 0.000020, 0.422000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 1.770470, 0.000050, 0.092000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 18.330430, 0.000020, 0.028000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 314.668150, 0.000090, 0.078000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 153.257190, 0.000050, 2.480000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 120.532830, 0.000010, 0.073000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, -1, 1}, 251.836420, 0.000020, 3.154000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 0, -1}, 240.393880, 0.000040, 0.072000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 1, -1}, 87.159540, 0.000020, 1.537000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 292.947970, 0.000030, 0.730000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 75.684810, 0.000040, 0.084000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -4, 2, 0}, 240.171660, 0.000010, 0.099000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 249.910610, 0.000080, 0.084000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 89.313520, 0.000030, 0.713000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 34.300420, 0.000030, 0.068000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 0, -1}, 355.687390, 0.000010, 0.077000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 1, -1}, 100.854210, 0.000020, 2.862000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -1, 2, -1}, 175.687390, 0.000010, 0.074000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 27.269660, 0.000020, 0.073000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 188.177600, 0.000040, 2.697000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 107.833590, 0.000040, 0.078000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, 1, -2}, 156.503750, 0.000010, 1.420000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 1, -1, -1}, 289.172880, 0.000020, 0.702000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 1, 0, -1}, 175.766880, 0.000030, 0.085000},
	{{0, 19, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 116.474720, 0.000050, 0.092000},
	{{0, 19, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 296.469870, 0.000020, 0.416000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 278.405030, 0.000030, 0.079000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, -1, 0}, 110.491470, 0.000020, 1.589000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 98.405030, 0.000030, 0.072000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 1, -1, -1}, 251.570880, 0.000020, 2.355000},
	{{0, 19, -16, 0, 0, 0, 0, 0, -2, 1, 0}, 7.019750, 0.000010, 0.294000},
	{{0, 19, -14, 0, 0, 0, 0, 0, 2, -2, 0}, 286.112080, 0.000010, 0.066000},
	{{0, 20, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 246.944420, 0.000030, 0.052000},
	{{0, 20, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 161.738610, 0.000020, 0.055000},
	{{0, 20, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 341.729130, 0.000020, 0.201000},
	{{0, 20, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 76.029210, 0.000030, 0.058000},
	{{0, 20, -25, 0, 0, 0, 0, 0, -2, 1, 0}, 249.609370, 0.000040, 0.252000},
	{{0, 20, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 69.533440, 0.000040, 0.062000},
	{{0, 20, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 161.766130, 0.000020, 0.097000},
	{{0, 20, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 218.107860, 0.000030, 0.066000},
	{{0, 20, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 139.359670, 0.000010, 0.507000},
	{{0, 20, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 45.920230, 0.000010, 0.089000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -3, 1, 1}, 102.530960, 0.000040, 12.123000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 135.850910, 0.000020, 0.070000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 315.850910, 0.000020, 0.081000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -1, 0, -1}, 293.416230, 0.000010, 0.065000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -1, 1, -1}, 293.416230, 0.000010, 0.494000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -1, 2, -1}, 113.416230, 0.000010, 0.089000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, -2, 0}, 278.708500, 0.000010, 0.062000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, -1, 0}, 278.480220, 0.000010, 0.364000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 98.708500, 0.000010, 0.095000},
	{{0, 20, -22, 0, 0, 0, 0, 0, 2, 0, 0}, 110.004400, 0.000030, 0.028000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 1, 0}, 18.184190, 0.000010, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -4, 2, 0}, 340.315580, 0.000020, 0.087000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 114.231190, 0.000140, 0.076000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 18.184190, 0.001180, 34.812000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 52.697410, 0.000080, 0.075000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, -1, 1}, 107.243340, 0.000020, 1.446000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 0, -1}, 228.306220, 0.000040, 0.070000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 1, -1}, 277.743000, 0.000010, 0.976000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 326.309860, 0.000010, 0.573000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 348.799110, 0.000050, 0.087000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 0, 1, 0}, 18.184190, 0.000010, 0.040000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 18.263990, 0.000030, 0.028000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 43.904220, 0.000010, 0.082000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 200.881740, 0.000040, 0.972000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, -1}, 283.381520, 0.000070, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, 0}, 93.621470, 0.000010, 7.056000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, -1}, 297.356710, 0.000710, 39.938000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 2, -1}, 297.914520, 0.000040, 0.076000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 141.583140, 0.000010, 0.071000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 299.842820, 0.000030, 0.080000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 260.806200, 0.000030, 0.089000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 99.773110, 0.000020, 0.493000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 145.902710, 0.000020, 0.065000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, -1, 1}, 201.052230, 0.000030, 0.764000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, 0, -1}, 325.608710, 0.000050, 0.081000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 206.354290, 0.000030, 3.926000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 0, -1}, 108.196550, 0.000020, 11.370000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 334.542570, 0.000060, 0.074000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 1, -2}, 294.249450, 0.000020, 12.690000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 1, -1, -1}, 21.769480, 0.000020, 1.251000},
	{{0, 20, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 114.344550, 0.000010, 0.098000},
	{{0, 20, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 294.344550, 0.000010, 0.330000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 241.816690, 0.000010, 0.083000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 61.816690, 0.000010, 0.069000},
	{{0, 20, -18, 0, 0, 0, 0, 0, 1, -1, -1}, 161.981840, 0.000010, 4.977000},
	{{0, 20, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 187.153230, 0.000010, 0.108000},
	{{0, 20, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 187.153230, 0.000010, 0.058000},
	{{0, 21, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 247.212130, 0.000030, 0.054000},
	{{0, 21, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 341.755880, 0.000020, 0.057000},
	{{0, 21, -27, 0, 0, 0, 0, 0, -2, 1, 0}, 341.720690, 0.000020, 0.230000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 71.445750, 0.000050, 0.060000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 249.529620, 0.000040, 0.299000},
	{{0, 21, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 255.988700, 0.000010, 0.101000},
	{{0, 21, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 69.822690, 0.000030, 0.123000},
	{{0, 21, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 63.089450, 0.000030, 0.064000},
	{{0, 21, -25, 0, 0, 0, 0, 0, -2, 1, 0}, 94.463780, 0.000020, 0.426000},
	{{0, 21, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 133.956430, 0.000030, 0.092000},
	{{0, 21, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 205.826140, 0.000050, 0.068000},
	{{0, 21, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 84.432950, 0.000030, 0.743000},
	{{0, 21, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 136.741420, 0.000010, 0.084000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, -1, 2}, 103.958800, 0.000070, 81.722000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 162.138580, 0.000020, 0.074000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 25.129550, 0.000050, 2.892000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 258.319390, 0.000010, 0.077000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -1, -1, 1}, 113.425010, 0.000010, 0.938000},
	{{0, 21, -23, 0, 0, 0, 0, 0, -1, 0, -1}, 293.425010, 0.000030, 0.068000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 98.714690, 0.000010, 0.472000},
	{{0, 21, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 98.714690, 0.000030, 0.090000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 169.790500, 0.000060, 0.079000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 323.978910, 0.000040, 1.528000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 217.153300, 0.000020, 0.072000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -1, 1}, 193.196360, 0.000060, 15.151000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, -1}, 283.769290, 0.000040, 0.073000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, 0}, 153.514560, 0.000020, 4.296000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 2, -1}, 299.015040, 0.000010, 0.078000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 0, -1, 0}, 225.554510, 0.000020, 0.893000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 327.442650, 0.000030, 0.082000},
	{{0, 21, -22, 0, 0, 0, 0, 0, 2, -2, 0}, 18.074970, 0.000020, 0.097000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 251.500440, 0.000020, 0.086000},
	{{0, 21, -21, 0, 0, 0, 0, 0, -1, 1, -1}, 54.270690, 0.000010, 1.665000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, -1, 0}, 279.484760, 0.000070, 8.350000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 245.733570, 0.000040, 0.076000},
	{{0, 21, -20, 0, 0, 0, 0, 0, -1, 1, -1}, 145.339830, 0.000020, 0.625000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 121.542080, 0.000010, 0.081000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 0, -1, 0}, 119.847580, 0.000020, 1.136000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 301.542080, 0.000010, 0.071000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 0, 1, -2}, 156.437700, 0.000010, 1.829000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -2, 0}, 215.537000, 0.000070, 147.570000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -1, -1}, 197.350290, 0.000030, 5.763000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 153.476190, 0.000050, 0.076000},
	{{0, 21, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 114.312420, 0.000040, 0.104000},
	{{0, 21, -19, 0, 0, 0, 0, 0, 0, -1, 0}, 225.383970, 0.000010, 0.532000},
	{{0, 21, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 201.325170, 0.000010, 0.065000},
	{{0, 21, -17, 0, 0, 0, 0, 0, 4, -3, -2}, 17.850440, 0.000030, 759.662000},
	{{0, 21, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 107.734470, 0.000020, 0.023000},
	{{0, 22, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 247.461380, 0.000030, 0.056000},
	{{0, 22, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 341.757330, 0.000030, 0.059000},
	{{0, 22, -28, 0, 0, 0, 0, 0, -2, 1, 0}, 341.726450, 0.000030, 0.269000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 70.714110, 0.000090, 0.063000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 1, 0}, 249.683330, 0.000030, 0.368000},
	{{0, 22, -27, 0, 0, 0, 0, 0, -2, 2, 0}, 255.946660, 0.000010, 0.095000},
	{{0, 22, -27, 0, 0, 0, 0, 0, 0, 0, 0}, 69.783760, 0.000030, 0.114000},
	{{0, 22, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 31.815540, 0.000030, 0.067000},
	{{0, 22, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 62.403000, 0.000010, 0.581000},
	{{0, 22, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 150.007420, 0.000010, 0.087000},
	{{0, 22, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 92.088130, 0.000060, 0.072000},
	{{0, 22, -25, 0, 0, 0, 0, 0, -2, 1, 0}, 219.067850, 0.000020, 1.388000},
	{{0, 22, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 187.171640, 0.000010, 0.080000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 6.855430, 0.000040, 3.574000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -1, -2, 1}, 293.431190, 0.000010, 0.073000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -1, -1, 1}, 141.307450, 0.000020, 2.270000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -1, 0, 1}, 113.431190, 0.000010, 0.078000},
	{{0, 22, -24, 0, 0, 0, 0, 0, -1, 1, -1}, 321.308700, 0.000020, 1.292000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 100.197370, 0.000010, 0.669000},
	{{0, 22, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 98.718450, 0.000030, 0.085000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -2, 1, 0}, 284.774660, 0.000010, 0.781000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, -2, 1}, 201.539070, 0.000020, 0.079000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 0, -1}, 67.170370, 0.000050, 0.077000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 0, 1}, 201.539070, 0.000020, 0.072000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 1, -1}, 70.409470, 0.000030, 4.425000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 2, -1}, 5.709170, 0.000020, 0.074000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, -2, 0}, 113.725160, 0.000010, 0.073000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 350.181300, 0.000050, 2.023000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 184.500990, 0.000020, 0.078000},
	{{0, 22, -23, 0, 0, 0, 0, 0, 2, 0, 0}, 18.036040, 0.000020, 0.027000},
	{{0, 22, -22, 0, 0, 0, 0, 0, 1, -1, -1}, 82.071210, 0.000040, 1.825000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 0, -2, 0}, 154.931660, 0.000020, 0.085000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 159.813000, 0.000070, 0.068000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, -2, -1}, 288.778190, 0.000020, 0.078000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 1, 0, -1}, 108.778190, 0.000020, 0.073000},
	{{0, 22, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 114.278510, 0.000010, 0.111000},
	{{0, 23, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 247.693740, 0.000030, 0.058000},
	{{0, 23, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 341.756600, 0.000030, 0.061000},
	{{0, 23, -29, 0, 0, 0, 0, 0, -2, 1, 0}, 341.717870, 0.000040, 0.323000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 70.846040, 0.000070, 0.065000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 1, 0}, 243.663500, 0.000010, 0.477000},
	{{0, 23, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 255.903140, 0.000010, 0.090000},
	{{0, 23, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 69.743240, 0.000030, 0.107000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 65.241850, 0.000020, 0.070000},
	{{0, 23, -27, 0, 0, 0, 0, 0, -2, 1, 0}, 189.395950, 0.000020, 0.914000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 79.627770, 0.000020, 0.075000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 96.003940, 0.000040, 10.559000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 259.627770, 0.000020, 0.076000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 216.640960, 0.000040, 0.081000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -2, 1, 0}, 120.897650, 0.000030, 1.105000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 60.630370, 0.000020, 0.071000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, -1, 1}, 121.246900, 0.000020, 5.404000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, -1}, 354.089400, 0.000050, 0.075000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, 0}, 131.740400, 0.000060, 54.684000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 1, -1}, 247.803590, 0.000040, 6.735000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 0, -2, 0}, 296.406680, 0.000020, 0.071000},
	{{0, 23, -25, 0, 0, 0, 0, 0, 0, -1, 0}, 22.792950, 0.000020, 1.151000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 333.532420, 0.000010, 0.525000},
	{{0, 23, -24, 0, 0, 0, 0, 0, -1, -1, 1}, 21.501760, 0.000010, 0.844000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 276.200690, 0.000010, 0.076000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 29.579800, 0.000110, 7.618000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, -1}, 176.159480, 0.000030, 28.187000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 187.380540, 0.000080, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 1, -1, -1}, 201.501760, 0.000010, 1.084000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, -2, 0}, 197.995520, 0.000010, 0.086000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 2, 0, 0}, 17.995520, 0.000010, 0.026000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 252.633290, 0.000020, 0.097000},
	{{0, 23, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 252.633290, 0.000020, 0.062000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, -2, 0}, 249.607830, 0.000010, 0.082000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 64.811110, 0.000030, 0.884000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 249.607830, 0.000010, 0.070000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -1, -1}, 281.569580, 0.000110, 12.901000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, -1}, 293.563340, 0.000040, 0.075000},
	{{0, 23, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 160.672540, 0.000020, 0.107000},
	{{0, 23, -22, 0, 0, 0, 0, 0, -2, 1, 0}, 340.672530, 0.000020, 0.256000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 1, -1, -1}, 175.627900, 0.000020, 0.928000},
	{{0, 23, -22, 0, 0, 0, 0, 0, 2, -1, -2}, 178.402290, 0.000080, 42.111000},
	{{0, 23, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 114.242880, 0.000010, 0.120000},
	{{0, 24, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 247.910490, 0.000030, 0.060000},
	{{0, 24, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 341.753790, 0.000010, 0.064000},
	{{0, 24, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 73.712050, 0.000050, 0.068000},
	{{0, 24, -29, 0, 0, 0, 0, 0, -2, 1, 0}, 249.589870, 0.000030, 0.681000},
	{{0, 24, -29, 0, 0, 0, 0, 0, 0, 0, 0}, 69.701200, 0.000030, 0.100000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 169.163470, 0.000020, 0.073000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 1, 0}, 107.961110, 0.000070, 2.131000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 349.163470, 0.000020, 0.078000},
	{{0, 24, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 276.812210, 0.000060, 0.079000},
	{{0, 24, -27, 0, 0, 0, 0, 0, -2, 1, 0}, 207.803730, 0.000030, 1.884000},
	{{0, 24, -27, 0, 0, 0, 0, 0, -1, -1, 1}, 278.492420, 0.000020, 5.279000},
	{{0, 24, -27, 0, 0, 0, 0, 0, 0, -1, 0}, 11.933420, 0.000030, 0.804000},
	{{0, 24, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 94.816300, 0.000020, 0.068000},
	{{0, 24, -26, 0, 0, 0, 0, 0, -1, -1, 1}, 113.436410, 0.000010, 1.234000},
	{{0, 24, -26, 0, 0, 0, 0, 0, -1, 1, -1}, 339.477480, 0.000020, 2.096000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -2, 0}, 185.250860, 0.000010, 0.074000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 43.463440, 0.000030, 4.112000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 352.201650, 0.000030, 0.077000},
	{{0, 24, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 167.739930, 0.000010, 0.093000},
	{{0, 24, -25, 0, 0, 0, 0, 0, -2, 1, 0}, 347.739930, 0.000010, 0.395000},
	{{0, 24, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 167.739930, 0.000010, 0.063000},
	{{0, 24, -25, 0, 0, 0, 0, 0, -1, 0, -1}, 21.462830, 0.000030, 0.085000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 0, -1, 0}, 278.086980, 0.000010, 1.321000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 161.561110, 0.000030, 0.071000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 1, -3, 1}, 201.462830, 0.000010, 27.360000},
	{{0, 24, -25, 0, 0, 0, 0, 0, 1, -2, -1}, 179.513350, 0.000020, 0.074000},
	{{0, 24, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 73.084290, 0.000010, 0.283000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 237.986320, 0.000010, 0.087000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 78.595990, 0.000040, 0.067000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 1, -1, -1}, 267.562550, 0.000010, 1.422000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 2, -3, 0}, 137.849180, 0.000040, 58.088000},
	{{0, 24, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 160.630220, 0.000020, 0.115000},
	{{0, 24, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 160.630220, 0.000020, 0.056000},
	{{0, 24, -23, 0, 0, 0, 0, 0, 0, -1, 0}, 341.110710, 0.000010, 0.363000},
	{{0, 25, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 248.113000, 0.000030, 0.062000},
	{{0, 25, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 341.749020, 0.000010, 0.066000},
	{{0, 25, -31, 0, 0, 0, 0, 0, -2, 1, 0}, 161.749020, 0.000010, 0.542000},
	{{0, 25, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 73.899740, 0.000030, 0.071000},
	{{0, 25, -30, 0, 0, 0, 0, 0, -2, 2, 0}, 75.875800, 0.000020, 0.081000},
	{{0, 25, -30, 0, 0, 0, 0, 0, 0, -1, 0}, 69.657680, 0.000010, 0.382000},
	{{0, 25, -30, 0, 0, 0, 0, 0, 0, 0, 0}, 69.657680, 0.000030, 0.094000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 102.210710, 0.000060, 0.076000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, 1, 0}, 245.917460, 0.000050, 6.396000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, 2, 0}, 51.749430, 0.000010, 0.075000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 160.125350, 0.000030, 0.083000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -2, 1, 0}, 244.871670, 0.000010, 0.865000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 278.917170, 0.000010, 0.069000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -1, 0, -1}, 38.627330, 0.000020, 0.076000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -1, 1, -1}, 75.857060, 0.000020, 9.749000},
	{{0, 25, -28, 0, 0, 0, 0, 0, -1, 2, -1}, 38.627330, 0.000020, 0.075000},
	{{0, 25, -28, 0, 0, 0, 0, 0, 0, -2, 0}, 212.525550, 0.000010, 0.072000},
	{{0, 25, -28, 0, 0, 0, 0, 0, 0, -1, 0}, 217.544860, 0.000030, 1.619000},
	{{0, 25, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 39.648460, 0.000030, 0.079000},
	{{0, 25, -27, 0, 0, 0, 0, 0, -1, 1, -1}, 293.435670, 0.000010, 0.907000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, -1, 0}, 146.532980, 0.000010, 2.616000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 0, 0}, 258.198680, 0.000020, 0.073000},
	{{0, 25, -27, 0, 0, 0, 0, 0, 0, 1, -2}, 247.098370, 0.000030, 20.488000},
	{{0, 25, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 321.468720, 0.000010, 0.317000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 0, -1, 0}, 327.235880, 0.000010, 0.723000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 186.663770, 0.000030, 0.068000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, -1, -1}, 158.592750, 0.000030, 3.044000},
	{{0, 25, -26, 0, 0, 0, 0, 0, 1, 1, -3}, 6.764350, 0.000060, 201.839000},
	{{0, 25, -24, 0, 0, 0, 0, 0, -2, 1, 0}, 163.915200, 0.000010, 0.194000},
	{{0, 25, -24, 0, 0, 0, 0, 0, 0, -1, 0}, 161.070200, 0.000010, 0.296000},
	{{0, 25, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 353.830360, 0.000030, 0.060000},
	{{0, 26, -33, 0, 0, 0, 0, 0, -2, 0, 0}, 248.302240, 0.000030, 0.065000},
	{{0, 26, -33, 0, 0, 0, 0, 0, -2, 1, 0}, 248.302240, 0.000010, 0.451000},
	{{0, 26, -32, 0, 0, 0, 0, 0, -3, 0, 2}, 196.683130, 0.000040, 418.786000},
	{{0, 26, -32, 0, 0, 0, 0, 0, -2, 1, 0}, 161.742360, 0.000010, 0.821000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 211.124170, 0.000040, 0.074000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, 2, 0}, 268.129690, 0.000020, 0.077000},
	{{0, 26, -31, 0, 0, 0, 0, 0, 0, -1, 0}, 69.612730, 0.000010, 0.502000},
	{{0, 26, -31, 0, 0, 0, 0, 0, 0, 0, 0}, 69.612730, 0.000030, 0.089000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 265.802690, 0.000030, 0.080000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -2, 1, 0}, 191.433820, 0.000020, 1.279000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -2, 2, 0}, 341.763000, 0.000020, 0.071000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -1, -1, 1}, 323.755640, 0.000030, 16.230000},
	{{0, 26, -30, 0, 0, 0, 0, 0, -1, 0, 0}, 229.788000, 0.000020, 9.511000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 197.303460, 0.000030, 0.087000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, 1, 0}, 20.523370, 0.000020, 0.561000},
	{{0, 26, -29, 0, 0, 0, 0, 0, -2, 2, 0}, 0.559820, 0.000020, 0.067000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, 0}, 233.188120, 0.000030, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, 0}, 238.396220, 0.000790, 127.422000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, 0}, 294.921990, 0.000030, 0.075000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, -2, 0}, 278.470460, 0.000010, 0.082000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, -1, 0}, 100.918510, 0.000010, 0.992000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 98.470460, 0.000010, 0.070000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, -1, -1}, 340.600350, 0.000050, 21.779000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, 0, -1}, 199.485750, 0.000040, 0.076000},
	{{0, 26, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 142.205950, 0.000020, 0.106000},
	{{0, 26, -27, 0, 0, 0, 0, 0, -2, 2, 0}, 142.205950, 0.000020, 0.059000},
	{{0, 26, -26, 0, 0, 0, 0, 0, -2, 1, 0}, 253.080750, 0.000010, 0.209000},
	{{0, 26, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 157.612010, 0.000010, 0.134000},
	{{0, 26, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 157.612010, 0.000010, 0.053000},
	{{0, 26, -25, 0, 0, 0, 0, 0, 0, -2, 0}, 161.028150, 0.000010, 0.108000},
	{{0, 26, -25, 0, 0, 0, 0, 0, 0, 0, 0}, 341.028150, 0.000010, 0.058000},
	{{0, 27, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 248.479300, 0.000030, 0.067000},
	{{0, 27, -33, 0, 0, 0, 0, 0, -2, 1, 0}, 334.062320, 0.000040, 1.687000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 350.004790, 0.000010, 0.078000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 1, 0}, 288.093600, 0.000020, 2.455000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 2, 0}, 211.107280, 0.000020, 0.073000},
	{{0, 27, -32, 0, 0, 0, 0, 0, 0, -1, 0}, 249.441030, 0.000030, 0.732000},
	{{0, 27, -32, 0, 0, 0, 0, 0, 0, 0, 0}, 69.566380, 0.000030, 0.084000},
	{{0, 27, -31, 0, 0, 0, 0, 0, 0, -1, 0}, 325.587950, 0.000010, 2.728000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 143.610820, 0.000030, 0.076000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -2, 1, 0}, 93.257980, 0.000020, 30.385000},
	{{0, 28, -34, 0, 0, 0, 0, 0, -2, 2, 0}, 13.069060, 0.000010, 0.075000},
	{{0, 28, -33, 0, 0, 0, 0, 0, -1, 1, -1}, 273.170530, 0.000030, 47.954000},
	{{0, 28, -33, 0, 0, 0, 0, 0, 0, -2, 0}, 69.389220, 0.000020, 0.071000},
	{{0, 28, -33, 0, 0, 0, 0, 0, 0, 0, 0}, 249.389220, 0.000020, 0.080000},
	{{0, 28, -32, 0, 0, 0, 0, 0, 0, -1, 0}, 252.589350, 0.000050, 3.863000},
	{{0, 28, -31, 0, 0, 0, 0, 0, 1, -1, -1}, 155.141500, 0.000010, 4.875000},
	{{0, 28, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 143.626570, 0.000010, 0.122000},
	{{0, 29, -36, 0, 0, 0, 0, 0, -2, -1, 2}, 134.851480, 0.000020, 124.208000},
	{{0, 29, -35, 0, 0, 0, 0, 0, -2, 1, 0}, 341.711870, 0.000010, 1.519000},
	{{0, 29, -35, 0, 0, 0, 0, 0, 0, -1, 0}, 161.711870, 0.000010, 0.896000},
	{{0, 29, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 68.527360, 0.000050, 0.086000},
	{{0, 29, -34, 0, 0, 0, 0, 0, -2, 2, 0}, 71.205390, 0.000020, 0.067000},
	{{0, 29, -34, 0, 0, 0, 0, 0, 0, -2, 0}, 255.330390, 0.000010, 0.075000},
	{{0, 29, -34, 0, 0, 0, 0, 0, 0, -1, 0}, 326.355350, 0.000010, 8.652000},
	{{0, 29, -33, 0, 0, 0, 0, 0, 1, -2, 0}, 31.621040, 0.000020, 385.960000},
	{{0, 29, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 99.700160, 0.000010, 0.132000},
	{{0, 30, -38, 0, 0, 0, 0, 0, -2, 1, 0}, 334.466900, 0.000020, 1.397000},
	{{0, 30, -37, 0, 0, 0, 0, 0, -2, 1, 0}, 23.440400, 0.000010, 3.522000},
	{{0, 30, -36, 0, 0, 0, 0, 0, -2, 0, 0}, 161.616330, 0.000060, 0.084000},
	{{0, 30, -36, 0, 0, 0, 0, 0, 0, 0, 0}, 161.698470, 0.000030, 0.078000},
	{{0, 30, -35, 0, 0, 0, 0, 0, 0, -2, 0}, 251.184510, 0.000010, 0.078000},
	{{0, 30, -35, 0, 0, 0, 0, 0, 0, 0, 0}, 248.728880, 0.000030, 0.073000},
	{{0, 30, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 159.971960, 0.000010, 0.143000},
	{{0, 30, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 256.673840, 0.000050, 35.458000},
	{{0, 31, -39, 0, 0, 0, 0, 0, -2, 0, 0}, 154.727890, 0.000040, 0.075000},
	{{0, 31, -39, 0, 0, 0, 0, 0, -2, 2, 0}, 154.727890, 0.000040, 0.076000},
	{{0, 31, -38, 0, 0, 0, 0, 0, -2, 0, 0}, 69.082410, 0.000020, 0.081000},
	{{0, 31, -38, 0, 0, 0, 0, 0, -2, 1, 0}, 69.041960, 0.000030, 1.100000},
	{{0, 31, -38, 0, 0, 0, 0, 0, -1, 0, 0}, 196.068440, 0.000010, 44.499000},
	{{0, 31, -37, 0, 0, 0, 0, 0, -2, 0, 0}, 341.662610, 0.000030, 0.088000},
	{{0, 31, -37, 0, 0, 0, 0, 0, -2, 1, 0}, 161.683510, 0.000010, 0.524000},
	{{0, 31, -37, 0, 0, 0, 0, 0, 0, -2, 0}, 161.596480, 0.000040, 0.076000},
	{{0, 31, -37, 0, 0, 0, 0, 0, 0, -1, 0}, 328.393400, 0.000060, 7.382000},
	{{0, 31, -37, 0, 0, 0, 0, 0, 0, 0, 0}, 161.596480, 0.000040, 0.075000},
	{{0, 31, -36, 0, 0, 0, 0, 0, -2, 0, 0}, 249.368080, 0.000020, 0.097000},
	{{0, 31, -36, 0, 0, 0, 0, 0, 0, -1, 0}, 69.368080, 0.000010, 0.881000},
	{{0, 31, -35, 0, 0, 0, 0, 0, 2, -1, -2}, 102.974810, 0.000010, 35.801000},
	{{0, 31, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 189.426350, 0.000020, 0.426000},
	{{0, 32, -38, 0, 0, 0, 0, 0, 0, -1, 0}, 161.667110, 0.000010, 1.314000},
	{{0, 32, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 113.852680, 0.000010, 0.368000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 1, -1}, 163.874030, 0.000010, 0.075000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 2, -1}, 163.874030, 0.000220, 2005.078000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -3, 3, -1}, 163.874030, 0.000010, 0.075000},
	{{0, 32, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 320.918560, 0.000010, 1.387000},
	{{0, 33, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 160.409360, 0.000010, 0.196000},
	{{0, 33, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 113.802380, 0.000010, 0.477000},
	{{0, 33, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 103.209050, 0.000010, 10.501000},
	{{0, 34, -42, 0, 0, 0, 0, 0, 0, -1, 0}, 193.748960, 0.000030, 83.102000},
	{{0, 34, -42, 0, 0, 0, 0, 0, 0, 0, 0}, 335.432220, 0.000070, 0.075000},
	{{0, 34, -35, 0, 0, 0, 0, 0, -2, 0, 0}, 160.537320, 0.000010, 0.224000},
	{{0, 34, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 121.020030, 0.000030, 0.680000},
	{{0, 34, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 320.942960, 0.000010, 1.886000},
	{{0, 35, -34, 0, 0, 0, 0, 0, -4, 2, 0}, 340.095220, 0.000020, 14.253000},
	{{0, 35, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 140.145770, 0.000020, 6.418000},
	{{0, 35, -31, 0, 0, 0, 0, 0, -1, 0, -1}, 117.699770, 0.000030, 9.799000},
	{{0, 36, -47, 0, 0, 0, 0, 0, -2, 1, 0}, 49.664730, 0.000030, 26.957000},
	{{0, 36, -36, 0, 0, 0, 0, 0, -2, 0, 0}, 252.439410, 0.000020, 0.451000},
	{{0, 36, -35, 0, 0, 0, 0, 0, -2, 0, 0}, 222.438050, 0.000020, 0.821000},
	{{0, 36, -32, 0, 0, 0, 0, 0, 0, -2, 0}, 332.693530, 0.000020, 136.522000},
	{{0, 37, -38, 0, 0, 0, 0, 0, -2, 0, 0}, 45.611130, 0.000010, 0.386000},
	{{0, 37, -36, 0, 0, 0, 0, 0, -2, 0, 0}, 261.091690, 0.000030, 1.686000},
	{{0, 38, -38, 0, 0, 0, 0, 0, -3, 0, 1}, 56.251550, 0.000030, 11.607000},
	{{0, 38, -37, 0, 0, 0, 0, 0, -2, 0, 0}, 28.987720, 0.000080, 30.876000},
	{{0, 38, -36, 0, 0, 0, 0, 0, -2, 0, 0}, 113.534470, 0.000010, 0.969000},
	{{0, 38, -36, 0, 0, 0, 0, 0, -1, 0, -1}, 251.375520, 0.000020, 46.780000},
	{{0, 39, -39, 0, 0, 0, 0, 0, -2, 0, 0}, 32.031760, 0.000020, 2.923000},
	{{0, 39, -38, 0, 0, 0, 0, 0, -2, 0, 0}, 232.352400, 0.000040, 1.520000},
	{{0, 39, -38, 0, 0, 0, 0, 0, -1, 0, -1}, 271.710370, 0.000020, 2.526000},
	{{0, 40, -41, 0, 0, 0, 0, 0, -3, 2, -1}, 172.397810, 0.000040, 271.239000},
	{{0, 40, -41, 0, 0, 0, 0, 0, -2, 0, 0}, 96.622490, 0.000010, 1.396000},
	{{0, 40, -40, 0, 0, 0, 0, 0, -2, 0, 0}, 5.879330, 0.000030, 3.528000},
	{{0, 40, -39, 0, 0, 0, 0, 0, -1, 0, -1}, 228.488200, 0.000010, 4.354000},
	{{0, 41, -43, 0, 0, 0, 0, 0, -3, 0, 1}, 181.023550, 0.000020, 26.827000},
	{{0, 41, -42, 0, 0, 0, 0, 0, -2, 0, 0}, 132.084860, 0.000050, 10.984000},
	{{0, 41, -41, 0, 0, 0, 0, 0, -1, 0, -1}, 250.779690, 0.000020, 6.906000},
	{{0, 42, -44, 0, 0, 0, 0, 0, -2, 0, 0}, 124.211480, 0.000010, 2.148000},
	{{0, 42, -43, 0, 0, 0, 0, 0, -2, 0, 0}, 96.550050, 0.000010, 1.871000},
	{{0, 42, -43, 0, 0, 0, 0, 0, -1, 0, -1}, 20.539490, 0.000020, 1.926000},
	{{0, 42, -42, 0, 0, 0, 0, 0, -1, 0, -1}, 292.603300, 0.000020, 2.080000},
	{{0, 43, -46, 0, 0, 0, 0, 0, -2, 0, 0}, 211.276770, 0.000010, 1.191000},
	{{0, 43, -45, 0, 0, 0, 0, 0, -2, 0, 0}, 264.563720, 0.000040, 6.250000},
	{{0, 43, -44, 0, 0, 0, 0, 0, -2, 0, 0}, 132.500760, 0.000020, 0.862000},
	{{0, 43, -44, 0, 0, 0, 0, 0, -1, 0, -1}, 343.399300, 0.000020, 9.413000},
	{{0, 43, -42, 0, 0, 0, 0, 0, 1, 0, -3}, 175.492360, 0.000070, 773.987000},
	{{0, 44, -47, 0, 0, 0, 0, 0, -2, 0, 0}, 19.574940, 0.000020, 4.663000},
	{{0, 44, -45, 0, 0, 0, 0, 0, 0, -2, 0}, 234.696910, 0.000030, 86.878000},
	{{0, 45, -49, 0, 0, 0, 0, 0, -2, 0, 0}, 304.063440, 0.000020, 1.698000},
	{{0, 45, -48, 0, 0, 0, 0, 0, -2, 0, 0}, 155.229930, 0.000020, 2.433000},
	{{0, 45, -47, 0, 0, 0, 0, 0, -1, 0, -1}, 113.071280, 0.000010, 2.799000},
	{{0, 46, -51, 0, 0, 0, 0, 0, -2, 0, 0}, 248.479420, 0.000020, 1.038000},
	{{0, 46, -50, 0, 0, 0, 0, 0, -2, 0, 0}, 74.826050, 0.000040, 27.342000},
	{{0, 47, -52, 0, 0, 0, 0, 0, -2, 0, 0}, 66.667550, 0.000010, 2.959000},
	{{0, 48, -54, 0, 0, 0, 0, 0, -2, 0, 0}, 341.236290, 0.000020, 1.404000},
	{{0, 48, -53, 0, 0, 0, 0, 0, -2, 0, 0}, 18.591160, 0.000010, 3.477000},
	{{0, 49, -55, 0, 0, 0, 0, 0, -2, 0, 0}, 159.168780, 0.000030, 11.513000},
	{{0, 50, -57, 0, 0, 0, 0, 0, -2, 0, 0}, 70.628200, 0.000010, 2.168000},
	{{0, 50, -56, 0, 0, 0, 0, 0, -2, 0, 0}, 341.193010, 0.000020, 1.856000},
	{{0, 51, -58, 0, 0, 0, 0, 0, -2, 0, 0}, 249.619500, 0.000010, 6.091000},
	{{0, 51, -55, 0, 0, 0, 0, 0, 1, 0, -3}, 88.136210, 0.000020, 345.601000},
	{{0, 52, -60, 0, 0, 0, 0, 0, -2, 0, 0}, 158.610620, 0.000020, 4.755000},
	{{0, 52, -58, 0, 0, 0, 0, 0, 0, -2, 0}, 341.027550, 0.000030, 63.711000},
	{{1, 0, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 191.148970, 0.000020, 0.075000},
	{{1, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 287.011480, 0.000020, 6.575000},
	{{3, 0, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 42.973310, 0.000010, 0.975000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 320.846200, 0.000050, 0.075000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 218.714940, 0.000230, 39.271000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 2, 0}, 218.369760, 0.000010, 0.076000},
	{{4, 0, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 123.750270, 0.000040, 7.897000},
	{{4, 0, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 43.575790, 0.000010, 2.836000},
	{{5, 0, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 289.237020, 0.000010, 3.588000},
	{{7, 0, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 142.845810, 0.000020, 1.486000},
	{{8, 0, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 7.639950, 0.000010, 1.920000},
	{{8, 0, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 114.910930, 0.000030, 2.087000},
	{{9, 0, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 322.073770, 0.000010, 2.712000},
	{{13, 0, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 214.043790, 0.000010, 62.252000}
};

static const struct planet_pert plan_pert_elp14 [ELP14_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 73.435780, 0.000100, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 277.117190, 0.000050, 0.088000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 1}, 300.691880, 0.000040, 0.089000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1}, 354.551590, 0.000010, 0.075000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1}, 354.551590, 0.000010, 0.074000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0}, 4.024180, 0.000060, 0.080000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, -1}, 300.722700, 0.000040, 0.088000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, -1}, 259.581320, 0.000010, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, -1}, 78.692820, 0.000060, 0.037000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 1}, 79.581320, 0.000050, 6.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, -1}, 270.672000, 0.000020, 0.074000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 0, 1}, 270.672000, 0.000020, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, -1}, 79.581320, 0.000050, 5.956000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, 1}, 78.692820, 0.000060, 0.037000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, 1}, 259.581320, 0.000010, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0}, 55.076500, 0.000020, 0.080000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 1}, 302.939440, 0.000030, 0.093000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0}, 294.374620, 0.000050, 0.084000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 2}, 114.374620, 0.000050, 0.067000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, -1}, 120.031400, 0.000030, 0.078000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1}, 120.031400, 0.000030, 0.072000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, -2}, 230.496560, 0.000030, 0.072000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0}, 12.948190, 0.000040, 0.078000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -1, 0, 0}, 159.716870, 0.000020, 0.088000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 0, 0}, 15.746060, 0.000090, 0.074000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 1, 0, -2}, 72.483110, 0.000030, 0.078000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 1, 0, 0}, 338.599460, 0.000040, 0.072000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, 0, -1}, 193.962280, 0.000030, 0.077000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, 0, -3}, 102.785020, 0.000010, 0.075000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, 0, -1}, 43.309310, 0.000070, 0.074000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 2, 0, -1}, 251.263400, 0.000020, 0.072000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 2, 0, -1}, 280.462290, 0.000060, 0.069000},
	{{0, 0, 0, 7, 0, 0, 0, 0, 2, 0, -1}, 129.655570, 0.000020, 0.067000},
	{{0, 0, 1, -6, 0, 0, 0, 0, -2, 0, 1}, 114.241150, 0.000030, 0.074000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 0, 1}, 135.822770, 0.000050, 0.077000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 0, 3}, 141.677360, 0.000010, 0.072000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -1, 0, 0}, 166.196130, 0.000050, 0.071000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -1, 0, 2}, 15.276080, 0.000020, 0.078000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 0, 0}, 83.247520, 0.000010, 0.074000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -1, 0, 2}, 83.247520, 0.000010, 0.075000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -1, 0, 0}, 109.851380, 0.000050, 0.077000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 1, 0, -2}, 320.566580, 0.000010, 0.066000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 1, 0, 0}, 320.566580, 0.000010, 0.085000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 1}, 52.928860, 0.000040, 0.088000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -1, 0, 0}, 128.118460, 0.000070, 0.080000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, -1}, 46.383240, 0.000030, 0.037000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 1}, 40.623150, 0.000020, 9.672000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, -1}, 40.623150, 0.000020, 4.346000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, 1}, 46.383240, 0.000030, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 1, 0, 0}, 351.370340, 0.000040, 0.081000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, -1}, 54.183320, 0.000020, 0.499000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, 1}, 54.183320, 0.000020, 0.040000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, -1}, 54.143470, 0.000060, 0.089000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 1}, 273.702540, 0.000020, 0.092000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 0, 0}, 122.137770, 0.000070, 0.084000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -1, 0, 2}, 319.355030, 0.000020, 0.067000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, -1}, 89.753740, 0.000040, 0.077000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 1}, 89.753740, 0.000040, 0.072000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 1, 0, 0}, 37.686110, 0.000020, 0.078000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, -3}, 86.194310, 0.000020, 0.066000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, -1}, 266.194310, 0.000020, 0.085000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 0, -1}, 30.477280, 0.000010, 0.079000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 0, 1}, 30.477280, 0.000010, 0.071000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, -1}, 43.950140, 0.000010, 0.027000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 1}, 43.948260, 0.000050, 0.095000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -1, 0, 0}, 342.040100, 0.000050, 0.087000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -1, 0}, 153.542950, 0.000020, 17.980000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 0}, 333.542380, 0.000320, 0.076000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 1, 0}, 333.542380, 0.000020, 0.038000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, -1}, 42.817460, 0.000020, 0.082000},
	{{0, 0, 1, 0, -2, 5, 0, 0, 1, 0, 0}, 141.263300, 0.000030, 0.075000},
	{{0, 0, 1, 0, -1, 0, 0, 0, 1, 0, 0}, 164.862310, 0.000120, 0.075000},
	{{0, 0, 1, 0, 0, -2, 0, 0, 1, 0, 0}, 14.881710, 0.000140, 0.075000},
	{{0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 0}, 273.506130, 0.000040, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 1}, 183.125430, 0.000040, 0.097000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, -2}, 101.831200, 0.000020, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 302.390440, 0.000050, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 2}, 178.303500, 0.000010, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, 0}, 21.300720, 0.000040, 0.530000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 120.799230, 0.000060, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 120.799230, 0.000060, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -2, 0}, 138.643160, 0.000030, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 0}, 189.575410, 0.000070, 8.850000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 11.136870, 0.001320, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0}, 9.575940, 0.000070, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -3}, 32.971630, 0.000020, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, -1}, 281.314340, 0.000060, 0.081000},
	{{0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0}, 340.862290, 0.000120, 0.075000},
	{{0, 0, 1, 0, 0, 2, 0, 0, 1, 0, 0}, 136.952010, 0.000060, 0.074000},
	{{0, 0, 1, 0, 1, -1, 0, 0, 1, 0, 0}, 167.073650, 0.000020, 0.075000},
	{{0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0}, 177.160170, 0.000140, 0.074000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 1, 0, 0}, 175.979860, 0.000080, 0.075000},
	{{0, 0, 1, 0, 2, 0, 0, 0, 1, 0, 0}, 141.866550, 0.000170, 0.074000},
	{{0, 0, 1, 0, 3, 0, 0, 0, 1, 0, 0}, 140.111310, 0.000020, 0.073000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 0, -1}, 151.535810, 0.000020, 0.084000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1}, 151.535810, 0.000020, 0.067000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0}, 254.263270, 0.000030, 0.072000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, 0, -2}, 178.986040, 0.000020, 0.081000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 1, 0, 0}, 358.986040, 0.000020, 0.069000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, 0, -3}, 195.519640, 0.000020, 0.074000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, 0, -1}, 183.424680, 0.000090, 0.075000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 2, 0, -3}, 71.267410, 0.000040, 0.081000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 2, 0, -1}, 251.267410, 0.000040, 0.069000},
	{{0, 0, 2, -9, 0, 0, 0, 0, -2, 0, 1}, 230.332980, 0.000060, 0.071000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 0, 1}, 80.557930, 0.000030, 0.074000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 0, 3}, 260.557930, 0.000030, 0.075000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 0, 1}, 108.194440, 0.000020, 0.077000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 2, -1}, 108.281040, 0.000010, 0.075000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 2, 1}, 288.281040, 0.000010, 0.074000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 0, 1}, 316.421070, 0.000010, 0.080000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -2, 0, 3}, 316.421070, 0.000010, 0.070000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -1, 0, 0}, 247.709600, 0.000020, 0.074000},
	{{0, 0, 2, -6, 0, 0, 0, 0, -1, 0, 2}, 278.110750, 0.000010, 0.075000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 0, 0}, 47.552730, 0.000040, 0.077000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 0, 2}, 189.559810, 0.000020, 0.072000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, 1}, 27.599500, 0.000020, 0.087000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -1, 0, 0}, 56.023250, 0.000050, 0.080000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, -1}, 189.147110, 0.000070, 0.074000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 0, 1}, 189.147110, 0.000070, 0.075000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, 0, -2}, 230.839830, 0.000010, 0.068000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 1, 0, 0}, 230.839830, 0.000010, 0.082000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 0, 0}, 99.158620, 0.000030, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -1, 0, 2}, 64.632080, 0.000020, 0.067000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, -1}, 57.095510, 0.000030, 0.077000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, 1}, 57.095510, 0.000030, 0.072000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 1, 0, 0}, 290.445120, 0.000050, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, -3}, 236.992910, 0.000020, 0.066000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, -1}, 236.767200, 0.000040, 0.085000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 1, 0, 0}, 202.604020, 0.000050, 0.075000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, -3}, 266.072430, 0.000020, 0.069000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, -1}, 266.072430, 0.000020, 0.082000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -1, 0, 0}, 119.186100, 0.000020, 0.092000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -1, 0, 2}, 299.186100, 0.000020, 0.063000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 1, 0, 0}, 194.068660, 0.000050, 0.072000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, 0, -1}, 297.292730, 0.000030, 0.078000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, -1}, 239.338620, 0.000020, 0.040000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 1}, 239.338560, 0.000020, 0.523000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, -1}, 241.354980, 0.000010, 0.086000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 1}, 241.354980, 0.000010, 0.066000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, -1}, 59.289160, 0.000030, 0.074000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 1}, 59.289160, 0.000030, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, -1}, 59.338530, 0.000100, 5.163000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 1}, 59.336970, 0.000110, 0.038000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 1, 0, 0}, 123.550440, 0.000020, 0.070000},
	{{0, 0, 2, 0, -1, 0, 0, 0, 1, 0, 0}, 185.349630, 0.000070, 0.070000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, -1}, 245.923500, 0.000020, 0.088000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 1}, 245.923500, 0.000020, 0.065000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 1, 0, 0}, 301.048030, 0.000060, 0.070000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, -3}, 154.155500, 0.000030, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, -1}, 342.929270, 0.000060, 0.075000},
	{{0, 0, 2, 0, 0, 3, 0, 0, 2, 0, -3}, 92.980420, 0.000040, 0.074000},
	{{0, 0, 2, 0, 0, 3, 0, 0, 2, 0, -1}, 272.980420, 0.000040, 0.075000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 1, 0, 0}, 140.187990, 0.000030, 0.069000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, 0, -3}, 261.441390, 0.000020, 0.074000},
	{{0, 0, 2, 0, 1, 0, 0, 0, 2, 0, -1}, 261.441390, 0.000020, 0.075000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 1, 0, -2}, 93.498570, 0.000020, 0.084000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 1, 0, 0}, 273.498570, 0.000020, 0.067000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, 0, -1}, 191.784340, 0.000090, 0.072000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 2, 0, -1}, 222.101750, 0.000060, 0.070000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 2, 0, -1}, 250.953410, 0.000030, 0.067000},
	{{0, 0, 2, 4, 0, 0, 0, 0, 2, 0, -3}, 280.456790, 0.000010, 0.088000},
	{{0, 0, 2, 4, 0, 0, 0, 0, 2, 0, -1}, 100.456790, 0.000010, 0.065000},
	{{0, 0, 3, -11, 0, 0, 0, 0, -2, 0, 1}, 21.146160, 0.000010, 0.071000},
	{{0, 0, 3, -11, 0, 0, 0, 0, -2, 0, 3}, 201.146160, 0.000010, 0.079000},
	{{0, 0, 3, -10, 0, 0, 0, 0, -2, 0, 1}, 230.620990, 0.000010, 0.073000},
	{{0, 0, 3, -10, 0, 0, 0, 0, -2, 0, 3}, 50.620990, 0.000010, 0.076000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 0, 1}, 79.378770, 0.000020, 0.076000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 2, 1}, 258.936330, 0.000030, 0.075000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 0, 1}, 108.025550, 0.000020, 0.080000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 0, 3}, 108.025550, 0.000020, 0.070000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -1, 0, 0}, 163.803820, 0.000030, 0.073000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 0, 0}, 3.925600, 0.000040, 0.076000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 2, 0}, 339.855510, 0.000050, 0.075000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -1, 0, 0}, 39.748880, 0.000030, 0.080000},
	{{0, 0, 3, -6, 0, 0, 0, 0, -1, 0, 2}, 176.162030, 0.000010, 0.070000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, -1}, 225.759890, 0.000030, 0.073000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, 1}, 225.759890, 0.000030, 0.076000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -1, 0, 0}, 108.643150, 0.000030, 0.083000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 0, -1}, 28.919670, 0.000030, 0.076000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 0, 1}, 28.919670, 0.000030, 0.073000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 0, -2}, 154.518820, 0.000020, 0.071000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 1, 0, 0}, 317.770440, 0.000060, 0.079000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, 0}, 43.897530, 0.000040, 0.087000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -1, 0, 2}, 303.725940, 0.000010, 0.065000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 0}, 287.589930, 0.000060, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, -1}, 236.884240, 0.000050, 0.082000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -1, 0, 0}, 111.979780, 0.000010, 0.091000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -1, 0, 2}, 111.979780, 0.000010, 0.063000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, -3}, 266.588040, 0.000010, 0.071000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, -1}, 265.723680, 0.000030, 0.079000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, -1}, 122.281190, 0.000020, 0.087000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 0, 1}, 122.281190, 0.000020, 0.065000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 1, 0, 0}, 277.842840, 0.000050, 0.070000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, -1}, 117.575880, 0.000030, 0.075000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 1, 0, -2}, 97.155370, 0.000020, 0.083000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 1, 0, 0}, 316.837230, 0.000030, 0.067000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, 0, -3}, 140.891320, 0.000040, 0.077000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, 0, -1}, 74.891590, 0.000020, 0.073000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 1, 0, -2}, 157.928070, 0.000030, 0.087000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0}, 153.811550, 0.000050, 0.065000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, -1}, 14.522580, 0.000040, 0.070000},
	{{0, 0, 3, 0, 1, 0, 0, 0, 1, 0, 0}, 321.690910, 0.000020, 0.065000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, 0, -1}, 250.900670, 0.000020, 0.065000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 2, 0, -3}, 100.393570, 0.000010, 0.091000},
	{{0, 0, 3, 3, 0, 0, 0, 0, 2, 0, -1}, 100.393570, 0.000010, 0.063000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 0, 1}, 50.587880, 0.000040, 0.076000},
	{{0, 0, 4, -10, 0, 0, 0, 0, -2, 0, 1}, 79.100460, 0.000050, 0.079000},
	{{0, 0, 4, -10, 0, 0, 0, 0, -1, 0, 0}, 167.752090, 0.000030, 0.073000},
	{{0, 0, 4, -9, 0, 0, 0, 0, -2, 0, 1}, 287.701700, 0.000010, 0.083000},
	{{0, 0, 4, -9, 0, 0, 0, 0, -2, 0, 3}, 287.701700, 0.000010, 0.068000},
	{{0, 0, 4, -9, 0, 0, 0, 0, -1, 0, 0}, 309.730270, 0.000020, 0.076000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -1, 0, 0}, 339.766840, 0.000060, 0.079000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -1, 0, 2}, 217.757550, 0.000020, 0.070000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, -1}, 1.931480, 0.000050, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 1}, 1.957330, 0.000270, 0.088000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, -1}, 2.128960, 0.000080, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, 1}, 2.075410, 0.000070, 0.515000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, -1}, 181.931530, 0.000010, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 1}, 181.931530, 0.000010, 0.076000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, -1}, 1.476850, 0.000110, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 1}, 1.287180, 0.000090, 6.017000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, -1}, 3.099290, 0.000100, 0.074000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 0, 1}, 3.099240, 0.000100, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, -1}, 1.287180, 0.000090, 5.977000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, 1}, 1.476850, 0.000110, 0.037000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, -1}, 181.932620, 0.000010, 0.076000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, 1}, 181.932620, 0.000010, 0.025000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, -1}, 2.076750, 0.000070, 0.515000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 1}, 2.130130, 0.000080, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, -1}, 1.958370, 0.000270, 0.088000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, 1}, 1.932670, 0.000050, 0.026000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 0, 0}, 13.124350, 0.000050, 0.083000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -1, 0, 2}, 224.046130, 0.000020, 0.068000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, -1}, 2.637170, 0.000010, 0.076000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, 1}, 2.637170, 0.000010, 0.073000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 1, 0, -2}, 232.819480, 0.000030, 0.070000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 1, 0, 0}, 232.819480, 0.000030, 0.079000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, 0, 0}, 19.250440, 0.000050, 0.087000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -1, 0, 2}, 252.933770, 0.000020, 0.065000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 1, 0, 0}, 286.616810, 0.000060, 0.076000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, -3}, 27.467640, 0.000010, 0.068000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, -1}, 207.593450, 0.000050, 0.082000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -1, 0, 0}, 86.498640, 0.000020, 0.091000},
	{{0, 0, 4, -5, 0, 0, 0, 0, -1, 0, 2}, 86.498640, 0.000020, 0.063000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 0, -2}, 336.176470, 0.000010, 0.076000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 1, 0, 0}, 132.452800, 0.000050, 0.073000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, -3}, 56.787050, 0.000030, 0.070000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 1, 0, -2}, 92.879110, 0.000010, 0.079000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 1, 0, 0}, 204.114690, 0.000070, 0.070000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, 0, -1}, 74.841670, 0.000030, 0.076000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 1, 0, 0}, 267.504160, 0.000020, 0.068000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, 0, -3}, 312.807130, 0.000020, 0.076000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, 0, -1}, 111.414080, 0.000060, 0.073000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 1, 0, -2}, 305.580330, 0.000020, 0.087000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 1, 0, 0}, 305.580330, 0.000020, 0.065000},
	{{0, 0, 4, -1, 0, 0, 0, 0, 2, 0, -1}, 12.940820, 0.000020, 0.068000},
	{{0, 0, 4, 0, -1, 0, 0, 0, 1, 0, 0}, 322.983090, 0.000050, 0.061000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 0, -3}, 200.718020, 0.000020, 0.087000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 0, -1}, 34.741820, 0.000040, 0.065000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 2, 0, -1}, 71.191720, 0.000030, 0.063000},
	{{0, 0, 5, -12, 0, 0, 0, 0, -2, 0, 1}, 50.285060, 0.000010, 0.079000},
	{{0, 0, 5, -12, 0, 0, 0, 0, -2, 0, 3}, 49.966950, 0.000030, 0.071000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -2, 0, 1}, 258.892900, 0.000020, 0.082000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -1, 0, 0}, 282.986940, 0.000040, 0.076000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -1, 0, 2}, 169.523500, 0.000020, 0.073000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 0, -1}, 179.971200, 0.000020, 0.076000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 0, 1}, 179.971200, 0.000020, 0.073000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -1, 0, 0}, 28.289320, 0.000010, 0.086000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -1, 0, 2}, 28.289320, 0.000010, 0.066000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 2, 0, -1}, 178.554790, 0.000030, 0.083000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -1, 0, 0}, 57.367480, 0.000010, 0.090000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -1, 0, 2}, 57.367480, 0.000010, 0.063000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 1, 0, 0}, 121.890600, 0.000050, 0.073000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, -3}, 27.598260, 0.000030, 0.070000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, -1}, 207.598260, 0.000030, 0.079000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 1, 0, 0}, 257.560630, 0.000030, 0.071000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -2, -1}, 59.884180, 0.000030, 0.075000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, 1}, 247.558240, 0.000020, 0.037000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, -3}, 228.811840, 0.000010, 0.073000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, 0, -1}, 54.689570, 0.000040, 0.076000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 1, 0, 0}, 283.592230, 0.000040, 0.068000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 1, 0, 0}, 346.061560, 0.000050, 0.066000},
	{{0, 0, 5, -1, 0, 0, 0, 0, 2, 0, -1}, 41.954820, 0.000020, 0.063000},
	{{0, 0, 5, 0, -2, 0, 0, 0, 1, 0, 0}, 142.073900, 0.000020, 0.058000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, 0, -1}, 101.312610, 0.000060, 0.061000},
	{{0, 0, 6, -14, 0, 0, 0, 0, -2, 0, 1}, 200.963780, 0.000030, 0.078000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -2, 0, 1}, 229.903970, 0.000020, 0.082000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -1, 0, 0}, 311.020790, 0.000020, 0.075000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -1, 0, 2}, 311.020790, 0.000020, 0.074000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 1, 0, 0}, 204.898470, 0.000080, 0.077000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 0, -2}, 208.949280, 0.000010, 0.075000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 1, 0, 0}, 69.708370, 0.000050, 0.074000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, 0, -3}, 178.418790, 0.000020, 0.070000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, 0, -1}, 178.418790, 0.000020, 0.080000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 1, 0, -2}, 35.757490, 0.000010, 0.079000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 1, 0, 0}, 238.382500, 0.000040, 0.071000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, 1}, 31.631860, 0.000030, 0.075000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, -1}, 43.906500, 0.000020, 5.148000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, 1}, 43.904770, 0.000020, 0.038000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, -1}, 27.844150, 0.000020, 0.077000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 1, 0, 0}, 243.185890, 0.000050, 0.068000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, -3}, 235.651120, 0.000010, 0.075000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, -1}, 235.651120, 0.000010, 0.074000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 1, 0, -2}, 48.257180, 0.000020, 0.086000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 1, 0, 0}, 290.956370, 0.000050, 0.066000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, 0, -1}, 84.673350, 0.000030, 0.071000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 1, 0, -2}, 280.282980, 0.000010, 0.090000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 1, 0, 0}, 354.019030, 0.000020, 0.064000},
	{{0, 0, 7, -15, 0, 0, 0, 0, -1, 0, 0}, 298.964110, 0.000020, 0.075000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, -1}, 274.507910, 0.000010, 0.075000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 0, 0, 1}, 274.507910, 0.000010, 0.074000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 0, -2}, 154.452820, 0.000010, 0.075000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 1, 0, 0}, 38.763080, 0.000040, 0.074000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 2, 0, -1}, 149.398450, 0.000020, 0.080000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 1, 0, 0}, 62.929780, 0.000020, 0.071000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 1, 0, -2}, 148.417360, 0.000020, 0.082000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 1, 0, 0}, 148.417360, 0.000020, 0.069000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 1, 0, -2}, 273.965300, 0.000010, 0.085000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 1, 0, 0}, 273.965300, 0.000010, 0.066000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 2, 0, -1}, 56.285060, 0.000050, 0.071000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 1, 0, -2}, 303.043470, 0.000010, 0.089000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 1, 0, 0}, 303.043470, 0.000010, 0.064000},
	{{0, 0, 8, -19, 0, 0, 0, 0, -2, 0, 1}, 286.850880, 0.000030, 0.075000},
	{{0, 0, 8, -17, 0, 0, 0, 0, -1, 0, 0}, 231.259420, 0.000030, 0.075000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, 1}, 242.587010, 0.000030, 0.089000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, -1}, 234.900430, 0.000010, 0.038000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, 1}, 234.900430, 0.000010, 5.222000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, -1}, 52.020350, 0.000040, 0.075000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 0, 1}, 52.020350, 0.000040, 0.074000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, -1}, 234.900430, 0.000010, 7.041000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, 1}, 234.900430, 0.000010, 0.037000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, -1}, 242.319460, 0.000020, 0.088000},
	{{0, 0, 8, -13, 0, 0, 0, 0, 1, 0, 0}, 163.494810, 0.000020, 0.074000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 1, 0, 0}, 68.708660, 0.000020, 0.071000},
	{{0, 0, 8, -12, 0, 0, 0, 0, 2, 0, -1}, 149.256720, 0.000040, 0.077000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, -3}, 6.366680, 0.000010, 0.075000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, 0, -1}, 5.073850, 0.000040, 0.074000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 1, 0, -2}, 59.341920, 0.000020, 0.085000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 1, 0, 0}, 59.341920, 0.000020, 0.066000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, -1}, 27.313730, 0.000060, 0.071000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, -1}, 55.953980, 0.000020, 0.069000},
	{{0, 0, 9, -21, 0, 0, 0, 0, -2, 0, 1}, 264.848590, 0.000010, 0.074000},
	{{0, 0, 9, -21, 0, 0, 0, 0, -2, 0, 3}, 84.848590, 0.000010, 0.075000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, -2}, 300.582580, 0.000010, 0.074000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 1, 0, 0}, 187.497090, 0.000100, 0.075000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 1, 0, -2}, 152.277380, 0.000020, 0.077000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 1, 0, 0}, 332.277380, 0.000020, 0.072000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, 0, -1}, 120.270720, 0.000020, 0.078000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, 0, -1}, 179.359490, 0.000030, 0.075000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 0, -1}, 358.239250, 0.000050, 0.072000},
	{{0, 0, 9, -11, 0, 0, 0, 0, 2, 0, -1}, 27.145180, 0.000030, 0.069000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 1, 0, -2}, 151.801960, 0.000030, 0.074000},
	{{0, 0, 10, -17, 0, 0, 0, 0, 1, 0, 0}, 151.801960, 0.000030, 0.075000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, 0, -1}, 300.652750, 0.000030, 0.075000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, 0, -1}, 329.152130, 0.000040, 0.072000},
	{{0, 0, 10, -13, 0, 0, 0, 0, 2, 0, -1}, 358.156250, 0.000030, 0.069000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 2, 0, -3}, 270.927020, 0.000010, 0.074000},
	{{0, 0, 11, -17, 0, 0, 0, 0, 2, 0, -1}, 91.029450, 0.000050, 0.075000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, 0, -3}, 120.154240, 0.000010, 0.077000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, 0, -1}, 300.154240, 0.000010, 0.072000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, -1}, 190.682520, 0.000010, 0.074000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -2, 1}, 190.682520, 0.000010, 0.075000},
	{{0, 0, 34, -41, 0, 0, 0, 0, -1, -1, 0}, 145.608260, 0.000010, 0.074000},
	{{0, 0, 34, -41, 0, 0, 0, 0, -1, -1, 2}, 145.608260, 0.000010, 0.075000},
	{{0, 1, -7, 0, 0, 0, 0, 0, -2, 0, 1}, 341.069900, 0.000020, 0.060000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 339.264290, 0.000020, 0.068000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 0, 3}, 339.264290, 0.000020, 0.082000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 270.218910, 0.000030, 0.073000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 3}, 90.218910, 0.000030, 0.076000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 12.480680, 0.000060, 0.068000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -1, 0, 2}, 240.170340, 0.000010, 0.083000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 1, 0, -2}, 6.676870, 0.000020, 0.059000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 6.676870, 0.000020, 0.100000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 301.362510, 0.000080, 0.073000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 0, 2}, 262.067050, 0.000040, 0.076000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 0, -3}, 109.322190, 0.000010, 0.059000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 109.322190, 0.000010, 0.101000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 305.175130, 0.000040, 0.086000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 83.116220, 0.000050, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, -2}, 201.872950, 0.000010, 0.038000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, 0}, 357.188130, 0.000030, 1.951000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, 0}, 267.667780, 0.000030, 0.073000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 246.360750, 0.000010, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 246.360750, 0.000010, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 0}, 0.115540, 0.000030, 0.793000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 2}, 180.115540, 0.000030, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, -2}, 15.187840, 0.000020, 0.067000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 199.890380, 0.000100, 0.083000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 2}, 8.410470, 0.000040, 0.026000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 1}, 252.369410, 0.000020, 0.094000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 85.399220, 0.000020, 0.085000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -1, 0, 2}, 192.342060, 0.000020, 0.066000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, -1}, 37.308050, 0.000010, 0.078000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 1}, 37.308050, 0.000010, 0.071000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, -2}, 104.827450, 0.000020, 0.072000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 104.827450, 0.000020, 0.077000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 0}, 341.829850, 0.000070, 0.093000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1}, 117.926180, 0.000070, 0.085000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 117.926180, 0.000070, 0.066000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 158.110770, 0.000010, 0.080000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -2, 2}, 158.110770, 0.000010, 0.070000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 338.110770, 0.000030, 1.354000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, -2}, 89.483210, 0.000020, 0.078000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 202.694230, 0.000190, 0.071000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, -3}, 239.758880, 0.000020, 0.072000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 342.203320, 0.000010, 0.077000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 254.642640, 0.000050, 0.103000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -1, 0, 2}, 2.606600, 0.000020, 0.058000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, -2}, 346.468200, 0.000020, 0.084000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 239.525360, 0.000020, 0.067000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, 0, -1}, 66.428870, 0.000020, 0.072000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 1, 0, 0}, 158.742540, 0.000050, 0.063000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 0, -1}, 309.008280, 0.000040, 0.067000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, 0, -1}, 20.621690, 0.000020, 0.063000},
	{{0, 2, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 341.119800, 0.000010, 0.062000},
	{{0, 2, -8, 0, 0, 0, 0, 0, -2, 0, 3}, 161.119800, 0.000010, 0.093000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 0, 1}, 256.447480, 0.000040, 0.066000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 0, 1}, 302.867110, 0.000050, 0.071000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 112.423600, 0.000020, 0.077000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 0, 3}, 112.423600, 0.000020, 0.073000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 2, -1}, 167.175980, 0.000030, 0.075000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 2, 1}, 302.789750, 0.000020, 0.074000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 47.367140, 0.000070, 0.071000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 1, 0, -2}, 165.227310, 0.000020, 0.062000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 19.066820, 0.000030, 0.094000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 136.782600, 0.000070, 0.076000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 0, 2}, 87.328840, 0.000010, 0.073000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 2, -2}, 186.113990, 0.000010, 0.074000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 2, 0}, 100.402380, 0.000030, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 285.471560, 0.000030, 0.071000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 285.471560, 0.000030, 0.079000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, -3}, 289.372090, 0.000010, 0.061000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 109.372090, 0.000010, 0.095000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 23.269650, 0.000020, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 1}, 34.586560, 0.000140, 0.090000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, -1}, 12.785010, 0.000020, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 1}, 12.785130, 0.000020, 0.456000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 106.788940, 0.000060, 0.083000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 17.569950, 0.000030, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 17.783220, 0.000020, 2.394000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 48.828380, 0.000090, 0.076000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 48.828380, 0.000090, 0.073000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, -1}, 17.783220, 0.000020, 11.864000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 1}, 17.569950, 0.000030, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, 0}, 0.015450, 0.000050, 0.072000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, 0}, 0.115350, 0.000050, 1.572000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, -2}, 334.108700, 0.000010, 0.070000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 194.300340, 0.000140, 0.079000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -3}, 195.143970, 0.000010, 0.065000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 17.754990, 0.000040, 0.086000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 355.869250, 0.000030, 0.090000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 311.604040, 0.000210, 0.073000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 284.370920, 0.000070, 0.080000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, -1}, 161.537760, 0.000010, 0.028000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 1}, 161.713340, 0.000020, 0.110000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 3}, 340.079070, 0.000030, 0.056000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, -2}, 106.376160, 0.000010, 0.027000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 322.463160, 0.000040, 0.099000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, 0}, 179.885110, 0.000060, 0.319000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, -2}, 152.989530, 0.000010, 0.082000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 0}, 220.279560, 0.000090, 0.068000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 2}, 59.209580, 0.000010, 0.024000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 165.312400, 0.000050, 0.074000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 1, 0, -2}, 114.552520, 0.000010, 0.089000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 239.287580, 0.000040, 0.064000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 1, 0, 0}, 321.510640, 0.000040, 0.060000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, 0, -3}, 8.447020, 0.000030, 0.089000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, 0, -1}, 8.447020, 0.000030, 0.064000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 0, -1}, 20.618590, 0.000020, 0.060000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 0, -3}, 288.015330, 0.000040, 0.108000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 0, -1}, 108.015330, 0.000040, 0.057000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 286.958990, 0.000010, 0.069000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -1, 0, 2}, 286.958990, 0.000010, 0.081000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 1}, 359.882500, 0.000030, 0.080000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, 0}, 56.983310, 0.000020, 0.037000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 56.920220, 0.000410, 0.074000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 0, 2}, 2.215510, 0.000010, 0.075000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, 0}, 236.988860, 0.000020, 4.230000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 50.463890, 0.000020, 0.089000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 202.222870, 0.000020, 0.087000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 153.846840, 0.000040, 0.074000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 153.846840, 0.000040, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 198.159910, 0.000020, 0.089000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, -1}, 28.061340, 0.000020, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 1}, 21.983940, 0.000080, 0.096000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, -2}, 303.808880, 0.000010, 0.026000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 91.290830, 0.000060, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, -1}, 8.451050, 0.000010, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 1}, 8.451050, 0.000010, 0.958000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 359.124530, 0.000020, 0.080000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 359.124530, 0.000020, 0.070000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, -1}, 8.451050, 0.000010, 1.409000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 1}, 8.451050, 0.000010, 0.036000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 301.815710, 0.000050, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, -1}, 14.202980, 0.000030, 0.074000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 0.114050, 0.000040, 95.796000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 14.202980, 0.000030, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 182.496820, 0.000250, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 16.342680, 0.000020, 0.082000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 51.126270, 0.000030, 0.095000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 246.727150, 0.000030, 0.070000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 358.058630, 0.000040, 0.076000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, -1}, 161.537570, 0.000010, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 1}, 161.537570, 0.000010, 0.119000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, -2}, 92.858200, 0.000020, 0.028000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 215.640940, 0.000060, 0.105000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, -1}, 171.667530, 0.000040, 0.095000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, 1}, 171.667530, 0.000040, 0.061000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, -2}, 171.602200, 0.000020, 0.086000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 227.623270, 0.000100, 0.066000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 125.370210, 0.000030, 0.070000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -2, 0}, 318.898230, 0.000030, 0.074000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -1, 0, 0}, 245.628910, 0.000070, 0.118000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, 0, -3}, 147.183310, 0.000020, 0.094000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 325.574990, 0.000040, 0.062000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 0, 1}, 161.547580, 0.000060, 0.068000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 0, 1}, 59.562730, 0.000020, 0.072000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 147.444790, 0.000050, 0.078000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 109.151680, 0.000050, 0.072000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -1, 0, 2}, 100.224920, 0.000010, 0.077000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 0, 1}, 339.040760, 0.000050, 0.085000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 237.030120, 0.000070, 0.078000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 129.547140, 0.000030, 0.084000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 90.923950, 0.000010, 0.084000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -1, 0, 2}, 90.923950, 0.000010, 0.067000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 286.770160, 0.000050, 0.077000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, 1}, 286.770160, 0.000050, 0.072000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 108.726760, 0.000050, 0.085000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 75.669120, 0.000060, 0.092000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 207.768380, 0.000030, 0.084000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 207.768380, 0.000030, 0.067000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, -2}, 290.151390, 0.000040, 0.077000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 352.672760, 0.000370, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 316.243110, 0.000020, 0.101000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 245.050090, 0.000020, 0.067000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, -3}, 263.378160, 0.000020, 0.077000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 76.696430, 0.000060, 0.072000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, -2}, 97.293340, 0.000020, 0.028000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 253.443980, 0.000040, 0.113000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, -1}, 356.316100, 0.000010, 0.101000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 356.316100, 0.000010, 0.059000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 201.212720, 0.000110, 0.063000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, 2}, 345.416040, 0.000020, 0.023000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, -1}, 94.176290, 0.000030, 0.067000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -1, 0, 0}, 246.379850, 0.000060, 0.127000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 1, 0, 0}, 262.162430, 0.000030, 0.059000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, 0, -1}, 333.553740, 0.000040, 0.059000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 0, 1}, 241.310530, 0.000030, 0.076000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 101.718770, 0.000010, 0.070000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -1, 0, 2}, 281.718770, 0.000010, 0.079000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -2, 0, 1}, 338.005970, 0.000020, 0.082000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 296.122770, 0.000060, 0.076000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 2}, 158.085520, 0.000020, 0.074000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 1}, 36.896730, 0.000040, 0.089000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 3}, 212.809340, 0.000010, 0.064000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 224.536050, 0.000080, 0.082000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -1, 0, 2}, 11.611860, 0.000030, 0.068000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 338.212170, 0.000030, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 0, 1}, 338.212170, 0.000030, 0.074000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 28.555290, 0.000070, 0.080000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 180.516030, 0.000030, 0.089000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 46.707810, 0.000110, 0.074000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 138.552080, 0.000060, 0.098000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, 2}, 359.942410, 0.000020, 0.060000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, -1}, 194.192810, 0.000060, 0.089000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, 1}, 193.554470, 0.000040, 0.064000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, -2}, 155.056810, 0.000020, 0.081000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 350.545650, 0.000120, 0.069000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, -1}, 198.448040, 0.000010, 0.077000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -2, 1}, 18.448040, 0.000010, 0.073000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -1}, 195.580510, 0.000030, 5.352000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -3}, 341.335440, 0.000020, 0.075000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, -1}, 15.603530, 0.000570, 0.074000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -1}, 15.576590, 0.000030, 0.037000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 296.785250, 0.000020, 0.108000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 348.395630, 0.000060, 0.065000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 106.258250, 0.000030, 0.069000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 0, -1}, 356.851700, 0.000010, 0.108000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 0, 1}, 356.851700, 0.000010, 0.057000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -1, 0}, 176.011780, 0.000010, 0.309000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, -1, 2}, 356.011780, 0.000010, 0.033000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 178.067910, 0.000060, 0.061000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, -1}, 358.807090, 0.000020, 0.065000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -1, 0, 0}, 247.294100, 0.000050, 0.138000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 1, 0, 0}, 261.057720, 0.000040, 0.057000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, 0, -3}, 338.488250, 0.000020, 0.106000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 338.488250, 0.000020, 0.057000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 0, 1}, 292.105140, 0.000010, 0.074000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 0, 3}, 195.252080, 0.000020, 0.075000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 0, 1}, 76.410080, 0.000020, 0.080000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 0, 3}, 256.410080, 0.000020, 0.070000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 210.041330, 0.000050, 0.086000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -1, 0, 2}, 200.694400, 0.000010, 0.066000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 350.985310, 0.000020, 0.076000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 126.345870, 0.000050, 0.094000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, -1}, 14.810530, 0.000020, 5.330000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 1}, 14.815940, 0.000020, 0.038000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, -2}, 192.834510, 0.000020, 0.027000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 74.475430, 0.000030, 0.104000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, -1}, 38.852570, 0.000020, 0.094000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, 1}, 38.852570, 0.000020, 0.062000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 335.647390, 0.000010, 0.066000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, 0, 2}, 299.921800, 0.000010, 0.024000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -1, 0, 0}, 276.390640, 0.000030, 0.116000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 350.375760, 0.000060, 0.062000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 0, 1}, 162.759960, 0.000030, 0.152000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 0, 3}, 342.759960, 0.000030, 0.049000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, -2}, 275.972010, 0.000020, 0.029000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -1, 0, 0}, 275.972010, 0.000020, 0.131000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 0, -1}, 299.368150, 0.000010, 0.115000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 0, 1}, 299.368150, 0.000010, 0.055000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, -1, 0}, 176.007310, 0.000020, 0.259000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 124.725930, 0.000030, 0.058000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 341.041690, 0.000020, 0.062000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 228.464480, 0.000070, 0.055000},
	{{0, 7, -14, 0, 0, 0, 0, 0, -2, 0, 1}, 60.711770, 0.000030, 0.072000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 129.666500, 0.000060, 0.100000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, -3}, 86.904340, 0.000010, 0.076000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, -1}, 86.904340, 0.000010, 0.073000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 51.990430, 0.000040, 0.111000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, -2}, 215.065070, 0.000020, 0.090000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 69.243250, 0.000030, 0.064000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 0, 0}, 305.259400, 0.000050, 0.125000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -1, 0, 2}, 108.214810, 0.000030, 0.053000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 286.902150, 0.000050, 0.060000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 0, 1}, 162.787350, 0.000020, 0.168000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 0, 3}, 162.787350, 0.000020, 0.048000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 133.486090, 0.000030, 0.056000},
	{{0, 7, -5, 0, 0, 0, 0, 0, 1, 0, 0}, 238.670230, 0.000030, 0.053000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 2, 0, -3}, 108.007040, 0.000020, 0.163000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 2, 0, -1}, 108.007040, 0.000020, 0.048000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 0, 1}, 43.426820, 0.000020, 0.075000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 0, 3}, 223.666900, 0.000010, 0.074000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 0, 1}, 341.642350, 0.000050, 0.081000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, -1}, 94.874580, 0.000010, 0.026000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 1}, 93.184760, 0.000070, 0.088000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, -1}, 87.103370, 0.000030, 0.037000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 1}, 81.685830, 0.000020, 5.850000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, -1}, 82.048020, 0.000030, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 1}, 82.048020, 0.000030, 0.074000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, -1}, 81.685830, 0.000020, 6.151000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 1}, 87.103370, 0.000030, 0.037000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 92.752240, 0.000070, 0.088000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, 1}, 92.752240, 0.000020, 0.026000},
	{{0, 8, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 26.067390, 0.000130, 0.075000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 220.335900, 0.000020, 0.096000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 306.519200, 0.000030, 0.070000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, -3}, 8.674880, 0.000010, 0.074000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 8.674880, 0.000010, 0.075000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 166.897190, 0.000040, 0.107000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 91.951590, 0.000060, 0.065000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, -3}, 109.487330, 0.000030, 0.080000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 2, 0, -1}, 289.487330, 0.000030, 0.070000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, -2}, 93.769170, 0.000010, 0.028000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 37.961730, 0.000030, 0.120000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 82.874290, 0.000010, 0.061000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 2}, 0.081830, 0.000030, 0.023000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 313.532170, 0.000040, 0.136000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -1, 0, 2}, 276.004050, 0.000020, 0.051000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, 0}, 123.780890, 0.000040, 0.054000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 1, 0, 0}, 227.807860, 0.000020, 0.052000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 0, 1}, 161.511390, 0.000030, 0.086000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 0, 1}, 250.181310, 0.000070, 0.094000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, 0, -1}, 70.150190, 0.000010, 0.078000},
	{{0, 9, -14, 0, 0, 0, 0, 0, 0, 0, 1}, 70.150190, 0.000010, 0.071000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 1, 0, -2}, 352.411070, 0.000020, 0.084000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 238.994710, 0.000020, 0.067000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, 0, -1}, 10.390830, 0.000020, 0.072000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 130.822050, 0.000050, 0.114000},
	{{0, 9, -11, 0, 0, 0, 0, 0, -1, 0, 2}, 245.594690, 0.000010, 0.055000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 0, -2}, 349.218500, 0.000020, 0.092000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 169.218500, 0.000020, 0.063000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, -3}, 109.763670, 0.000020, 0.084000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 289.763670, 0.000020, 0.067000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 70.582590, 0.000050, 0.129000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 180.069410, 0.000050, 0.059000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, -3}, 18.362410, 0.000030, 0.092000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, -1}, 198.362410, 0.000030, 0.063000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, -2}, 207.581760, 0.000010, 0.113000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 82.241670, 0.000060, 0.056000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -1, 0, 0}, 330.282610, 0.000040, 0.174000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, 0, -1}, 336.719180, 0.000020, 0.147000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, 0, 1}, 336.719180, 0.000020, 0.050000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, -2}, 70.975150, 0.000020, 0.127000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 1, 0, 0}, 143.753450, 0.000020, 0.053000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 0, 1}, 250.148210, 0.000020, 0.099000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 0, 3}, 250.148210, 0.000020, 0.060000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 193.811350, 0.000010, 0.110000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -1, 0, 2}, 193.811350, 0.000010, 0.056000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 172.043280, 0.000040, 0.064000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 118.035760, 0.000030, 0.123000},
	{{0, 10, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 212.471240, 0.000040, 0.060000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, 0}, 96.880890, 0.000030, 0.141000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 196.510120, 0.000020, 0.057000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, -1}, 198.367140, 0.000040, 0.060000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 52.352020, 0.000030, 0.054000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, 0, 1}, 161.491640, 0.000010, 0.246000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, 0, 3}, 161.491640, 0.000010, 0.044000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, -2}, 329.648580, 0.000020, 0.031000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 329.648580, 0.000020, 0.196000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, 0}, 224.102790, 0.000020, 0.051000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 1, 0, 2}, 111.033750, 0.000020, 0.022000},
	{{0, 10, -5, 0, 0, 0, 0, 0, 2, 0, -1}, 289.743920, 0.000020, 0.044000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, -1}, 60.662720, 0.000010, 0.026000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, 1}, 60.662720, 0.000020, 0.088000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 0, -1}, 60.662720, 0.000010, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, -1}, 60.662720, 0.000070, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, -1}, 60.191250, 0.000640, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 1}, 60.191250, 0.000640, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, 1}, 60.662720, 0.000070, 0.037000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -2, 1}, 60.662720, 0.000010, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, -1}, 60.662720, 0.000020, 0.088000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, 1}, 60.662720, 0.000010, 0.026000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 0, 1}, 70.115000, 0.000030, 0.106000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 212.073670, 0.000030, 0.058000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 104.390210, 0.000030, 0.154000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 1, -2}, 21.829270, 0.000010, 0.050000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 1, 0}, 201.829270, 0.000010, 0.148000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, -1}, 198.367280, 0.000030, 0.058000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 51.884580, 0.000040, 0.052000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, 0}, 274.278470, 0.000020, 0.223000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, 2}, 94.278470, 0.000020, 0.045000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 1, -2}, 201.255250, 0.000020, 0.055000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 1, 0}, 21.255250, 0.000020, 0.114000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, -2}, 251.064870, 0.000010, 0.152000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 1, 0, 0}, 251.064870, 0.000010, 0.049000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 108.260530, 0.000020, 0.171000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 0, 2}, 108.260530, 0.000020, 0.048000},
	{{0, 12, -13, 0, 0, 0, 0, 0, -1, 1, 0}, 201.812700, 0.000030, 0.135000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 124.365070, 0.000040, 0.053000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, -1}, 198.346620, 0.000020, 0.056000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 292.601960, 0.000020, 0.206000},
	{{0, 12, -12, 0, 0, 0, 0, 0, -1, 0, 2}, 292.601960, 0.000020, 0.045000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 24.027600, 0.000040, 0.050000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 1, -2}, 201.240760, 0.000020, 0.057000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -1, 1, 0}, 21.240760, 0.000020, 0.106000},
	{{0, 12, -11, 0, 0, 0, 0, 0, 1, 0, 0}, 318.849430, 0.000030, 0.048000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, -1}, 321.115230, 0.000050, 0.075000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 1, 1}, 321.115230, 0.000050, 0.074000},
	{{0, 13, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 91.525260, 0.000050, 0.054000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 49.712150, 0.000040, 0.191000},
	{{0, 13, -14, 0, 0, 0, 0, 0, -1, 1, 0}, 201.794080, 0.000020, 0.125000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 117.965180, 0.000040, 0.051000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 0, 0}, 328.077850, 0.000040, 0.309000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 1, -2}, 201.224200, 0.000020, 0.059000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 1, 0}, 21.224200, 0.000020, 0.100000},
	{{0, 13, -12, 0, 0, 0, 0, 0, 1, 0, 0}, 347.824270, 0.000050, 0.047000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 1, 0, -2}, 91.553330, 0.000020, 0.130000},
	{{0, 14, -16, 0, 0, 0, 0, 0, 1, 0, 0}, 91.553330, 0.000020, 0.052000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -1, 0, 0}, 72.752180, 0.000020, 0.217000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -1, 0, 2}, 87.705920, 0.000010, 0.045000},
	{{0, 14, -15, 0, 0, 0, 0, 0, -1, 1, 0}, 201.773420, 0.000020, 0.116000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 1, 0, -2}, 117.813890, 0.000010, 0.149000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 117.813890, 0.000010, 0.050000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, -2}, 21.205570, 0.000020, 0.034000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 0, 0}, 201.205570, 0.000020, 0.383000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 1, -2}, 201.205570, 0.000020, 0.062000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -1, 1, 0}, 21.205570, 0.000020, 0.094000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, -2}, 112.946700, 0.000010, 0.212000},
	{{0, 14, -13, 0, 0, 0, 0, 0, 1, 0, 0}, 323.542920, 0.000030, 0.045000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -1, 0, 0}, 113.327680, 0.000020, 0.201000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -1, 0, -2}, 201.750750, 0.000010, 0.032000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -1, 0, 0}, 21.750750, 0.000010, 0.251000},
	{{0, 15, -16, 0, 0, 0, 0, 0, -1, 1, 0}, 201.750750, 0.000020, 0.108000},
	{{0, 15, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 267.453820, 0.000020, 0.046000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 0, 0}, 201.184910, 0.000040, 0.504000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 1, -2}, 201.184910, 0.000020, 0.064000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 1, 0}, 21.184910, 0.000020, 0.089000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 1, 0, 0}, 289.818960, 0.000040, 0.044000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, -1}, 108.328360, 0.000020, 0.074000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 1, 1}, 108.328360, 0.000020, 0.075000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -1, 0, 0}, 21.726110, 0.000030, 0.298000},
	{{0, 16, -17, 0, 0, 0, 0, 0, 1, 0, 0}, 359.925200, 0.000050, 0.047000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, -1, 1}, 342.831880, 0.000020, 0.074000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, -1, 3}, 162.831880, 0.000020, 0.075000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -1, 0, 0}, 201.162250, 0.000040, 0.735000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, 0, -2}, 289.638050, 0.000020, 0.288000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 1, 0, 0}, 289.638050, 0.000020, 0.043000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -1, 0, 0}, 21.699540, 0.000020, 0.366000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 1, 0, -2}, 359.896730, 0.000020, 0.207000},
	{{0, 17, -18, 0, 0, 0, 0, 0, 1, 0, 0}, 359.896730, 0.000020, 0.045000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, -1, 0}, 201.137610, 0.000020, 0.071000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, -1, 2}, 201.137610, 0.000020, 0.078000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 1, -2}, 146.519810, 0.000020, 0.070000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 1, 0}, 146.519810, 0.000020, 0.080000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -1, 0, 0}, 21.671070, 0.000020, 0.474000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 1, 0, 0}, 175.797210, 0.000020, 0.041000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -2, 1}, 217.502430, 0.000010, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, -1}, 217.502430, 0.000020, 0.097000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, 1}, 217.502430, 0.000010, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, -1}, 114.565500, 0.000040, 0.019000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 1}, 114.565500, 0.000040, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, -1}, 114.565500, 0.000220, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 1}, 114.565500, 0.000380, 0.088000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, -1}, 114.565500, 0.000250, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, -1}, 114.565500, 0.000110, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, 1}, 114.565500, 0.000020, 0.076000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, -1}, 114.559720, 0.001250, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -3}, 294.565500, 0.000010, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, -1}, 114.508840, 0.011260, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 1}, 114.623740, 0.011230, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 3}, 294.565500, 0.000010, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -1}, 290.173870, 0.000030, 6.132000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 1}, 114.677480, 0.001210, 0.037000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, -1}, 114.565500, 0.000020, 0.076000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 1}, 114.565500, 0.000110, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 1}, 114.565500, 0.000250, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, -1}, 114.565500, 0.000380, 0.088000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 1}, 114.565500, 0.000220, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, -1}, 114.565500, 0.000040, 0.041000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, 1}, 114.565500, 0.000040, 0.019000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, -1}, 11.628570, 0.000010, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, 1}, 11.628570, 0.000020, 0.097000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 0, -1}, 11.628570, 0.000010, 0.042000},
	{{0, 19, -20, 0, 0, 0, 0, 0, -1, 1, 0}, 201.640740, 0.000020, 0.085000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, -1}, 18.184190, 0.000050, 0.075000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, 1}, 18.184190, 0.000050, 0.074000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 1, 0}, 201.608610, 0.000030, 0.081000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, -2}, 296.754070, 0.000030, 0.074000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 1, 0}, 317.442380, 0.000050, 0.075000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, 1, -2}, 201.052240, 0.000020, 0.080000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, 1, 0}, 201.052240, 0.000020, 0.069000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -1, 0}, 48.151580, 0.000020, 0.074000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, -1, 2}, 228.151580, 0.000020, 0.075000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -1, -2}, 288.903310, 0.000020, 0.074000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, -1, 0}, 288.903310, 0.000020, 0.075000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 1, 0}, 83.050360, 0.000020, 0.073000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -1, -2}, 267.561100, 0.000020, 0.075000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, -1, 0}, 87.561100, 0.000020, 0.074000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, -1}, 238.396220, 0.000040, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -1, 1}, 238.396220, 0.000040, 0.074000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, -1}, 218.714940, 0.000010, 0.074000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 1, 1}, 218.714940, 0.000010, 0.075000}
};

static const struct planet_pert plan_pert_elp15 [ELP15_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 90.000000, 0.000030, 99999.999000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 277.418350, 0.000020, 0.067000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 177.303670, 0.000020, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 60.078940, 0.000040, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 0.780260, 0.000430, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 0, 0}, 234.612130, 0.000110, 0.040000},
	{{0, 0, 0, 0, 0, 1, 0, 0, -2, 1, 0}, 232.101290, 0.000050, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, -1, 0}, 242.914820, 0.000080, 0.076000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0}, 62.914820, 0.000080, 0.075000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, -1, 0}, 51.999970, 0.000050, 0.087000},
	{{0, 0, 0, 0, 0, 1, 0, 0, 2, 0, 0}, 54.567360, 0.000100, 0.040000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 0, 0}, 30.691880, 0.000220, 0.041000},
	{{0, 0, 0, 0, 1, 0, 0, 0, -2, 1, 0}, 38.288830, 0.000240, 0.088000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 0}, 312.643000, 0.000160, 0.076000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0}, 132.027260, 0.000160, 0.075000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, -1, 0}, 218.660270, 0.000230, 0.086000},
	{{0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0}, 210.722650, 0.000190, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 0, 0}, 42.641590, 0.000140, 0.040000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 1, 0}, 5.316820, 0.000240, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, -2, 2, 0}, 169.385290, 0.000020, 0.564000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -2, 0}, 169.693060, 0.000060, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, -1, 0}, 169.082180, 0.001200, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 1, 0}, 349.082180, 0.001200, 0.075000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 0, 2, 0}, 349.693430, 0.000060, 0.038000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -2, 0}, 349.384600, 0.000020, 0.563000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, -1, 0}, 185.188010, 0.000250, 0.087000},
	{{0, 0, 0, 0, 2, -5, 0, 0, 2, 0, 0}, 221.322880, 0.000140, 0.040000},
	{{0, 0, 0, 0, 2, 0, 0, 0, -2, 0, 0}, 45.925890, 0.000040, 0.041000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, -1, 0}, 326.499310, 0.000050, 0.076000},
	{{0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 0}, 146.499310, 0.000050, 0.074000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, -2, 0}, 32.939420, 0.000020, 0.020000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 0, 0}, 213.438840, 0.000160, 0.041000},
	{{0, 0, 0, 1, 0, 0, 0, 0, -2, 2, 0}, 209.497820, 0.000020, 0.434000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0}, 215.917830, 0.000070, 0.079000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0}, 217.855400, 0.000140, 1.881000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0}, 35.917830, 0.000070, 0.073000},
	{{0, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0}, 37.842270, 0.000020, 0.037000},
	{{0, 0, 0, 2, 0, 0, 0, 0, -2, 0, 0}, 155.592630, 0.000030, 0.042000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -2, 0}, 61.853960, 0.000030, 0.039000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 0}, 237.254780, 0.000040, 0.082000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0}, 241.853960, 0.000030, 0.940000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 0}, 57.254780, 0.000040, 0.070000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, -1, -1}, 125.531100, 0.000020, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 1, 1, -1}, 305.531100, 0.000020, 0.075000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -3, 0}, 235.089240, 0.000030, 0.072000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -2, 0}, 59.459560, 0.000040, 1.407000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, -1, 0}, 55.089240, 0.000030, 0.080000},
	{{0, 0, 0, 2, 0, 0, 0, 0, 2, 0, 0}, 59.459560, 0.000040, 0.039000},
	{{0, 0, 0, 3, 0, 0, 0, 0, -2, 1, 0}, 90.959650, 0.000020, 0.101000},
	{{0, 0, 0, 3, 0, 0, 0, 0, -2, 3, 0}, 90.959650, 0.000020, 0.060000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 0, -1, 0}, 90.764550, 0.000020, 0.086000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -3, 0}, 120.706880, 0.000020, 0.074000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, -1, 0}, 87.447600, 0.000200, 0.076000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 2, 0, 0}, 272.904390, 0.000080, 0.038000},
	{{0, 0, 0, 3, 0, 0, 0, 0, 4, -3, 0}, 90.764550, 0.000020, 0.088000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, -1, -2}, 132.428500, 0.000030, 0.076000},
	{{0, 0, 0, 4, 0, 0, 0, 0, 2, 1, -2}, 312.428500, 0.000030, 0.075000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 0, -1, 0}, 341.399280, 0.000030, 0.094000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0}, 161.350460, 0.000050, 0.376000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0}, 161.399280, 0.000030, 0.063000},
	{{0, 0, 0, 5, 0, 0, 0, 0, 2, 0, 0}, 341.399200, 0.000150, 0.037000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0}, 190.462290, 0.000020, 0.313000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0}, 190.462290, 0.000020, 0.034000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 2, -1, 0}, 9.138430, 0.000070, 0.068000},
	{{0, 0, 0, 6, 0, 0, 0, 0, 2, 0, 0}, 189.137140, 0.000070, 0.036000},
	{{0, 0, 0, 8, 0, 0, 0, 0, 2, -1, 0}, 248.397980, 0.000030, 0.064000},
	{{0, 0, 1, -7, 0, 0, 0, 0, -2, 0, 0}, 350.125830, 0.000060, 0.036000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, -2, 0}, 349.461620, 0.000020, 0.034000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, -1, 0}, 349.467900, 0.000030, 0.063000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, 0, 0}, 349.461620, 0.000020, 0.367000},
	{{0, 0, 1, -7, 0, 0, 0, 0, 0, 1, 0}, 169.467900, 0.000030, 0.095000},
	{{0, 0, 1, -6, 0, 0, 0, 0, 0, -1, 0}, 18.499670, 0.000030, 0.065000},
	{{0, 0, 1, -6, 0, 0, 0, 0, 0, 0, 0}, 18.514200, 0.000050, 0.457000},
	{{0, 0, 1, -6, 0, 0, 0, 0, 0, 1, 0}, 198.499670, 0.000030, 0.090000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 1, 0}, 61.575060, 0.000090, 0.076000},
	{{0, 0, 1, -5, 0, 0, 0, 0, -2, 3, 0}, 34.545250, 0.000040, 0.075000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 0, 0}, 264.849260, 0.000100, 0.039000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 1, 0}, 274.469060, 0.000040, 0.079000},
	{{0, 0, 1, -4, 0, 0, 0, 0, -2, 2, 0}, 103.193750, 0.000020, 1.545000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 0, 0}, 120.586010, 0.000060, 0.039000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 1, 0}, 125.197850, 0.000060, 0.083000},
	{{0, 0, 1, -3, 0, 0, 0, 0, -2, 2, 0}, 312.094020, 0.000020, 0.848000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, -1, 0}, 118.247310, 0.000100, 0.072000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 0, 0}, 298.619540, 0.000020, 1.681000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 1, 0}, 298.247310, 0.000100, 0.079000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 0, 2, 0}, 118.619540, 0.000020, 0.039000},
	{{0, 0, 1, -3, 0, 0, 0, 0, 2, 0, 0}, 298.317850, 0.000250, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 0, 0}, 145.306240, 0.000240, 0.040000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 1, 0}, 150.818020, 0.000240, 0.087000},
	{{0, 0, 1, -2, 0, 0, 0, 0, -2, 3, 0}, 333.899070, 0.000020, 0.067000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, -1, 0}, 132.984470, 0.000520, 0.075000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 0, 0}, 148.933940, 0.000090, 15.781000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 1, 0}, 312.929290, 0.000520, 0.076000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 0, 2, 0}, 310.172030, 0.000020, 0.038000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, -1, 0}, 328.388670, 0.000280, 0.088000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 0, 0}, 322.628340, 0.000220, 0.041000},
	{{0, 0, 1, -2, 0, 0, 0, 0, 2, 2, 0}, 147.069400, 0.000020, 0.020000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 0, 0}, 183.702540, 0.000200, 0.041000},
	{{0, 0, 1, -1, 0, 0, 0, 0, -2, 1, 0}, 182.819010, 0.000100, 0.091000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, -2, 0}, 1.869780, 0.000030, 0.038000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0}, 4.869280, 0.000030, 2.135000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, -1, 0}, 356.927970, 0.000050, 0.084000},
	{{0, 0, 1, -1, 0, 0, 0, 0, 2, 0, 0}, 356.369780, 0.000230, 0.040000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 0, 0}, 122.652030, 0.000110, 0.042000},
	{{0, 0, 1, 0, -3, 0, 0, 0, -2, 1, 0}, 122.652060, 0.000040, 0.093000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, -1, 0}, 121.155350, 0.000030, 0.080000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 0, 1, 0}, 301.155350, 0.000030, 0.071000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, -1, 0}, 303.685240, 0.000030, 0.082000},
	{{0, 0, 1, 0, -3, 0, 0, 0, 2, 0, 0}, 303.685240, 0.000030, 0.039000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 0, 0}, 133.916600, 0.000350, 0.042000},
	{{0, 0, 1, 0, -2, 0, 0, 0, -2, 1, 0}, 134.210330, 0.000190, 0.094000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, -1, 0}, 132.587560, 0.000230, 0.080000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 0, 0}, 314.047010, 0.000040, 1.203000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 0, 1, 0}, 312.288040, 0.000190, 0.071000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, -2, 0}, 314.373790, 0.000020, 0.075000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 1, 0, 0}, 314.373790, 0.000020, 0.076000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, -1, 0}, 312.305190, 0.000080, 0.081000},
	{{0, 0, 1, 0, -2, 0, 0, 0, 2, 0, 0}, 312.794130, 0.000140, 0.039000},
	{{0, 0, 1, 0, -1, 0, 0, 0, -2, 0, 0}, 202.458350, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, -2, 0}, 33.062800, 0.000020, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 138.157610, 0.000040, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 219.697110, 0.000090, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -2, 2, 0}, 51.916740, 0.000040, 0.360000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, -1, 1}, 282.417370, 0.000020, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 1}, 111.300720, 0.000050, 0.487000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, -1}, 144.359240, 0.000040, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 1, 1}, 102.417370, 0.000020, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 208.034990, 0.000090, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 28.818970, 0.000100, 1.000000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 28.034990, 0.000090, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0}, 151.428960, 0.000020, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -3, 1}, 263.824650, 0.000020, 0.077000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, -1}, 217.390750, 0.000080, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, -1, 1}, 6.413720, 0.000050, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1}, 232.922050, 0.000050, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 1, 1, -1}, 37.390750, 0.000080, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 106.749430, 0.000020, 0.071000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -2, 0}, 85.595620, 0.000020, 1.292000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 253.341030, 0.000030, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 265.595620, 0.000020, 0.039000},
	{{0, 0, 1, 0, 1, -5, 0, 0, -2, 0, 0}, 198.351930, 0.000030, 0.042000},
	{{0, 0, 1, 0, 1, 0, 0, 0, -2, 0, 0}, 263.944460, 0.000060, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 0, 0}, 254.340260, 0.000200, 0.042000},
	{{0, 0, 1, 0, 2, -5, 0, 0, -2, 1, 0}, 254.340260, 0.000070, 0.095000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, -1, 0}, 253.607360, 0.000070, 0.082000},
	{{0, 0, 1, 0, 2, -5, 0, 0, 0, 1, 0}, 73.607360, 0.000070, 0.070000},
	{{0, 0, 1, 0, 4, 0, 0, 0, 2, -3, 0}, 157.725020, 0.000020, 0.073000},
	{{0, 0, 1, 0, 4, 0, 0, 0, 2, -1, 0}, 337.725020, 0.000020, 0.078000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, -1, 0}, 61.798120, 0.000040, 0.085000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0}, 246.089040, 0.000100, 0.653000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0}, 241.798120, 0.000040, 0.068000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -3, 0}, 37.815950, 0.000020, 0.074000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, -1, 0}, 76.058570, 0.000070, 0.077000},
	{{0, 0, 1, 1, 0, 0, 0, 0, 2, 0, 0}, 231.572150, 0.000060, 0.038000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, -3, 0}, 272.748140, 0.000020, 0.077000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, -1, 0}, 269.676120, 0.000100, 0.074000},
	{{0, 0, 1, 2, 0, 0, 0, 0, 2, 0, 0}, 269.175960, 0.000060, 0.037000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 0}, 312.360030, 0.000030, 0.385000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, -1, 0}, 309.455600, 0.000060, 0.071000},
	{{0, 0, 1, 3, 0, 0, 0, 0, 2, 0, 0}, 129.724210, 0.000030, 0.037000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 0, -1, 0}, 341.267420, 0.000030, 0.099000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 0, 0, 0}, 161.249230, 0.000060, 0.320000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 0, 1, 0}, 161.267420, 0.000030, 0.061000},
	{{0, 0, 1, 4, 0, 0, 0, 0, 2, 0, 0}, 341.312590, 0.000200, 0.036000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 0, 0, 0}, 190.404010, 0.000020, 0.273000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 0, 2, 0}, 190.404010, 0.000020, 0.033000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 2, -2, 0}, 188.464570, 0.000040, 0.531000},
	{{0, 0, 1, 5, 0, 0, 0, 0, 2, 0, 0}, 188.464570, 0.000040, 0.035000},
	{{0, 0, 2, -11, 0, 0, 0, 0, -2, 0, 0}, 82.368510, 0.000040, 0.035000},
	{{0, 0, 2, -8, 0, 0, 0, 0, -2, 0, 0}, 350.021800, 0.000060, 0.037000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, -2, 0}, 349.392860, 0.000020, 0.035000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, -1, 0}, 349.376640, 0.000030, 0.064000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, 0, 0}, 349.392860, 0.000020, 0.444000},
	{{0, 0, 2, -8, 0, 0, 0, 0, 0, 1, 0}, 169.376640, 0.000030, 0.091000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 1, 0}, 25.083040, 0.000150, 0.076000},
	{{0, 0, 2, -7, 0, 0, 0, 0, -2, 3, 0}, 13.341520, 0.000030, 0.075000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 0, -1, 0}, 18.304930, 0.000030, 0.067000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 2, -2, 0}, 31.079660, 0.000020, 0.286000},
	{{0, 0, 2, -7, 0, 0, 0, 0, 2, 0, 0}, 31.079660, 0.000020, 0.043000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 0, 0}, 270.394140, 0.000100, 0.039000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 1, 0}, 270.402850, 0.000100, 0.082000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 2, 0}, 254.583830, 0.000020, 0.896000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -2, 3, 0}, 254.432920, 0.000020, 0.070000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 1, -1}, 292.981140, 0.000030, 0.076000},
	{{0, 0, 2, -5, 0, 0, 0, 0, -1, 3, -1}, 292.981140, 0.000030, 0.075000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, -1, 0}, 95.188620, 0.000040, 0.072000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 0, 0}, 268.661580, 0.000040, 1.519000},
	{{0, 0, 2, -5, 0, 0, 0, 0, 0, 1, 0}, 275.188620, 0.000040, 0.079000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 0, 0}, 121.037110, 0.000150, 0.040000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 1, 0}, 118.348490, 0.000090, 0.086000},
	{{0, 0, 2, -4, 0, 0, 0, 0, -2, 3, 0}, 123.352970, 0.000020, 0.067000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, -1, 0}, 111.840630, 0.000200, 0.075000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 1, 0}, 292.750970, 0.000240, 0.076000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 0, 2, 0}, 118.142030, 0.000030, 0.038000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, -1, 0}, 299.774840, 0.000160, 0.088000},
	{{0, 0, 2, -4, 0, 0, 0, 0, 2, 0, 0}, 297.866410, 0.000370, 0.041000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 0, 0}, 148.686250, 0.000180, 0.041000},
	{{0, 0, 2, -3, 0, 0, 0, 0, -2, 1, 0}, 148.756220, 0.000090, 0.090000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, -1, 0}, 154.130250, 0.000090, 0.078000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 0, 0}, 326.395830, 0.000040, 2.470000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 0, 1, 0}, 334.130250, 0.000090, 0.073000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, -1, 0}, 326.064330, 0.000060, 0.084000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 0, 0}, 326.724490, 0.000260, 0.040000},
	{{0, 0, 2, -3, 0, 0, 0, 0, 2, 2, 0}, 146.849840, 0.000030, 0.019000},
	{{0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 0}, 180.422210, 0.000180, 0.042000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -2, 0}, 2.857820, 0.000030, 0.039000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, -1, 0}, 354.143150, 0.000040, 0.081000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0}, 182.857820, 0.000030, 1.068000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 0, 1, 0}, 174.143150, 0.000040, 0.070000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, -2, 0}, 176.619720, 0.000040, 1.194000},
	{{0, 0, 2, -2, 0, 0, 0, 0, 2, 0, 0}, 356.612680, 0.000080, 0.039000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 0, 0}, 212.773910, 0.000240, 0.043000},
	{{0, 0, 2, -1, 0, 0, 0, 0, -2, 2, 0}, 212.559120, 0.000030, 0.308000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -3, 0}, 34.802580, 0.000020, 0.074000},
	{{0, 0, 2, -1, 0, 0, 0, 0, 2, -1, 0}, 214.802580, 0.000020, 0.077000},
	{{0, 0, 2, 0, -4, 0, 0, 0, -2, 0, 0}, 341.456580, 0.000060, 0.043000},
	{{0, 0, 2, 0, -4, 0, 0, 0, 2, -1, 0}, 339.644630, 0.000120, 0.076000},
	{{0, 0, 2, 0, -4, 5, 0, 0, 2, -1, 0}, 164.546740, 0.000040, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 0, 0}, 333.088320, 0.000210, 0.043000},
	{{0, 0, 2, 0, -3, 0, 0, 0, -2, 1, 0}, 333.088320, 0.000050, 0.103000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, -1, 0}, 329.602570, 0.000400, 0.087000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 0}, 149.871280, 0.000070, 0.572000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 0, 1, 0}, 152.566320, 0.000030, 0.067000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -3, 0}, 150.397330, 0.000060, 0.075000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -2, 0}, 149.310130, 0.000120, 37.133000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, -1, 0}, 329.337770, 0.002250, 0.076000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 2, 0, 0}, 329.338620, 0.000120, 0.038000},
	{{0, 0, 2, 0, -3, 0, 0, 0, 4, -2, 0}, 329.312380, 0.000040, 0.040000},
	{{0, 0, 2, 0, -2, 0, 0, 0, -2, 0, 0}, 40.394870, 0.000060, 0.044000},
	{{0, 0, 2, 0, -2, 0, 0, 0, 2, -1, 0}, 266.547660, 0.000100, 0.075000},
	{{0, 0, 2, 0, 0, -5, 0, 0, -2, 0, 0}, 14.910520, 0.000030, 0.044000},
	{{0, 0, 2, 0, 0, -5, 0, 0, 2, -1, 0}, 194.696840, 0.000050, 0.075000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, -2, 0}, 140.014870, 0.000030, 0.020000},
	{{0, 0, 2, 0, 0, 0, 0, 0, -2, 0, 0}, 155.243800, 0.000110, 0.044000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, -1, 0}, 167.065840, 0.000030, 0.089000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 224.446080, 0.000080, 0.500000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 0}, 347.065840, 0.000030, 0.066000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 85.031140, 0.000020, 0.077000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 272.836130, 0.000150, 0.074000},
	{{0, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 222.908790, 0.000230, 0.037000},
	{{0, 0, 2, 0, 3, 0, 0, 0, 2, -1, 0}, 157.759070, 0.000040, 0.073000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, -3, 0}, 268.361840, 0.000030, 0.080000},
	{{0, 0, 2, 1, 0, 0, 0, 0, 2, -1, 0}, 88.361840, 0.000030, 0.071000},
	{{0, 0, 2, 2, 0, 0, 0, 0, -2, 0, 0}, 118.055570, 0.000020, 0.046000},
	{{0, 0, 2, 2, 0, 0, 0, 0, -2, 2, 0}, 118.055570, 0.000020, 0.207000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 2, -1, 0}, 311.089810, 0.000120, 0.069000},
	{{0, 0, 2, 2, 0, 0, 0, 0, 2, 0, 0}, 131.092550, 0.000120, 0.036000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 0}, 160.927670, 0.000030, 0.278000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 2, -1, 0}, 340.563420, 0.000060, 0.066000},
	{{0, 0, 2, 3, 0, 0, 0, 0, 2, 0, 0}, 341.164500, 0.000190, 0.035000},
	{{0, 0, 3, -12, 0, 0, 0, 0, -2, 0, 0}, 82.225600, 0.000060, 0.036000},
	{{0, 0, 3, -10, 0, 0, 0, 0, 0, 0, 0}, 140.204350, 0.000030, 0.432000},
	{{0, 0, 3, -9, 0, 0, 0, 0, -2, 0, 0}, 357.563850, 0.000060, 0.038000},
	{{0, 0, 3, -9, 0, 0, 0, 0, 0, -1, 0}, 349.231330, 0.000030, 0.066000},
	{{0, 0, 3, -9, 0, 0, 0, 0, 0, 1, 0}, 169.231330, 0.000030, 0.087000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 1, 0}, 19.709170, 0.000040, 0.079000},
	{{0, 0, 3, -8, 0, 0, 0, 0, -2, 3, 0}, 199.709170, 0.000040, 0.073000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, -1, 0}, 18.231980, 0.000050, 0.069000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 0, 1, 0}, 198.231980, 0.000050, 0.083000},
	{{0, 0, 3, -8, 0, 0, 0, 0, 2, 0, 0}, 30.736430, 0.000050, 0.043000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, -1, 0}, 194.867720, 0.000020, 0.070000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 0, 1, 0}, 14.867720, 0.000020, 0.082000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, -1, 0}, 14.927890, 0.000080, 0.095000},
	{{0, 0, 3, -8, 3, 0, 0, 0, 2, 0, 0}, 14.927890, 0.000220, 0.042000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -2, 0, 0}, 239.761960, 0.000100, 0.039000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -2, 1, 0}, 241.504240, 0.000110, 0.082000},
	{{0, 0, 3, -7, 0, 0, 0, 0, -1, 1, -1}, 273.580240, 0.000050, 0.075000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, -1, 0}, 48.182610, 0.000030, 0.072000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 0, 1, 0}, 228.182610, 0.000030, 0.080000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, -3, 0}, 59.523240, 0.000020, 0.063000},
	{{0, 0, 3, -7, 0, 0, 0, 0, 2, -1, 0}, 59.523240, 0.000020, 0.093000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, -1, 0}, 79.814050, 0.000140, 0.074000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 0, 0}, 268.468520, 0.000040, 5.260000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 0, 1, 0}, 259.814050, 0.000140, 0.077000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, -1, 0}, 279.600420, 0.000020, 0.089000},
	{{0, 0, 3, -6, 0, 0, 0, 0, 2, 0, 0}, 269.951060, 0.000080, 0.041000},
	{{0, 0, 3, -5, 0, 0, 0, 0, -2, 0, 0}, 120.893230, 0.000170, 0.041000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, -1, 0}, 138.084970, 0.000060, 0.077000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, -2}, 296.574240, 0.000030, 0.075000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 1, 0}, 318.084970, 0.000060, 0.074000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 0, 3, -2}, 116.574240, 0.000030, 0.075000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -3, 0}, 296.154400, 0.000030, 0.068000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, -1, 0}, 297.020830, 0.000070, 0.085000},
	{{0, 0, 3, -5, 0, 0, 0, 0, 2, 0, 0}, 297.515200, 0.000300, 0.040000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 0, 0}, 144.729420, 0.000240, 0.042000},
	{{0, 0, 3, -4, 0, 0, 0, 0, -2, 1, 0}, 145.356590, 0.000100, 0.094000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -2, 0}, 163.745280, 0.000020, 0.039000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, -1, 0}, 147.482590, 0.000040, 0.081000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 0, 1, 0}, 327.482590, 0.000040, 0.071000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 1, 0, 0}, 326.280530, 0.000030, 0.076000},
	{{0, 0, 3, -4, 0, 0, 0, 0, 2, 0, 0}, 327.205720, 0.000250, 0.039000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 0, 0}, 183.612720, 0.000190, 0.043000},
	{{0, 0, 3, -3, 0, 0, 0, 0, -2, 1, 0}, 183.004430, 0.000040, 0.099000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, -2, 0}, 2.782730, 0.000030, 0.040000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 0, 0, 0}, 182.782730, 0.000030, 0.712000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -3, 0}, 174.600990, 0.000040, 0.073000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, -1, 0}, 174.600990, 0.000040, 0.078000},
	{{0, 0, 3, -3, 0, 0, 0, 0, 2, 0, 0}, 356.127620, 0.000040, 0.038000},
	{{0, 0, 3, -2, 0, 0, 0, 0, -2, 0, 0}, 212.667860, 0.000190, 0.044000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, -1, 0}, 35.587390, 0.000030, 0.088000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 0, 1, 0}, 215.587390, 0.000030, 0.066000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, -1, 0}, 218.102700, 0.000110, 0.075000},
	{{0, 0, 3, -2, 0, 0, 0, 0, 2, 0, 0}, 32.173380, 0.000050, 0.037000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 0, 0, 0}, 241.363960, 0.000040, 0.405000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, -2, 0}, 63.175560, 0.000030, 1.440000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, -1, 0}, 41.038960, 0.000040, 0.072000},
	{{0, 0, 3, -1, 0, 0, 0, 0, 2, 0, 0}, 246.021960, 0.000130, 0.037000},
	{{0, 0, 3, 0, -2, 0, 0, 0, 3, -1, -1}, 284.631910, 0.000070, 0.075000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, -1, 0}, 111.949750, 0.000030, 0.098000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 291.949750, 0.000060, 0.333000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 0, 1, 0}, 291.949750, 0.000030, 0.062000},
	{{0, 0, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 229.832130, 0.000280, 0.036000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 0}, 131.989690, 0.000020, 0.283000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 0, 2, 0}, 131.989690, 0.000020, 0.033000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 2, -1, 0}, 130.196710, 0.000070, 0.067000},
	{{0, 0, 3, 1, 0, 0, 0, 0, 2, 0, 0}, 130.315140, 0.000060, 0.035000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, -2, 0}, 342.191070, 0.000030, 0.437000},
	{{0, 0, 3, 2, 0, 0, 0, 0, 2, 0, 0}, 162.191070, 0.000030, 0.035000},
	{{0, 0, 3, 4, 0, 0, 0, 0, 2, -1, 0}, 219.151530, 0.000040, 0.060000},
	{{0, 0, 3, 5, 0, 0, 0, 0, 2, 0, 0}, 68.039090, 0.000040, 0.033000},
	{{0, 0, 4, -13, 0, 0, 0, 0, -2, 0, 0}, 82.163060, 0.000030, 0.036000},
	{{0, 0, 4, -13, 0, 0, 0, 0, -2, 2, 0}, 262.163060, 0.000030, 0.879000},
	{{0, 0, 4, -11, 0, 0, 0, 0, -2, 1, 0}, 330.987710, 0.000050, 0.075000},
	{{0, 0, 4, -11, 0, 0, 0, 0, 0, -1, 0}, 320.176780, 0.000020, 0.066000},
	{{0, 0, 4, -11, 0, 0, 0, 0, 0, 0, 0}, 140.130260, 0.000030, 0.541000},
	{{0, 0, 4, -11, 0, 0, 0, 0, 0, 1, 0}, 140.176780, 0.000020, 0.088000},
	{{0, 0, 4, -10, 0, 0, 0, 0, -2, 0, 0}, 1.821780, 0.000040, 0.038000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 0, -1, 0}, 349.115090, 0.000040, 0.069000},
	{{0, 0, 4, -10, 0, 0, 0, 0, 0, 1, 0}, 169.115090, 0.000040, 0.084000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, -2, 0}, 210.506410, 0.000030, 0.391000},
	{{0, 0, 4, -9, 0, 0, 0, 0, 2, 0, 0}, 30.506410, 0.000030, 0.042000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 0, 0}, 237.929780, 0.000120, 0.040000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 1, 0}, 234.067820, 0.000030, 0.085000},
	{{0, 0, 4, -8, 0, 0, 0, 0, -2, 3, 0}, 234.067820, 0.000030, 0.068000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, -1, 0}, 62.130100, 0.000080, 0.074000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 0, 1, 0}, 242.130100, 0.000080, 0.077000},
	{{0, 0, 4, -8, 0, 0, 0, 0, 2, 0, 0}, 241.465060, 0.000040, 0.041000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -4, 1, 0}, 91.931480, 0.000040, 0.028000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, -1, 0}, 91.931480, 0.000150, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 0, 0}, 91.970230, 0.001340, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 1, 0}, 92.132350, 0.001310, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, -2, 2, 0}, 272.442980, 0.000060, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -2, 0}, 91.353930, 0.000110, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, -1, 0}, 91.297650, 0.001780, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 1, 0}, 271.297850, 0.001780, 0.075000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 0, 2, 0}, 271.353960, 0.000110, 0.038000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -2, 0}, 92.444410, 0.000060, 0.564000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, -1, 0}, 272.133640, 0.001320, 0.087000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 0, 0}, 271.971250, 0.001340, 0.040000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 2, 1, 0}, 271.932670, 0.000150, 0.026000},
	{{0, 0, 4, -8, 3, 0, 0, 0, 4, -1, 0}, 271.932670, 0.000040, 0.028000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 0, 0}, 88.702570, 0.000050, 0.041000},
	{{0, 0, 4, -7, 0, 0, 0, 0, -2, 2, 0}, 88.702570, 0.000050, 0.487000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, -1, 0}, 88.816990, 0.000040, 0.077000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 0, 0}, 268.455560, 0.000020, 3.594000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 1, 0}, 268.816990, 0.000040, 0.074000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 0, 2, 0}, 268.455560, 0.000020, 0.037000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -2, 0}, 88.279100, 0.000030, 0.669000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, -1, 0}, 268.563660, 0.000060, 0.085000},
	{{0, 0, 4, -7, 0, 0, 0, 0, 2, 0, 0}, 268.279100, 0.000030, 0.040000},
	{{0, 0, 4, -6, 0, 0, 0, 0, -2, 0, 0}, 118.491790, 0.000180, 0.042000},
	{{0, 0, 4, -6, 0, 0, 0, 0, 2, 0, 0}, 297.583680, 0.000280, 0.039000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 0, 0}, 156.055510, 0.000050, 0.745000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 0, 2, 0}, 147.495490, 0.000020, 0.036000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, -3, 0}, 329.200330, 0.000040, 0.073000},
	{{0, 0, 4, -5, 0, 0, 0, 0, 2, 0, 0}, 326.853080, 0.000180, 0.038000},
	{{0, 0, 4, -4, 0, 0, 0, 0, -2, 0, 0}, 182.042150, 0.000160, 0.044000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, -2, 0}, 25.980260, 0.000020, 0.041000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 0, 0, 0}, 205.980260, 0.000020, 0.534000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -3, 0}, 201.316700, 0.000020, 0.076000},
	{{0, 0, 4, -4, 0, 0, 0, 0, 2, -1, 0}, 177.580800, 0.000090, 0.075000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, -2, 0}, 33.002360, 0.000020, 0.041000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, -1, 0}, 32.538690, 0.000030, 0.092000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 0, 0}, 225.909630, 0.000050, 0.416000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 1, 0}, 212.538690, 0.000030, 0.064000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 0, 2, 0}, 57.710240, 0.000020, 0.035000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, -2, 0}, 19.479750, 0.000030, 1.585000},
	{{0, 0, 4, -3, 0, 0, 0, 0, 2, 0, 0}, 199.479750, 0.000030, 0.037000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 0, 0, 0}, 240.993470, 0.000030, 0.341000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, -3, 0}, 247.994730, 0.000030, 0.083000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, -1, 0}, 61.407670, 0.000070, 0.069000},
	{{0, 0, 4, -2, 0, 0, 0, 0, 2, 0, 0}, 244.477780, 0.000130, 0.036000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0}, 120.867890, 0.000050, 0.250000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 0, 2, 0}, 120.867890, 0.000050, 0.033000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, -1, 0}, 287.545570, 0.000070, 0.065000},
	{{0, 0, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 84.757480, 0.000110, 0.035000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 0, -1, 0}, 161.191720, 0.000020, 0.115000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 0, 1, 0}, 341.191720, 0.000020, 0.056000},
	{{0, 0, 4, 1, 0, 0, 0, 0, 2, 0, 0}, 341.351960, 0.000140, 0.034000},
	{{0, 0, 5, -14, 0, 0, 0, 0, -2, 0, 0}, 82.102800, 0.000030, 0.037000},
	{{0, 0, 5, -14, 0, 0, 0, 0, -2, 2, 0}, 262.102800, 0.000030, 1.494000},
	{{0, 0, 5, -13, 0, 0, 0, 0, -2, 1, 0}, 286.442350, 0.000020, 0.075000},
	{{0, 0, 5, -13, 0, 0, 0, 0, -2, 3, 0}, 286.442350, 0.000020, 0.076000},
	{{0, 0, 5, -12, 0, 0, 0, 0, 0, -1, 0}, 320.067520, 0.000030, 0.068000},
	{{0, 0, 5, -12, 0, 0, 0, 0, 0, 1, 0}, 140.067520, 0.000030, 0.084000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -2, 0, 0}, 11.362500, 0.000020, 0.039000},
	{{0, 0, 5, -11, 0, 0, 0, 0, -2, 2, 0}, 11.362500, 0.000020, 1.081000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, -1, 0}, 214.317830, 0.000020, 0.074000},
	{{0, 0, 5, -10, 0, 0, 0, 0, 0, 1, 0}, 34.317830, 0.000020, 0.077000},
	{{0, 0, 5, -9, 0, 0, 0, 0, -2, 1, 0}, 56.153460, 0.000050, 0.089000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, -1, 0}, 235.039120, 0.000070, 0.077000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 0, 1, 0}, 55.039120, 0.000070, 0.074000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, -1, 0}, 239.121930, 0.000030, 0.085000},
	{{0, 0, 5, -9, 0, 0, 0, 0, 2, 0, 0}, 239.470070, 0.000060, 0.040000},
	{{0, 0, 5, -8, 0, 0, 0, 0, -2, 0, 0}, 90.684810, 0.000050, 0.042000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -3, 1}, 191.587430, 0.000020, 0.076000},
	{{0, 0, 5, -8, 0, 0, 0, 0, 1, -1, 1}, 141.866790, 0.000040, 0.075000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 0, 0}, 349.658450, 0.000220, 0.042000},
	{{0, 0, 5, -8, 3, 0, 0, 0, -2, 1, 0}, 349.658450, 0.000080, 0.095000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, -1, 0}, 350.728770, 0.000020, 0.082000},
	{{0, 0, 5, -8, 3, 0, 0, 0, 0, 1, 0}, 170.728770, 0.000020, 0.070000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 0, 0}, 121.526450, 0.000030, 0.043000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 1, 0}, 305.454510, 0.000060, 0.098000},
	{{0, 0, 5, -7, 0, 0, 0, 0, -2, 2, 0}, 301.526450, 0.000030, 0.328000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 0, 0}, 298.013400, 0.000060, 0.782000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 0, 2, 0}, 117.287910, 0.000020, 0.036000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -2, 0}, 120.983170, 0.000030, 2.017000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, -1, 0}, 139.451470, 0.000040, 0.078000},
	{{0, 0, 5, -7, 0, 0, 0, 0, 2, 0, 0}, 297.290540, 0.000200, 0.038000},
	{{0, 0, 5, -6, 0, 0, 0, 0, -2, 0, 0}, 146.375210, 0.000060, 0.044000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, -1, 0}, 157.556290, 0.000060, 0.087000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 0, 0, 0}, 164.142490, 0.000020, 0.553000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -3, 0}, 293.138170, 0.000030, 0.076000},
	{{0, 0, 5, -6, 0, 0, 0, 0, 2, -1, 0}, 157.557600, 0.000350, 0.075000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 0, 0}, 182.101410, 0.000040, 0.045000},
	{{0, 0, 5, -5, 0, 0, 0, 0, -2, 2, 0}, 2.101410, 0.000040, 0.243000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, -2, 0}, 20.499540, 0.000030, 0.041000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 0, 0}, 193.387550, 0.000050, 0.427000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 0, 2, 0}, 2.981490, 0.000020, 0.035000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -3, 0}, 3.011570, 0.000020, 0.079000},
	{{0, 0, 5, -5, 0, 0, 0, 0, 2, -1, 0}, 183.011570, 0.000020, 0.072000},
	{{0, 0, 5, -4, 0, 0, 0, 0, -2, 1, 0}, 32.306070, 0.000050, 0.116000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 0, 0, 0}, 212.624440, 0.000070, 0.348000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, -3, 0}, 45.147260, 0.000020, 0.082000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, -1, 0}, 32.343030, 0.000110, 0.070000},
	{{0, 0, 5, -4, 0, 0, 0, 0, 2, 0, 0}, 204.708810, 0.000080, 0.036000},
	{{0, 0, 5, -3, 0, 0, 0, 0, 2, -1, 0}, 70.065320, 0.000100, 0.067000},
	{{0, 0, 5, -2, 0, 0, 0, 0, -2, 0, 0}, 87.286920, 0.000020, 0.048000},
	{{0, 0, 5, -2, 0, 0, 0, 0, -2, 2, 0}, 267.286920, 0.000020, 0.175000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0}, 160.944840, 0.000040, 0.200000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, -3, 0}, 160.956660, 0.000030, 0.100000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, -1, 0}, 25.378230, 0.000170, 0.061000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 2, 0, 0}, 14.947550, 0.000450, 0.034000},
	{{0, 0, 5, 0, 0, 0, 0, 0, 4, 0, 0}, 18.015100, 0.000040, 0.018000},
	{{0, 0, 6, -16, 0, 0, 0, 0, -2, 1, 0}, 233.054940, 0.000060, 0.071000},
	{{0, 0, 6, -15, 0, 0, 0, 0, -2, 0, 0}, 82.038470, 0.000030, 0.037000},
	{{0, 0, 6, -15, 0, 0, 0, 0, -2, 2, 0}, 262.038470, 0.000030, 4.969000},
	{{0, 0, 6, -14, 0, 0, 0, 0, -2, 1, 0}, 310.758920, 0.000030, 0.077000},
	{{0, 0, 6, -14, 0, 0, 0, 0, -2, 3, 0}, 130.758920, 0.000030, 0.074000},
	{{0, 0, 6, -13, 0, 0, 0, 0, -1, 0, 0}, 319.903970, 0.000030, 0.075000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, -1, 0}, 319.906720, 0.000040, 0.071000},
	{{0, 0, 6, -13, 0, 0, 0, 0, 0, 1, 0}, 139.906720, 0.000040, 0.081000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, -1, 0}, 171.400000, 0.000020, 0.073000},
	{{0, 0, 6, -12, 0, 0, 0, 0, 0, 1, 0}, 351.400000, 0.000020, 0.078000},
	{{0, 0, 6, -11, 0, 0, 0, 0, -2, 0, 0}, 30.571020, 0.000060, 0.041000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, -1, 0}, 208.268810, 0.000020, 0.076000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 0, 1, 0}, 28.268810, 0.000020, 0.075000},
	{{0, 0, 6, -11, 0, 0, 0, 0, 2, 0, 0}, 210.086660, 0.000040, 0.040000},
	{{0, 0, 6, -10, 0, 0, 0, 0, -2, 0, 0}, 59.010060, 0.000030, 0.042000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, -1, 0}, 85.189260, 0.000020, 0.080000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 0, 1, 0}, 265.189260, 0.000020, 0.072000},
	{{0, 0, 6, -10, 0, 0, 0, 0, 2, -1, 0}, 240.272240, 0.000030, 0.082000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 0, 0}, 267.630990, 0.000030, 0.043000},
	{{0, 0, 6, -9, 0, 0, 0, 0, -2, 2, 0}, 87.630990, 0.000030, 0.335000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -3, 0}, 95.181660, 0.000030, 0.072000},
	{{0, 0, 6, -9, 0, 0, 0, 0, 2, -1, 0}, 95.181660, 0.000030, 0.079000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 0, 0}, 120.889660, 0.000060, 0.043000},
	{{0, 0, 6, -8, 0, 0, 0, 0, -2, 2, 0}, 304.011350, 0.000030, 0.284000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, -1, 0}, 320.902390, 0.000060, 0.087000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 0, 0}, 297.541390, 0.000020, 0.573000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 1, 0}, 295.990060, 0.000030, 0.067000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 0, 2, 0}, 297.541390, 0.000020, 0.035000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -3, 0}, 333.241070, 0.000020, 0.075000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -2, 0}, 120.031570, 0.000040, 36.376000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, -1, 0}, 313.695520, 0.000510, 0.076000},
	{{0, 0, 6, -8, 0, 0, 0, 0, 2, 0, 0}, 305.358360, 0.000080, 0.038000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 0, 0}, 152.667330, 0.000050, 0.045000},
	{{0, 0, 6, -7, 0, 0, 0, 0, -2, 1, 0}, 334.492370, 0.000050, 0.109000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 0, 0, 0}, 157.633350, 0.000040, 0.439000},
	{{0, 0, 6, -7, 0, 0, 0, 0, 2, 0, 0}, 326.977720, 0.000030, 0.037000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 0, 0}, 183.959350, 0.000020, 0.046000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 1, 0}, 3.423030, 0.000060, 0.115000},
	{{0, 0, 6, -6, 0, 0, 0, 0, -2, 2, 0}, 3.959350, 0.000020, 0.218000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, -2, 0}, 81.402450, 0.000020, 0.042000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 0, 0, 0}, 196.348270, 0.000090, 0.356000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -3, 0}, 168.666810, 0.000030, 0.082000},
	{{0, 0, 6, -6, 0, 0, 0, 0, 2, -1, 0}, 168.666810, 0.000030, 0.070000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, -1, 0}, 23.377050, 0.000060, 0.067000},
	{{0, 0, 6, -5, 0, 0, 0, 0, 2, 0, 0}, 212.415540, 0.000100, 0.036000},
	{{0, 0, 6, -4, 0, 0, 0, 0, 2, -1, 0}, 72.196930, 0.000090, 0.065000},
	{{0, 0, 6, -3, 0, 0, 0, 0, 2, -3, 0}, 281.222340, 0.000040, 0.094000},
	{{0, 0, 6, -3, 0, 0, 0, 0, 2, -1, 0}, 101.222340, 0.000040, 0.063000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, -3, 0}, 311.388220, 0.000020, 0.099000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, -2, 0}, 311.324500, 0.000020, 0.316000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, -1, 0}, 131.388220, 0.000020, 0.061000},
	{{0, 0, 6, -2, 0, 0, 0, 0, 2, 0, 0}, 132.437200, 0.000070, 0.034000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0}, 316.152280, 0.000040, 0.167000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 2, -1, 0}, 215.053650, 0.000030, 0.057000},
	{{0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 0}, 108.960650, 0.000190, 0.033000},
	{{0, 0, 7, -16, 0, 0, 0, 0, -2, 0, 0}, 81.965220, 0.000070, 0.038000},
	{{0, 0, 7, -16, 0, 0, 0, 0, -2, 1, 0}, 263.371280, 0.000030, 0.077000},
	{{0, 0, 7, -16, 0, 0, 0, 0, -2, 3, 0}, 263.371280, 0.000030, 0.074000},
	{{0, 0, 7, -15, 0, 0, 0, 0, -2, 1, 0}, 111.349140, 0.000040, 0.080000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, -1, 0}, 290.910860, 0.000020, 0.070000},
	{{0, 0, 7, -15, 0, 0, 0, 0, 0, 1, 0}, 110.910860, 0.000020, 0.081000},
	{{0, 0, 7, -14, 0, 0, 0, 0, -2, 1, 0}, 140.223390, 0.000030, 0.084000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 0, 0}, 3.308800, 0.000060, 0.041000},
	{{0, 0, 7, -13, 0, 0, 0, 0, -2, 1, 0}, 153.201840, 0.000030, 0.088000},
	{{0, 0, 7, -13, 0, 0, 0, 0, 2, 0, 0}, 181.148370, 0.000060, 0.040000},
	{{0, 0, 7, -11, 0, 0, 0, 0, -2, 0, 0}, 250.855440, 0.000040, 0.042000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, -1, 0}, 59.217390, 0.000020, 0.083000},
	{{0, 0, 7, -11, 0, 0, 0, 0, 0, 1, 0}, 239.217390, 0.000020, 0.069000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, -1, 0}, 88.438470, 0.000020, 0.086000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 0, 1, 0}, 268.438470, 0.000020, 0.067000},
	{{0, 0, 7, -10, 0, 0, 0, 0, 2, -1, 0}, 248.983110, 0.000120, 0.076000},
	{{0, 0, 7, -9, 0, 0, 0, 0, -2, 0, 0}, 123.575740, 0.000100, 0.044000},
	{{0, 0, 7, -9, 0, 0, 0, 0, 2, 0, 0}, 297.047400, 0.000070, 0.037000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 0, 0}, 158.729990, 0.000060, 0.045000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 1, 0}, 334.390840, 0.000020, 0.114000},
	{{0, 0, 7, -8, 0, 0, 0, 0, -2, 3, 0}, 334.390840, 0.000020, 0.056000},
	{{0, 0, 7, -8, 0, 0, 0, 0, 0, 0, 0}, 156.862180, 0.000040, 0.364000},
	{{0, 0, 7, -7, 0, 0, 0, 0, -2, 0, 0}, 182.522920, 0.000060, 0.047000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -2, 0}, 358.325390, 0.000030, 0.665000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, -1, 0}, 356.356430, 0.000080, 0.068000},
	{{0, 0, 7, -7, 0, 0, 0, 0, 2, 0, 0}, 178.325390, 0.000030, 0.036000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 0, 0, 0}, 212.986860, 0.000060, 0.262000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, -2, 0}, 36.871280, 0.000020, 0.491000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, -1, 0}, 210.348140, 0.000030, 0.065000},
	{{0, 0, 7, -6, 0, 0, 0, 0, 2, 0, 0}, 216.066970, 0.000140, 0.035000},
	{{0, 0, 7, -5, 0, 0, 0, 0, 2, -1, 0}, 72.434560, 0.000100, 0.063000},
	{{0, 0, 7, -4, 0, 0, 0, 0, 2, -1, 0}, 101.228210, 0.000050, 0.061000},
	{{0, 0, 7, -4, 0, 0, 0, 0, 2, 0, 0}, 101.421380, 0.000040, 0.034000},
	{{0, 0, 7, -3, 0, 0, 0, 0, 2, -1, 0}, 131.256720, 0.000040, 0.059000},
	{{0, 0, 7, -3, 0, 0, 0, 0, 2, 0, 0}, 131.528540, 0.000070, 0.033000},
	{{0, 0, 8, -17, 0, 0, 0, 0, -2, 0, 0}, 81.879300, 0.000060, 0.039000},
	{{0, 0, 8, -16, 0, 0, 0, 0, 0, -1, 0}, 290.535280, 0.000020, 0.073000},
	{{0, 0, 8, -16, 0, 0, 0, 0, 0, 1, 0}, 110.535280, 0.000020, 0.078000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 0, 0}, 334.145060, 0.000160, 0.040000},
	{{0, 0, 8, -15, 0, 0, 0, 0, -2, 1, 0}, 344.807890, 0.000090, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, -1, 0}, 325.676520, 0.000250, 0.076000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 0, 1, 0}, 146.441420, 0.000290, 0.075000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, -1, 0}, 154.182380, 0.000150, 0.087000},
	{{0, 0, 8, -15, 0, 0, 0, 0, 2, 0, 0}, 152.157630, 0.000180, 0.040000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 1, 0}, 168.008980, 0.000020, 0.092000},
	{{0, 0, 8, -14, 0, 0, 0, 0, -2, 3, 0}, 168.008980, 0.000020, 0.064000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, -1, 0}, 163.303890, 0.000030, 0.079000},
	{{0, 0, 8, -14, 0, 0, 0, 0, 0, 1, 0}, 343.303890, 0.000030, 0.072000},
	{{0, 0, 8, -13, 0, 0, 0, 0, -2, 0, 0}, 200.372410, 0.000090, 0.042000},
	{{0, 0, 8, -12, 0, 0, 0, 0, -2, 0, 0}, 246.103730, 0.000050, 0.043000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -3, 0}, 95.506060, 0.000040, 0.078000},
	{{0, 0, 8, -11, 0, 0, 0, 0, 2, -1, 0}, 275.506060, 0.000040, 0.073000},
	{{0, 0, 8, -10, 0, 0, 0, 0, -2, 0, 0}, 126.725490, 0.000090, 0.045000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 0, 0, 0}, 297.335250, 0.000030, 0.373000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, -2, 0}, 297.643690, 0.000040, 1.100000},
	{{0, 0, 8, -10, 0, 0, 0, 0, 2, 0, 0}, 297.643690, 0.000040, 0.036000},
	{{0, 0, 8, -9, 0, 0, 0, 0, -2, 0, 0}, 147.584840, 0.000070, 0.046000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 0, 0, 0}, 153.879760, 0.000050, 0.311000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -3, 0}, 144.166420, 0.000020, 0.085000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, -1, 0}, 144.166420, 0.000020, 0.068000},
	{{0, 0, 8, -9, 0, 0, 0, 0, 2, 0, 0}, 323.512050, 0.000040, 0.036000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, -2, 0}, 2.776590, 0.000030, 0.044000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 0, 0, 0}, 182.776590, 0.000030, 0.267000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -3, 0}, 335.808970, 0.000020, 0.089000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -2, 0}, 167.578570, 0.000020, 0.507000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, -1, 0}, 335.808970, 0.000020, 0.066000},
	{{0, 0, 8, -8, 0, 0, 0, 0, 2, 0, 0}, 167.578570, 0.000020, 0.035000},
	{{0, 0, 8, -7, 0, 0, 0, 0, -2, 0, 0}, 211.422010, 0.000030, 0.049000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 0, 0, 0}, 211.479950, 0.000050, 0.234000},
	{{0, 0, 8, -7, 0, 0, 0, 0, 2, 0, 0}, 217.237900, 0.000110, 0.034000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, -3, 0}, 73.467790, 0.000030, 0.098000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, -2, 0}, 71.914240, 0.000060, 0.329000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, -1, 0}, 73.467790, 0.000030, 0.061000},
	{{0, 0, 8, -6, 0, 0, 0, 0, 2, 0, 0}, 250.894330, 0.000030, 0.034000},
	{{0, 0, 8, -5, 0, 0, 0, 0, 2, -2, 0}, 115.089050, 0.000020, 0.280000},
	{{0, 0, 8, -5, 0, 0, 0, 0, 2, 0, 0}, 115.089050, 0.000020, 0.033000},
	{{0, 0, 8, -4, 0, 0, 0, 0, 2, 0, 0}, 130.837450, 0.000060, 0.033000},
	{{0, 0, 9, -19, 0, 0, 0, 0, -2, 1, 0}, 52.849270, 0.000060, 0.079000},
	{{0, 0, 9, -18, 0, 0, 0, 0, -2, 0, 0}, 81.777770, 0.000060, 0.040000},
	{{0, 0, 9, -18, 0, 0, 0, 0, -2, 1, 0}, 81.777770, 0.000050, 0.083000},
	{{0, 0, 9, -18, 0, 0, 0, 0, 0, -1, 0}, 261.777760, 0.000020, 0.072000},
	{{0, 0, 9, -18, 0, 0, 0, 0, 0, 1, 0}, 81.777760, 0.000020, 0.079000},
	{{0, 0, 9, -17, 0, 0, 0, 0, -2, 0, 0}, 303.331630, 0.000050, 0.040000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, -1, 0}, 252.123830, 0.000020, 0.075000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 0, 1, 0}, 72.123830, 0.000020, 0.076000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, -1, 0}, 123.600020, 0.000030, 0.087000},
	{{0, 0, 9, -17, 0, 0, 0, 0, 2, 0, 0}, 123.600020, 0.000060, 0.040000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 0, 0}, 139.893090, 0.000030, 0.041000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 1, 0}, 139.324340, 0.000020, 0.091000},
	{{0, 0, 9, -16, 0, 0, 0, 0, -2, 3, 0}, 139.324340, 0.000020, 0.064000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, -1, 0}, 139.367470, 0.000040, 0.078000},
	{{0, 0, 9, -16, 0, 0, 0, 0, 0, 1, 0}, 319.367470, 0.000040, 0.073000},
	{{0, 0, 9, -15, 0, 0, 0, 0, -2, 0, 0}, 199.885450, 0.000080, 0.042000},
	{{0, 0, 9, -15, 0, 0, 0, 0, 2, -1, 0}, 1.134000, 0.000040, 0.080000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, -2, 0}, 210.162550, 0.000030, 4.596000},
	{{0, 0, 9, -14, 0, 0, 0, 0, 2, 0, 0}, 30.162550, 0.000030, 0.038000},
	{{0, 0, 9, -13, 0, 0, 0, 0, -2, 0, 0}, 257.860880, 0.000050, 0.044000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -3, 0}, 245.900780, 0.000030, 0.077000},
	{{0, 0, 9, -13, 0, 0, 0, 0, 2, -1, 0}, 245.900780, 0.000030, 0.074000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -3, 0}, 88.506310, 0.000040, 0.081000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -2, 0}, 88.731300, 0.000020, 1.182000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, -1, 0}, 88.506310, 0.000040, 0.071000},
	{{0, 0, 9, -12, 0, 0, 0, 0, 2, 0, 0}, 268.731300, 0.000020, 0.037000},
	{{0, 0, 9, -11, 0, 0, 0, 0, -2, 0, 0}, 125.591730, 0.000060, 0.046000},
	{{0, 0, 9, -10, 0, 0, 0, 0, -2, 0, 0}, 152.183830, 0.000110, 0.047000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 0, 0, 0}, 153.746130, 0.000040, 0.272000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -3, 0}, 145.617770, 0.000030, 0.088000},
	{{0, 0, 9, -10, 0, 0, 0, 0, 2, -1, 0}, 325.617770, 0.000030, 0.066000},
	{{0, 0, 9, -9, 0, 0, 0, 0, 0, 0, 0}, 194.387180, 0.000050, 0.237000},
	{{0, 0, 9, -8, 0, 0, 0, 0, 2, 0, 0}, 223.161010, 0.000100, 0.034000},
	{{0, 0, 9, -7, 0, 0, 0, 0, 2, -2, 0}, 71.719530, 0.000040, 0.285000},
	{{0, 0, 9, -7, 0, 0, 0, 0, 2, 0, 0}, 251.719530, 0.000040, 0.033000},
	{{0, 0, 9, -6, 0, 0, 0, 0, 2, -1, 0}, 102.544350, 0.000060, 0.058000},
	{{0, 0, 10, -19, 0, 0, 0, 0, -2, 0, 0}, 81.658160, 0.000060, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 0, 0}, 252.297790, 0.000100, 0.040000},
	{{0, 0, 10, -19, 0, 3, 0, 0, -2, 1, 0}, 252.297790, 0.000060, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, -1, 0}, 72.297790, 0.000060, 0.087000},
	{{0, 0, 10, -19, 0, 3, 0, 0, 2, 0, 0}, 72.297790, 0.000100, 0.040000},
	{{0, 0, 10, -18, 0, 0, 0, 0, -2, 0, 0}, 110.458140, 0.000070, 0.041000},
	{{0, 0, 10, -18, 0, 0, 0, 0, -2, 1, 0}, 290.435320, 0.000030, 0.090000},
	{{0, 0, 10, -18, 0, 0, 0, 0, 0, -1, 0}, 110.429740, 0.000040, 0.078000},
	{{0, 0, 10, -18, 0, 0, 0, 0, 0, 1, 0}, 290.429740, 0.000040, 0.073000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 0, 0}, 139.779730, 0.000030, 0.042000},
	{{0, 0, 10, -17, 0, 0, 0, 0, -2, 2, 0}, 319.779730, 0.000030, 0.366000},
	{{0, 0, 10, -16, 0, 0, 0, 0, -2, 0, 0}, 167.041850, 0.000060, 0.043000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -3, 0}, 211.202990, 0.000020, 0.077000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -2, 0}, 210.124080, 0.000030, 3.989000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, -1, 0}, 29.390530, 0.000060, 0.074000},
	{{0, 0, 10, -15, 0, 0, 0, 0, 2, 0, 0}, 30.124080, 0.000030, 0.037000},
	{{0, 0, 10, -14, 0, 0, 0, 0, -2, 0, 0}, 245.966190, 0.000020, 0.045000},
	{{0, 0, 10, -14, 0, 0, 0, 0, -2, 2, 0}, 245.966190, 0.000020, 0.231000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, -3, 0}, 239.711250, 0.000020, 0.080000},
	{{0, 0, 10, -14, 0, 0, 0, 0, 2, -1, 0}, 59.711250, 0.000020, 0.071000},
	{{0, 0, 10, -12, 0, 0, 0, 0, -2, 0, 0}, 125.321870, 0.000030, 0.047000},
	{{0, 0, 10, -12, 0, 0, 0, 0, -2, 2, 0}, 125.321870, 0.000030, 0.185000},
	{{0, 0, 10, -12, 0, 0, 0, 0, 2, -1, 0}, 117.454700, 0.000030, 0.066000},
	{{0, 0, 10, -11, 0, 0, 0, 0, -2, 0, 0}, 153.167810, 0.000040, 0.049000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 0, 0, 0}, 146.387240, 0.000040, 0.241000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -3, 0}, 324.922400, 0.000030, 0.092000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -2, 0}, 325.128350, 0.000030, 0.421000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, -1, 0}, 324.922400, 0.000030, 0.064000},
	{{0, 0, 10, -11, 0, 0, 0, 0, 2, 0, 0}, 145.128350, 0.000030, 0.035000},
	{{0, 0, 10, -10, 0, 0, 0, 0, 0, 0, 0}, 182.250340, 0.000050, 0.214000},
	{{0, 0, 10, -9, 0, 0, 0, 0, 2, 0, 0}, 223.172630, 0.000100, 0.033000},
	{{0, 0, 10, -8, 0, 0, 0, 0, 2, 0, 0}, 251.745390, 0.000070, 0.033000},
	{{0, 0, 10, -7, 0, 0, 0, 0, 2, -2, 0}, 99.918060, 0.000030, 0.222000},
	{{0, 0, 10, -7, 0, 0, 0, 0, 2, 0, 0}, 279.918060, 0.000030, 0.032000},
	{{0, 0, 10, -6, 0, 0, 0, 0, 2, -1, 0}, 131.321700, 0.000030, 0.055000},
	{{0, 0, 11, -21, 0, 0, 0, 0, -2, 0, 0}, 232.612710, 0.000030, 0.040000},
	{{0, 0, 11, -21, 0, 0, 0, 0, 0, -1, 0}, 232.417520, 0.000020, 0.075000},
	{{0, 0, 11, -21, 0, 0, 0, 0, 0, 1, 0}, 52.417520, 0.000020, 0.076000},
	{{0, 0, 11, -20, 0, 0, 0, 0, -2, 0, 0}, 81.518390, 0.000050, 0.041000},
	{{0, 0, 11, -20, 0, 0, 0, 0, 0, -1, 0}, 81.518380, 0.000030, 0.078000},
	{{0, 0, 11, -20, 0, 0, 0, 0, 0, 1, 0}, 261.518380, 0.000030, 0.073000},
	{{0, 0, 11, -19, 0, 0, 0, 0, -2, 0, 0}, 110.251770, 0.000060, 0.042000},
	{{0, 0, 11, -18, 0, 0, 0, 0, -2, 0, 0}, 138.716840, 0.000070, 0.043000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 2, -3, 0}, 152.051050, 0.000030, 0.074000},
	{{0, 0, 11, -18, 0, 0, 0, 0, 2, -1, 0}, 332.051050, 0.000030, 0.077000},
	{{0, 0, 11, -17, 0, 0, 0, 0, -2, 0, 0}, 166.495220, 0.000020, 0.044000},
	{{0, 0, 11, -17, 0, 0, 0, 0, -2, 2, 0}, 166.495220, 0.000020, 0.268000},
	{{0, 0, 11, -16, 0, 0, 0, 0, 2, 0, 0}, 30.074350, 0.000050, 0.037000},
	{{0, 0, 11, -15, 0, 0, 0, 0, -2, 0, 0}, 247.146020, 0.000030, 0.046000},
	{{0, 0, 11, -15, 0, 0, 0, 0, -2, 2, 0}, 67.146020, 0.000030, 0.208000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, -3, 0}, 87.970540, 0.000030, 0.087000},
	{{0, 0, 11, -14, 0, 0, 0, 0, 2, -1, 0}, 267.970540, 0.000030, 0.066000},
	{{0, 0, 11, -13, 0, 0, 0, 0, -2, 0, 0}, 121.409760, 0.000040, 0.048000},
	{{0, 0, 11, -13, 0, 0, 0, 0, 2, -1, 0}, 296.606460, 0.000040, 0.064000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, -2, 0}, 144.523830, 0.000020, 0.351000},
	{{0, 0, 11, -12, 0, 0, 0, 0, 2, 0, 0}, 144.523830, 0.000020, 0.034000},
	{{0, 0, 11, -10, 0, 0, 0, 0, 2, 0, 0}, 229.562260, 0.000080, 0.033000},
	{{0, 0, 11, -9, 0, 0, 0, 0, 2, 0, 0}, 258.926720, 0.000060, 0.032000},
	{{0, 0, 11, -8, 0, 0, 0, 0, 2, 0, 0}, 281.787850, 0.000050, 0.032000},
	{{0, 0, 12, -26, 0, 0, 0, 0, -2, 1, 0}, 116.869900, 0.000050, 0.075000},
	{{0, 0, 12, -22, 0, 0, 0, 0, -2, 0, 0}, 232.503040, 0.000030, 0.041000},
	{{0, 0, 12, -21, 0, 0, 0, 0, -2, 0, 0}, 81.356540, 0.000020, 0.042000},
	{{0, 0, 12, -21, 0, 0, 0, 0, -2, 2, 0}, 81.356540, 0.000020, 0.383000},
	{{0, 0, 12, -20, 0, 0, 0, 0, -2, 0, 0}, 110.013500, 0.000060, 0.043000},
	{{0, 0, 12, -19, 0, 0, 0, 0, -2, 0, 0}, 138.338880, 0.000050, 0.044000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, -3, 0}, 1.011290, 0.000030, 0.079000},
	{{0, 0, 12, -18, 0, 0, 0, 0, 2, -1, 0}, 181.011290, 0.000030, 0.072000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, -1, 0}, 210.009370, 0.000050, 0.069000},
	{{0, 0, 12, -17, 0, 0, 0, 0, 2, 0, 0}, 30.009370, 0.000040, 0.036000},
	{{0, 0, 12, -16, 0, 0, 0, 0, -2, 0, 0}, 247.065760, 0.000030, 0.047000},
	{{0, 0, 12, -16, 0, 0, 0, 0, -2, 2, 0}, 67.065760, 0.000030, 0.190000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, -2, 0}, 238.960650, 0.000030, 0.582000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, -1, 0}, 238.960650, 0.000050, 0.067000},
	{{0, 0, 12, -16, 0, 0, 0, 0, 2, 0, 0}, 58.960650, 0.000030, 0.035000},
	{{0, 0, 12, -15, 0, 0, 0, 0, -2, 0, 0}, 93.242940, 0.000060, 0.048000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, -2, 0}, 267.780520, 0.000030, 0.444000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, -1, 0}, 267.780520, 0.000040, 0.064000},
	{{0, 0, 12, -15, 0, 0, 0, 0, 2, 0, 0}, 87.780520, 0.000030, 0.035000},
	{{0, 0, 12, -14, 0, 0, 0, 0, -2, 0, 0}, 123.877630, 0.000030, 0.050000},
	{{0, 0, 12, -14, 0, 0, 0, 0, 2, 0, 0}, 116.021890, 0.000040, 0.034000},
	{{0, 0, 12, -11, 0, 0, 0, 0, 2, -2, 0}, 224.290110, 0.000020, 0.228000},
	{{0, 0, 12, -11, 0, 0, 0, 0, 2, 0, 0}, 224.179990, 0.000050, 0.032000},
	{{0, 0, 12, -10, 0, 0, 0, 0, 2, 0, 0}, 252.780220, 0.000040, 0.032000},
	{{0, 0, 12, -9, 0, 0, 0, 0, 2, 0, 0}, 281.613290, 0.000040, 0.031000},
	{{0, 0, 13, -21, 0, 0, 0, 0, -2, 0, 0}, 109.740600, 0.000020, 0.044000},
	{{0, 0, 13, -21, 0, 0, 0, 0, -2, 2, 0}, 109.740600, 0.000020, 0.277000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 2, -3, 0}, 299.685010, 0.000030, 0.076000},
	{{0, 0, 13, -21, 0, 0, 0, 0, 2, -1, 0}, 119.685010, 0.000030, 0.075000},
	{{0, 0, 13, -18, 0, 0, 0, 0, 2, 0, 0}, 29.926140, 0.000040, 0.036000},
	{{0, 0, 13, -17, 0, 0, 0, 0, -2, 0, 0}, 246.964870, 0.000050, 0.048000},
	{{0, 0, 13, -17, 0, 0, 0, 0, 2, 0, 0}, 58.824880, 0.000050, 0.035000},
	{{0, 0, 13, -16, 0, 0, 0, 0, -2, 0, 0}, 94.957710, 0.000040, 0.049000},
	{{0, 0, 13, -16, 0, 0, 0, 0, 2, 0, 0}, 87.548930, 0.000050, 0.034000},
	{{0, 0, 13, -15, 0, 0, 0, 0, -2, 0, 0}, 123.616450, 0.000020, 0.051000},
	{{0, 0, 13, -15, 0, 0, 0, 0, -2, 2, 0}, 303.616450, 0.000020, 0.147000},
	{{0, 0, 13, -15, 0, 0, 0, 0, 2, 0, 0}, 115.820570, 0.000040, 0.034000},
	{{0, 0, 13, -12, 0, 0, 0, 0, 2, 0, 0}, 224.057430, 0.000030, 0.032000},
	{{0, 0, 14, -23, 0, 0, 0, 0, 2, -1, 0}, 46.539890, 0.000040, 0.075000},
	{{0, 0, 14, -21, 0, 0, 0, 0, -2, 0, 0}, 317.382860, 0.000030, 0.046000},
	{{0, 0, 14, -18, 0, 0, 0, 0, -2, 0, 0}, 246.854410, 0.000050, 0.049000},
	{{0, 0, 14, -18, 0, 0, 0, 0, 2, 0, 0}, 58.659250, 0.000040, 0.034000},
	{{0, 0, 14, -17, 0, 0, 0, 0, 2, 0, 0}, 87.272020, 0.000040, 0.034000},
	{{0, 0, 14, -16, 0, 0, 0, 0, -2, 0, 0}, 123.349960, 0.000020, 0.052000},
	{{0, 0, 14, -16, 0, 0, 0, 0, -2, 2, 0}, 123.349960, 0.000020, 0.138000},
	{{0, 0, 14, -12, 0, 0, 0, 0, 2, -2, 0}, 73.092620, 0.000030, 0.171000},
	{{0, 0, 14, -12, 0, 0, 0, 0, 2, 0, 0}, 253.092620, 0.000030, 0.031000},
	{{0, 0, 15, -20, 0, 0, 0, 0, 2, 0, 0}, 29.737390, 0.000030, 0.034000},
	{{0, 0, 15, -19, 0, 0, 0, 0, -2, 0, 0}, 246.719980, 0.000050, 0.050000},
	{{0, 0, 15, -19, 0, 0, 0, 0, 2, -2, 0}, 238.485070, 0.000020, 0.320000},
	{{0, 0, 15, -19, 0, 0, 0, 0, 2, 0, 0}, 58.485070, 0.000020, 0.034000},
	{{0, 0, 15, -13, 0, 0, 0, 0, 2, 0, 0}, 252.843320, 0.000040, 0.030000},
	{{0, 0, 15, -12, 0, 0, 0, 0, 2, -2, 0}, 101.640010, 0.000020, 0.146000},
	{{0, 0, 15, -12, 0, 0, 0, 0, 2, 0, 0}, 281.640010, 0.000020, 0.030000},
	{{0, 0, 16, -20, 0, 0, 0, 0, -2, 0, 0}, 246.564470, 0.000020, 0.052000},
	{{0, 0, 16, -20, 0, 0, 0, 0, -2, 2, 0}, 246.564470, 0.000020, 0.140000},
	{{0, 0, 16, -20, 0, 0, 0, 0, 2, 0, 0}, 58.249440, 0.000030, 0.033000},
	{{0, 0, 17, -20, 0, 0, 0, 0, -2, 0, 0}, 274.987760, 0.000030, 0.054000},
	{{0, 0, 17, -20, 0, 0, 0, 0, -2, 2, 0}, 94.987760, 0.000030, 0.123000},
	{{0, 0, 18, -21, 0, 0, 0, 0, -2, 0, 0}, 274.700380, 0.000050, 0.056000},
	{{0, 0, 18, -20, 0, 0, 0, 0, -2, 0, 0}, 302.831220, 0.000030, 0.058000},
	{{0, 0, 18, -20, 0, 0, 0, 0, -2, 2, 0}, 122.831220, 0.000030, 0.109000},
	{{0, 0, 19, -21, 0, 0, 0, 0, -2, 0, 0}, 302.337670, 0.000020, 0.059000},
	{{0, 0, 19, -21, 0, 0, 0, 0, -2, 2, 0}, 302.337670, 0.000020, 0.104000},
	{{0, 0, 37, -48, 0, 0, 0, 0, -2, 0, 0}, 222.295500, 0.000020, 0.075000},
	{{0, 0, 37, -48, 0, 0, 0, 0, -2, 2, 0}, 42.295500, 0.000020, 0.075000},
	{{0, 1, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 71.069900, 0.000200, 0.033000},
	{{0, 1, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 252.048540, 0.000050, 0.186000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 160.472710, 0.000060, 0.019000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 160.210610, 0.000190, 0.063000},
	{{0, 1, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 8.359580, 0.000040, 0.385000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 106.098450, 0.000050, 0.036000},
	{{0, 1, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 295.973350, 0.000050, 0.067000},
	{{0, 1, -5, 0, 0, 0, 0, 0, 0, -2, 0}, 69.421810, 0.000020, 0.033000},
	{{0, 1, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 69.421810, 0.000020, 0.296000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 302.738180, 0.000210, 0.037000},
	{{0, 1, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 141.855380, 0.000060, 0.072000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 257.942210, 0.000020, 0.035000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 244.419350, 0.000020, 0.064000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 257.942210, 0.000020, 0.421000},
	{{0, 1, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 64.419350, 0.000020, 0.092000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 61.657730, 0.000070, 0.078000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, -1, 1}, 28.162970, 0.000030, 0.074000},
	{{0, 1, -3, 0, 0, 0, 0, 0, -1, 1, 1}, 208.162970, 0.000030, 0.077000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 331.217950, 0.000040, 0.068000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 151.217950, 0.000040, 0.084000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 159.640380, 0.000030, 0.061000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 159.640380, 0.000030, 0.099000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 17.442400, 0.000080, 0.043000},
	{{0, 1, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 18.218080, 0.000030, 0.020000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 115.707130, 0.000440, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 75.689380, 0.000040, 0.084000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, -1, 1}, 270.386290, 0.000020, 0.080000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 0, 1}, 67.776810, 0.000030, 1.472000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, -1}, 115.957760, 0.000040, 0.077000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 1, 1}, 90.386290, 0.000020, 0.072000},
	{{0, 1, -2, 0, 0, 0, 0, 0, -1, 2, 1}, 273.984630, 0.000020, 0.037000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -3, 2}, 289.488080, 0.000020, 0.075000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 42.948390, 0.000020, 0.073000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, -1, 2}, 101.555140, 0.000060, 0.076000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 179.296120, 0.000030, 2.670000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 222.948390, 0.000020, 0.078000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -2, 1}, 167.484860, 0.000020, 0.913000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 293.704080, 0.000030, 0.068000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 311.860210, 0.000060, 0.082000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 270.581180, 0.000080, 0.700000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 0, 1}, 347.484860, 0.000020, 0.039000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 113.704080, 0.000030, 0.085000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 1, 2, -1}, 90.115530, 0.000030, 0.040000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 295.603180, 0.000040, 0.090000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 281.294470, 0.000030, 0.041000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, -2, 0}, 288.116140, 0.000020, 0.044000},
	{{0, 1, -2, 0, 0, 0, 0, 0, 4, 0, 0}, 108.116140, 0.000020, 0.020000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 171.535840, 0.000190, 0.041000},
	{{0, 1, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 0.248260, 0.000090, 0.092000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 191.615130, 0.000050, 0.079000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 18.308330, 0.000090, 1.599000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 11.615130, 0.000050, 0.072000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 207.309130, 0.000060, 0.083000},
	{{0, 1, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 218.784240, 0.000040, 0.039000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -4, 0, 0}, 249.600290, 0.000050, 0.021000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 108.644020, 0.000030, 0.043000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 1, 0}, 73.200480, 0.000260, 0.101000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 2, 0}, 178.228540, 0.000030, 0.294000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -2, 3, 0}, 281.602930, 0.000030, 0.060000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, -1, 1}, 89.885290, 0.000020, 0.095000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, -1}, 190.668090, 0.000050, 0.041000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 1}, 269.885290, 0.000020, 0.373000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 1, 1}, 269.885290, 0.000020, 0.063000},
	{{0, 1, 0, 0, 0, 0, 0, 0, -1, 2, 1}, 269.885290, 0.000020, 0.034000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 195.586660, 0.000040, 0.086000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 22.003170, 0.000030, 0.615000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 15.586660, 0.000040, 0.067000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 90.106290, 0.000130, 0.076000},
	{{0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 239.686880, 0.000270, 0.038000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, -2, 0}, 161.871000, 0.000020, 0.021000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 0, 0}, 162.589520, 0.000080, 0.045000},
	{{0, 1, 1, 0, 0, 0, 0, 0, -2, 1, 0}, 8.996840, 0.000040, 0.113000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 189.742820, 0.000090, 0.381000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 352.274630, 0.000020, 0.081000},
	{{0, 1, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 352.274630, 0.000020, 0.071000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 181.313380, 0.000060, 0.066000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 266.090320, 0.000180, 0.035000},
	{{0, 1, 2, 0, 0, 0, 0, 0, 2, 2, 0}, 275.524920, 0.000030, 0.018000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 110.341090, 0.000050, 0.216000},
	{{0, 1, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 302.382700, 0.000200, 0.034000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 13.544020, 0.000020, 0.033000},
	{{0, 1, 4, 0, 0, 0, 0, 0, 2, 2, 0}, 193.544020, 0.000020, 0.018000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 2, -1, 0}, 317.249130, 0.000040, 0.055000},
	{{0, 1, 5, 0, 0, 0, 0, 0, 2, 0, 0}, 326.776350, 0.000100, 0.032000},
	{{0, 1, 6, 0, 0, 0, 0, 0, 2, -2, 0}, 216.184340, 0.000030, 0.171000},
	{{0, 1, 6, 0, 0, 0, 0, 0, 2, 0, 0}, 36.184340, 0.000030, 0.031000},
	{{0, 2, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 71.119800, 0.000210, 0.034000},
	{{0, 2, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 71.511050, 0.000030, 0.032000},
	{{0, 2, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 251.511050, 0.000030, 0.211000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -4, 0, 0}, 160.429180, 0.000050, 0.019000},
	{{0, 2, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 160.209320, 0.000180, 0.066000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 346.447440, 0.000020, 0.059000},
	{{0, 2, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 166.447440, 0.000020, 0.105000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 137.905970, 0.000030, 0.036000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 319.721410, 0.000020, 0.070000},
	{{0, 2, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 139.721410, 0.000020, 0.081000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 303.175330, 0.000190, 0.038000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 254.254670, 0.000030, 0.076000},
	{{0, 2, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 191.328180, 0.000020, 0.075000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 238.897880, 0.000040, 0.572000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 79.933040, 0.000020, 0.284000},
	{{0, 2, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 259.933040, 0.000020, 0.044000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 19.634880, 0.000040, 0.039000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 355.395850, 0.000070, 0.082000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, -1, 1}, 210.036000, 0.000020, 0.077000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, -1}, 147.075770, 0.000020, 0.075000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 1, 1}, 30.036000, 0.000020, 0.074000},
	{{0, 2, -4, 0, 0, 0, 0, 0, -1, 3, -1}, 327.075770, 0.000020, 0.076000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 69.709470, 0.000030, 0.071000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 249.709470, 0.000030, 0.080000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 324.347840, 0.000030, 0.063000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 144.347840, 0.000030, 0.093000},
	{{0, 2, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 36.947400, 0.000140, 0.042000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 115.648690, 0.000070, 0.026000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 21.439230, 0.000300, 0.041000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 102.761930, 0.000340, 0.089000},
	{{0, 2, -3, 0, 0, 0, 0, 0, -2, 2, 0}, 229.808340, 0.000020, 0.494000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 84.844270, 0.000020, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 108.272030, 0.000510, 0.077000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 214.015640, 0.000060, 3.983000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 288.362690, 0.000470, 0.074000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 287.731170, 0.000020, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, -1}, 261.602830, 0.000020, 0.037000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -2, 1}, 253.719540, 0.000020, 2.131000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, -1, -1}, 72.692590, 0.000040, 0.071000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 267.457580, 0.000070, 1.246000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 0, 1}, 15.057760, 0.000040, 0.038000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 1, 1, -1}, 252.692590, 0.000040, 0.080000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 132.239620, 0.000020, 0.068000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 231.331430, 0.000020, 0.657000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 287.191420, 0.000460, 0.085000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 287.341070, 0.000190, 0.040000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 2, 2, 0}, 107.019680, 0.000020, 0.019000},
	{{0, 2, -3, 0, 0, 0, 0, 0, 4, 0, 0}, 108.172970, 0.000050, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, -2, 0}, 343.296250, 0.000030, 0.020000},
	{{0, 2, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 143.889840, 0.000100, 0.043000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, -2, 0}, 196.294910, 0.000030, 0.040000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 47.682620, 0.000020, 0.799000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 79.605300, 0.000030, 1.912000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 223.435830, 0.000090, 0.079000},
	{{0, 2, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 259.605300, 0.000030, 0.038000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -4, 0, 0}, 72.099210, 0.000050, 0.021000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 234.935270, 0.000220, 0.044000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -2, 1, 0}, 250.513290, 0.000350, 0.108000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 0, 1}, 269.885120, 0.000060, 0.303000},
	{{0, 2, -1, 0, 0, 0, 0, 0, -1, 1, -1}, 269.885110, 0.000050, 0.097000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, -1, 0}, 129.927180, 0.000060, 0.091000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 3.342130, 0.000060, 0.444000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 0, 1, 0}, 349.399920, 0.000050, 0.064000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, -2, 1}, 155.223810, 0.000020, 0.653000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 1, 0, 1}, 155.223810, 0.000020, 0.036000},
	{{0, 2, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 229.174310, 0.000210, 0.037000},
	{{0, 2, 0, 0, 0, 0, 0, 0, -2, 0, 0}, 162.743790, 0.000050, 0.047000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, -1, 0}, 161.802000, 0.000030, 0.100000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 32.243490, 0.000040, 0.308000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 341.802000, 0.000030, 0.061000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 355.755070, 0.000030, 0.085000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 99.273090, 0.000060, 0.068000},
	{{0, 2, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 262.221090, 0.000070, 0.036000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 98.415560, 0.000040, 0.111000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 305.289450, 0.000040, 0.235000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 278.415560, 0.000040, 0.057000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, -3, 0}, 164.267740, 0.000020, 0.093000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, -1, 0}, 164.267740, 0.000020, 0.064000},
	{{0, 2, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 203.471640, 0.000260, 0.034000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 110.291900, 0.000050, 0.190000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 151.497540, 0.000020, 0.102000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -2, 0}, 225.029140, 0.000020, 0.288000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 151.497540, 0.000020, 0.060000},
	{{0, 2, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 297.129990, 0.000180, 0.033000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0}, 19.790040, 0.000030, 0.160000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, -1, 0}, 19.695750, 0.000230, 0.056000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 13.543840, 0.000020, 0.032000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 1, 0}, 199.384140, 0.000050, 0.023000},
	{{0, 2, 3, 0, 0, 0, 0, 0, 2, 2, 0}, 193.543840, 0.000020, 0.017000},
	{{0, 2, 4, 0, 0, 0, 0, 0, 2, -2, 0}, 323.620100, 0.000030, 0.183000},
	{{0, 2, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 143.620100, 0.000030, 0.031000},
	{{0, 2, 5, 0, 0, 0, 0, 0, 2, -2, 0}, 215.144790, 0.000020, 0.154000},
	{{0, 2, 5, 0, 0, 0, 0, 0, 2, 0, 0}, 35.144790, 0.000020, 0.030000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 71.179060, 0.000210, 0.035000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 57.300830, 0.000030, 0.064000},
	{{0, 3, -9, 0, 0, 0, 0, 0, -2, 3, 0}, 237.300830, 0.000030, 0.092000},
	{{0, 3, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 71.526310, 0.000030, 0.033000},
	{{0, 3, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 251.526310, 0.000030, 0.243000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -4, 0, 0}, 160.388720, 0.000030, 0.019000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -4, 2, 0}, 160.388720, 0.000030, 0.038000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 161.763660, 0.000150, 0.036000},
	{{0, 3, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 160.206560, 0.000180, 0.068000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 346.441110, 0.000020, 0.061000},
	{{0, 3, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 166.441110, 0.000020, 0.099000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, -1, 2}, 227.637460, 0.000040, 0.075000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 137.607580, 0.000030, 0.037000},
	{{0, 3, -7, 0, 0, 0, 0, 0, -2, 1, 2}, 47.637460, 0.000040, 0.076000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 60.170140, 0.000020, 0.065000},
	{{0, 3, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 240.170140, 0.000020, 0.090000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 319.076130, 0.000180, 0.039000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 278.622690, 0.000040, 0.079000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 335.610280, 0.000020, 1.537000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, -1, 1}, 122.000660, 0.000030, 0.075000},
	{{0, 3, -6, 0, 0, 0, 0, 0, -1, 1, 1}, 302.000660, 0.000030, 0.076000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 57.278480, 0.000020, 0.036000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 237.278480, 0.000020, 0.890000},
	{{0, 3, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 238.467940, 0.000050, 0.042000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 301.039260, 0.000170, 0.040000},
	{{0, 3, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 289.434330, 0.000110, 0.086000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 305.135740, 0.000180, 0.075000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 305.811560, 0.000030, 8.102000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 125.135740, 0.000180, 0.076000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 63.854400, 0.000020, 0.527000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 98.659620, 0.000120, 0.088000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 90.354270, 0.000130, 0.041000},
	{{0, 3, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 42.797540, 0.000030, 0.020000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, -1, 0}, 118.115210, 0.000020, 0.027000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 108.977030, 0.000390, 0.042000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 92.455170, 0.000180, 0.094000},
	{{0, 3, -4, 0, 0, 0, 0, 0, -1, 0, 0}, 280.895670, 0.000060, 0.087000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 101.640240, 0.000300, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 203.436120, 0.000050, 1.141000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 282.587810, 0.000260, 0.071000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -2, 0}, 115.617550, 0.000030, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, -1, 1}, 45.938210, 0.000040, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 270.114050, 0.000040, 5.644000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 0}, 281.166730, 0.000350, 0.075000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 31.902290, 0.000050, 0.037000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 291.467270, 0.000190, 0.081000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 290.134980, 0.000020, 0.039000},
	{{0, 3, -4, 0, 0, 0, 0, 0, 4, 0, 0}, 108.221050, 0.000040, 0.020000},
	{{0, 3, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 350.039350, 0.000150, 0.044000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 192.932140, 0.000040, 0.041000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 154.386320, 0.000150, 0.075000},
	{{0, 3, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 256.419680, 0.000050, 0.038000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 243.122090, 0.000530, 0.046000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 251.595720, 0.000450, 0.116000},
	{{0, 3, -2, 0, 0, 0, 0, 0, -1, 0, -1}, 106.716800, 0.000070, 0.044000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 56.609870, 0.000040, 0.096000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 335.872610, 0.000060, 0.348000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 236.609870, 0.000040, 0.062000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -3, 1}, 234.112320, 0.000020, 0.090000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, -1}, 54.110390, 0.000020, 0.087000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, -1, 1}, 54.112320, 0.000020, 0.065000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 0, -1}, 204.990350, 0.000040, 0.549000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 1, 1, -1}, 234.110390, 0.000020, 0.066000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 308.414200, 0.000040, 0.907000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 243.657920, 0.000400, 0.036000},
	{{0, 3, -2, 0, 0, 0, 0, 0, 3, -1, -1}, 335.371570, 0.000040, 0.075000},
	{{0, 3, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 83.720730, 0.000060, 0.048000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, -1, 0}, 81.507230, 0.000050, 0.065000},
	{{0, 3, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 291.040370, 0.000060, 0.035000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 289.708020, 0.000030, 0.205000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 76.760140, 0.000060, 0.061000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 236.194700, 0.000450, 0.034000},
	{{0, 3, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 108.895490, 0.000020, 0.018000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 110.264930, 0.000060, 0.170000},
	{{0, 3, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 290.649140, 0.000200, 0.033000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0}, 193.544230, 0.000050, 0.145000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 16.426460, 0.000220, 0.032000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 2, 2, 0}, 13.544260, 0.000020, 0.017000},
	{{0, 3, 2, 0, 0, 0, 0, 0, 4, 0, 0}, 18.820590, 0.000050, 0.018000},
	{{0, 3, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 282.712200, 0.000040, 0.031000},
	{{0, 3, 4, 0, 0, 0, 0, 0, 2, 0, 0}, 36.108070, 0.000040, 0.030000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 71.241330, 0.000210, 0.035000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 77.606810, 0.000020, 0.067000},
	{{0, 4, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 257.606810, 0.000020, 0.087000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 71.547580, 0.000030, 0.033000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 251.547580, 0.000030, 0.060000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 251.547580, 0.000030, 0.286000},
	{{0, 4, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 71.547580, 0.000030, 0.102000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -4, 0, 0}, 160.350890, 0.000020, 0.019000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -4, 2, 0}, 160.350890, 0.000020, 0.039000},
	{{0, 4, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 161.491810, 0.000140, 0.037000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 145.471220, 0.000020, 0.034000},
	{{0, 4, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 325.471220, 0.000020, 0.400000},
	{{0, 4, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 57.822120, 0.000030, 0.077000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 57.460610, 0.000030, 0.068000},
	{{0, 4, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 237.460610, 0.000030, 0.085000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 307.185810, 0.000400, 0.040000},
	{{0, 4, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 182.392340, 0.000060, 0.083000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 314.593840, 0.000040, 0.073000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 134.593840, 0.000040, 0.078000},
	{{0, 4, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 106.011950, 0.000040, 0.091000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 324.321590, 0.000070, 0.041000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 274.686240, 0.000020, 0.091000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 2, 0}, 165.555030, 0.000030, 0.439000},
	{{0, 4, -6, 0, 0, 0, 0, 0, -2, 3, 0}, 94.686240, 0.000020, 0.064000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 344.567560, 0.000080, 0.078000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 321.438400, 0.000040, 1.992000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 164.567560, 0.000080, 0.073000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 1, -1, 1}, 126.649220, 0.000040, 0.077000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 197.149150, 0.000200, 0.040000},
	{{0, 4, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 18.491900, 0.000030, 0.019000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 288.840540, 0.000220, 0.043000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 293.865320, 0.000020, 0.100000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 66.329270, 0.000020, 0.305000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -2, 3, 0}, 113.865320, 0.000020, 0.060000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 0, -1}, 20.763550, 0.000020, 0.041000},
	{{0, 4, -5, 0, 0, 0, 0, 0, -1, 2, -1}, 200.763550, 0.000020, 0.450000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 54.421270, 0.000080, 0.085000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 187.405760, 0.000050, 0.666000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 211.274600, 0.000050, 0.068000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 82.690470, 0.000030, 0.036000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, -1}, 336.720780, 0.000020, 0.078000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, -1, 1}, 231.136880, 0.000060, 0.071000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, -1}, 270.111290, 0.000020, 2.231000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 0, 1}, 31.101250, 0.000040, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 1, -1}, 156.720780, 0.000020, 0.073000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 1, 2, -1}, 270.111290, 0.000020, 0.037000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 38.076900, 0.000100, 0.077000},
	{{0, 4, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 319.145730, 0.000060, 0.038000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 344.262290, 0.000100, 0.045000},
	{{0, 4, -4, 0, 0, 0, 0, 0, -2, 2, 0}, 13.796290, 0.000020, 0.234000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 181.331610, 0.000030, 0.042000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 165.236520, 0.000020, 0.400000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 143.515070, 0.000060, 0.072000},
	{{0, 4, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 273.914090, 0.000040, 0.037000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 241.269040, 0.000260, 0.047000},
	{{0, 4, -3, 0, 0, 0, 0, 0, -2, 1, 0}, 251.886010, 0.000460, 0.125000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 8.034690, 0.000020, 0.103000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 1.946800, 0.000030, 0.286000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 188.034690, 0.000020, 0.060000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 0, 2, 0}, 1.946800, 0.000030, 0.033000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 1, 0, -1}, 204.102180, 0.000040, 0.408000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -3, 0}, 291.901020, 0.000020, 0.087000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 291.901020, 0.000020, 0.067000},
	{{0, 4, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 234.093080, 0.000190, 0.035000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 0, 0}, 339.384000, 0.000140, 0.049000},
	{{0, 4, -2, 0, 0, 0, 0, 0, -2, 1, 0}, 151.725280, 0.000040, 0.143000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -3, 0}, 146.259970, 0.000030, 0.095000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -2, 0}, 135.731260, 0.000030, 0.367000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 326.259970, 0.000030, 0.063000},
	{{0, 4, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 302.927250, 0.000070, 0.034000},
	{{0, 4, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 243.883870, 0.000280, 0.033000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 109.718890, 0.000040, 0.154000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 323.653640, 0.000020, 0.212000},
	{{0, 4, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 293.714250, 0.000210, 0.032000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 13.544690, 0.000020, 0.031000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 2, 2, 0}, 193.544690, 0.000020, 0.017000},
	{{0, 4, 1, 0, 0, 0, 0, 0, 4, 0, 0}, 18.015560, 0.000030, 0.018000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, -3, 0}, 303.435900, 0.000020, 0.153000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, -1, 0}, 303.435900, 0.000020, 0.050000},
	{{0, 4, 2, 0, 0, 0, 0, 0, 2, 0, 0}, 312.195340, 0.000050, 0.030000},
	{{0, 4, 3, 0, 0, 0, 0, 0, 2, 0, 0}, 37.004800, 0.000030, 0.029000},
	{{0, 5, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 330.326510, 0.000040, 0.065000},
	{{0, 5, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 71.302820, 0.000210, 0.036000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 251.571560, 0.000030, 0.062000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 251.571560, 0.000060, 0.348000},
	{{0, 5, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 71.571560, 0.000030, 0.096000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 148.243890, 0.000020, 0.075000},
	{{0, 5, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 148.243890, 0.000020, 0.076000},
	{{0, 5, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 324.685380, 0.000040, 0.534000},
	{{0, 5, -9, 0, 0, 0, 0, 0, -1, 0, 0}, 46.486350, 0.000060, 0.076000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 34.188550, 0.000030, 0.071000},
	{{0, 5, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 214.188550, 0.000030, 0.081000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 306.986320, 0.000360, 0.041000},
	{{0, 5, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 322.473040, 0.000040, 0.088000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 12.466650, 0.000040, 0.076000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 192.466650, 0.000040, 0.075000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 295.409060, 0.000030, 0.067000},
	{{0, 5, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 115.409060, 0.000030, 0.086000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 47.470980, 0.000080, 0.042000},
	{{0, 5, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 192.646670, 0.000050, 0.097000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 176.925220, 0.000070, 0.082000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 332.234670, 0.000030, 0.887000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 356.925220, 0.000070, 0.070000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -3, 1}, 1.146060, 0.000030, 0.078000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, -1}, 135.400230, 0.000030, 0.076000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 181.146060, 0.000030, 0.073000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 1, 1, -1}, 315.400230, 0.000030, 0.075000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -3, 0}, 251.677280, 0.000020, 0.072000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 71.677280, 0.000020, 0.079000},
	{{0, 5, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 199.555110, 0.000220, 0.039000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -2, 1, 0}, 347.534010, 0.000050, 0.107000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 0, -1}, 20.258650, 0.000020, 0.042000},
	{{0, 5, -6, 0, 0, 0, 0, 0, -1, 2, -1}, 200.258650, 0.000020, 0.351000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 190.068460, 0.000030, 0.041000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 353.411960, 0.000030, 0.090000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 241.372090, 0.000070, 0.470000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 173.411960, 0.000030, 0.065000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 30.452060, 0.000030, 0.036000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, -2}, 106.754910, 0.000070, 0.076000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 270.895870, 0.000170, 0.073000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 94.854430, 0.000070, 0.037000},
	{{0, 5, -6, 0, 0, 0, 0, 0, 2, 1, -2}, 286.754910, 0.000070, 0.075000},
	{{0, 5, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 345.574800, 0.000110, 0.046000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 343.057650, 0.000020, 0.099000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 29.718860, 0.000020, 0.320000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 163.057650, 0.000020, 0.061000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 29.718860, 0.000020, 0.034000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 87.728570, 0.000040, 0.068000},
	{{0, 5, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 267.729190, 0.000040, 0.036000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 244.943830, 0.000270, 0.049000},
	{{0, 5, -4, 0, 0, 0, 0, 0, -2, 1, 0}, 252.364980, 0.000430, 0.136000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 91.709470, 0.000030, 0.110000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 271.709470, 0.000030, 0.058000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, -1}, 203.362230, 0.000040, 0.325000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 1, 0, 1}, 216.059890, 0.000030, 0.033000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 113.945370, 0.000020, 0.092000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 10.863090, 0.000060, 0.064000},
	{{0, 5, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 231.972900, 0.000160, 0.035000},
	{{0, 5, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 164.261030, 0.000040, 0.051000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 325.740310, 0.000030, 0.060000},
	{{0, 5, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 288.432310, 0.000050, 0.033000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 0, -1, 0}, 56.281510, 0.000020, 0.140000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 0, 1, 0}, 236.281510, 0.000020, 0.052000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, -1, 0}, 358.671820, 0.000050, 0.057000},
	{{0, 5, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 254.271610, 0.000400, 0.032000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 0, 0, 0}, 109.751940, 0.000040, 0.140000},
	{{0, 5, -1, 0, 0, 0, 0, 0, 2, 0, 0}, 293.716500, 0.000210, 0.031000},
	{{0, 5, 1, 0, 0, 0, 0, 0, 2, 0, 0}, 313.656440, 0.000040, 0.030000},
	{{0, 6, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 330.305790, 0.000030, 0.068000},
	{{0, 6, -13, 0, 0, 0, 0, 0, -2, 3, 0}, 150.305790, 0.000030, 0.085000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 71.361410, 0.000200, 0.037000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 262.058110, 0.000020, 0.073000},
	{{0, 6, -12, 0, 0, 0, 0, 0, -2, 3, 0}, 262.058110, 0.000020, 0.078000},
	{{0, 6, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 251.596130, 0.000060, 0.445000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, -1, 0}, 340.280690, 0.000040, 0.025000},
	{{0, 6, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 217.148790, 0.000040, 0.079000},
	{{0, 6, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 323.841670, 0.000030, 0.802000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 210.192270, 0.000020, 0.040000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 158.298380, 0.000020, 0.085000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 210.192270, 0.000020, 0.655000},
	{{0, 6, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 338.298380, 0.000020, 0.068000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 359.465670, 0.000020, 0.074000},
	{{0, 6, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 179.465670, 0.000020, 0.077000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 282.147960, 0.000150, 0.042000},
	{{0, 6, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 298.305980, 0.000040, 0.093000},
	{{0, 6, -9, 0, 0, 0, 0, 0, 1, -1, 1}, 301.697190, 0.000060, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 353.073560, 0.000050, 0.044000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 284.817240, 0.000080, 0.087000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 117.618760, 0.000040, 0.075000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 284.131530, 0.000470, 0.076000},
	{{0, 6, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 199.613690, 0.000200, 0.038000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -2, 1, 0}, 11.531310, 0.000060, 0.115000},
	{{0, 6, -7, 0, 0, 0, 0, 0, -1, 0, -1}, 19.831890, 0.000040, 0.043000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -2, 0}, 213.530280, 0.000020, 0.042000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, -1, 0}, 144.976160, 0.000030, 0.095000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 213.530280, 0.000020, 0.363000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 0, 1, 0}, 324.976160, 0.000030, 0.062000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 1, -1, 1}, 90.100490, 0.000050, 0.065000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 91.441640, 0.000030, 1.021000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 281.921350, 0.000060, 0.070000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 91.441640, 0.000030, 0.036000},
	{{0, 6, -7, 0, 0, 0, 0, 0, 2, 1, 0}, 288.319180, 0.000030, 0.025000},
	{{0, 6, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 350.332020, 0.000100, 0.048000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 343.691100, 0.000030, 0.105000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 163.691100, 0.000030, 0.059000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 4.373050, 0.000100, 0.066000},
	{{0, 6, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 236.227220, 0.000030, 0.035000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -4, 0, 0}, 72.759960, 0.000030, 0.022000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -4, 2, 0}, 252.759960, 0.000030, 0.055000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 244.344400, 0.000260, 0.050000},
	{{0, 6, -5, 0, 0, 0, 0, 0, -2, 1, 0}, 252.759960, 0.000410, 0.149000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, -1, 0}, 70.845610, 0.000050, 0.118000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 0, 1, 0}, 250.845610, 0.000050, 0.056000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 30.616750, 0.000030, 0.062000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 68.022650, 0.000020, 0.034000},
	{{0, 6, -5, 0, 0, 0, 0, 0, 2, 2, 0}, 248.022650, 0.000020, 0.018000},
	{{0, 6, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 165.436510, 0.000040, 0.053000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 339.146220, 0.000020, 0.108000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 339.146220, 0.000020, 0.058000},
	{{0, 6, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 239.735360, 0.000030, 0.033000},
	{{0, 6, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 280.904440, 0.000050, 0.056000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 57.446020, 0.000030, 0.154000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 237.446020, 0.000030, 0.050000},
	{{0, 6, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 255.134400, 0.000340, 0.032000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 108.934330, 0.000030, 0.129000},
	{{0, 6, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 299.250420, 0.000200, 0.031000},
	{{0, 7, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 71.415970, 0.000190, 0.038000},
	{{0, 7, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 251.619990, 0.000060, 0.617000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 340.247210, 0.000030, 0.026000},
	{{0, 7, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 333.468130, 0.000030, 0.039000},
	{{0, 7, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 323.048390, 0.000030, 1.609000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 219.729510, 0.000040, 0.041000},
	{{0, 7, -11, 0, 0, 0, 0, 0, -2, 1, 0}, 217.677040, 0.000070, 0.090000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 210.764340, 0.000020, 0.078000},
	{{0, 7, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 30.764340, 0.000020, 0.073000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, -2, 0}, 305.985750, 0.000030, 0.020000},
	{{0, 7, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 276.397240, 0.000140, 0.043000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 70.579360, 0.000020, 0.084000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 233.024810, 0.000030, 0.725000},
	{{0, 7, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 250.579360, 0.000020, 0.068000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 16.740380, 0.000030, 0.045000},
	{{0, 7, -9, 0, 0, 0, 0, 0, -2, 2, 0}, 196.740380, 0.000030, 0.241000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 19.399930, 0.000030, 0.092000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 8.597030, 0.000050, 0.420000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 199.399930, 0.000030, 0.064000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 53.464830, 0.000020, 0.079000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 233.464830, 0.000020, 0.072000},
	{{0, 7, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 199.668260, 0.000170, 0.037000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 293.340940, 0.000170, 0.047000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 252.228990, 0.000020, 0.194000},
	{{0, 7, -8, 0, 0, 0, 0, 0, -1, 0, -1}, 19.468860, 0.000030, 0.045000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, -2, 0}, 200.079780, 0.000030, 0.043000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 126.492720, 0.000040, 0.101000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 200.079780, 0.000030, 0.296000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 306.492720, 0.000040, 0.060000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, -3, 0}, 72.868690, 0.000020, 0.086000},
	{{0, 7, -8, 0, 0, 0, 0, 0, 2, 1, 0}, 288.338890, 0.000020, 0.024000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 352.793630, 0.000080, 0.049000},
	{{0, 7, -7, 0, 0, 0, 0, 0, -2, 2, 0}, 10.010500, 0.000030, 0.163000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -2, 0}, 332.182420, 0.000030, 0.384000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, -1, 0}, 356.021840, 0.000100, 0.063000},
	{{0, 7, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 192.014340, 0.000090, 0.034000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -4, 0, 0}, 72.787350, 0.000030, 0.023000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -4, 2, 0}, 252.787350, 0.000030, 0.057000},
	{{0, 7, -6, 0, 0, 0, 0, 0, -2, 0, 0}, 241.905360, 0.000250, 0.052000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, -1, 0}, 95.099930, 0.000040, 0.127000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 252.504980, 0.000050, 0.186000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 1, 0}, 275.099930, 0.000040, 0.054000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 0, 2, 0}, 55.196700, 0.000020, 0.031000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 1, 0, 1}, 229.186000, 0.000040, 0.032000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, -1, 0}, 60.434860, 0.000080, 0.059000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 215.075330, 0.000020, 0.033000},
	{{0, 7, -6, 0, 0, 0, 0, 0, 2, 2, 0}, 71.141250, 0.000020, 0.018000},
	{{0, 7, -4, 0, 0, 0, 0, 0, -2, 0, 0}, 281.237880, 0.000060, 0.058000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 0, -1, 0}, 57.197700, 0.000020, 0.170000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 0, 1, 0}, 237.197700, 0.000020, 0.048000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 179.817280, 0.000030, 0.178000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 19.329980, 0.000050, 0.031000},
	{{0, 7, -4, 0, 0, 0, 0, 0, 2, 2, 0}, 236.949900, 0.000020, 0.017000},
	{{0, 7, -3, 0, 0, 0, 0, 0, 2, 0, 0}, 290.882060, 0.000170, 0.030000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 0, 0, 0}, 195.719880, 0.000040, 0.107000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 0, 2, 0}, 13.540440, 0.000020, 0.028000},
	{{0, 7, -2, 0, 0, 0, 0, 0, 2, 0, 0}, 16.431220, 0.000150, 0.029000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 151.766650, 0.000030, 0.037000},
	{{0, 8, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 331.766650, 0.000030, 4.509000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 70.663570, 0.000150, 0.039000},
	{{0, 8, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 77.797560, 0.000020, 1.285000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 251.642340, 0.000050, 1.004000},
	{{0, 8, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 105.660780, 0.000070, 0.042000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 185.328730, 0.000370, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 183.946900, 0.000340, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 173.960530, 0.000480, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 325.617210, 0.000020, 238.919000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 354.016420, 0.000480, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 351.299520, 0.000020, 0.038000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 7.100120, 0.000310, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 2.843440, 0.000390, 0.040000},
	{{0, 8, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 185.727210, 0.000070, 0.044000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 232.330870, 0.000030, 0.499000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 279.324800, 0.000030, 4.345000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, -1, 0}, 276.258360, 0.000060, 0.074000},
	{{0, 8, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 99.324800, 0.000030, 0.037000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 62.352570, 0.000020, 0.046000},
	{{0, 8, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 62.352570, 0.000020, 0.209000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, -1, 0}, 18.815060, 0.000030, 0.098000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 353.830620, 0.000020, 0.333000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 1, 0}, 198.815060, 0.000030, 0.062000},
	{{0, 8, -10, 0, 0, 0, 0, 0, 0, 2, 0}, 17.595910, 0.000030, 0.034000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 288.846700, 0.000170, 0.048000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 321.479240, 0.000020, 0.046000},
	{{0, 8, -9, 0, 0, 0, 0, 0, -1, 2, -1}, 141.479240, 0.000020, 0.212000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, -2, 0}, 200.098560, 0.000020, 0.044000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, -1, 0}, 99.128520, 0.000040, 0.108000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 249.147240, 0.000050, 0.250000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 0, 1, 0}, 279.128520, 0.000040, 0.058000},
	{{0, 8, -9, 0, 0, 0, 0, 0, 1, 0, 1}, 270.081830, 0.000060, 0.034000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, -2, 0}, 343.880680, 0.000030, 0.022000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 348.873270, 0.000040, 0.051000},
	{{0, 8, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 355.510680, 0.000020, 0.148000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 359.763210, 0.000040, 0.061000},
	{{0, 8, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 184.312460, 0.000090, 0.034000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -4, 0, 0}, 72.809590, 0.000020, 0.023000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -4, 2, 0}, 72.809590, 0.000020, 0.059000},
	{{0, 8, -7, 0, 0, 0, 0, 0, -2, 0, 0}, 118.080160, 0.000060, 0.053000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 235.951310, 0.000090, 0.167000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 0, 2, 0}, 65.660460, 0.000020, 0.031000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 1, 0, 1}, 201.761390, 0.000040, 0.031000},
	{{0, 8, -7, 0, 0, 0, 0, 0, 2, 0, 0}, 210.429760, 0.000070, 0.033000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, -2, 0}, 165.563640, 0.000030, 0.051000},
	{{0, 8, -6, 0, 0, 0, 0, 0, 0, 0, 0}, 345.563640, 0.000030, 0.143000},
	{{0, 8, -5, 0, 0, 0, 0, 0, -2, 0, 0}, 280.854830, 0.000030, 0.060000},
	{{0, 8, -5, 0, 0, 0, 0, 0, -2, 2, 0}, 100.854830, 0.000030, 0.102000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 0, 0, 0}, 234.716180, 0.000020, 0.125000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 0, 2, 0}, 234.716180, 0.000020, 0.029000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, -2, 0}, 176.522290, 0.000020, 0.161000},
	{{0, 8, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 42.260420, 0.000050, 0.031000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -3, 0}, 289.107770, 0.000020, 0.166000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -2, 0}, 294.993980, 0.000020, 0.138000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 109.107770, 0.000020, 0.049000},
	{{0, 8, -4, 0, 0, 0, 0, 0, 2, 0, 0}, 114.993980, 0.000020, 0.030000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 195.913880, 0.000040, 0.100000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 18.000700, 0.000020, 0.047000},
	{{0, 8, -3, 0, 0, 0, 0, 0, 2, 1, 0}, 198.000700, 0.000020, 0.021000},
	{{0, 9, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 152.417070, 0.000030, 0.038000},
	{{0, 9, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 332.417070, 0.000030, 2.477000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 266.512810, 0.000020, 0.040000},
	{{0, 9, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 86.512810, 0.000020, 0.712000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, -1, 0}, 263.117960, 0.000030, 0.073000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 251.662720, 0.000050, 2.701000},
	{{0, 9, -15, 0, 0, 0, 0, 0, 0, 1, 0}, 83.117960, 0.000030, 0.078000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, -1, 0}, 340.181310, 0.000020, 0.027000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 334.710420, 0.000030, 0.041000},
	{{0, 9, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 160.181310, 0.000020, 0.092000},
	{{0, 9, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 245.953600, 0.000080, 0.043000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 206.450370, 0.000060, 0.045000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 51.731110, 0.000030, 0.113000},
	{{0, 9, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 118.858520, 0.000020, 0.227000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, -2, 0}, 67.566550, 0.000030, 0.042000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 94.221080, 0.000020, 0.094000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 247.566550, 0.000030, 0.380000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 274.221080, 0.000020, 0.063000},
	{{0, 9, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 100.055390, 0.000050, 0.037000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 13.096620, 0.000030, 0.276000},
	{{0, 9, -11, 0, 0, 0, 0, 0, 0, 2, 0}, 10.855260, 0.000020, 0.033000},
	{{0, 9, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 321.034410, 0.000040, 0.047000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 1, 0, 1}, 270.069420, 0.000050, 0.033000},
	{{0, 9, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 108.362410, 0.000410, 0.034000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, -2, 0}, 343.965210, 0.000020, 0.022000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 355.021400, 0.000060, 0.052000},
	{{0, 9, -9, 0, 0, 0, 0, 0, -2, 1, 0}, 343.965210, 0.000060, 0.171000},
	{{0, 9, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 190.061760, 0.000070, 0.033000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 112.675880, 0.000100, 0.055000},
	{{0, 9, -8, 0, 0, 0, 0, 0, -2, 1, 0}, 71.290610, 0.000030, 0.206000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, -1, 0}, 268.332700, 0.000020, 0.151000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 239.056190, 0.000050, 0.151000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 0, 1, 0}, 88.332700, 0.000020, 0.050000},
	{{0, 9, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 201.683700, 0.000050, 0.032000},
	{{0, 9, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 349.633690, 0.000050, 0.131000},
	{{0, 9, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 35.415980, 0.000080, 0.030000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, -1, 0}, 109.166360, 0.000040, 0.047000},
	{{0, 9, -5, 0, 0, 0, 0, 0, 2, 0, 0}, 110.854810, 0.000060, 0.029000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 0, -2, 0}, 18.097640, 0.000020, 0.063000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 0, 0, 0}, 198.097640, 0.000020, 0.094000},
	{{0, 9, -4, 0, 0, 0, 0, 0, 2, -1, 0}, 193.529660, 0.000040, 0.045000},
	{{0, 10, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 153.017660, 0.000060, 0.039000},
	{{0, 10, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 153.017660, 0.000030, 0.082000},
	{{0, 10, -17, 0, 0, 0, 0, 0, -2, 3, 0}, 333.017660, 0.000030, 0.070000},
	{{0, 10, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 265.949080, 0.000020, 0.041000},
	{{0, 10, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 265.949080, 0.000020, 0.493000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 251.680880, 0.000020, 0.038000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 83.084850, 0.000040, 0.077000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 251.680880, 0.000020, 3.918000},
	{{0, 10, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 263.084850, 0.000040, 0.074000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 160.436440, 0.000520, 0.043000},
	{{0, 10, -15, 0, 0, 0, 0, 0, -2, 1, 0}, 166.339790, 0.000030, 0.098000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -3, 0}, 160.148250, 0.000040, 0.073000},
	{{0, 10, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 340.148250, 0.000040, 0.079000},
	{{0, 10, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 241.697340, 0.000070, 0.044000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 216.072930, 0.000050, 0.047000},
	{{0, 10, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 93.664560, 0.000050, 0.122000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 259.502150, 0.000050, 0.307000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, -3, 0}, 105.646380, 0.000020, 0.085000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, -1, 0}, 285.646380, 0.000020, 0.068000},
	{{0, 10, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 100.711060, 0.000040, 0.036000},
	{{0, 10, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 167.599150, 0.000040, 0.049000},
	{{0, 10, -11, 0, 0, 0, 0, 0, -1, 0, -1}, 320.644350, 0.000040, 0.049000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, -1, 0}, 288.367140, 0.000030, 0.125000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 312.694210, 0.000040, 0.190000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 0, 1, 0}, 108.367140, 0.000030, 0.054000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, -2, 1}, 270.054920, 0.000020, 0.221000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 1, 0, 1}, 270.054920, 0.000020, 0.032000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 108.367140, 0.000300, 0.033000},
	{{0, 10, -11, 0, 0, 0, 0, 0, 2, 2, 0}, 108.367140, 0.000030, 0.018000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 0.998480, 0.000040, 0.054000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 1, 0}, 344.042590, 0.000020, 0.191000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 2, 0}, 0.998480, 0.000040, 0.125000},
	{{0, 10, -10, 0, 0, 0, 0, 0, -2, 3, 0}, 344.042590, 0.000020, 0.047000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, -2, 0}, 186.350590, 0.000020, 0.049000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 0, 0, 0}, 186.350590, 0.000020, 0.160000},
	{{0, 10, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 187.724680, 0.000080, 0.032000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -2, 0, 0}, 128.245520, 0.000090, 0.057000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 0, -1}, 184.509890, 0.000020, 0.054000},
	{{0, 10, -9, 0, 0, 0, 0, 0, -1, 2, -1}, 4.509890, 0.000020, 0.125000},
	{{0, 10, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 211.752820, 0.000060, 0.031000},
	{{0, 10, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 355.760360, 0.000040, 0.121000},
	{{0, 10, -7, 0, 0, 0, 0, 0, 0, 0, 0}, 248.879510, 0.000050, 0.108000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, -2, 0}, 110.501350, 0.000030, 0.118000},
	{{0, 10, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 110.501350, 0.000030, 0.029000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, -1, 0}, 150.662720, 0.000210, 0.040000},
	{{0, 10, -3, 0, 0, 0, 0, 0, -2, 0, 0}, 150.662720, 0.000130, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -3, 0}, 150.662720, 0.000040, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -2, 0}, 149.609000, 0.000730, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, -1, 0}, 225.680430, 0.000300, 1911.695000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 0, 0}, 330.179450, 0.000600, 0.075000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 0, 1, 0}, 330.662720, 0.000040, 0.038000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -2, 0}, 330.662720, 0.000130, 0.087000},
	{{0, 10, -3, 0, 0, 0, 0, 0, 2, -1, 0}, 330.662720, 0.000210, 0.040000},
	{{0, 11, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 153.571750, 0.000060, 0.040000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 160.114680, 0.000040, 0.020000},
	{{0, 11, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 160.114680, 0.000430, 0.044000},
	{{0, 11, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 24.320560, 0.000030, 0.075000},
	{{0, 11, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 215.246060, 0.000060, 0.046000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 249.165980, 0.000030, 0.048000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 1, 0}, 130.252220, 0.000040, 0.132000},
	{{0, 11, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 169.643080, 0.000040, 0.177000},
	{{0, 11, -14, 0, 0, 0, 0, 0, 0, 0, 0}, 271.403030, 0.000040, 0.258000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 109.232530, 0.000030, 0.050000},
	{{0, 11, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 219.788080, 0.000030, 0.150000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, -2, 0}, 350.210560, 0.000020, 0.046000},
	{{0, 11, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 350.210560, 0.000020, 0.205000},
	{{0, 11, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 320.299140, 0.000040, 0.050000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, -1, 0}, 288.367690, 0.000020, 0.136000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 0, 0}, 265.629250, 0.000030, 0.170000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 1, 0}, 108.367690, 0.000020, 0.052000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 0, 2, 0}, 294.037460, 0.000020, 0.031000},
	{{0, 11, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 288.367690, 0.000050, 0.033000},
	{{0, 11, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 173.714890, 0.000060, 0.032000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 128.477380, 0.000090, 0.059000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 0, -1}, 184.278450, 0.000020, 0.056000},
	{{0, 11, -10, 0, 0, 0, 0, 0, -1, 2, -1}, 4.278450, 0.000020, 0.116000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, -3, 0}, 251.085310, 0.000020, 0.140000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, -1, 0}, 251.085310, 0.000020, 0.052000},
	{{0, 11, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 218.435040, 0.000050, 0.031000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 0, 0, 0}, 248.928570, 0.000020, 0.101000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 0, 2, 0}, 248.928570, 0.000020, 0.027000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 2, -1, 0}, 244.550960, 0.000040, 0.047000},
	{{0, 11, -8, 0, 0, 0, 0, 0, 2, 0, 0}, 150.700570, 0.000030, 0.029000},
	{{0, 11, -6, 0, 0, 0, 0, 0, 2, 0, 0}, 17.969630, 0.000330, 0.027000},
	{{0, 12, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 154.082820, 0.000060, 0.041000},
	{{0, 12, -18, 0, 0, 0, 0, 0, -2, 1, 0}, 71.710150, 0.000070, 0.100000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 71.710150, 0.000030, 0.085000},
	{{0, 12, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 251.710150, 0.000030, 0.068000},
	{{0, 12, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 160.080530, 0.000330, 0.045000},
	{{0, 12, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 340.094340, 0.000030, 0.071000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 175.243780, 0.000040, 0.047000},
	{{0, 12, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 268.962620, 0.000020, 0.189000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 296.635250, 0.000030, 0.049000},
	{{0, 12, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 116.635250, 0.000030, 0.159000},
	{{0, 12, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 271.427570, 0.000040, 0.222000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 86.859760, 0.000030, 0.052000},
	{{0, 12, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 266.859760, 0.000030, 0.137000},
	{{0, 12, -14, 0, 0, 0, 0, 0, 2, -1, 0}, 199.756580, 0.000040, 0.059000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 132.385330, 0.000020, 0.154000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 0, 2, 0}, 277.838740, 0.000030, 0.030000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, -2, 0}, 282.597400, 0.000020, 0.211000},
	{{0, 12, -13, 0, 0, 0, 0, 0, 2, 0, 0}, 107.793580, 0.000230, 0.032000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 162.565290, 0.000020, 0.174000},
	{{0, 12, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 162.565290, 0.000020, 0.031000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 128.553690, 0.000050, 0.062000},
	{{0, 12, -11, 0, 0, 0, 0, 0, -2, 2, 0}, 308.553690, 0.000050, 0.097000},
	{{0, 12, -10, 0, 0, 0, 0, 0, 2, 0, 0}, 148.267190, 0.000040, 0.029000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, -3, 0}, 248.968110, 0.000020, 0.221000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, -2, 0}, 9.653920, 0.000020, 0.115000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, -1, 0}, 248.968110, 0.000020, 0.045000},
	{{0, 12, -9, 0, 0, 0, 0, 0, 2, 0, 0}, 189.653920, 0.000020, 0.028000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 0, 0}, 92.899650, 0.000090, 0.076000},
	{{0, 12, -8, 0, 0, 0, 0, 0, -2, 2, 0}, 205.021320, 0.000070, 0.075000},
	{{0, 13, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 154.554320, 0.000050, 0.042000},
	{{0, 13, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 71.721250, 0.000050, 0.107000},
	{{0, 13, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 340.045600, 0.000050, 0.046000},
	{{0, 13, -18, 0, 0, 0, 0, 0, 0, -1, 0}, 340.045600, 0.000030, 0.099000},
	{{0, 13, -18, 0, 0, 0, 0, 0, 0, 1, 0}, 160.045600, 0.000030, 0.061000},
	{{0, 13, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 112.249740, 0.000050, 0.049000},
	{{0, 13, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 299.174230, 0.000030, 0.051000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 122.908660, 0.000020, 0.047000},
	{{0, 13, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 302.908660, 0.000020, 0.195000},
	{{0, 13, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 86.538040, 0.000050, 0.054000},
	{{0, 13, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 107.443980, 0.000240, 0.031000},
	{{0, 13, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 165.242880, 0.000150, 0.060000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, -1, 0}, 252.852250, 0.000030, 0.035000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 0, 0}, 239.068360, 0.000140, 0.064000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 1, 0}, 72.852250, 0.000030, 0.426000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -2, 2, 0}, 139.992280, 0.000020, 0.092000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 183.904820, 0.000020, 0.060000},
	{{0, 13, -12, 0, 0, 0, 0, 0, -1, 2, -1}, 183.904820, 0.000020, 0.102000},
	{{0, 13, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 160.119300, 0.000050, 0.029000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, -2, 2}, 277.345800, 0.000030, 0.075000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 0}, 45.743070, 0.000050, 0.073000},
	{{0, 13, -10, 0, 0, 0, 0, 0, -2, 0, 2}, 97.345800, 0.000030, 0.076000},
	{{0, 14, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 154.989590, 0.000050, 0.044000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, -2, 0}, 340.009770, 0.000020, 0.021000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 340.044000, 0.000270, 0.048000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, 1, 0}, 340.009770, 0.000040, 0.129000},
	{{0, 14, -19, 0, 0, 0, 0, 0, -2, 3, 0}, 160.009770, 0.000040, 0.053000},
	{{0, 14, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 97.349760, 0.000060, 0.050000},
	{{0, 14, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 298.684780, 0.000040, 0.053000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 302.884660, 0.000020, 0.048000},
	{{0, 14, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 302.884660, 0.000020, 0.174000},
	{{0, 14, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 87.912760, 0.000050, 0.056000},
	{{0, 14, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 108.347170, 0.000050, 0.052000},
	{{0, 14, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 338.787300, 0.000050, 0.063000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 134.107690, 0.000040, 0.067000},
	{{0, 14, -13, 0, 0, 0, 0, 0, -2, 1, 0}, 252.848850, 0.000410, 0.580000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, -2, 0}, 160.211180, 0.000020, 0.111000},
	{{0, 14, -12, 0, 0, 0, 0, 0, 2, 0, 0}, 160.211180, 0.000020, 0.028000},
	{{0, 14, -11, 0, 0, 0, 0, 0, -2, 0, 0}, 234.758760, 0.000060, 0.077000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 0, -2, 0}, 125.186990, 0.000020, 0.068000},
	{{0, 14, -11, 0, 0, 0, 0, 0, 0, 0, 0}, 305.186990, 0.000020, 0.085000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 0, 0, 0}, 17.919950, 0.000020, 0.073000},
	{{0, 14, -9, 0, 0, 0, 0, 0, 0, 2, 0}, 197.919950, 0.000020, 0.025000},
	{{0, 15, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 155.391720, 0.000020, 0.045000},
	{{0, 15, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 155.391720, 0.000020, 0.241000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 340.020460, 0.000190, 0.049000},
	{{0, 15, -20, 0, 0, 0, 0, 0, -2, 1, 0}, 339.972940, 0.000050, 0.141000},
	{{0, 15, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 92.712950, 0.000050, 0.052000},
	{{0, 15, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 312.138660, 0.000040, 0.054000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 71.241960, 0.000030, 0.058000},
	{{0, 15, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 251.241960, 0.000030, 0.109000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 103.474430, 0.000050, 0.119000},
	{{0, 15, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 108.333740, 0.000040, 0.050000},
	{{0, 15, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 341.953660, 0.000070, 0.065000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 0, 0}, 95.250110, 0.000030, 0.070000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -2, 2, 0}, 275.250110, 0.000030, 0.082000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 183.613470, 0.000020, 0.065000},
	{{0, 15, -14, 0, 0, 0, 0, 0, -1, 2, -1}, 3.613470, 0.000020, 0.090000},
	{{0, 15, -14, 0, 0, 0, 0, 0, 2, 0, 0}, 113.254010, 0.000030, 0.028000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 0, 0}, 165.179560, 0.000040, 0.075000},
	{{0, 15, -13, 0, 0, 0, 0, 0, -2, 2, 0}, 68.642910, 0.000030, 0.076000},
	{{0, 15, -12, 0, 0, 0, 0, 0, -1, 0, -1}, 85.147180, 0.000040, 0.075000},
	{{0, 16, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 339.991990, 0.000170, 0.051000},
	{{0, 16, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 159.935060, 0.000070, 0.200000},
	{{0, 16, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 118.711010, 0.000040, 0.053000},
	{{0, 16, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 299.108660, 0.000040, 0.056000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 94.660080, 0.000020, 0.060000},
	{{0, 16, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 274.660080, 0.000020, 0.102000},
	{{0, 16, -18, 0, 0, 0, 0, 0, 2, 0, 0}, 19.925100, 0.000050, 0.031000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 85.585670, 0.000020, 0.064000},
	{{0, 16, -17, 0, 0, 0, 0, 0, -2, 2, 0}, 85.585670, 0.000020, 0.093000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 338.325820, 0.000080, 0.068000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -2, 2, 0}, 204.347080, 0.000020, 0.085000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -1, 0, -1}, 202.739170, 0.000020, 0.063000},
	{{0, 16, -16, 0, 0, 0, 0, 0, -1, 2, -1}, 202.739170, 0.000020, 0.093000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 221.675680, 0.000020, 0.073000},
	{{0, 16, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 221.675680, 0.000020, 0.078000},
	{{0, 16, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 75.696630, 0.000050, 0.028000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, -1}, 181.209940, 0.000050, 0.073000},
	{{0, 16, -14, 0, 0, 0, 0, 0, -1, 0, 1}, 181.209940, 0.000050, 0.077000},
	{{0, 16, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 77.776000, 0.000090, 0.077000},
	{{0, 16, -11, 0, 0, 0, 0, 0, 2, -2, 0}, 193.428260, 0.000020, 0.076000},
	{{0, 16, -11, 0, 0, 0, 0, 0, 2, 0, 0}, 13.428260, 0.000020, 0.025000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 166.141070, 0.000020, 0.052000},
	{{0, 17, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 346.141070, 0.000020, 0.135000},
	{{0, 17, -22, 0, 0, 0, 0, 0, 0, 0, 0}, 159.896050, 0.000060, 0.178000},
	{{0, 17, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 119.893210, 0.000040, 0.055000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 59.833160, 0.000020, 0.062000},
	{{0, 17, -19, 0, 0, 0, 0, 0, -2, 2, 0}, 59.833160, 0.000020, 0.096000},
	{{0, 17, -19, 0, 0, 0, 0, 0, 2, 0, 0}, 19.955140, 0.000040, 0.030000},
	{{0, 17, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 85.145480, 0.000050, 0.066000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 244.587600, 0.000040, 0.071000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -1, 0, -1}, 202.763500, 0.000020, 0.066000},
	{{0, 17, -17, 0, 0, 0, 0, 0, -1, 2, -1}, 22.763500, 0.000020, 0.088000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 252.818680, 0.000020, 0.025000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 252.818680, 0.000020, 0.076000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, -2, 1}, 56.519830, 0.000030, 0.072000},
	{{0, 17, -16, 0, 0, 0, 0, 0, -1, 0, 1}, 236.519830, 0.000030, 0.079000},
	{{0, 18, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 166.105450, 0.000040, 0.054000},
	{{0, 18, -23, 0, 0, 0, 0, 0, 0, 0, 0}, 159.855890, 0.000050, 0.160000},
	{{0, 18, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 132.021960, 0.000030, 0.057000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 0, 0}, 60.182050, 0.000020, 0.065000},
	{{0, 18, -20, 0, 0, 0, 0, 0, -2, 2, 0}, 60.182050, 0.000020, 0.091000},
	{{0, 18, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 71.012680, 0.000040, 0.069000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 215.629820, 0.000020, 0.074000},
	{{0, 18, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 35.629820, 0.000020, 0.077000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, -1, 0}, 127.502430, 0.000040, 0.039000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 321.292910, 0.000050, 0.080000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -2, 1, 0}, 72.802570, 0.000380, 1.286000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, -2, 1}, 79.597850, 0.000020, 0.076000},
	{{0, 18, -17, 0, 0, 0, 0, 0, -1, 0, 1}, 79.597850, 0.000020, 0.075000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 127.502430, 0.000060, 0.070000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 127.502430, 0.000080, 0.082000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -2, 0}, 127.502430, 0.000090, 0.095000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, -1, 0}, 127.502430, 0.000250, 0.042000},
	{{0, 18, -17, 0, 0, 0, 0, 0, 2, 0, 0}, 127.502430, 0.000020, 0.027000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, -1, 0}, 204.565500, 0.000030, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 0, 0}, 204.565500, 0.000060, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -4, 1, 0}, 204.565500, 0.000030, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -3, 0}, 204.565500, 0.000030, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -2, 0}, 204.565500, 0.000320, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, -1, 0}, 204.565500, 0.003640, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -2, 0, 0}, 204.589140, 0.002410, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, -1, -1, 0}, 24.565500, 0.000070, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -4, 0}, 204.565500, 0.000040, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -3, 0}, 204.453910, 0.000720, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 0}, 204.554060, 0.013020, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -2, 2}, 204.565500, 0.000050, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, -1, 0}, 351.087990, 0.000550, 273.043000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, -2}, 24.565500, 0.000050, 0.074000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 0, 0}, 24.795240, 0.012250, 0.075000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 1, 0}, 24.684040, 0.000680, 0.038000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 0, 2, 0}, 24.565500, 0.000040, 0.025000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 1, -1, 0}, 204.565500, 0.000070, 0.081000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -2, 0}, 24.577090, 0.002260, 0.087000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, -1, 0}, 24.565500, 0.003640, 0.040000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 0, 0}, 24.565500, 0.000320, 0.026000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 2, 1, 0}, 24.565500, 0.000030, 0.020000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -3, 0}, 24.565500, 0.000030, 0.044000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -2, 0}, 24.565500, 0.000060, 0.028000},
	{{0, 18, -16, 0, 0, 0, 0, 0, 4, -1, 0}, 24.565500, 0.000030, 0.020000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -2, 0}, 101.628570, 0.000020, 0.027000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, -1, 0}, 101.628570, 0.000250, 0.042000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 0, 0}, 102.856860, 0.000070, 0.095000},
	{{0, 18, -15, 0, 0, 0, 0, 0, -2, 2, 0}, 98.410310, 0.000030, 0.062000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, -2, 0}, 101.628570, 0.000080, 0.082000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 0, 0, 0}, 101.628570, 0.000060, 0.070000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 1, 0, -1}, 44.230710, 0.000040, 0.076000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, -1, 0}, 101.628570, 0.000040, 0.039000},
	{{0, 18, -15, 0, 0, 0, 0, 0, 2, 0, 0}, 69.060730, 0.000040, 0.026000},
	{{0, 19, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 336.656550, 0.000030, 0.050000},
	{{0, 19, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 166.068140, 0.000030, 0.056000},
	{{0, 19, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 159.814550, 0.000020, 0.051000},
	{{0, 19, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 159.814550, 0.000020, 0.145000},
	{{0, 19, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 159.118650, 0.000040, 0.059000},
	{{0, 19, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 71.473330, 0.000020, 0.104000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 86.471660, 0.000050, 0.067000},
	{{0, 19, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 167.649070, 0.000020, 0.086000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 71.436730, 0.000020, 0.064000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 251.436730, 0.000020, 0.092000},
	{{0, 19, -20, 0, 0, 0, 0, 0, 2, 0, 0}, 288.251920, 0.000050, 0.028000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 55.149400, 0.000080, 0.078000},
	{{0, 19, -19, 0, 0, 0, 0, 0, -1, 0, -1}, 330.393880, 0.000040, 0.072000},
	{{0, 19, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 333.793180, 0.000060, 0.084000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -2, 0, 0}, 339.920760, 0.000070, 0.084000},
	{{0, 19, -18, 0, 0, 0, 0, 0, -2, 2, 0}, 304.232780, 0.000030, 0.068000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, -2, 0}, 117.350990, 0.000020, 0.073000},
	{{0, 19, -18, 0, 0, 0, 0, 0, 0, 0, 0}, 29.221500, 0.000040, 0.078000},
	{{0, 19, -17, 0, 0, 0, 0, 0, -2, 0, 0}, 206.474720, 0.000050, 0.092000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, -2, 0}, 8.405030, 0.000020, 0.079000},
	{{0, 19, -17, 0, 0, 0, 0, 0, 0, 0, 0}, 8.405030, 0.000020, 0.072000},
	{{0, 20, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 159.554120, 0.000040, 0.062000},
	{{0, 20, -24, 0, 0, 0, 0, 0, -2, 2, 0}, 71.668500, 0.000020, 0.097000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 225.850910, 0.000020, 0.070000},
	{{0, 20, -22, 0, 0, 0, 0, 0, -2, 2, 0}, 225.850910, 0.000020, 0.081000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 0, 0}, 204.207410, 0.000130, 0.076000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 1, 0}, 231.738970, 0.000330, 34.812000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -2, 2, 0}, 322.763070, 0.000080, 0.075000},
	{{0, 20, -21, 0, 0, 0, 0, 0, -1, 0, -1}, 318.306220, 0.000040, 0.070000},
	{{0, 20, -21, 0, 0, 0, 0, 0, 2, 0, 0}, 288.225160, 0.000040, 0.028000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 0, -1}, 27.356710, 0.000040, 0.075000},
	{{0, 20, -20, 0, 0, 0, 0, 0, -1, 2, -1}, 207.356710, 0.000040, 0.076000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, -2, 0}, 216.474650, 0.000020, 0.071000},
	{{0, 20, -20, 0, 0, 0, 0, 0, 0, 0, 0}, 216.474650, 0.000020, 0.080000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -2, 0, 0}, 350.787810, 0.000030, 0.089000},
	{{0, 20, -19, 0, 0, 0, 0, 0, -1, 0, -1}, 55.608710, 0.000050, 0.081000},
	{{0, 20, -19, 0, 0, 0, 0, 0, 0, 0, 0}, 238.771390, 0.000050, 0.074000},
	{{0, 21, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 339.822690, 0.000030, 0.123000},
	{{0, 21, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 153.124220, 0.000030, 0.064000},
	{{0, 21, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 43.904550, 0.000030, 0.092000},
	{{0, 21, -24, 0, 0, 0, 0, 0, -2, 0, 0}, 291.385730, 0.000030, 0.068000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -2, 0, 0}, 265.710800, 0.000050, 0.079000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 0, -1}, 17.147490, 0.000020, 0.073000},
	{{0, 21, -22, 0, 0, 0, 0, 0, -1, 2, -1}, 197.147490, 0.000020, 0.078000},
	{{0, 21, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 155.737920, 0.000040, 0.076000},
	{{0, 21, -20, 0, 0, 0, 0, 0, 1, 0, -1}, 63.476230, 0.000040, 0.076000},
	{{0, 22, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 121.829030, 0.000030, 0.067000},
	{{0, 22, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 182.095590, 0.000060, 0.072000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 0, -1}, 157.153160, 0.000050, 0.077000},
	{{0, 22, -23, 0, 0, 0, 0, 0, -1, 2, -1}, 275.799700, 0.000020, 0.074000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 0, -2, 0}, 244.362970, 0.000030, 0.085000},
	{{0, 22, -21, 0, 0, 0, 0, 0, 0, 0, 0}, 64.362970, 0.000030, 0.068000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 0, 0}, 169.627770, 0.000020, 0.075000},
	{{0, 23, -26, 0, 0, 0, 0, 0, -2, 2, 0}, 169.627770, 0.000020, 0.076000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -2, 0, 0}, 313.331150, 0.000030, 0.081000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -2, 2, 0}, 313.331150, 0.000030, 0.071000},
	{{0, 23, -25, 0, 0, 0, 0, 0, -1, 0, -1}, 84.089400, 0.000050, 0.075000},
	{{0, 23, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 97.386630, 0.000070, 0.075000},
	{{0, 23, -23, 0, 0, 0, 0, 0, 1, 0, -1}, 203.562700, 0.000040, 0.075000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 0, 0}, 259.163470, 0.000020, 0.073000},
	{{0, 24, -28, 0, 0, 0, 0, 0, -2, 2, 0}, 259.163470, 0.000020, 0.078000},
	{{0, 24, -27, 0, 0, 0, 0, 0, -2, 0, 0}, 6.812210, 0.000050, 0.079000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, -2, 0}, 265.309160, 0.000020, 0.074000},
	{{0, 24, -26, 0, 0, 0, 0, 0, 0, 0, 0}, 265.309160, 0.000020, 0.077000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, -2, 0}, 344.480600, 0.000030, 0.087000},
	{{0, 24, -24, 0, 0, 0, 0, 0, 0, 0, 0}, 344.480600, 0.000030, 0.067000},
	{{0, 24, -23, 0, 0, 0, 0, 0, -2, 0, 0}, 250.630220, 0.000020, 0.115000},
	{{0, 24, -23, 0, 0, 0, 0, 0, -2, 2, 0}, 70.630220, 0.000020, 0.056000},
	{{0, 25, -30, 0, 0, 0, 0, 0, -2, 0, 0}, 165.875800, 0.000020, 0.071000},
	{{0, 25, -30, 0, 0, 0, 0, 0, -2, 2, 0}, 345.875800, 0.000020, 0.081000},
	{{0, 25, -29, 0, 0, 0, 0, 0, -2, 0, 0}, 192.204470, 0.000050, 0.076000},
	{{0, 25, -28, 0, 0, 0, 0, 0, 0, -2, 0}, 307.923150, 0.000020, 0.072000},
	{{0, 25, -28, 0, 0, 0, 0, 0, 0, 0, 0}, 307.923150, 0.000020, 0.079000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, 0, 0}, 276.433900, 0.000030, 0.074000},
	{{0, 26, -31, 0, 0, 0, 0, 0, -2, 2, 0}, 178.066910, 0.000020, 0.077000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, -2, 0}, 352.006710, 0.000030, 0.075000},
	{{0, 26, -29, 0, 0, 0, 0, 0, 0, 0, 0}, 172.006710, 0.000030, 0.075000},
	{{0, 26, -28, 0, 0, 0, 0, 0, 1, 0, -1}, 109.485890, 0.000040, 0.076000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 0, 0}, 121.107280, 0.000020, 0.078000},
	{{0, 27, -32, 0, 0, 0, 0, 0, -2, 2, 0}, 121.107280, 0.000020, 0.073000},
	{{0, 28, -33, 0, 0, 0, 0, 0, 0, -2, 0}, 159.389220, 0.000020, 0.071000},
	{{0, 28, -33, 0, 0, 0, 0, 0, 0, 0, 0}, 159.389220, 0.000020, 0.080000},
	{{0, 29, -34, 0, 0, 0, 0, 0, -2, 0, 0}, 158.705470, 0.000060, 0.086000},
	{{0, 29, -34, 0, 0, 0, 0, 0, -2, 2, 0}, 341.199600, 0.000020, 0.067000},
	{{0, 30, -36, 0, 0, 0, 0, 0, -2, 0, 0}, 251.616330, 0.000050, 0.084000},
	{{0, 31, -39, 0, 0, 0, 0, 0, -2, 0, 0}, 244.727890, 0.000040, 0.075000},
	{{0, 31, -39, 0, 0, 0, 0, 0, -2, 2, 0}, 64.727890, 0.000040, 0.076000},
	{{0, 31, -37, 0, 0, 0, 0, 0, 0, -2, 0}, 251.596480, 0.000040, 0.076000},
	{{0, 31, -37, 0, 0, 0, 0, 0, 0, 0, 0}, 71.596480, 0.000040, 0.075000},
	{{0, 34, -42, 0, 0, 0, 0, 0, 0, 0, 0}, 245.432240, 0.000060, 0.075000},
	{{3, 0, -1, 0, 0, 0, 0, 0, -2, 0, 0}, 63.348720, 0.000050, 0.075000}
};

static const struct planet_pert plan_pert_elp16 [ELP16_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2}, 180.000310, 0.000020, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2}, 359.999680, 0.000120, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 180.005670, 0.009630, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2}, 0.000000, 0.000020, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 180.000060, 0.000650, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0}, 179.999860, 0.000050, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 153.735670, 0.000090, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 154.274800, 0.001350, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 155.766300, 0.006610, 1.000000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 154.628450, 0.001200, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0}, 153.962480, 0.000080, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 336.258460, 0.000020, 0.089000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 154.007450, 0.000080, 0.500000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 155.895600, 0.000010, 0.066000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0}, 24.155170, 0.000010, 0.096000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, -1, 0}, 24.155110, 0.000030, 0.530000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0}, 24.082860, 0.000310, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 1, 0}, 23.352310, 0.000020, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0}, 0.000000, 0.000010, 1.127000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 346.968090, 0.000020, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -2, 0}, 336.316370, 0.000030, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -1, 0}, 165.169900, 0.000180, 8.850000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0}, 335.786800, 0.001590, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0}, 335.844920, 0.000110, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 0}, 210.915390, 0.000030, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 0}, 40.766890, 0.000170, 0.095000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 0}, 198.781970, 0.000170, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, 0}, 182.660550, 0.000010, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -3, 0}, 180.001520, 0.000020, 0.067000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0}, 179.999190, 0.000180, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, -2}, 359.999760, 0.000020, 0.065000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0}, 180.074000, 0.001810, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -2}, 359.999820, 0.000150, 0.474000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 179.709820, 0.000430, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0}, 179.999990, 0.000110, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -2, 0}, 350.808270, 0.000010, 1.292000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, 0}, 335.904130, 0.000560, 0.080000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, -2}, 335.928130, 0.000010, 0.903000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0}, 155.911330, 0.000070, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0}, 155.905870, 0.000020, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -2, 0}, 11.985930, 0.000020, 4.425000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 0}, 156.005890, 0.000240, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, -2}, 180.000000, 0.000040, 9.300000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0}, 156.003960, 0.000020, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -1, 0}, 334.711310, 0.000020, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0}, 335.838480, 0.000020, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -2, 0}, 180.000030, 0.000020, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -1, 0}, 180.000210, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, -1, 1}, 275.131490, 0.000010, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 1, -1}, 275.131000, 0.000060, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 1, 1}, 95.132400, 0.000040, 0.106000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 2, -1}, 275.133540, 0.000100, 0.043000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 0, 0}, 77.000070, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 0, 1}, 275.132280, 0.000040, 0.097000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 1, 0}, 77.056430, 0.000040, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, -1, 1}, 95.132280, 0.000010, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 0, -1}, 95.125390, 0.000010, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 0, 1}, 275.132140, 0.000230, 0.949000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 1, -1}, 95.138270, 0.000010, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 2, -1}, 275.133550, 0.000020, 1.388000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -2, -1}, 95.135430, 0.000080, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -2, 1}, 275.131400, 0.000110, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, -1}, 95.136080, 0.000530, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 1}, 275.131510, 0.001460, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -1}, 95.144820, 0.000800, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 1}, 95.132220, 0.008510, 0.487000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 3}, 275.132310, 0.000020, 0.035000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, -1}, 275.133480, 0.007720, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, 1}, 95.130890, 0.000060, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 2, -1}, 275.134130, 0.000940, 0.581000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 2, 1}, 275.132150, 0.000080, 0.035000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 3, -1}, 275.134300, 0.000100, 0.067000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 3, 1}, 275.132280, 0.000010, 0.024000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, -1, -1}, 95.135680, 0.000040, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, -1, 1}, 275.131570, 0.000080, 0.098000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, -1}, 95.139030, 0.000100, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, 1}, 95.132230, 0.000330, 0.327000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 1, -1}, 275.133560, 0.000330, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 2, -1}, 275.134220, 0.000040, 0.368000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, -1}, 275.138070, 0.000010, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 76.154820, 0.000030, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 95.130380, 0.000150, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 72.382690, 0.000090, 1.000000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 275.132200, 0.000090, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, -1}, 95.133390, 0.000070, 1.200000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 75.534110, 0.000020, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 2, -1}, 95.133730, 0.000010, 0.071000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -2, -1}, 275.135010, 0.000030, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -1, -1}, 275.135400, 0.000220, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -1, 1}, 95.127140, 0.000010, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 0, -1}, 95.132430, 0.000410, 0.949000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 0, 1}, 95.131610, 0.000010, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 1, -1}, 95.134060, 0.000520, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 1, 1}, 95.132280, 0.000050, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 2, -1}, 95.134250, 0.000060, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -4, -1}, 95.134560, 0.000020, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -3, -1}, 95.134630, 0.000290, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -3, 1}, 275.131070, 0.000020, 0.077000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, -3}, 275.134600, 0.000030, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, -1}, 95.134650, 0.004100, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, 1}, 275.131120, 0.000420, 3.575000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, -3}, 275.134610, 0.000180, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, -1}, 95.134590, 0.061740, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 0}, 77.021810, 0.000010, 8.850000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 1}, 95.131570, 0.008580, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 3}, 275.131860, 0.000030, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, -3}, 275.134720, 0.000470, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, -1}, 95.135230, 0.289380, 18.600000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1}, 95.132250, 0.061540, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 3}, 275.132280, 0.000130, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -3}, 95.136410, 0.000030, 0.073000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -1}, 95.134530, 0.062450, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 1}, 95.132210, 0.006610, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 3}, 275.132280, 0.000030, 0.015000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, -1}, 95.134490, 0.004320, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, 1}, 95.132170, 0.000570, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 3, -1}, 95.134500, 0.000310, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 3, 1}, 95.132200, 0.000050, 0.015000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 4, -1}, 95.134560, 0.000020, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -2, -1}, 95.134980, 0.000040, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -1, -1}, 95.135600, 0.000280, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 0, -1}, 275.132120, 0.000460, 1.057000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 1}, 275.132480, 0.000060, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 1, -1}, 275.134000, 0.000390, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 1, 1}, 275.132280, 0.000040, 0.024000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 2, -1}, 275.134240, 0.000050, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 0, -1}, 275.133190, 0.000310, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 0, 1}, 275.132280, 0.000040, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 1, -1}, 275.133810, 0.000050, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 1, 0, -1}, 95.132290, 0.000050, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -2, 0, -1}, 95.134290, 0.000020, 0.044000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, -2, -1}, 275.134450, 0.000030, 0.354000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, -1, -1}, 275.134320, 0.000220, 0.096000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, -1, 1}, 95.132280, 0.000060, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 0, -1}, 95.134170, 0.000360, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 0, 1}, 95.132280, 0.000060, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 1, -1}, 95.134270, 0.000080, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 1, 1}, 95.132280, 0.000010, 0.016000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -3, -1}, 275.134560, 0.000080, 0.066000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -2, -1}, 275.134550, 0.000790, 0.547000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -2, 1}, 95.131660, 0.000110, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, -1}, 275.134410, 0.004650, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, 1}, 95.132230, 0.001430, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, -3}, 95.135050, 0.000030, 0.463000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, -1}, 95.133950, 0.005820, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, 1}, 95.132230, 0.000840, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 1, -3}, 275.135580, 0.000010, 0.090000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 1, -1}, 95.134160, 0.001060, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 1, 1}, 95.132180, 0.000140, 0.015000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 2, -1}, 95.134240, 0.000120, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 2, 1}, 95.132280, 0.000020, 0.013000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 3, -1}, 95.134280, 0.000010, 0.016000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, -1, -1}, 95.133190, 0.000070, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, -1, 1}, 275.132280, 0.000010, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, 0, -1}, 275.133490, 0.000080, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, 1, -1}, 275.133850, 0.000020, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -2, -1}, 275.134390, 0.000060, 0.044000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -2, 1}, 95.132280, 0.000030, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -1, -1}, 95.133460, 0.000070, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -1, 1}, 95.132280, 0.000030, 0.016000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, 0, -1}, 95.133870, 0.000070, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, 0, 1}, 95.132280, 0.000010, 0.013000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, 1, -1}, 95.134020, 0.000020, 0.016000},
	{{0, 8, -13, 0, 0, 0, 0, -2, 0, 0, 0}, 234.686280, 0.000010, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, -2, 0, 1, 0}, 234.688660, 0.000020, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 234.675720, 0.000030, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 0, 0}, 234.688840, 0.000140, 238.919000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 234.675740, 0.000030, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 2, 0, -1, 0}, 234.688870, 0.000020, 0.087000},
	{{0, 8, -13, 0, 0, 0, 0, 2, 0, 0, 0}, 234.686430, 0.000010, 0.040000}
};


static const struct planet_pert plan_pert_elp17 [ELP17_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 0.000020, 0.000680, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1}, 180.000000, 0.000410, 5.997000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1}, 180.000010, 0.000390, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -1}, 180.001340, 0.000010, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1}, 180.000030, 0.000050, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, -1}, 155.901410, 0.000070, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 1}, 155.893880, 0.000060, 0.857000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 155.968620, 0.000060, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 155.967260, 0.000060, 0.069000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, -1}, 155.890290, 0.000050, 1.200000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1}, 155.898640, 0.000060, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, -1}, 24.155180, 0.000010, 0.487000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 1}, 24.155030, 0.000010, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -1, 1}, 168.916350, 0.000010, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, -1}, 335.844750, 0.000070, 18.600000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1}, 335.844940, 0.000070, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 1}, 24.070780, 0.000010, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, -1}, 25.707420, 0.000060, 0.097000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -2, -1}, 180.000140, 0.000010, 0.066000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, -1}, 179.999890, 0.000110, 0.515000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 1}, 180.000010, 0.000070, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -1}, 359.999760, 0.000570, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1}, 179.999980, 0.000030, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, -1}, 359.999560, 0.000020, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, -1}, 335.902940, 0.000020, 1.063000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, 1}, 335.899440, 0.000020, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, -1}, 335.905980, 0.000060, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, -1}, 156.004240, 0.000010, 16.885000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 1}, 156.003930, 0.000010, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, -1}, 335.589470, 0.000020, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, -3, -1, 1, 0}, 275.132280, 0.000010, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, -1, 0}, 95.132280, 0.000040, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 0, 0}, 95.132310, 0.000290, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 0, 2}, 95.132250, 0.000010, 0.108000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 1, 0}, 95.132230, 0.000500, 0.044000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 2, 0}, 95.132170, 0.000040, 0.104000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 1, 0, 0}, 95.132280, 0.000030, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 1, 1, 0}, 95.132280, 0.000040, 0.046000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 0, 0}, 275.132280, 0.000030, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 0, 1}, 77.052900, 0.000030, 0.097000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 1, 0}, 275.132280, 0.000020, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -2, 0, 0}, 275.131050, 0.000020, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, -1, 0}, 275.132280, 0.000060, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 0, 0}, 275.132210, 0.000960, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 0, 2}, 275.132320, 0.000010, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 1, 0}, 275.132280, 0.000060, 1.127000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -3, 0}, 95.132280, 0.000010, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -2, 0}, 95.132510, 0.000170, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, -2}, 95.135300, 0.000060, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 0}, 95.132360, 0.002640, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 2}, 275.131750, 0.000080, 0.450000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -2}, 95.136840, 0.000140, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0}, 95.132260, 0.048340, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 2}, 95.132250, 0.000500, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, -2}, 275.132860, 0.000240, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, 0}, 95.132240, 0.012090, 0.530000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, 2}, 95.132290, 0.000070, 0.035000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 2, 0}, 95.132160, 0.001080, 0.066000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 3, 0}, 95.132040, 0.000100, 0.035000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 4, 0}, 95.132280, 0.000010, 0.024000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, -1, 0}, 95.132390, 0.000140, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, -2}, 95.136410, 0.000010, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, 0}, 95.132280, 0.002270, 0.096000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, 2}, 95.132300, 0.000020, 0.061000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 1, -2}, 275.132870, 0.000010, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 1, 0}, 95.132230, 0.000540, 0.346000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 2, 0}, 95.132170, 0.000050, 0.062000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 2, 0, 0}, 95.132280, 0.000080, 0.107000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 2, 1, 0}, 95.132280, 0.000020, 0.257000},
	{{0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0}, 95.132280, 0.000060, 99999.999000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 275.132280, 0.000040, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 257.755660, 0.000020, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0}, 275.132280, 0.000350, 1.000000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 257.755660, 0.000020, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 275.132280, 0.000030, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -2, 0}, 275.132280, 0.000020, 0.071000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -1, -2}, 275.135520, 0.000010, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -1, 0}, 275.132370, 0.000380, 1.127000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 0, -2}, 95.131340, 0.000010, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 0, 0}, 275.131750, 0.000440, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 1, -2}, 95.134010, 0.000020, 0.819000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 1, 0}, 275.132140, 0.000480, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 2, 0}, 275.132160, 0.000060, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -3, -2}, 95.134610, 0.000030, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -3, 0}, 95.132120, 0.000150, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, -2}, 95.134640, 0.000370, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, 0}, 95.132090, 0.002940, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, 2}, 275.131830, 0.000040, 0.073000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, -2}, 95.134670, 0.003250, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 0}, 95.132340, 0.077550, 8.850000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 2}, 95.131920, 0.000750, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, -4}, 275.134850, 0.000010, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, -2}, 95.135100, 0.009170, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0}, 275.132260, 1.374970, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 2}, 95.132230, 0.001420, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -2}, 95.134720, 0.001980, 4.535000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0}, 275.132170, 0.072450, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 2}, 95.132230, 0.000230, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, -2}, 95.134900, 0.000130, 0.077000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, 0}, 275.132070, 0.004270, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, 2}, 95.132280, 0.000030, 0.015000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 3, -2}, 95.134770, 0.000010, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 3, 0}, 275.131970, 0.000260, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 4, 0}, 275.132030, 0.000020, 0.015000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -2, 0}, 95.132280, 0.000020, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -1, -2}, 95.135500, 0.000020, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -1, 0}, 95.132310, 0.000440, 0.898000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0}, 95.132930, 0.000370, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 1, -2}, 275.134100, 0.000010, 1.283000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 1, 0}, 95.132200, 0.000370, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 2, 0}, 95.132160, 0.000040, 0.024000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, -1, 0}, 275.132280, 0.000010, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 0, -1}, 77.148570, 0.000010, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 0, 0}, 95.132230, 0.000390, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 1, 0}, 95.132280, 0.000050, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 1, 0, 0}, 275.132280, 0.000060, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -2, -1, 0}, 275.132280, 0.000020, 0.044000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -2, 0, 0}, 275.132280, 0.000030, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, -1, -2}, 275.134460, 0.000010, 0.334000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, -1, 0}, 275.132280, 0.000670, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 0, -2}, 95.135440, 0.000030, 0.097000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 0, 0}, 275.132200, 0.000580, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 1, 0}, 275.132100, 0.000080, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -3, -2}, 275.134560, 0.000010, 0.035000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -3, 0}, 275.132280, 0.000020, 0.602000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -2, -2}, 275.134570, 0.000070, 0.066000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -2, 0}, 95.132670, 0.000120, 0.086000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -2, 2}, 95.131910, 0.000020, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, -2}, 275.134560, 0.000260, 0.501000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, 0}, 275.132280, 0.015040, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, 2}, 95.132280, 0.000060, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, -2}, 95.135710, 0.000500, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, 0}, 275.132200, 0.008490, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, 2}, 95.132280, 0.000030, 0.015000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 1, -2}, 95.134460, 0.000140, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 1, 0}, 275.132100, 0.001050, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 2, -2}, 95.134330, 0.000020, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 2, 0}, 275.132000, 0.000100, 0.015000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 3, 0}, 275.132280, 0.000010, 0.013000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, -1, 0}, 95.132340, 0.000100, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, 0, 0}, 95.132200, 0.000090, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, 1, 0}, 95.132280, 0.000020, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, 4, 0, -1, 0}, 95.132280, 0.000020, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 5, -1, -2, 0}, 275.132280, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 5, -1, -1, 0}, 275.132280, 0.000030, 0.021000},
	{{0, 0, 1, 0, 0, 0, 0, 5, -1, 0, 0}, 275.132280, 0.000010, 0.016000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -2, 0}, 275.132310, 0.000180, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -1, 0}, 275.132230, 0.000220, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, 0, 0}, 275.132140, 0.000080, 0.016000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, 1, 0}, 275.132280, 0.000020, 0.013000}
};


static const struct planet_pert plan_pert_elp18 [ELP18_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 270.000000, 0.027020, 99999.999000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2}, 270.000300, 0.000040, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2}, 89.999620, 0.000100, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 89.997520, 0.010350, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 90.000070, 0.000530, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0}, 89.999790, 0.000030, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 245.887100, 0.000070, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 244.233790, 0.001260, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 64.429400, 0.001120, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0}, 65.901690, 0.000060, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, -1, 0}, 114.155070, 0.000030, 0.530000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0}, 294.141830, 0.000250, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 261.052170, 0.000020, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -2, 0}, 66.292360, 0.000030, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -1, 0}, 65.777390, 0.000080, 8.850000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0}, 245.786310, 0.001470, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0}, 245.844950, 0.000080, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 0}, 114.064750, 0.000030, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 0}, 301.712510, 0.000290, 0.095000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 0}, 105.063900, 0.000220, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0}, 270.000210, 0.000220, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, -2}, 89.999750, 0.000020, 0.065000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0}, 90.094720, 0.001660, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -2}, 89.999740, 0.000020, 0.474000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 89.730460, 0.000570, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0}, 90.000030, 0.000070, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -2, 0}, 65.876750, 0.000040, 1.292000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, 0}, 246.392670, 0.000510, 0.080000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0}, 63.779870, 0.000100, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 0}, 66.003910, 0.000230, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -2, 0}, 89.999260, 0.000020, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -1, 0}, 90.000010, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 0, -1}, 185.136030, 0.000030, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 0, 1}, 185.132160, 0.000080, 0.044000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 1, -1}, 5.132270, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 1, 1}, 185.132510, 0.000040, 0.106000},
	{{0, 0, 1, 0, 0, 0, 0, -3, 0, 2, -1}, 5.133520, 0.000070, 0.043000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 0, 0}, 166.994390, 0.000040, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 0, 1}, 5.132280, 0.000030, 0.097000},
	{{0, 0, 1, 0, 0, 0, 0, -2, 0, 1, 0}, 167.073450, 0.000020, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 0, -1}, 5.136660, 0.000030, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, -1, -1, 0, 1}, 185.132280, 0.000020, 0.949000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -2, -1}, 185.134700, 0.000070, 0.019000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -2, 1}, 5.131420, 0.000070, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, -1}, 185.134980, 0.000660, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 1}, 5.131380, 0.001010, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -1}, 185.136030, 0.003280, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 1}, 5.132370, 0.001490, 0.487000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, -1}, 5.133430, 0.006480, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, 1}, 5.132170, 0.001330, 0.065000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 2, -1}, 185.134140, 0.001100, 0.581000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 2, 1}, 5.132280, 0.000070, 0.035000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 3, -1}, 185.134340, 0.000100, 0.067000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, -1, -1}, 185.135050, 0.000050, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, -1, 1}, 5.131420, 0.000050, 0.098000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, -1}, 185.136100, 0.000220, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, 1}, 5.132280, 0.000100, 0.327000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 1, -1}, 5.133540, 0.000250, 0.095000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 1, 1}, 5.132280, 0.000050, 0.061000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 2, -1}, 185.134330, 0.000040, 0.368000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0}, 165.969050, 0.000020, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, -1}, 185.130430, 0.000140, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1}, 185.132280, 0.000120, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, -1}, 5.133340, 0.000030, 1.200000},
	{{0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0}, 345.969050, 0.000020, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -2, -1}, 5.134930, 0.000030, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -1, -1}, 5.135440, 0.000210, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, -1, 1}, 185.133860, 0.000020, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 0, -1}, 185.132270, 0.000040, 0.949000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 0, 1}, 185.132280, 0.000030, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 1, -1}, 5.134040, 0.000460, 0.082000},
	{{0, 0, 1, 0, 0, 0, 0, 1, -1, 2, -1}, 5.134270, 0.000040, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -3, -1}, 185.134560, 0.000190, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, -1}, 185.134590, 0.003110, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, 1}, 185.131930, 0.000820, 3.575000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, -1}, 185.134590, 0.057030, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 1}, 5.131900, 0.014470, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, -1}, 185.129890, 0.001830, 18.600000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1}, 185.133090, 0.000350, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -3}, 185.135040, 0.000100, 0.073000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -1}, 5.134530, 0.057650, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, -1}, 5.134530, 0.003140, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 3, -1}, 5.134560, 0.000190, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -2, -1}, 185.134940, 0.000030, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -1, -1}, 185.135590, 0.000250, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, -1, 1}, 5.133040, 0.000040, 0.069000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 0, -1}, 185.132270, 0.000040, 1.057000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 1}, 185.132280, 0.000020, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 1, -1}, 185.134020, 0.000370, 0.070000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 1, 2, -1}, 185.134280, 0.000040, 0.036000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 0, -1}, 185.133190, 0.000270, 0.081000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 0, 1, -1}, 185.133870, 0.000030, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 2, 1, 0, -1}, 5.132290, 0.000040, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, -2, -1}, 5.134330, 0.000040, 0.354000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, -1, -1}, 185.134380, 0.000150, 0.096000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 0, -1}, 5.134690, 0.000350, 0.042000},
	{{0, 0, 1, 0, 0, 0, 0, 3, -1, 1, -1}, 5.134570, 0.000060, 0.027000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -3, -1}, 5.134510, 0.000090, 0.066000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -2, -1}, 5.134560, 0.000910, 0.547000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -2, 1}, 5.131870, 0.000140, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, -1}, 185.134560, 0.003510, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, 1}, 5.131830, 0.000110, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, -1}, 5.134690, 0.005030, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 1, -1}, 5.134620, 0.000760, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 2, -1}, 5.134700, 0.000070, 0.020000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, -1, -1}, 5.133210, 0.000050, 0.080000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 1, 0, -1}, 185.134510, 0.000060, 0.039000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -2, -1}, 185.134450, 0.000040, 0.044000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, -1, -1}, 5.132270, 0.000020, 0.028000},
	{{0, 0, 1, 0, 0, 0, 0, 5, 0, 0, -1}, 5.134720, 0.000040, 0.020000},
	{{0, 8, -13, 0, 0, 0, 0, -2, 0, 0, 0}, 324.685940, 0.000030, 0.040000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, -1, 0}, 324.677090, 0.000030, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 0, 0, 1, 0}, 144.677090, 0.000030, 0.075000},
	{{0, 8, -13, 0, 0, 0, 0, 2, 0, 0, 0}, 144.686110, 0.000030, 0.040000}
};


static const struct planet_pert plan_pert_elp19 [ELP19_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2}, 180.000000, 0.000020, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2}, 0.000000, 0.000110, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 0.000000, 0.000970, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 0.000000, 0.000350, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0}, 0.000000, 0.000040, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -4, 0}, 0.000000, 0.000120, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -3, -2}, 180.000000, 0.000020, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -3, 0}, 0.000000, 0.001690, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, -2}, 180.000000, 0.000130, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 0.000000, 0.024380, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 2}, 180.000000, 0.000060, 0.750000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, -2}, 180.000000, 0.000760, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 0.000000, 0.371150, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 2}, 0.000000, 0.000200, 0.069000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -2}, 180.000000, 0.000190, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 0.000000, 1.676800, 1.000000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2}, 180.000000, 0.001040, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, -2}, 0.000000, 0.000210, 0.079000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 0.000000, 0.275600, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2}, 180.000000, 0.000660, 0.024000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, -2}, 180.000000, 0.000070, 1.500000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0}, 0.000000, 0.019230, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2}, 180.000000, 0.000110, 0.018000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0}, 0.000000, 0.001380, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 2}, 180.000000, 0.000010, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 0}, 0.000000, 0.000100, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 0.000000, 0.000080, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 0.000000, 0.000970, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, -2}, 180.000000, 0.000020, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 0.000000, 0.012930, 0.089000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -2}, 0.000000, 0.000020, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 0.000000, 0.037470, 0.500000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2}, 180.000000, 0.000030, 0.035000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 0.000000, 0.005850, 0.066000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 2}, 180.000000, 0.000010, 0.024000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 0.000000, 0.000330, 0.035000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 0}, 0.000000, 0.000020, 0.024000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -2, 0}, 0.000000, 0.000030, 0.043000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -1, 0}, 0.000000, 0.000390, 0.098000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 0.000000, 0.000760, 0.333000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0}, 0.000000, 0.000140, 0.062000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, -1, 0}, 0.000000, 0.000010, 0.108000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0}, 0.000000, 0.000010, 0.250000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -3, 0, 0}, 180.000000, 0.000020, 0.107000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, -1, 0}, 180.000000, 0.000010, 0.346000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0}, 180.000000, 0.000220, 0.096000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, -2, 0}, 0.000000, 0.000020, 0.066000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, -1, 0}, 0.000000, 0.000340, 0.530000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, -2}, 0.000000, 0.000030, 0.065000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0}, 0.000000, 0.001410, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 1, 0}, 0.000000, 0.000300, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 2, 0}, 0.000000, 0.000040, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -2, 0}, 0.000000, 0.000020, 0.071000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0}, 0.000000, 0.000040, 1.127000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 0.000000, 0.000110, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0}, 180.000000, 0.000030, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -3, 0}, 180.000000, 0.000060, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -2, 0}, 180.000000, 0.000880, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -1, 0}, 180.000000, 0.002700, 8.850000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0}, 180.000000, 0.045160, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 2}, 0.000000, 0.000090, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0}, 180.000000, 0.003170, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 2}, 0.000000, 0.000020, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 0}, 180.000000, 0.000230, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 0}, 180.000000, 0.000020, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, -2, 0}, 180.000000, 0.000020, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, -1, 0}, 0.000000, 0.000020, 0.898000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 0.000000, 0.000200, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0}, 0.000000, 0.000040, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -4, -1, 0}, 180.000000, 0.000080, 0.134000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -4, 0, 0}, 180.000000, 0.000130, 0.048000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -4, 1, 0}, 180.000000, 0.000010, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, -2, 0}, 180.000000, 0.000070, 0.209000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, -1, 0}, 180.000000, 0.001860, 0.118000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 0, -2}, 180.000000, 0.000010, 0.196000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 0, 0}, 180.000000, 0.002560, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 1, 0}, 180.000000, 0.000250, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 2, 0}, 180.000000, 0.000020, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -3, 0}, 180.000000, 0.000080, 0.059000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -2, 0}, 180.000000, 0.001480, 0.265000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -1, -2}, 0.000000, 0.000020, 0.058000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -1, 0}, 180.000000, 0.037070, 0.105000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -1, 2}, 0.000000, 0.000080, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, -2}, 180.000000, 0.000320, 0.243000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 0}, 180.000000, 0.040480, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 2}, 0.000000, 0.000090, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, -2}, 0.000000, 0.000080, 0.109000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, 0}, 180.000000, 0.003780, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, 2}, 0.000000, 0.000020, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 2, 0}, 180.000000, 0.000320, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 3, 0}, 180.000000, 0.000030, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -4, 0}, 180.000000, 0.000070, 0.034000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -3, 0}, 180.000000, 0.001200, 0.062000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, -2}, 0.000000, 0.000070, 0.034000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, 0}, 180.000000, 0.021650, 0.360000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, 2}, 0.000000, 0.000050, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, -2}, 0.000000, 0.000150, 0.061000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 0}, 180.000000, 0.516420, 0.095000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 2}, 0.000000, 0.001070, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, -2}, 180.000000, 0.005390, 0.322000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 0}, 180.000000, 0.413830, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 2}, 0.000000, 0.000960, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, -2}, 0.000000, 0.000940, 0.099000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, 0}, 180.000000, 0.036490, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, 2}, 0.000000, 0.000190, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 2, -2}, 0.000000, 0.000070, 0.043000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 2, 0}, 180.000000, 0.002950, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 2, 2}, 0.000000, 0.000030, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 3, 0}, 180.000000, 0.000230, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 4, 0}, 180.000000, 0.000020, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -3, 0}, 180.000000, 0.000030, 0.067000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0}, 180.000000, 0.000310, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0}, 0.000000, 0.008190, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 2}, 180.000000, 0.000020, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -2}, 0.000000, 0.000290, 0.474000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 0.000000, 0.010720, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 2}, 180.000000, 0.000030, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, -2}, 180.000000, 0.000050, 0.090000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0}, 0.000000, 0.001280, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0}, 0.000000, 0.000130, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 3, 0}, 0.000000, 0.000010, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -4, 0}, 180.000000, 0.000050, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -3, 0}, 180.000000, 0.000450, 0.071000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -2, 0}, 180.000000, 0.006310, 1.292000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, 0}, 0.000000, 0.071180, 0.080000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, 2}, 180.000000, 0.000170, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, -2}, 0.000000, 0.003620, 0.903000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0}, 0.000000, 0.061280, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 2}, 180.000000, 0.000160, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, -2}, 180.000000, 0.000210, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0}, 0.000000, 0.007340, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 2}, 180.000000, 0.000040, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 2, -2}, 180.000000, 0.000020, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 2, 0}, 0.000000, 0.000730, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 3, 0}, 0.000000, 0.000070, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -3, 0}, 0.000000, 0.000050, 0.077000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -2, 0}, 0.000000, 0.001260, 4.425000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, -2}, 0.000000, 0.000030, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 0}, 0.000000, 0.012700, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 2}, 180.000000, 0.000030, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, -2}, 0.000000, 0.000120, 9.300000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0}, 0.000000, 0.000940, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 0}, 0.000000, 0.000070, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 3, -1, 0}, 0.000000, 0.000010, 0.069000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -2, -2, 0}, 0.000000, 0.000020, 0.116000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -2, -1, 0}, 0.000000, 0.000060, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -2, 0, 0}, 180.000000, 0.000030, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, -2, 0}, 0.000000, 0.000210, 0.104000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, -1, 0}, 0.000000, 0.000580, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, 0, -2}, 0.000000, 0.000050, 0.108000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, 0, 0}, 180.000000, 0.000170, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 0, -1, 0}, 180.000000, 0.000070, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0}, 180.000000, 0.000040, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -3, 0}, 0.000000, 0.000020, 0.602000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -2, 0}, 0.000000, 0.000110, 0.086000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -1, 0}, 180.000000, 0.000690, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 0, -2}, 180.000000, 0.000020, 0.089000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0}, 180.000000, 0.000380, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 0}, 180.000000, 0.000060, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, -2, 0}, 180.000000, 0.000060, 0.050000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, -1, 0}, 180.000000, 0.000130, 0.030000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, 0, 0}, 180.000000, 0.000070, 0.022000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, 1, 0}, 180.000000, 0.000010, 0.017000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -3, 0}, 180.000000, 0.000030, 0.130000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -2, 0}, 180.000000, 0.000790, 0.048000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -1, 0}, 180.000000, 0.001550, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 0, 0}, 180.000000, 0.000760, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 1, 0}, 180.000000, 0.000120, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 2, 0}, 180.000000, 0.000010, 0.014000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -3, 0}, 180.000000, 0.000250, 0.115000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -2, 0}, 180.000000, 0.006860, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -2, 2}, 0.000000, 0.000040, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -1, -2}, 180.000000, 0.000060, 0.119000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -1, 0}, 180.000000, 0.010970, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -1, 2}, 0.000000, 0.000060, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, -2}, 180.000000, 0.000020, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, 0}, 180.000000, 0.004690, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, 2}, 0.000000, 0.000030, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 1, -2}, 0.000000, 0.000020, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 1, 0}, 180.000000, 0.000710, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 2, 0}, 180.000000, 0.000080, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -2, 0}, 0.000000, 0.000180, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -1, 0}, 0.000000, 0.000410, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 0.000000, 0.000220, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 0}, 0.000000, 0.000040, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -3, 0}, 180.000000, 0.000070, 0.093000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -2, 0}, 0.000000, 0.000900, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -1, -2}, 0.000000, 0.000050, 0.096000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -1, 0}, 0.000000, 0.001600, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0}, 0.000000, 0.000730, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 1, 0}, 0.000000, 0.000130, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 2, 0}, 0.000000, 0.000020, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, -3, 0}, 0.000000, 0.000020, 0.085000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, -2, 0}, 0.000000, 0.000180, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, -1, 0}, 0.000000, 0.000110, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, 0, 0}, 0.000000, 0.000010, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 5, -1, -2, 0}, 0.000000, 0.000020, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 5, 1, -1, 0}, 180.000000, 0.000010, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -2, -3, 0}, 180.000000, 0.000020, 0.031000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -2, -2, 0}, 180.000000, 0.000040, 0.022000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -2, -1, 0}, 180.000000, 0.000040, 0.017000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -2, 0, 0}, 180.000000, 0.000010, 0.014000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -3, 0}, 180.000000, 0.000100, 0.030000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -2, 0}, 180.000000, 0.000230, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -1, 0}, 180.000000, 0.000180, 0.017000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, 0, 0}, 180.000000, 0.000060, 0.014000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, 1, 0}, 180.000000, 0.000010, 0.012000},
	{{0, 0, 0, 0, 0, 0, 0, 6, 0, -2, 0}, 0.000000, 0.000010, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 6, 0, -1, 0}, 0.000000, 0.000010, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 6, 1, -3, 0}, 0.000000, 0.000010, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 6, 1, -2, 0}, 0.000000, 0.000030, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 6, 1, -1, 0}, 0.000000, 0.000030, 0.016000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 1}, 14.813110, 0.000010, 0.089000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 1}, 194.813110, 0.000070, 0.487000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, -1}, 14.813110, 0.000060, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, -1}, 194.813110, 0.000040, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, -1}, 194.813110, 0.000530, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 1}, 194.813110, 0.000070, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, -1}, 194.813110, 0.002470, 18.600000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1}, 194.813110, 0.000520, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -1}, 194.813110, 0.000530, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 1}, 194.813110, 0.000060, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, -1}, 194.813110, 0.000040, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, -1}, 14.813110, 0.000040, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, 1}, 194.813110, 0.000010, 0.026000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, -1}, 194.813110, 0.000050, 0.041000}
};

static const struct planet_pert plan_pert_elp20 [ELP20_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1}, 0.000000, 0.000070, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1}, 0.000000, 0.000080, 5.997000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1}, 0.000000, 0.000080, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -1}, 0.000000, 0.000050, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1}, 0.000000, 0.000030, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -4, -1}, 0.000000, 0.000020, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -3, -1}, 0.000000, 0.000190, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -3, 1}, 0.000000, 0.000060, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, -1}, 0.000000, 0.002000, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 1}, 0.000000, 0.000760, 0.083000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, -3}, 180.000000, 0.000020, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, -1}, 0.000000, 0.016960, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 1}, 0.000000, 0.014190, 0.857000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 3}, 0.000000, 0.000020, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1}, 0.000000, 0.012150, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1}, 0.000000, 0.016230, 0.069000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 3}, 180.000000, 0.000030, 0.024000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, -3}, 0.000000, 0.000020, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, -1}, 0.000000, 0.012790, 1.200000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1}, 0.000000, 0.013380, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3}, 180.000000, 0.000020, 0.018000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, -1}, 0.000000, 0.000790, 0.071000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1}, 0.000000, 0.001610, 0.024000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 3, -1}, 0.000000, 0.000060, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 1}, 0.000000, 0.000160, 0.018000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 1}, 0.000000, 0.000010, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, -1}, 0.000000, 0.000080, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 1}, 0.000000, 0.000030, 0.090000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, -1}, 0.000000, 0.000570, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 1}, 0.000000, 0.000480, 0.462000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -1}, 0.000000, 0.000090, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1}, 0.000000, 0.000290, 0.065000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, -1}, 0.000000, 0.000310, 0.545000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1}, 0.000000, 0.000280, 0.035000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 2, -1}, 0.000000, 0.000010, 0.066000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 1}, 0.000000, 0.000030, 0.024000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -1, -1}, 0.000000, 0.000020, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -1, 1}, 0.000000, 0.000010, 0.316000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 0, -1}, 180.000000, 0.000010, 0.327000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 1}, 180.000000, 0.000010, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, -1, -1}, 180.000000, 0.000030, 0.065000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, -1}, 0.000000, 0.000030, 0.487000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 1}, 0.000000, 0.000050, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 1, -1}, 0.000000, 0.000050, 0.089000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 1, 1}, 0.000000, 0.000020, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -2, -1}, 180.000000, 0.000040, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -2, 1}, 180.000000, 0.000040, 3.575000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -1, -1}, 180.000000, 0.000020, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -1, 1}, 0.000000, 0.000140, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, -1}, 180.000000, 0.002020, 18.600000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1}, 180.000000, 0.002020, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 1, -1}, 180.000000, 0.000090, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1}, 180.000000, 0.000260, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 1}, 180.000000, 0.000030, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 1}, 0.000000, 0.000010, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -4, 0, -1}, 180.000000, 0.000010, 0.137000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, -1, -1}, 180.000000, 0.000070, 0.202000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, -1, 1}, 180.000000, 0.000080, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 0, -1}, 180.000000, 0.000280, 0.120000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 0, 1}, 180.000000, 0.000120, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 1, -1}, 180.000000, 0.000020, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 1, 1}, 180.000000, 0.000020, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -2, -1}, 180.000000, 0.000110, 0.058000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -1, -1}, 180.000000, 0.001350, 0.254000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -1, 1}, 180.000000, 0.001580, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, -3}, 180.000000, 0.000010, 0.057000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, -1}, 180.000000, 0.005460, 0.107000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 1}, 180.000000, 0.001930, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, -1}, 180.000000, 0.000350, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, 1}, 180.000000, 0.000290, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 2, -1}, 180.000000, 0.000030, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 2, 1}, 180.000000, 0.000030, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -4, -1}, 180.000000, 0.000010, 0.023000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -3, -1}, 180.000000, 0.000140, 0.034000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -3, 1}, 180.000000, 0.000020, 0.384000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, -1}, 180.000000, 0.001640, 0.062000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, 1}, 0.000000, 0.000160, 0.094000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, -3}, 180.000000, 0.000030, 0.034000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, -1}, 180.000000, 0.018690, 0.340000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 1}, 180.000000, 0.022290, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 3}, 0.000000, 0.000030, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, -3}, 180.000000, 0.000220, 0.060000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, -1}, 180.000000, 0.074300, 0.097000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 1}, 180.000000, 0.019990, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 3}, 0.000000, 0.000020, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, -3}, 0.000000, 0.000040, 0.305000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, -1}, 180.000000, 0.004430, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, 1}, 180.000000, 0.002850, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 2, -1}, 180.000000, 0.000320, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 2, 1}, 180.000000, 0.000310, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 3, -1}, 180.000000, 0.000020, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 3, 1}, 180.000000, 0.000030, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, -1}, 0.000000, 0.000260, 0.515000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 1}, 0.000000, 0.000370, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -3}, 0.000000, 0.000010, 0.064000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -1}, 0.000000, 0.002950, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1}, 0.000000, 0.000530, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, -1}, 0.000000, 0.000220, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 1}, 0.000000, 0.000100, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 2, -1}, 0.000000, 0.000020, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 1}, 0.000000, 0.000010, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -3, -1}, 180.000000, 0.000050, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -2, -1}, 180.000000, 0.000200, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -2, 1}, 180.000000, 0.000140, 0.079000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, -1}, 0.000000, 0.001980, 1.063000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, 1}, 0.000000, 0.003300, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, -3}, 0.000000, 0.000140, 0.069000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, -1}, 0.000000, 0.030430, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 1}, 0.000000, 0.003180, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, -3}, 180.000000, 0.000010, 0.785000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, -1}, 0.000000, 0.002070, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 1}, 0.000000, 0.000600, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 2, -1}, 0.000000, 0.000160, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 2, 1}, 0.000000, 0.000080, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 3, -1}, 0.000000, 0.000010, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -2, -1}, 0.000000, 0.000060, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -2, 1}, 0.000000, 0.000030, 0.073000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, -1}, 0.000000, 0.000530, 16.885000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 1}, 0.000000, 0.000570, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, -1}, 0.000000, 0.000680, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 1}, 0.000000, 0.000070, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 1, -1}, 0.000000, 0.000030, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, -1, -1}, 0.000000, 0.000050, 0.106000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, -1, 1}, 0.000000, 0.000030, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, 0, -1}, 0.000000, 0.000060, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -1, -1}, 180.000000, 0.000030, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -1, 1}, 180.000000, 0.000050, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 0, -1}, 180.000000, 0.000090, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 1}, 180.000000, 0.000030, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 1, -1}, 180.000000, 0.000010, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, -1, -1}, 180.000000, 0.000010, 0.051000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, -1, 1}, 180.000000, 0.000010, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, 0, -1}, 180.000000, 0.000010, 0.030000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -2, -1}, 180.000000, 0.000010, 0.133000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -2, 1}, 180.000000, 0.000060, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -1, -1}, 180.000000, 0.000170, 0.048000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -1, 1}, 180.000000, 0.000120, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 0, -1}, 180.000000, 0.000150, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 0, 1}, 180.000000, 0.000060, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 1, -1}, 180.000000, 0.000020, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 1, 1}, 180.000000, 0.000010, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -2, -1}, 180.000000, 0.000130, 0.117000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -2, 1}, 180.000000, 0.000540, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -1, -1}, 180.000000, 0.001490, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -1, 1}, 180.000000, 0.000850, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, -3}, 180.000000, 0.000010, 0.122000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, -1}, 180.000000, 0.001040, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, 1}, 180.000000, 0.000400, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 1, -1}, 180.000000, 0.000140, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 1, 1}, 180.000000, 0.000080, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 2, -1}, 180.000000, 0.000020, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 2, 1}, 180.000000, 0.000010, 0.011000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -2, 1}, 0.000000, 0.000010, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -1, -1}, 0.000000, 0.000080, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -1, 1}, 0.000000, 0.000030, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, 0, -1}, 0.000000, 0.000070, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 1}, 0.000000, 0.000020, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, 1, -1}, 0.000000, 0.000010, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -2, 1}, 0.000000, 0.000070, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -1, -1}, 0.000000, 0.000430, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -1, 1}, 0.000000, 0.000130, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 0, -1}, 0.000000, 0.000280, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 1}, 0.000000, 0.000060, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 1, -1}, 0.000000, 0.000040, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 1, 1}, 0.000000, 0.000010, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, -2, 1}, 0.000000, 0.000010, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, -1, -1}, 0.000000, 0.000020, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -3, 1}, 180.000000, 0.000010, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -2, -1}, 180.000000, 0.000030, 0.030000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -2, 1}, 180.000000, 0.000020, 0.017000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -1, -1}, 180.000000, 0.000040, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -1, 1}, 180.000000, 0.000020, 0.014000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, 0, -1}, 180.000000, 0.000020, 0.017000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, -1, 0}, 194.813110, 0.000020, 0.041000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0}, 194.813110, 0.000410, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, 0}, 194.813110, 0.000100, 0.530000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 1, 0, 0}, 194.813110, 0.000020, 0.096000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, 0}, 194.813110, 0.000020, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, -2}, 194.813110, 0.000030, 0.037000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 0}, 194.813110, 0.000660, 8.850000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, -2}, 194.813110, 0.000080, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0}, 14.813110, 0.011720, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 2}, 194.813110, 0.000010, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -2}, 194.813110, 0.000020, 4.535000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0}, 14.813110, 0.000620, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, 0}, 14.813110, 0.000040, 0.025000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, 0}, 14.813110, 0.000130, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, 0}, 14.813110, 0.000070, 0.026000}
};

static const struct planet_pert plan_pert_elp21 [ELP21_SIZE] = 
{
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, 270.000000, 0.001490, 99999.999000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -2}, 90.000000, 0.000100, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0}, 270.000000, 0.001740, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0}, 270.000000, 0.000290, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0}, 270.000000, 0.000030, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -4, 0}, 90.000000, 0.000070, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -3, 0}, 90.000000, 0.001060, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 0}, 90.000000, 0.017640, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -2, 2}, 90.000000, 0.000130, 0.750000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, -2}, 90.000000, 0.000020, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0}, 90.000000, 0.326540, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 2}, 270.000000, 0.000840, 0.069000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -2}, 90.000000, 0.000470, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0}, 270.000000, 0.123020, 1.000000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2}, 90.000000, 0.000400, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, -2}, 90.000000, 0.000620, 0.079000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0}, 270.000000, 0.263960, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, -2}, 270.000000, 0.000080, 1.500000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0}, 270.000000, 0.014490, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0}, 270.000000, 0.000890, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 0}, 270.000000, 0.000060, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -3, 0}, 90.000000, 0.000050, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -2, 0}, 90.000000, 0.000690, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 0}, 90.000000, 0.010660, 0.089000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, -1, 2}, 270.000000, 0.000020, 0.064000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -2}, 90.000000, 0.000030, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0}, 270.000000, 0.005360, 0.500000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0}, 270.000000, 0.005870, 0.066000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0}, 270.000000, 0.000260, 0.035000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -2, 0}, 90.000000, 0.000020, 0.043000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, -1, 0}, 90.000000, 0.000290, 0.098000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0}, 270.000000, 0.000160, 0.333000},
	{{0, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0}, 270.000000, 0.000140, 0.062000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, -1, 0}, 270.000000, 0.000040, 0.346000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -2, 0, 0}, 90.000000, 0.000150, 0.096000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, -1, 0}, 270.000000, 0.000290, 0.530000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, -2}, 90.000000, 0.000030, 0.065000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0}, 270.000000, 0.001260, 0.088000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 1, 0}, 270.000000, 0.000280, 0.041000},
	{{0, 0, 0, 0, 0, 0, 0, 1, -1, 2, 0}, 270.000000, 0.000030, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -2, 0}, 90.000000, 0.000020, 0.071000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0}, 90.000000, 0.000040, 1.127000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0}, 270.000000, 0.000080, 0.081000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0}, 90.000000, 0.000020, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -3, 0}, 270.000000, 0.000040, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -2, 0}, 270.000000, 0.000840, 0.076000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, -1, 0}, 270.000000, 0.002140, 8.850000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, -2}, 270.000000, 0.000080, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0}, 90.000000, 0.041940, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 0}, 90.000000, 0.002350, 0.038000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 0}, 90.000000, 0.000150, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, -1, 0}, 270.000000, 0.000020, 0.898000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0}, 270.000000, 0.000190, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0}, 270.000000, 0.000030, 0.036000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -4, -1, 0}, 90.000000, 0.000040, 0.134000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -4, 0, 0}, 90.000000, 0.000160, 0.048000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, -2, 0}, 270.000000, 0.000080, 0.209000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, -1, 0}, 90.000000, 0.001120, 0.118000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 0, 0}, 90.000000, 0.003100, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -3, 1, 0}, 90.000000, 0.000220, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -3, 0}, 270.000000, 0.000080, 0.059000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -2, 0}, 270.000000, 0.001730, 0.265000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -1, -2}, 270.000000, 0.000050, 0.058000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, -1, 0}, 90.000000, 0.024900, 0.105000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, -2}, 270.000000, 0.000140, 0.243000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 0, 0}, 90.000000, 0.049700, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, -2}, 270.000000, 0.000040, 0.109000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 1, 0}, 90.000000, 0.003310, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -2, 2, 0}, 90.000000, 0.000230, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -4, 0}, 270.000000, 0.000060, 0.034000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -3, 0}, 270.000000, 0.001250, 0.062000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, -2}, 270.000000, 0.000040, 0.034000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, 0}, 270.000000, 0.025290, 0.360000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -2, 2}, 270.000000, 0.000080, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, -2}, 270.000000, 0.000810, 0.061000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 0}, 90.000000, 0.382450, 0.095000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, -1, 2}, 270.000000, 0.000090, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, -2}, 270.000000, 0.001650, 0.322000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 0, 0}, 90.000000, 0.513950, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, -2}, 270.000000, 0.000530, 0.099000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 1, 0}, 90.000000, 0.032220, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 2, -2}, 270.000000, 0.000050, 0.043000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 2, 0}, 90.000000, 0.002130, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, -1, 3, 0}, 90.000000, 0.000150, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -3, 0}, 270.000000, 0.000020, 0.067000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0}, 90.000000, 0.000040, 0.564000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0}, 270.000000, 0.006330, 0.087000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, -2}, 90.000000, 0.000050, 0.474000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0}, 270.000000, 0.013560, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, -2}, 90.000000, 0.000030, 0.090000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0}, 270.000000, 0.001140, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0}, 270.000000, 0.000090, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -4, 0}, 270.000000, 0.000040, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -3, 0}, 270.000000, 0.000430, 0.071000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -2, 0}, 270.000000, 0.000390, 1.292000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, -2}, 90.000000, 0.000120, 0.070000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, -1, 0}, 270.000000, 0.060680, 0.080000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, -2}, 90.000000, 0.000340, 0.903000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0}, 270.000000, 0.077540, 0.039000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, -2}, 90.000000, 0.000140, 0.082000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0}, 270.000000, 0.006580, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 2, 0}, 270.000000, 0.000530, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 1, 3, 0}, 270.000000, 0.000040, 0.015000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -3, 0}, 90.000000, 0.000050, 0.077000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -2, 0}, 90.000000, 0.000550, 4.425000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, -2}, 90.000000, 0.000050, 0.075000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, -1, 0}, 270.000000, 0.011860, 0.074000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0}, 270.000000, 0.000740, 0.037000},
	{{0, 0, 0, 0, 0, 0, 0, 2, 2, 1, 0}, 270.000000, 0.000050, 0.025000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -2, -1, 0}, 270.000000, 0.000070, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -2, 0, 0}, 90.000000, 0.000050, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, -2, 0}, 270.000000, 0.000130, 0.104000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, -1, 0}, 270.000000, 0.000640, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, 0, -2}, 270.000000, 0.000040, 0.108000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, 0, 0}, 90.000000, 0.000400, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 3, -1, 1, 0}, 90.000000, 0.000020, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 0, -1, 0}, 90.000000, 0.000060, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0}, 90.000000, 0.000030, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -2, 0}, 270.000000, 0.000100, 0.086000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, -1, 0}, 90.000000, 0.000530, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 0, -2}, 90.000000, 0.000020, 0.089000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 0}, 90.000000, 0.000270, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 0}, 90.000000, 0.000040, 0.019000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, -2, 0}, 90.000000, 0.000040, 0.050000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, -1, 0}, 90.000000, 0.000120, 0.030000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -3, 0, 0}, 90.000000, 0.000060, 0.022000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -2, 0}, 90.000000, 0.000540, 0.048000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, -1, 0}, 90.000000, 0.001400, 0.029000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 0, -2}, 90.000000, 0.000020, 0.048000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 0, 0}, 90.000000, 0.000640, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -2, 1, 0}, 90.000000, 0.000090, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -3, 0}, 90.000000, 0.000110, 0.115000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -2, 0}, 90.000000, 0.004760, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -1, -2}, 90.000000, 0.000070, 0.119000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, -1, 0}, 90.000000, 0.009930, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, -2}, 90.000000, 0.000140, 0.046000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 0, 0}, 90.000000, 0.003940, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 1, 0}, 90.000000, 0.000510, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, -1, 2, 0}, 90.000000, 0.000050, 0.013000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -2, 0}, 270.000000, 0.000120, 0.044000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, -1, 0}, 270.000000, 0.000380, 0.028000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0}, 270.000000, 0.000190, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 0}, 270.000000, 0.000030, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -3, 0}, 90.000000, 0.000060, 0.093000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -2, 0}, 270.000000, 0.000600, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -1, -2}, 270.000000, 0.000040, 0.096000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, -1, 0}, 270.000000, 0.001460, 0.027000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 0, -2}, 270.000000, 0.000050, 0.042000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 0, 0}, 270.000000, 0.000610, 0.020000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 1, 1, 0}, 270.000000, 0.000090, 0.016000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, -2, 0}, 270.000000, 0.000130, 0.040000},
	{{0, 0, 0, 0, 0, 0, 0, 4, 2, -1, 0}, 270.000000, 0.000090, 0.026000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -2, -2, 0}, 90.000000, 0.000030, 0.022000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -2, -1, 0}, 90.000000, 0.000030, 0.017000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -3, 0}, 90.000000, 0.000060, 0.030000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -2, 0}, 90.000000, 0.000170, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, -1, 0}, 90.000000, 0.000130, 0.017000},
	{{0, 0, 0, 0, 0, 0, 0, 6, -1, 0, 0}, 90.000000, 0.000040, 0.014000},
	{{0, 0, 0, 0, 0, 0, 0, 6, 1, -2, 0}, 270.000000, 0.000020, 0.021000},
	{{0, 0, 0, 0, 0, 0, 0, 6, 1, -1, 0}, 270.000000, 0.000020, 0.016000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 0, -1}, 284.813110, 0.000030, 0.040000},
	{{0, 0, 1, 0, 0, 0, 0, -1, 0, 1, -1}, 104.813110, 0.000050, 0.087000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -2, -1}, 284.813110, 0.000030, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, -1}, 284.813110, 0.000490, 0.075000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, -1, 1}, 104.813110, 0.000120, 0.074000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 1, -1}, 104.813110, 0.000490, 0.076000},
	{{0, 0, 1, 0, 0, 0, 0, 1, 0, 2, -1}, 104.813110, 0.000030, 0.038000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, -1, -1}, 284.813110, 0.000030, 0.088000},
	{{0, 0, 1, 0, 0, 0, 0, 3, 0, 0, -1}, 104.813110, 0.000040, 0.041000}
};


static const tidal_effects tidal_effects_elp22 [ELP22_SIZE] = 
{
	{0, {1, 1, -1, -1}, 192.936650, 0.000040, 0.075000},
	{0, {1, 1, 0, -1}, 192.936650, 0.000820, 18.600000},
	{0, {1, 1, 1, -1}, 192.936650, 0.000040, 0.076000}
};


static const tidal_effects tidal_effects_elp23 [ELP23_SIZE] = 
{
	{0, {1, 1, 0, -2}, 192.936630, 0.000040, 0.074000},
	{0, {1, 1, 0, 0}, 192.936640, 0.000040, 0.075000}
};

static const tidal_effects tidal_effects_elp24 [ELP24_SIZE] = 
{
	{0, {1, 1, -1, -1}, 282.936650, 0.000040, 0.075000},
	{0, {1, 1, 1, -1}, 102.936650, 0.000040, 0.076000}
};

static const tidal_effects tidal_effects_elp25 [ELP25_SIZE] = 
{
	{0, {0, 0, 1, 0}, 0.000000, 0.000580, 0.075000},
	{0, {0, 0, 2, 0}, 0.000000, 0.000040, 0.038000},
	{0, {2, 0, -2, 0}, 0.000000, 0.000020, 0.564000},
	{0, {2, 0, -1, 0}, 0.000000, 0.000210, 0.087000},
	{0, {2, 0, 0, 0}, 0.000000, 0.000090, 0.040000},
	{0, {2, 0, 1, 0}, 0.000000, 0.000010, 0.026000}
};

static const tidal_effects tidal_effects_elp26 [ELP26_SIZE] = 
{
	{0, {0, 0, 0, 1}, 180.000000, 0.000050, 0.075000},
	{0, {0, 0, 1, -1}, 0.000000, 0.000030, 5.997000},
	{0, {0, 0, 1, 1}, 0.000000, 0.000030, 0.037000},
	{0, {2, 0, 0, -1}, 0.000000, 0.000010, 0.088000}
};

static const tidal_effects tidal_effects_elp27 [ELP27_SIZE] = 
{
	{0, {0, 0, 0, 0}, 90.000000, 0.003560, 99999.999000},
	{0, {0, 0, 1, 0}, 270.000000, 0.000720, 0.075000},
	{0, {0, 0, 2, 0}, 270.000000, 0.000030, 0.038000},
	{0, {2, 0, -1, 0}, 270.000000, 0.000190, 0.087000},
	{0, {2, 0, 0, 0}, 270.000000, 0.000130, 0.040000}
};

static const moon_pert moon_pert_elp28 [ELP28_SIZE] = 
{
	{0, {0, 0, 0, 1}, 303.961850, 0.000040, 0.075000},
	{0, {0, 0, 1, -1}, 259.883930, 0.000160, 5.997000},
	{0, {0, 0, 2, -2}, 0.430200, 0.000400, 2.998000},
	{0, {0, 0, 3, -2}, 0.433790, 0.000020, 0.077000},
	{0, {0, 1, -1, 0}, 359.998580, 0.000140, 0.082000},
	{0, {0, 1, 0, 0}, 359.999820, 0.002230, 1.000000},
	{0, {0, 1, 1, 0}, 359.999610, 0.000140, 0.070000},
	{0, {1, 0, -1, 0}, 359.993310, 0.000090, 1.127000},
	{0, {1, 0, 0, 0}, 359.995370, 0.000010, 0.081000},
	{0, {1, 1, -1, 0}, 0.064180, 0.000030, 8.850000},
	{0, {2, -1, -1, 0}, 180.000950, 0.000040, 0.095000},
	{0, {2, -1, 0, 0}, 180.000140, 0.000030, 0.042000},
	{0, {2, 0, -3, 0}, 179.981260, 0.000010, 0.067000},
	{0, {2, 0, -2, 0}, 179.983660, 0.000250, 0.564000},
	{0, {2, 0, -1, 0}, 179.996380, 0.000140, 0.087000},
	{0, {2, 0, 0, -2}, 179.958640, 0.000030, 0.474000},
	{0, {2, 0, 0, 0}, 179.999040, 0.000020, 0.040000},
	{0, {2, 1, -2, 0}, 179.991840, 0.000020, 1.292000},
	{0, {2, 1, -1, 0}, 0.003130, 0.000020, 0.080000},
	{0, {2, 1, 0, 0}, 359.999650, 0.000020, 0.039000}
};


static const moon_pert moon_pert_elp29 [ELP29_SIZE] = 
{
	{0, {0, 0, 1, -1}, 0.021990, 0.000030, 5.997000},
	{0, {0, 0, 1, 0}, 245.990670, 0.000010, 0.075000},
	{0, {0, 0, 1, 1}, 0.005300, 0.000010, 0.037000},
	{0, {0, 0, 2, -3}, 0.422830, 0.000020, 0.073000},
	{0, {0, 0, 2, -1}, 0.745050, 0.000010, 0.076000},
	{0, {0, 1, -1, -1}, 359.999820, 0.000010, 0.039000},
	{0, {0, 1, 0, -1}, 359.999820, 0.000100, 0.081000},
	{0, {0, 1, 0, 1}, 359.999820, 0.000100, 0.069000},
	{0, {0, 1, 1, 1}, 359.999820, 0.000010, 0.036000},
	{0, {2, 0, -2, -1}, 179.983560, 0.000010, 0.066000},
	{0, {2, 0, -2, 1}, 179.983530, 0.000010, 0.086000},
	{0, {2, 0, 0, -1}, 179.994780, 0.000050, 0.088000}
};

static const moon_pert moon_pert_elp30 [ELP30_SIZE] = 
{
	{0, {0, 0, 0, 0}, 90.000000, 0.001300, 99999.999000},
	{0, {0, 0, 0, 1}, 213.957200, 0.000030, 0.075000},
	{0, {0, 0, 0, 2}, 270.037450, 0.000020, 0.037000},
	{0, {0, 0, 1, 0}, 90.075970, 0.000040, 0.075000},
	{0, {0, 0, 3, -2}, 270.434290, 0.000020, 0.077000},
	{0, {0, 1, -1, 0}, 89.999190, 0.000130, 0.082000},
	{0, {0, 1, 0, 0}, 270.000070, 0.000220, 1.000000},
	{0, {0, 1, 1, 0}, 269.999030, 0.000110, 0.070000},
	{0, {2, -1, -1, 0}, 89.998150, 0.000020, 0.095000},
	{0, {2, -1, 0, 0}, 90.000520, 0.000030, 0.042000},
	{0, {2, 0, -2, 0}, 269.985850, 0.000050, 0.564000},
	{0, {2, 0, -1, 0}, 89.998630, 0.000130, 0.087000},
	{0, {2, 1, -1, 0}, 269.999820, 0.000020, 0.080000},
	{0, {2, 1, 0, 0}, 269.999820, 0.000030, 0.039000}
};


static const rel_pert rel_pert_elp31 [ELP31_SIZE] = 
{
	{0, {0, 1, -1, 0}, 179.934730, 0.000060, 0.082000},
	{0, {0, 1, 0, 0}, 179.985320, 0.000810, 1.000000},
	{0, {0, 1, 1, 0}, 179.963230, 0.000050, 0.070000},
	{0, {1, 0, 0, 0}, 0.000010, 0.000130, 0.081000},
	{0, {1, 1, 0, 0}, 180.022820, 0.000010, 0.075000},
	{0, {2, -1, -1, 0}, 0.022640, 0.000020, 0.095000},
	{0, {2, 0, -1, 0}, 359.988260, 0.000020, 0.087000},
	{0, {2, 0, 0, 0}, 180.000190, 0.000550, 0.040000},
	{0, {2, 0, 1, 0}, 180.000170, 0.000060, 0.026000},
	{0, {2, 1, -1, 0}, 180.749540, 0.000010, 0.080000},
	{0, {4, 0, -1, 0}, 180.000350, 0.000010, 0.028000}
};

static const rel_pert rel_pert_elp32 [ELP32_SIZE] = 
{
	{0, {0, 1, 0, -1}, 179.998030, 0.000040, 0.081000},
	{0, {0, 1, 0, 1}, 179.997980, 0.000040, 0.069000},
	{0, {2, 0, 0, -1}, 359.998100, 0.000020, 0.088000},
	{0, {2, 0, 0, 1}, 180.000260, 0.000020, 0.026000}
};

static const rel_pert rel_pert_elp33 [ELP33_SIZE] = 
{
	{0, {0, 0, 0, 0}, 270.000000, 0.008280, 99999.999000},
	{0, {0, 0, 1, 0}, 89.999940, 0.000430, 0.075000},
	{0, {0, 1, -1, 0}, 269.932920, 0.000050, 0.082000},
	{0, {0, 1, 0, 0}, 270.009080, 0.000090, 1.000000},
	{0, {0, 1, 1, 0}, 89.957650, 0.000050, 0.070000},
	{0, {1, 0, 0, 0}, 270.000020, 0.000060, 0.081000},
	{0, {2, -1, 0, 0}, 89.970710, 0.000020, 0.042000},
	{0, {2, 0, -1, 0}, 269.993670, 0.000030, 0.087000},
	{0, {2, 0, 0, 0}, 90.000140, 0.001060, 0.040000},
	{0, {2, 0, 1, 0}, 90.000100, 0.000080, 0.026000}
};


static const plan_sol_pert plan_sol_pert_elp34 [ELP34_SIZE] = 
{
	{0, {0, 1, -2, 0}, 0.000000, 0.000070, 0.039000},
	{0, {0, 1, -1, 0}, 0.000000, 0.001080, 0.082000},
	{0, {0, 1, 0, 0}, 0.000000, 0.004870, 1.000000},
	{0, {0, 1, 1, 0}, 0.000000, 0.000800, 0.070000},
	{0, {0, 1, 2, 0}, 0.000000, 0.000060, 0.036000},
	{0, {0, 2, -1, 0}, 0.000000, 0.000040, 0.089000},
	{0, {0, 2, 0, 0}, 0.000000, 0.000110, 0.500000},
	{0, {0, 2, 1, 0}, 0.000000, 0.000020, 0.066000},
	{0, {1, 1, 0, 0}, 180.000000, 0.000130, 0.075000},
	{0, {2, -2, -1, 0}, 180.000000, 0.000110, 0.105000},
	{0, {2, -2, 0, 0}, 180.000000, 0.000120, 0.044000},
	{0, {2, -2, 1, 0}, 180.000000, 0.000010, 0.028000},
	{0, {2, -1, -2, 0}, 180.000000, 0.000060, 0.360000},
	{0, {2, -1, -1, 0}, 180.000000, 0.001500, 0.095000},
	{0, {2, -1, 0, -2}, 180.000000, 0.000020, 0.322000},
	{0, {2, -1, 0, 0}, 180.000000, 0.001200, 0.042000},
	{0, {2, -1, 1, 0}, 180.000000, 0.000110, 0.027000},
	{0, {2, 0, -1, 0}, 0.000000, 0.000020, 0.087000},
	{0, {2, 0, 0, 0}, 0.000000, 0.000030, 0.040000},
	{0, {2, 1, -2, 0}, 180.000000, 0.000020, 1.292000},
	{0, {2, 1, -1, 0}, 0.000000, 0.000210, 0.080000},
	{0, {2, 1, 0, -2}, 0.000000, 0.000010, 0.903000},
	{0, {2, 1, 0, 0}, 0.000000, 0.000180, 0.039000},
	{0, {2, 1, 1, 0}, 0.000000, 0.000020, 0.026000},
	{0, {2, 2, -1, 0}, 0.000000, 0.000040, 0.074000},
	{0, {4, -1, -2, 0}, 180.000000, 0.000020, 0.046000},
	{0, {4, -1, -1, 0}, 180.000000, 0.000030, 0.028000},
	{0, {4, -1, 0, 0}, 180.000000, 0.000010, 0.021000}
};

static const plan_sol_pert plan_sol_pert_elp35 [ELP35_SIZE] = 
{
	{0, {0, 1, -1, -1}, 0.000000, 0.000050, 0.039000},
	{0, {0, 1, -1, 1}, 0.000000, 0.000040, 0.857000},
	{0, {0, 1, 0, -1}, 0.000000, 0.000040, 0.081000},
	{0, {0, 1, 0, 1}, 0.000000, 0.000050, 0.069000},
	{0, {0, 1, 1, -1}, 0.000000, 0.000040, 1.200000},
	{0, {0, 1, 1, 1}, 0.000000, 0.000040, 0.036000},
	{0, {2, -2, 0, -1}, 180.000000, 0.000020, 0.107000},
	{0, {2, -1, -1, -1}, 180.000000, 0.000050, 0.340000},
	{0, {2, -1, -1, 1}, 180.000000, 0.000060, 0.042000},
	{0, {2, -1, 0, -1}, 180.000000, 0.000220, 0.097000},
	{0, {2, -1, 0, 1}, 180.000000, 0.000060, 0.027000},
	{0, {2, -1, 1, -1}, 180.000000, 0.000010, 0.042000},
	{0, {2, 1, 0, -1}, 0.000000, 0.000090, 0.081000}
};

static const plan_sol_pert plan_sol_pert_elp36 [ELP36_SIZE] = 
{
	{0, {0, 1, -2, 0}, 90.000000, 0.000050, 0.039000},
	{0, {0, 1, -1, 0}, 90.000000, 0.000950, 0.082000},
	{0, {0, 1, 0, 0}, 270.000000, 0.000360, 1.000000},
	{0, {0, 1, 1, 0}, 270.000000, 0.000770, 0.070000},
	{0, {0, 1, 2, 0}, 270.000000, 0.000040, 0.036000},
	{0, {0, 2, -1, 0}, 90.000000, 0.000030, 0.089000},
	{0, {1, 1, 0, 0}, 90.000000, 0.000120, 0.075000},
	{0, {2, -2, -1, 0}, 90.000000, 0.000070, 0.105000},
	{0, {2, -2, 0, 0}, 90.000000, 0.000140, 0.044000},
	{0, {2, -1, -2, 0}, 270.000000, 0.000070, 0.360000},
	{0, {2, -1, -1, 0}, 90.000000, 0.001110, 0.095000},
	{0, {2, -1, 0, 0}, 90.000000, 0.001490, 0.042000},
	{0, {2, -1, 1, 0}, 90.000000, 0.000090, 0.027000},
	{0, {2, 0, 0, 0}, 270.000000, 0.000040, 0.040000},
	{0, {2, 1, -1, 0}, 270.000000, 0.000180, 0.080000},
	{0, {2, 1, 0, 0}, 270.000000, 0.000230, 0.039000},
	{0, {2, 1, 1, 0}, 270.000000, 0.000020, 0.026000},
	{0, {2, 2, -1, 0}, 270.000000, 0.000030, 0.074000},
	{0, {4, -1, -1, 0}, 90.000000, 0.000030, 0.028000}
};

/* sum lunar elp1 series */
static double sum_series_elp1 (double* t)
{
	double result = 0;
	double x,y;
	double tgv;
	int i,j,k;
	
  	for (j=0; j< ELP1_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(main_elp1[j].A) > pre[0]) {
			/* derivatives of A */
			tgv = main_elp1[j].B[0] + DTASM * main_elp1[j].B[4];
			x = main_elp1[j].A + tgv * (DELNP - AM * DELNU) + 
				main_elp1[j].B[1] * DELG + main_elp1[j].B[2] * 
				DELE + main_elp1[j].B[3] * DELEP;
		
			y = 0;
			for (k = 0; k < 5; k++) {
				for (i = 0; i < 4; i++) 
					y += main_elp1[j].ilu[i] * del[i][k] * t[k];
			}
			
			/* y in correct quad */
			y = ln_range_radians2(y);
			result += x * sin(y);
		}
	}
	return result;
}

/* sum lunar elp2 series */
static double sum_series_elp2 (double* t)
{
	double result = 0;
	double x,y;
	double tgv;
	int i,j,k;
	
  	for (j=0; j< ELP2_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(main_elp2[j].A) > pre[1]) {
			/* derivatives of A */
			tgv = main_elp2[j].B[0] + DTASM * main_elp2[j].B[4];
			x = main_elp2[j].A + tgv * (DELNP - AM * DELNU) + 
				main_elp2[j].B[1] * DELG + main_elp2[j].B[2] * 
				DELE + main_elp2[j].B[3] * DELEP;
		
			y = 0;
			for (k = 0; k < 5; k++) {
				for (i = 0; i < 4; i++) 
					y += main_elp2[j].ilu[i] * del[i][k] * t[k];
			}
			/* y in correct quad */
			y = ln_range_radians2(y);
			result += x * sin(y);
		}
	}
	return result;
}

/* sum lunar elp3 series */
static double sum_series_elp3 (double* t)
{
	double result = 0;
	double x,y;
	double tgv;
	int i,j,k;
	
  	for (j=0; j< ELP3_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(main_elp3[j].A) > pre[2]) {
			/* derivatives of A */
			tgv = main_elp3[j].B[0] + DTASM * main_elp3[j].B[4];
			x = main_elp3[j].A + tgv * (DELNP - AM * DELNU) + 
				main_elp3[j].B[1] * DELG + main_elp3[j].B[2] * 
				DELE + main_elp3[j].B[3] * DELEP;
		
			y = 0;
			for (k = 0; k < 5; k++) {
				for (i = 0; i < 4; i++) 
					y += main_elp3[j].ilu[i] * del[i][k] * t[k];
			}
			y += (M_PI_2);
			/* y in correct quad */
			y = ln_range_radians2(y);
			result += x * sin(y);
		}
	}
	return result;
}


/* sum lunar elp4 series */
static double sum_series_elp4(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP4_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(earth_pert_elp4[j].A) > pre[0]) {
			y = earth_pert_elp4[j].O * DEG;
			for (k = 0; k < 2; k++)  {
				y += earth_pert_elp4[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += earth_pert_elp4[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += earth_pert_elp4[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp5 series */
static double sum_series_elp5(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP5_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(earth_pert_elp5[j].A) > pre[1]) {
			y = earth_pert_elp5[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += earth_pert_elp5[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += earth_pert_elp5[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += earth_pert_elp5[j].A * sin(y);
		}
	}
	return result;
}


/* sum lunar elp6 series */
static double sum_series_elp6(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP6_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(earth_pert_elp6[j].A) > pre[2]) {
			y = earth_pert_elp6[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += earth_pert_elp6[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += earth_pert_elp6[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += earth_pert_elp6[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp7 series */
static double sum_series_elp7(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP7_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(earth_pert_elp7[j].A) > pre[0]) {
			A = earth_pert_elp7[j].A * t[1];
			y = earth_pert_elp7[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += earth_pert_elp7[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += earth_pert_elp7[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp8 series */
static double sum_series_elp8(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP8_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(earth_pert_elp8[j].A) > pre[1]) {
			y = earth_pert_elp8[j].O * DEG;
			A = earth_pert_elp8[j].A * t[1];
			for (k = 0; k < 2; k++) {
				y += earth_pert_elp8[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += earth_pert_elp8[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp9 series */
static double sum_series_elp9(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP9_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(earth_pert_elp9[j].A) > pre[2]) {
			A = earth_pert_elp9[j].A * t[1];
			y = earth_pert_elp9[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += earth_pert_elp9[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += earth_pert_elp9[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp10 series */
static double sum_series_elp10(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP10_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp10[j].O) > pre[0]) {
			y = plan_pert_elp10[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				y += (plan_pert_elp10[j].ipla[8] * del[0][k] 
				+ plan_pert_elp10[j].ipla[9] * del[2][k] 
				+ plan_pert_elp10[j].ipla[10] * del [3][k]) * t[k];
				for (i = 0; i < 8; i++) 
					y += plan_pert_elp10[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += plan_pert_elp10[j].O * sin(y);
		}
	}
	return result;
}

/* sum lunar elp11 series */
static double sum_series_elp11(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP11_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp11[j].O) > pre[1]) {
			y = plan_pert_elp11[j].theta * DEG;
			for (k = 0; k < 2; k++)  {
				y += (plan_pert_elp11[j].ipla[8] * del[0][k] 
				+ plan_pert_elp11[j].ipla[9] * del[2][k] 
				+ plan_pert_elp11[j].ipla[10] * del [3][k]) * t[k];
				for (i = 0; i < 8; i++) 
					y += plan_pert_elp11[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += plan_pert_elp11[j].O * sin(y);
		}
	}
	return result;
}

/* sum lunar elp12 series */
static double sum_series_elp12(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP12_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp12[j].O) > pre[2]) {
			y = plan_pert_elp12[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				y += (plan_pert_elp12[j].ipla[8] * del[0][k] 
				+ plan_pert_elp12[j].ipla[9] * del[2][k] 
				+ plan_pert_elp12[j].ipla[10] * del [3][k]) * t[k];
				for (i = 0; i < 8; i++) 
					y += plan_pert_elp12[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += plan_pert_elp12[j].O * sin(y);
		}
	}
	return result;
}

/* sum lunar elp13 series */
static double sum_series_elp13(double *t)
{
	double result = 0;
	int i,j,k;
	double y,x;
	
	for (j=0; j< ELP13_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp13[j].O) > pre[0]) {
			y = plan_pert_elp13[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				y += (plan_pert_elp13[j].ipla[8] * del[0][k] 
				+ plan_pert_elp13[j].ipla[9] * del[2][k] 
				+ plan_pert_elp13[j].ipla[10] * del [3][k]) * t[k];
				for (i = 0; i < 8; i++) 
					y += plan_pert_elp13[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			x = plan_pert_elp13[j].O * t[1];
			result += x * sin(y);
		}
	}
	return result;
}

/* sum lunar elp14 series */
static double sum_series_elp14(double *t)
{
	double result = 0;
	int i,j,k;
	double y,x;
	
	for (j=0; j< ELP14_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp14[j].O) > pre[1]) {
			y = plan_pert_elp14[j].theta * DEG;
			for (k = 0; k < 2; k++)  {
				y += (plan_pert_elp14[j].ipla[8] * del[0][k] 
				+ plan_pert_elp14[j].ipla[9] * del[2][k] 
				+ plan_pert_elp14[j].ipla[10] * del [3][k]) * t[k];
				for (i = 0; i < 8; i++) 
					y += plan_pert_elp14[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			x = plan_pert_elp14[j].O * t[1];
			result += x * sin(y);
		}
	}
	return result;
}


/* sum lunar elp15 series */
static double sum_series_elp15(double *t)
{
	double result = 0;
	int i,j,k;
	double y,x;
	
	for (j=0; j< ELP15_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp15[j].O) > pre[2]) {
			y = plan_pert_elp15[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				y += (plan_pert_elp15[j].ipla[8] * del[0][k] 
				+ plan_pert_elp15[j].ipla[9] * del[2][k] 
				+ plan_pert_elp15[j].ipla[10] * del [3][k]) * t[k];
				for (i = 0; i < 8; i++) 
					y += plan_pert_elp15[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			x = plan_pert_elp15[j].O * t[1];
			result += x * sin(y);
		}
	}
	return result;
}

/* sum lunar elp16 series */
static double sum_series_elp16(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP16_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp16[j].O) > pre[0]) {
			y = plan_pert_elp16[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				for (i = 0; i < 4; i++) 
					y += plan_pert_elp16[j].ipla[i + 7] * del[i][k] * t[k];
				for (i = 0; i < 7; i++) 
					y += plan_pert_elp16[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += plan_pert_elp16[j].O * sin(y);
		}
	}
	return result;
}

static double sum_series_elp17(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP17_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp17[j].O) > pre[1]) {
			y = plan_pert_elp17[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				for (i = 0; i < 4; i++) 
					y += plan_pert_elp17[j].ipla[i + 7] * del[i][k] * t[k];
				for (i = 0; i < 7; i++) 
					y += plan_pert_elp17[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += plan_pert_elp17[j].O * sin(y);
		}
	}
	return result;
}

static double sum_series_elp18(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP18_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp18[j].O) > pre[2]) {
			y = plan_pert_elp18[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				for (i = 0; i < 4; i++) 
					y += plan_pert_elp18[j].ipla[i + 7] * del[i][k] * t[k];
				for (i = 0; i < 7; i++) 
					y += plan_pert_elp18[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += plan_pert_elp18[j].O * sin(y);
		}
	}
	return result;
}

static double sum_series_elp19(double *t)
{
	double result = 0;
	int i,j,k;
	double y,x;
	
	for (j=0; j< ELP19_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp19[j].O) > pre[0]) {
			y = plan_pert_elp19[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				for (i = 0; i < 4; i++) 
					y += plan_pert_elp19[j].ipla[i + 7] * del[i][k] * t[k];
				for (i = 0; i < 7; i++) 
					y += plan_pert_elp19[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			x = plan_pert_elp19[j].O * t[1];
			result += x * sin(y);
		}
	}
	return result;
}

static double sum_series_elp20(double *t)
{
	double result = 0;
	int i,j,k;
	double y,x;
	
	for (j=0; j< ELP20_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp20[j].O) > pre[1]) {
			y = plan_pert_elp20[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				for (i = 0; i < 4; i++) 
					y += plan_pert_elp20[j].ipla[i + 7] * del[i][k] * t[k];
				for (i = 0; i < 7; i++) 
					y += plan_pert_elp20[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			x = plan_pert_elp20[j].O * t[1];
			result += x * sin(y);
		}
	}
	return result;
}

static double sum_series_elp21(double *t)
{
	double result = 0;
	int i,j,k;
	double y,x;
	
	for (j=0; j< ELP21_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_pert_elp21[j].O) > pre[2]) {
			y = plan_pert_elp21[j].theta * DEG;
			for (k = 0; k < 2; k++) {
				for (i = 0; i < 4; i++) 
					y += plan_pert_elp21[j].ipla[i + 7] * del[i][k] * t[k];
				for (i = 0; i < 7; i++) 
					y += plan_pert_elp21[j].ipla[i] * p[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			x = plan_pert_elp21[j].O * t[1];
			result += x * sin(y);
		}
	}
	return result;
}

/* sum lunar elp22 series */
static double sum_series_elp22(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP22_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(tidal_effects_elp22[j].A) > pre[0]) {
			y = tidal_effects_elp22[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += tidal_effects_elp22[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += tidal_effects_elp22[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += tidal_effects_elp22[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp23 series */
static double sum_series_elp23(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP23_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(tidal_effects_elp23[j].A) > pre[1]) {
			y = tidal_effects_elp23[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += tidal_effects_elp23[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += tidal_effects_elp23[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += tidal_effects_elp23[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp24 series */
static double sum_series_elp24(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP24_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(tidal_effects_elp24[j].A) > pre[2]) {
			y = tidal_effects_elp24[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += tidal_effects_elp24[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += tidal_effects_elp24[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += tidal_effects_elp24[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp25 series */
static double sum_series_elp25(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP25_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(tidal_effects_elp25[j].A) > pre[0]) {
			A = tidal_effects_elp25[j].A * t[1];
			y = tidal_effects_elp25[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += tidal_effects_elp25[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += tidal_effects_elp25[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp26 series */
static double sum_series_elp26(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP26_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(tidal_effects_elp26[j].A) > pre[1]) {
			A = tidal_effects_elp26[j].A * t[1];
			y = tidal_effects_elp26[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += tidal_effects_elp26[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += tidal_effects_elp26[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp27 series */
static double sum_series_elp27(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP27_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(tidal_effects_elp27[j].A) > pre[2]) {
			A = tidal_effects_elp27[j].A * t[1];
			y = tidal_effects_elp27[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += tidal_effects_elp27[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += tidal_effects_elp27[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp28 series */
static double sum_series_elp28(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP28_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(moon_pert_elp28[j].A) > pre[0]) {
			y = moon_pert_elp28[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += moon_pert_elp28[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += moon_pert_elp28[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += moon_pert_elp28[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp29 series */
static double sum_series_elp29(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP29_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(moon_pert_elp29[j].A) > pre[1]) {
			y = moon_pert_elp29[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += moon_pert_elp29[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += moon_pert_elp29[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += moon_pert_elp29[j].A * sin(y);
		}
	}
	return result;
}


/* sum lunar elp30 series */
static double sum_series_elp30(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP30_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(moon_pert_elp30[j].A) > pre[2]) {
			y = moon_pert_elp30[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += moon_pert_elp30[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += moon_pert_elp30[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += moon_pert_elp30[j].A * sin(y);
		}
	}
	return result;
}


/* sum lunar elp31 series */
static double sum_series_elp31(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP31_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(rel_pert_elp31[j].A) > pre[0]) {
			y = rel_pert_elp31[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += rel_pert_elp31[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += rel_pert_elp31[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += rel_pert_elp31[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp32 series */
static double sum_series_elp32(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP32_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(rel_pert_elp32[j].A) > pre[1]) {
			y = rel_pert_elp32[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += rel_pert_elp32[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += rel_pert_elp32[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += rel_pert_elp32[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp33 series */
static double sum_series_elp33(double *t)
{
	double result = 0;
	int i,j,k;
	double y;
	
	for (j=0; j< ELP33_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(rel_pert_elp33[j].A) > pre[2]) {
			y = rel_pert_elp33[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += rel_pert_elp33[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += rel_pert_elp33[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += rel_pert_elp33[j].A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp34 series */
static double sum_series_elp34(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP34_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_sol_pert_elp34[j].A) > pre[0]) {
			A = plan_sol_pert_elp34[j].A * t[2];
			y = plan_sol_pert_elp34[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += plan_sol_pert_elp34[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += plan_sol_pert_elp34[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}
/* sum lunar elp35 series */
static double sum_series_elp35(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP35_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_sol_pert_elp35[j].A) > pre[1]) {
			A = plan_sol_pert_elp35[j].A * t[2];
			y = plan_sol_pert_elp35[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += plan_sol_pert_elp35[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += plan_sol_pert_elp35[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/* sum lunar elp36 series */
static double sum_series_elp36(double *t)
{
	double result = 0;
	int i,j,k;
	double y, A;
	
	for (j=0; j< ELP36_SIZE; j++) {
		/* do we need to calc this value */
		if (fabs(plan_sol_pert_elp36[j].A) > pre[2]) {
			A = plan_sol_pert_elp36[j].A * t[2];
			y = plan_sol_pert_elp36[j].O * DEG;
			for (k = 0; k < 2; k++) {
				y += plan_sol_pert_elp36[j].iz * zeta[k] * t[k];
				for (i = 0; i < 4; i++) 
					y += plan_sol_pert_elp36[j].ilu[i] * del[i][k] * t[k];
			}
			/* put y in correct quad */
			y = ln_range_radians2(y);
			result += A * sin(y);
		}
	}
	return result;
}

/*! \fn void ln_get_lunar_geo_posn(double JD, struct ln_rect_posn *pos, double precision);
* \param JD Julian day.
* \param pos Pointer to a geocentric position structure to held result.
* \param precision The truncation level of the series in radians for longitude 
* and latitude and in km for distance. (Valid range 0 - 0.01, 0 being highest accuracy) 
* \ingroup lunar
*
* Calculate the rectangular geocentric lunar coordinates to the inertial mean
* ecliptic and equinox of J2000. 
* The geocentric coordinates returned are in units of km.
* 
* This function is based upon the Lunar Solution ELP2000-82B by 
* Michelle Chapront-Touze and Jean Chapront of the Bureau des Longitudes, 
* Paris.
*/ 
/* ELP 2000-82B theory */
void ln_get_lunar_geo_posn(double JD, struct ln_rect_posn *moon, double precision)
{
	double t[5];
	double elp[36];
	double a,b,c;
	double x,y,z;
	double pw,qw, pwqw, pw2, qw2, ra;
	
	/* is precision too low ? */
	if (precision > 0.01)
		precision = 0.01;
	
	/* is value in cache ? */
	if(JD == c_JD && precision >= c_precision) {
		moon->X = c_X;
		moon->Y = c_Y;
		moon->Z = c_Z;
		return;
	}
	
	/* calc julian centuries */
	t[0] = 1.0;
	t[1] =(JD - 2451545.0) / 36525.0;
	t[2] = t[1] * t[1];
	t[3] = t[2] * t[1];
	t[4] = t[3] * t[1];
	
	/* calc precision */
	pre[0] = precision * RAD;
	pre[1] = precision * RAD;
	pre[2] = precision * ATH;
	
	/* sum elp series */
	elp[0] = sum_series_elp1(t);
	elp[1] = sum_series_elp2(t);
	elp[2] = sum_series_elp3(t);
	elp[3] = sum_series_elp4(t);
	elp[4] = sum_series_elp5(t);
	elp[5] = sum_series_elp6(t);
	elp[6] = sum_series_elp7(t);
	elp[7] = sum_series_elp8(t);
	elp[8] = sum_series_elp9(t);
	elp[9] = sum_series_elp10(t);
	elp[10] = sum_series_elp11(t);
	elp[11] = sum_series_elp12(t);
	elp[12] = sum_series_elp13(t);
	elp[13] = sum_series_elp14(t);
	elp[14] = sum_series_elp15(t);
	elp[15] = sum_series_elp16(t);
	elp[16] = sum_series_elp17(t);
	elp[17] = sum_series_elp18(t);
	elp[18] = sum_series_elp19(t);
	elp[19] = sum_series_elp20(t);
	elp[20] = sum_series_elp21(t);
	elp[21] = sum_series_elp22(t);
	elp[22] = sum_series_elp23(t);
	elp[23] = sum_series_elp24(t);
	elp[24] = sum_series_elp25(t);
	elp[25] = sum_series_elp26(t);
	elp[26] = sum_series_elp27(t);
	elp[27] = sum_series_elp28(t);
	elp[28] = sum_series_elp29(t);
	elp[29] = sum_series_elp30(t);
	elp[30] = sum_series_elp31(t);
	elp[31] = sum_series_elp32(t);
	elp[32] = sum_series_elp33(t);
	elp[33] = sum_series_elp34(t);
	elp[34] = sum_series_elp35(t);
	elp[35] = sum_series_elp36(t);
	
	a = elp[0] + elp[3] + elp[6] + elp[9] + elp[12] +
		elp[15] + elp[18] + elp[21] + elp[24] +
		elp[27] + elp[30] + elp[33];
	b = elp[1] + elp[4] + elp[7] + elp[10] + elp[13] +
		elp[16] + elp[19] + elp[22] + elp[25] +
		elp[28] + elp[31] + elp[34];
	c = elp[2] + elp[5] + elp[8] + elp[11] + elp[14] +
		elp[17] + elp[20] + elp[23] + elp[26] +
		elp[29] + elp[32] + elp[35];
		
	/* calculate geocentric coords */
	a = a / RAD + W1[0] + W1[1] * t[1] + W1[2] * t[2] + W1[3] * t[3]
	    + W1[4] * t[4];
	b = b / RAD;
	c = c * A0 / ATH;
	
	x = c * cos(b);
	y = x * sin(a);
	x = x * cos(a);
	z = c * sin(b);
	
	/* Laskars series */
	pw = (P1 + P2 * t[1] + P3 * t[2] + P4 * t[3] + P5 * t[4]) * t[1];
	qw = (Q1 + Q2 * t[1] + Q3 * t[2] + Q4 * t[3] + Q5 * t[4]) * t[1];
	ra = 2.0 * sqrt(1 - pw * pw - qw * qw);
	pwqw = 2.0 * pw * qw;
	pw2 = 1.0 - 2.0 * pw * pw;
	qw2 = 1.0 - 2.0 * qw * qw;
	pw = pw * ra;
	qw = qw * ra;
	a = pw2 * x + pwqw * y + pw * z;
	b = pwqw * x + qw2 * y - qw * z;
	c = -pw * x + qw * y + (pw2 + qw2 -1) * z;

	/* save cache and result */
	c_JD = JD;
	c_X = moon->X = a;
	c_Y = moon->Y = b;
	c_Z = moon->Z = c;
}

/*! \fn void ln_get_lunar_equ_coords_prec(double JD, struct ln_equ_posn *position, double precision);
* \param JD Julian Day
* \param position Pointer to a struct ln_lnlat_posn to store result.
* \param precision The truncation level of the series in radians for longitude 
* and latitude and in km for distance. (Valid range 0 - 0.01, 0 being highest accuracy) 
* \ingroup lunar
*
* Calculate the lunar RA and DEC for Julian day JD. 
* Accuracy is better than 10 arcsecs in right ascension and 4 arcsecs in declination.
*/ 
void ln_get_lunar_equ_coords_prec(double JD, struct ln_equ_posn *position,
	double precision)
{
	struct ln_lnlat_posn ecl;
		
	ln_get_lunar_ecl_coords(JD, &ecl, precision);
	ln_get_equ_from_ecl(&ecl, JD, position);
}

/*! \fn void ln_get_lunar_equ_coords(double JD, struct ln_equ_posn *position);
* \param JD Julian Day
* \param position Pointer to a struct ln_lnlat_posn to store result.
* \ingroup lunar
*
* Calculate the lunar RA and DEC for Julian day JD. 
* Accuracy is better than 10 arcsecs in right ascension and 4 arcsecs in declination.
*/ 
void ln_get_lunar_equ_coords(double JD, struct ln_equ_posn *position)
{
	ln_get_lunar_equ_coords_prec(JD, position, 0);
}

/*! \fn void ln_get_lunar_ecl_coords(double JD, struct ln_lnlat_posn *position, double precision);
* \param JD Julian Day
* \param position Pointer to a struct ln_lnlat_posn to store result.
* \param precision The truncation level of the series in radians for longitude 
* and latitude and in km for distance. (Valid range 0 - 0.01, 0 being highest accuracy) 
* \ingroup lunar
*
* Calculate the lunar longitude and latitude for Julian day JD.
* Accuracy is better than 10 arcsecs in longitude and 4 arcsecs in latitude.
*/ 
void ln_get_lunar_ecl_coords(double JD, struct ln_lnlat_posn *position,
	double precision)
{
	struct ln_rect_posn moon;
	
	/* get lunar geocentric position */
	ln_get_lunar_geo_posn(JD, &moon, precision);
	
	/* convert to long and lat */
	position->lng = atan2(moon.Y, moon.X);
	position->lat = atan2(moon.Z,
		(sqrt((moon.X * moon.X) + (moon.Y * moon.Y))));
	position->lng = ln_range_degrees(ln_rad_to_deg(position->lng));
	position->lat = ln_rad_to_deg(position->lat);
}

/*! \fn double ln_get_lunar_earth_dist(double JD);
* \param JD Julian Day
* \return The distance between the Earth and Moon in km.
* \ingroup lunar
*
* Calculates the distance between the centre of the Earth and the
* centre of the Moon in km.
*/ 
double ln_get_lunar_earth_dist(double JD)
{
	struct ln_rect_posn moon;
		
	ln_get_lunar_geo_posn(JD, &moon, 0.00001);
	return sqrt((moon.X * moon.X) + (moon.Y * moon.Y) + (moon.Z * moon.Z));
}


/*! \fn double ln_get_lunar_phase(double JD);
* \param JD Julian Day
* \return Phase angle. (Value between 0 and 180)
* \ingroup lunar
*
* Calculates the angle Sun - Moon - Earth.
*/ 
double ln_get_lunar_phase(double JD)
{
	double phase = 0;
	struct ln_lnlat_posn moon, sunlp;
	double lunar_elong;
	double R, delta;
		
	/* get lunar and solar long + lat */
	ln_get_lunar_ecl_coords(JD, &moon, 0.0001);
	ln_get_solar_ecl_coords(JD, &sunlp);
	
	/* calc lunar geocentric elongation equ 48.2 */
	lunar_elong = acos(cos(ln_deg_to_rad(moon.lat)) *
		cos(ln_deg_to_rad(sunlp.lng - moon.lng)));
	
	/* now calc phase Equ 48.2 */
	R = ln_get_earth_solar_dist(JD);
	delta = ln_get_lunar_earth_dist(JD);
	R = R * AU; /* convert R to km */
	phase = atan2((R * sin(lunar_elong)), (delta - R * cos(lunar_elong)));
	return ln_rad_to_deg(phase);
}

/*! \fn double ln_get_lunar_disk(double JD);
* \param JD Julian Day
* \return Illuminated fraction. (Value between 0 and 1)
* \brief Calculate the illuminated fraction of the moons disk
* \ingroup lunar
*
* Calculates the illuminated fraction of the Moon's disk. 
*/ 
double ln_get_lunar_disk(double JD)
{
	double i;
	
	/* Equ 48.1 */
	i = ln_deg_to_rad(ln_get_lunar_phase(JD));
	return (1.0 + cos(i)) / 2.0;
}

/*! \fn double ln_get_lunar_bright_limb(double JD);
* \param JD Julian Day
* \return The position angle in degrees.
* \brief Calculate the position angle of the Moon's bright limb.
* \ingroup lunar
*
* Calculates the position angle of the midpoint of the illuminated limb of the 
* moon, reckoned eastward from the north point of the disk.
*
* The angle is near 270 deg for first quarter and near 90 deg after a full moon.
* The position angle of the cusps are +90 deg and -90 deg. 
*/ 
double ln_get_lunar_bright_limb(double JD)
{
	double angle;
	double x,y;
	
	struct ln_equ_posn moon, sunlp;
		
	/* get lunar and solar long + lat */
	ln_get_lunar_equ_coords(JD, &moon);
	ln_get_solar_equ_coords(JD, &sunlp);
	
	/* Equ 48.5 */
	x = cos(ln_deg_to_rad(sunlp.dec)) * sin(ln_deg_to_rad(sunlp.ra - moon.ra));
	y = sin((ln_deg_to_rad(sunlp.dec)) * cos(ln_deg_to_rad(moon.dec))) 
		- (cos(ln_deg_to_rad(sunlp.dec)) * sin(ln_deg_to_rad(moon.dec)) 
		* cos(ln_deg_to_rad(sunlp.ra - moon.ra)));
	angle = atan2(x,y);

	angle = ln_range_radians(angle);
	return ln_rad_to_deg(angle);
}


/*! \fn double ln_get_lunar_rst(double JD, struct ln_lnlat_posn *observer, struct ln_rst_time *rst);
* \param JD Julian day
* \param observer Observers position
* \param rst Pointer to store Rise, Set and Transit time in JD
* \return 0 for success, else 1 for circumpolar.
* \todo Improve lunar standard altitude for rst
*
* Calculate the time the rise, set and transit (crosses the local meridian at upper culmination)
* time of the Moon for the given Julian day.
*
* Note: this functions returns 1 if the Moon is circumpolar, that is it remains the whole
* day either above or below the horizon.
*/
int ln_get_lunar_rst(double JD, struct ln_lnlat_posn *observer,
	struct ln_rst_time *rst)
{
	return ln_get_body_rst_horizon(JD, observer, ln_get_lunar_equ_coords,
		LN_LUNAR_STANDART_HORIZON, rst);
}

/*! \fn double ln_get_lunar_sdiam(double JD)
* \param JD Julian day
* \return Semidiameter in arc seconds
* \todo Use Topocentric distance.
*
* Calculate the semidiameter of the Moon in arc seconds for the 
* given julian day.
*/
double ln_get_lunar_sdiam(double JD)
{
	double So = 358473400; 
	double dist;
	
	dist = ln_get_lunar_earth_dist(JD);
	return So / dist;
}

/*! \fn double ln_get_lunar_long_asc_node(double JD);
* \param JD Julian Day.
* \return Longitude of ascending node in degrees.
*
* Calculate the mean longitude of the Moons ascening node
* for the given Julian day.
*/ 
double ln_get_lunar_long_asc_node(double JD)
{
	/* calc julian centuries */
	double T =(JD - 2451545.0) / 36525.0;
	double omega = 125.0445479;
	double T2 = T * T;
	double T3 = T2 * T;
	double T4 = T3 * T;
	
	/* equ 47.7 */
	omega -= 1934.1362891 * T + 0.0020754 * T2 + T3 / 467441.0 -
		T4 / 60616000.0;
	return omega;
}


/*! \fn double ln_get_lunar_long_perigee(double JD);
* \param JD Julian Day
* \return Longitude of Moons mean perigee in degrees.
*
* Calculate the longitude of the Moon's mean perigee.
*/ 
double ln_get_lunar_long_perigee(double JD)
{
	/* calc julian centuries */
	double T =(JD - 2451545.0) / 36525.0;
	double per = 83.3532465;
	double T2 = T * T;
	double T3 = T2 * T;
	double T4 = T3 * T;
	
	/* equ 47.7 */
	per += 4069.0137287 * T - 0.0103200 * T2 - T3 / 80053.0 + T4 / 18999000.0;
	return per;
}

/*! \example lunar.c
 * 
 * Examples of how to use Lunar functions. 
 */
